// Rank0Data is a list of entries
//  <f, rank, tors, bas, deg3, run, primes>, where
// * f is the polynomial defining the curve  C: y^2 = f(x)
// * rank is the Mordell-Weil rank of J(Q), where J is the Jacobian of C
// * tors is the sequence of invariants of the torsion subgroup of J
// * bas is a sequence of polynomials of degree 2 such that
//     [Rep(Points(J, a, 2)) : a in bas]
//   is a sequence of generators of J(Q) modulo torsion
// * deg3 = <a, c, b> specifies a rational degree-3 divisor on C:
//     f(x) - b(x)^2 = l*a(x)*c(x) ,
//   the divisor is given by  a(x) = 0, y = b(x)
// * run = [q1, q2, ..., qn] is a sequence of primes such that
//     B0 = 1, B1 = q1, B2 = q1*q2, ..., Bn = q1*q2*...*qn = B
//   is a suitable sequence for the successive computation of bounds
//   on the image of C(Q) in J(Q)/Bj*J(Q), such that the last bound is empty
// * primes = {p1, p2, ..., pm} is a set of primes or prime powers such that
//   the information coming from J(Z/pj*Z) is sufficient to get the empty
//   bound with B as above
//

// In these cases, the Mordell-Weil group is trivial, which already
// implies that there are no rational points on the curves.

_<x> := PolynomialRing(Rationals());

Rank0Data := [
// no. 1
<-3*x^6 + 3*x^5 + 3*x^4 + x^3 + x^2 + x - 1, 0, [],
  [],
  <x^3 - 2*x^2 + x - 1, x^3 + x^2 - 1/3, P!0>,
  [],
  {}>,

// no. 2
<-x^6 + x^5 - x^4 + 3*x^3 + x^2 - x - 3, 0, [],
  [],
  <x^3 - x^2 + 2*x - 3, x^3 - x - 1, P!0>,
  [],
  {}>,

// no. 3
<-x^6 + 3*x^5 - 3*x^4 + x^3 + 3*x^2 + x - 1, 0, [],
  [],
  <x^3 - 2*x^2 + 3*x - 1, x^3 - x^2 - 2*x - 1, P!0>,
  [],
  {}>

];
