// Rank3Data is a list of entries
//  <f, rank, tors, bas, deg3, run, primes>, where
// * f is the polynomial defining the curve  C: y^2 = f(x)
// * rank is the Mordell-Weil rank of J(Q), where J is the Jacobian of C
// * tors is the sequence of invariants of the torsion subgroup of J
// * bas is a sequence of polynomials of degree 2 such that
//     [Rep(Points(J, a, 2)) : a in bas]
//   is a sequence of generators of J(Q) modulo torsion
// * deg3 = <a, c, b> specifies a rational degree-3 divisor on C:
//     f(x) - b(x)^2 = l*a(x)*c(x) ,
//   the divisor is given by  a(x) = 0, y = b(x)
// * run = [q1, q2, ..., qn] is a sequence of primes such that
//     B0 = 1, B1 = q1, B2 = q1*q2, ..., Bn = q1*q2*...*qn = B
//   is a suitable sequence for the successive computation of bounds
//   on the image of C(Q) in J(Q)/Bj*J(Q), such that the last bound is empty
// * primes = {p1, p2, ..., pm} is a set of primes or prime powers such that
//   the information coming from J(Z/pj*Z) is sufficient to get the empty
//   bound with B as above

_<x> := PolynomialRing(Rationals());

Rank3Data := [
// no. 1
<-3*x^6 + 3*x^5 + 2*x^3 + 2*x^2 + x + 2, 3, [],
  [x^2 + x + 1,
   x^2 - 5/4*x - 1/2,
   x^2 - 45/28*x + 1/2],
  <x^3 + 1/3*x + 2/3, x^3 - x^2 - 1, x^2>,
  [ 17, 2, 13, 3, 5, 2, 3, 7, 2, 11 ],
  { 2^4, 3^3, 5^2, 7^2, 11^2, 13^2, 17^2, 59, 83, 89, 97, 103, 107, 113, 163, 
    173, 191, 199, 349, 389, 443, 463, 541, 563, 593, 863, 1187, 1483, 1583 }>,

// no. 2
<2*x^6 + 3*x^5 + 3*x^4 + x^3 + 3*x^2 + 3, 3, [],
  [x^2 + x + 1,
   x^2 + 2*x - 1,
   x^2 - 18*x + 6],
  <x^3 - x^2 - 4*x + 1, x^3 + 5/2*x^2 + 6*x + 3/2, 2*x^2 + 7*x>,
  [ 2, 3, 3, 2 ],
  { 2^2, 3^2, 7, 13, 29, 43, 97 }>,

// no. 3
<3*x^6 + 3*x^5 - x^4 - 2*x^3 + x^2 + x - 3, 3, [],
  [x^2 - x + 1,
   x^2 + 1,
   x^2 - 1144/1033*x + 6544/1033],
  <x^3 - x^2 - 3*x - 4, x^3 + 2*x^2 + 5/3*x + 1, 3*x^2 + 5*x + 3>,
  [ 2, 3, 2, 2, 2, 7, 19, 11, 5, 5 ],
  { 2^5, 3^2, 5^3, 7^2, 11^2, 17, 19^2, 31, 37, 41, 47, 83, 211, 223, 257, 
    311, 313, 419, 421, 809, 877, 1171, 1259, 1699 }>,

// no. 4
<3*x^6 + x^5 - 2*x^4 - 2*x^3 - x^2 - 2*x + 2, 3, [],
  [x^2 - x - 1,
   x^2 - 1/2*x + 1/2,
   x^2 + 275/13*x + 497/52],
  <x^3 + 2*x - 1, x^3 + 1/3*x^2 - 8/3*x - 1/3, -4*x + 1>,
  [ 2, 3, 5, 3, 2, 11, 7 ],
  { 2^3, 3^3, 5^2, 7^2, 11^2, 13, 29, 67, 71, 73, 83, 103, 137, 167, 197, 
    227, 373, 397, 499 }>,

// no. 5
<2*x^6 - 2*x^4 + x^3 - 2*x^2 - 1, 3, [],
  [x^2 + x + 1,
   x^2 - 2,
   x^2 + 5/23*x - 185/46],
  <x^3 + x^2 + 1, x^3 - x^2 - 1/2, x>,
  [ 5, 5, 3, 2, 17, 3, 3, 7 ],
  { 2, 3^3, 5^3, 7, 13, 17, 19, 29, 37, 41, 79, 157, 191, 211, 353, 359, 479 }>,

// no. 6
<3*x^6 + x^5 + 3*x^4 - 2*x^2 - x - 1, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 - 43/1374*x + 13/687],
  <x^3 + x^2 - 2*x + 1, x^3 - 2/3*x^2 - 5/3*x - 2/3, -4*x^2 + 1>,
  [ 2, 3, 5, 11, 2, 3, 3, 2, 7, 17 ],
  { 2^3, 3^4, 5^2, 7^2, 11^2, 17^2, 47, 53, 59, 73, 83, 131, 137, 157, 229, 
    239, 251, 307, 313, 317, 1039, 1327, 1523, 1753 }>,

// no. 7
<3*x^6 + 3*x^5 + 3*x^4 + 2*x^3 - x^2 + 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 5/2*x - 2,
   x^2 - 61/46*x + 14/23],
  <x^3 + 5/2*x^2 - 2*x + 7/2, x^3 - 3/2*x^2 + 8/3*x - 19/6, -7/2*x^2 + 4*x - 
11/2>,
  [ 2, 3, 3, 3, 2, 2, 5, 13, 3, 11, 17, 7 ],
  { 2^3, 3^4, 5^3, 7^2, 11^2, 13^2, 17^2, 19, 23, 29, 43, 71, 89, 101, 107, 
    113, 131, 139, 167, 199, 227, 233, 239, 283, 293, 337, 349, 457, 509, 523, 
    569, 881, 977, 1223, 1607, 1693, 1823 }>,

// no. 8
<2*x^6 - 3*x^5 - 3*x^4 + x^3 - x^2 - 2, 3, [],
  [x^2 + 2*x + 2,
   x^2 + 3*x + 11,
   x^2 + 6/23*x + 1/23],
  <x^3 + 1/2*x^2 - 1/2*x + 1/2, x^3 - 2*x^2 - 2*x - 2, 2*x^2 + x>,
  [ 2 ],
  { 2, 7 }>,

// no. 9
<-2*x^6 + 3*x^5 + 3*x^4 - 2*x^3 + 2*x^2 - 3*x - 3, 3, [],
  [x^2 - x - 1,
   x^2 + 1,
   x^2 - 3805811/3940134*x - 133747034/84712881],
  <x^3 - 2*x^2 - 7/9*x + 19/9, x^3 + 1/2*x^2 + 3*x + 9/2, -7/3*x^2 + 1/3*x + 4>,
  [ 2, 2, 3, 5, 2, 11, 3, 7, 19 ],
  { 2^3, 3^3, 5^2, 7^2, 11^2, 19^2, 23, 53, 67, 73, 103, 109, 127, 157, 271, 
    317, 349, 487, 571, 607, 769, 863, 1117, 1759 }>,

// no. 10
<-2*x^6 - x^5 + 3*x^4 - 3*x^3 + 2, 3, [],
  [x^2 + x - 1,
   x^2 + 2*x + 1/3,
   x^2 + 38/803*x - 23/803],
  <x^3 + 7/2*x^2 + 6*x + 2, x^3 - 3*x^2 + 7/2*x - 1/4, -x^2 + 11/2*x + 1>,
  [ 2, 2, 7, 5, 3, 11 ],
  { 2^2, 5^2, 7^2, 11^2, 19, 29, 31, 41, 59, 67, 97, 101, 109, 139, 191, 419 }>,

// no. 11
<3*x^6 + x^5 - 2*x^4 + x^3 - x^2 - 3, 3, [],
  [x^2 - x + 1,
   x^2 - 2,
   x^2 + 1101/3674*x + 67/1837],
  <x^3 + x^2 - 3/4*x - 3/2, x^3 - 2/3*x^2 - 4/3*x + 8/3, -5/2*x^2 + 3>,
  [ 2, 2, 2, 2, 5, 5, 3, 3 ],
  { 2^4, 3^3, 5^3, 23, 61, 79, 439, 521, 911 }>,

// no. 12
<-2*x^6 + 3*x^5 - 3*x^4 + 2*x^3 + 3*x^2 + 3*x - 3, 3, [],
  [x^2 - 3*x + 3,
   x^2 - 32/17*x + 13/17,
   x^2 - 317/146*x + 74/73],
  <x^3 - 3/2*x^2 + 3*x - 3/2, x^3 - x - 1, x^2>,
  [ 2, 2, 2, 2, 2, 11, 3 ],
  { 2^5, 3, 5, 11^2, 29, 43, 73, 163, 251, 349, 1033, 1093 }>,

// no. 13
<3*x^6 + 2*x^4 - x^3 + 2*x^2 + x + 3, 3, [],
  [x^2 + 1,
   x^2 + 1/2,
   x^2 + 2030/3263*x + 2411/6526],
  <x^3 + x^2 + 1/3*x - 1/3, x^3 - x^2 + x - 2, x^2 + 2*x + 1>,
  [ 2, 2, 3, 3, 5, 2 ],
  { 2^3, 3^3, 5^2, 7, 19, 79, 137 }>,

// no. 14
<-x^6 + 2*x^5 + 3*x^3 - 2*x^2 - x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 1,
   x^2 + 187/265*x + 8299/6890],
  <x^3 - 2*x^2 + x - 4, x^3 - 3/4*x - 1, -1/2*x^2 + 1/2*x + 1>,
  [ 2, 2, 2, 5, 3, 3, 11, 13 ],
  { 2^3, 3^3, 5^2, 7, 11^2, 13^2, 17, 31, 89, 107, 193, 197, 211, 
    229, 293, 347, 367, 601 }>,

// no. 15
<-2*x^6 + 3*x^5 + 3*x^4 + 2*x^3 + x^2 + 2*x - 3, 3, [],
  [x^2 + 2,
   x^2 - x + 1,
   x^2 + 16/3],
  <x^3 - 2*x - 2, x^3 - 3/2*x^2 + x - 1, x^2 + x + 1>,
  [ 2, 2, 2, 2, 2, 2, 3, 19, 5 ],
  { 2^6, 3^2, 5^2, 13, 17, 19^2, 37, 71, 173, 283, 599, 823, 953 }>,

// no. 16
<-x^6 - x^5 + 3*x^4 - 3*x^3 + x^2 - 2*x - 2, 3, [],
  [x^2 + 1,
   x^2 + 2,
   x^2 + 117/2705*x + 2259/2705],
  <x^3 - 1/2*x^2 + 2*x + 2, x^3 + 3/2*x^2 - 2*x + 3/2, -3/2*x^2 - 3/2*x + 1>,
  [ 2, 2, 2, 5, 3, 11, 2, 2, 7, 7, 2, 17, 5, 3 ],
  { 2^6, 3^3, 5^3, 7^2, 11^2, 17^2, 19, 67, 109, 127, 131, 167, 307, 313, 
    317, 349, 367, 479, 509, 541, 569, 601, 727, 733, 919, 967, 983 }>,

// no. 17
<-2*x^6 + 3*x^5 + 3*x^4 + 3*x^3 - x^2 + 2*x + 2, 3, [],
  [x^2 - 1/3,
   x^2 - 1/3*x + 1/3,
   x^2 + 1887/1387*x + 809/1387],
  <x^3 + 5/2*x^2 + 5/2*x + 1/2, x^3 - 4*x^2 + 8*x - 2, 2*x^2 + 5*x>,
  [ 2, 2, 2, 7 ],
  { 2, 3, 7, 13, 17 }>,

// no. 18
<-2*x^6 - 2*x^5 - 2*x^4 - 3*x^3 - 2*x^2 + 3*x + 2, 3, [],
  [x^2 - x + 1,
   x^2 - 1/3,
   x^2 + 101/51*x + 529/153],
  <x^3 + 3/2*x + 1, x^3 + x^2 - 1, x^2>,
  [],
  { 5 }>,

// no. 19
<-3*x^6 + x^5 + 3*x^4 + 2*x^3 + 2*x - 3, 3, [],
  [x^2 - 1/12*x + 1/2,
   x^2 - 3/4*x + 1/4,
   x^2 + 5/3*x + 38/3],
  <x^3 - 5/4*x^2 + x - 1, x^3 + 11/12*x^2 - 1/3*x - 1, -5/4*x^2>,
  [ 2, 3 ],
  { 2, 3^2, 5, 13, 17 }>,

// no. 20
<3*x^6 + 2*x^5 + 2*x^3 + 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 - 4/3*x + 4/3,
   x^2 + 619763/336299*x + 571627/336299],
  <x^3 + 2*x^2 + x + 4, x^3 - 4/3*x^2 + 11/12*x - 1/3, 3/2*x^2 - 7/2*x + 1>,
  [],
  { 2^2 }>,

// no. 21
<-3*x^6 + 2*x^5 - x^4 + 3*x^3 + 2*x + 3, 3, [],
  [x^2 - x + 1,
   x^2 - 1/2*x - 3/4,
   x^2 - 2642/3297*x - 2522/3297],
  <x^3 - 2*x^2 + 2*x + 2, x^3 + 4/3*x^2 + 4/3*x - 1/3, x^2 + 4*x + 1>,
  [ 2, 2, 3, 3, 2 ],
  { 2^3, 3^3, 7, 37, 293 }>,

// no. 22
<-x^6 - 2*x^5 + x^4 - x^3 - 2*x^2 + x - 3, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 + 180/37*x + 337/37],
  <x^3 - x + 1, x^3 + 2*x^2 + x + 4, -x^2 - x + 1>,
  [ 2, 3, 3, 3, 2, 7, 13, 5 ],
  { 2^2, 3^4, 5^2, 7^2, 11, 13^2, 19, 31, 41, 59, 79, 131, 163, 167, 227, 
    269, 401, 443, 739, 919, 1153, 1163, 1733 }>,

// no. 23
<-2*x^6 - 2*x^5 + 3*x^4 + 3*x^3 + 3*x^2 - x - 1, 3, [],
  [x^2 + x - 1,
   x^2 - 1/2,
   x^2 + 5/9*x - 17/9],
  <x^3 + x^2 - 1/2, x^3 - x - 1, -x^2 + x>,
  [ 2, 3, 7, 2, 2, 2, 3, 5, 2 ],
  { 2^5, 3^3, 5^2, 7^2, 41, 43, 53, 101, 127, 137, 151, 199, 677, 773, 1873, 
    4289, 4987 }>,

// no. 24
<2*x^6 + 3*x^4 + x^3 + x^2 - 3*x + 3, 3, [],
  [x^2 + 1,
   x^2 + x - 1/2,
   x^2 + 1/7*x + 13/7],
  <x^3 - 3*x + 3, x^3 + 1/2, -3*x^2 + x>,
  [ 2, 3, 3, 3, 2, 5 ],
  { 2^2, 3^4, 17, 23, 73, 79, 107, 109, 113, 151, 239, 347 }>,

// no. 25
<3*x^6 - x^5 - 3*x^4 + x^3 - 3*x^2 - 3, 3, [],
  [x^2 - 2,
   x^2 - 3/2*x + 1,
   x^2 + 5/3*x + 7/9],
  <x^3 - 3/2*x^2 - 3, x^3 + 7/6*x^2 + 1/3, 3/2*x^2 + 3*x>,
  [ 2, 3, 2, 2, 3, 5, 7, 29 ],
  { 2^3, 3^3, 5^2, 7^2, 11, 13, 17, 83, 89, 101, 109, 193, 269, 359, 
    401, 421, 433, 439, 449, 811, 1399, 2063, 3037, 4007 }>,

// no. 26
<2*x^6 + 2*x^5 + x^3 - 2*x^2 + 2*x + 3, 3, [],
  [x^2 + x - 1,
   x^2 + 2*x - 2,
   x^2 - 1898/1127*x + 1298/1127],
  <x^3 + x^2 + 1/2*x - 1/2, x^3 - 5*x - 3, 3*x^2 + 3*x>,
  [ 2 ],
  { 2, 3^2 }>,

// no. 27
<-2*x^6 + x^4 - 2*x^3 - 3*x^2 - x + 3, 3, [],
  [x^2 - 1/2,
   x^2 + x + 2/3,
   x^2 + 703/695*x + 2522/3475],
  <x^3 + 2*x^2 + 5/2*x + 1, x^3 - 2*x^2 + 3*x - 1, 2*x^2 + 1>,
  [ 2, 2, 2, 2, 5, 2, 3, 13, 17, 7, 11 ],
  { 2^5, 5^2, 7^2, 13^2, 17^2, 29, 31, 43, 47, 53, 83, 107, 109, 167, 193, 
    197, 199, 257, 281, 409, 457, 563, 659, 773 }>,

// no. 28
<2*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - 3*x^2 + 2*x - 2, 3, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 19*x - 27,
   x^2 - 962/463*x - 3201/463],
  <x^3 + 10*x^2 + 6*x + 9, x^3 - 23/2*x^2 - 5*x - 11, 15*x^2 + 8*x + 14>,
  [ 2, 2, 2, 2 ],
  { 2^4, 7, 11, 41, 107 }>,

// no. 29
<-2*x^6 + 2*x^5 + 2*x^4 + 3*x^3 - 2*x^2 + 3, 3, [],
  [x^2 - x - 1,
   x^2 - 1/2,
   x^2 + 5928/6001*x + 32087/12002],
  <x^3 - 2/9*x^2 - x - 3, x^3 - 7/9*x^2 - 1/6*x + 1/2, -1/9*x^2 + 5/3*x>,
  [ 2, 3, 5, 3, 3, 13, 7 ],
  { 2, 3^4, 5^2, 7^2, 11, 13^2, 37, 47, 67, 109, 223, 317, 337, 401, 
    449, 521, 1499 }>,

// no. 30
<2*x^6 - 2*x^4 + 3*x^3 - 2*x^2 - 3*x - 2, 3, [],
  [x^2 + x + 2,
   x^2 - 3,
   x^2 + 1344/151*x + 1723/151],
  <x^3 + 2*x^2 + 2*x - 9, x^3 - 2*x^2 - 7/2*x + 19/2, 3*x^2 + 4*x - 13>,
  [ 2, 3, 2, 2, 2, 3, 3, 17, 11, 5 ],
  { 2^4, 3^4, 11^2, 13, 17^2, 43, 47, 83, 103, 127, 131, 317, 419, 491, 
    659, 743, 1087, 1201, 1453, 1657, 1787 }>,

// no. 31
<3*x^6 + x^4 + 2*x^3 - x^2 + 3*x - 3, 3, [],
  [x^2 - x + 1,
   x^2 + 3/2,
   x^2 - 10419/24827*x + 19956/24827],
  <x^3 - 2*x^2 - 3/4*x - 3, x^3 + 2*x^2 + x + 4/3, 7/2*x^2 + 5/2*x + 3>,
  [ 2, 2, 2, 2, 2, 3, 3, 3, 5, 23, 7 ],
  { 2^5, 3^4, 5^2, 7^2, 13, 19, 41, 53, 59, 67, 89, 103, 239, 401, 829, 
    929, 1069, 1303, 1637, 1811 }>,

// no. 32
<2*x^6 + 2*x^5 + 2*x^4 - x^3 + 3*x - 3, 3, [],
  [x^2 + 3,
   x^2 - 3/2,
   x^2 + 320/359*x - 5347/3231],
  <x^3 + x^2 - 9/4*x + 3, x^3 + 1/8*x - 1/2, 5/2*x^2 - 5/4*x>,
  [ 2, 5, 5, 3, 19, 2, 7, 3, 13, 17 ],
  { 2^2, 3^3, 5^3, 7^2, 13^2, 17^2, 19^2, 31, 41, 61, 103, 127, 151, 191, 
    389, 401, 563, 641, 1567, 1621, 1871, 2011, 2371, 3637, 5689, 5783, 6047, 
    6367, 6907 }>,

// no. 33
<-2*x^6 - 2*x^5 + 3*x^4 - x^3 - x^2 - x - 2, 3, [],
  [x^2 + 4/3*x + 1,
   x^2 - x + 1/3,
   x^2 + 13/3*x + 17/3],
  <x^3 + 5/3*x^2 + x + 1, x^3 - 2/3*x^2 - 1/2*x + 1, -4/3*x^2>,
  [ 3, 5 ],
  { 5, 11 }>,

// no. 34
<-3*x^6 - x^5 - x^4 - x^3 + x^2 + 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 106/91*x + 46/91],
  <x^3 + 1/3*x^2 + 1/3*x + 1/3, x^3 + 3*x - 3, -3*x^2 + x>,
  [ 2, 3, 3, 5, 17, 7, 5, 11, 3, 43 ],
  { 2, 3^4, 5^3, 7^2, 11^2, 17^2, 19, 41, 67, 79, 97, 103, 191, 239, 
    383, 401, 463, 491, 521, 541, 617, 733, 883, 1453, 2447, 2957, 3727 }>,

// no. 35
<3*x^6 - 3*x^5 - x^4 - x^3 - x^2 + 2*x - 1, 3, [],
  [x^2 + 1,
   x^2 - 2,
   x^2 + 4299/3289*x + 1189/1012],
  <x^3 - 7*x^2 + 5*x - 1, x^3 + 6*x^2 + 10/3*x + 2/3, -10*x^2 + x + 1>,
  [ 2, 2, 2, 3, 3 ],
  { 2^3, 3^3, 5, 31, 47, 103, 127, 229, 467 }>,

// no. 36
<3*x^6 + 2*x^5 + x^3 + 3*x^2 - 2*x + 3, 3, [],
  [x^2 - 2,
   x^2 - x + 3/2,
   x^2 - 4/661*x - 858/661],
  <x^3 - 3*x^2 - 2*x + 1, x^3 + 11/3*x^2 + 14/3*x + 2/3, -5*x^2 - 6*x + 1>,
  [ 2, 2, 3, 7, 5, 2, 3, 3, 13, 37, 5 ],
  { 2^3, 3^4, 5^3, 7^2, 11, 13^2, 23, 41, 43, 47, 59, 67, 79, 97, 107, 
    137, 179, 257, 373, 593, 751, 971 }>,

// no. 37
<3*x^6 - x^5 + x^4 - x^3 + 2*x^2 + 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 2624/6203*x + 2651/6203],
  <x^3 - 3/2*x^2 - 1, x^3 + 7/6*x^2 - 1, 5/2*x^2 + x>,
  [],
  { 2^3 }>,

// no. 38
<2*x^6 + 2*x^5 - x^3 - 3*x^2 + x + 2, 3, [],
  [x^2 + x - 1,
   x^2 + 1,
   x^2 + 8/7*x - 1/2],
  <x^3 + x - 1/2, x^3 + x^2 - 3*x - 1, 2*x^2 + 1>,
  [ 2, 2, 3 ],
  { 2, 3^2, 19, 127 }>,

// no. 39
<-2*x^6 + 3*x^5 + 3*x^4 + 3*x^3 + 3*x^2 - 2*x - 1, 3, [],
  [x^2 - x - 1,
   x^2 - 2*x - 1,
   x^2 - 117/409*x - 153/409],
  <x^3 - 3/2*x^2 + 2, x^3 + 1/2*x + 1/4, -2*x^2 - 3/2*x>,
  [ 2, 3, 2 ],
  { 2, 3^2, 5, 13, 23, 73, 191 }>,

// no. 40
<-3*x^6 + 2*x^5 - x^4 - 2*x^3 - 3*x^2 - x + 3, 3, [],
  [x^2 + x + 1,
   x^2 - x + 2,
   x^2 + 1312/3133*x - 944/3133],
  <x^3 - 2/3*x^2 + 2/3*x + 1, x^3 + x - 1, -2*x^2 + x>,
  [ 2, 2, 3, 5, 3 ],
  { 3^3, 5, 11, 13, 59, 311, 383, 467 }>,

// no. 41
<3*x^6 - x^4 - x^3 + x^2 - 3*x - 1, 3, [],
  [x^2 - 2*x - 1,
   x^2 - 3*x - 1,
   x^2 - 119/83*x - 257/498],
  <x^3 + x^2 + 5/6*x + 1/3, x^3 - x^2 - 1/2*x - 1, -x^2 - 5/2*x>,
  [ 2, 2, 2, 3, 5, 13, 19, 11, 23 ],
  { 2^3, 3^2, 5^2, 7, 11^2, 13^2, 19^2, 23, 31, 61, 127, 151, 199, 257, 
    269, 313, 347, 367, 373, 397, 433, 479, 557, 563, 643, 3833, 4547, 4759 }>,

// no. 42
<2*x^6 + 3*x^5 + 3*x^4 - 2*x^3 - x^2 + x - 3, 3, [],
  [x^2 + 2*x + 3,
   x^2 + x + 13/23,
   x^2 + 201/161*x - 67/23],
  <x^3 + x^2 + 1, x^3 + 1/2*x^2 + 1/2*x - 3/2, -x^2 + x>,
  [ 2, 2, 3, 7, 5 ],
  { 2, 3, 5^2, 13, 31, 53, 71, 83, 107 }>,

// no. 43
<3*x^6 - 3*x^4 + x^3 - x + 3, 3, [],
  [x^2 - x - 1,
   x^2 - 6*x - 1,
   x^2 + 7*x + 11/2],
  <x^3 - 7/3*x - 2/3, x^3 + x - 1, -x^2 - 3*x + 1>,
  [ 2, 3, 2, 3, 5, 2, 3, 5, 11, 7, 19, 23 ],
  { 2^3, 3^4, 5^3, 7^2, 11^2, 13, 29, 47, 53, 71, 73, 149, 151, 157, 179, 
    199, 283,313, 347, 419, 463, 593, 683, 727, 929, 1093, 1103, 1151, 1301, 
    1447, 1471, 1867, 1951 }>,

// no. 44
<-2*x^6 + 2*x^5 + 2*x^4 - 3*x^3 + 2*x^2 + 3*x - 2, 3, [],
  [x^2 - x + 1,
   x^2 + 1,
   x^2 + 895/257*x + 977/257],
  <x^3 + x^2 - 1, x^3 - 2*x^2 + 3/2*x - 1, -x^2 + 2*x>,
  [ 2, 3, 7, 3, 13, 11, 5, 17 ],
  { 2, 3^3, 5^2, 7^2, 11^2, 13^2, 17^2, 19, 29, 73, 101, 107, 109, 131, 
    149, 223, 229, 251, 359, 389, 503, 509, 769 }>,

// no. 45
<3*x^6 + 2*x^5 - 3*x^4 + 3*x^3 - x^2 - 3*x - 3, 3, [],
  [x^2 - 3,
   x^2 + 4*x + 13,
   x^2 + 5/3*x + 163/48],
  <x^3 + 8/3*x^2 + 7/3*x + 4/3, x^3 - 2*x^2 - x - 1, 3*x^2 + 4*x + 1>,
  [],
  { 2^2 }>,

// no. 46
<-2*x^6 + 2*x^5 - 2*x^4 + x^2 + x + 3, 3, [],
  [x^2 - x + 3/2,
   x^2 + 1/3*x + 2/3,
   x^2 - 848/571*x + 1912/1713],
  <x^3 - x^2 + x + 2, x^3 + 1/2*x - 1/2, x^2 + x + 1>,
  [ 2, 2, 3, 5, 13, 2, 7, 17, 11, 3, 3 ],
  { 2^3, 3^4, 5^2, 7^2, 11^2, 13^2, 17^2, 23, 29, 31, 47, 73, 79, 97, 107, 
    179, 263, 307, 311, 383, 503, 599, 829, 1061, 1151, 1193, 1217 }>,

// no. 47
<3*x^6 - 3*x^5 - x^4 - 2, 3, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 5/11*x - 27/11,
   x^2 + 96/13*x - 166/13],
  <x^3 - x + 1, x^3 - x^2 - 2/3*x - 2/3, -2*x^2 + x>,
  [ 2, 2, 2, 3, 2, 5, 7 ],
  { 2^4, 3^2, 5^2, 7^2, 11, 19, 31, 73, 103, 173, 1949, 3701 }>,

// no. 48
<3*x^6 + 2*x^5 - 3*x^4 - 3*x^3 + 3*x^2 - x - 3, 3, [],
  [x^2 - 1/3*x - 1,
   x^2 + 2*x + 3/2,
   x^2 + 4453/897*x + 1009/299],
  <x^3 + 2*x^2 - 1/2*x + 2, x^3 - 4/3*x^2 + 5/6*x - 2/3, 2*x^2 - 7/2*x + 1>,
  [ 2, 2, 2, 3, 13, 11, 5, 3 ],
  { 2^3, 3^3, 5^2, 7, 11^2, 13^2, 59, 71, 179, 313, 443, 457, 827, 839, 
    857, 2381 }>,

// no. 49
<2*x^6 + 2*x^5 - 2*x^4 - x^3 - 2*x^2 - 3*x + 3, 3, [],
  [x^2 + x - 1,
   x^2 + 1,
   x^2 - 140/79*x + 44/79],
  <x^3 + 10/7*x^2 - 5/7*x - 2/7, x^3 - 3/7*x^2 - 16/7*x + 11/14, -16/7*x^2 - 
6/7*x + 13/7>,
  [ 2, 3, 2, 2, 5, 17, 19, 7, 43 ],
  { 2^3, 3^2, 5^2, 7^2, 13, 17^2, 19^2, 31, 67, 173, 181, 227, 233, 241, 
    269, 389, 409, 467, 739, 1051, 1097, 1433, 1447, 1489, 1697 }>,

// no. 50
<2*x^6 + x^5 + 3*x^4 + 3*x^3 + 3*x^2 + 2*x - 3, 3, [],
  [x^2 + x - 1,
   x^2 - 2*x - 4,
   x^2 + 680/1271*x + 3307/1271],
  <x^3 + 9/7*x^2 + 13/7*x + 3, x^3 - 11/14*x^2 + 9/14*x - 1/2, 1/7*x^2 - 
18/7*x>,
  [ 2, 3 ],
  { 2, 3^2, 5, 7, 29 }>,

// no. 51
<-x^6 + 2*x^5 + 3*x^4 - x^3 - 3*x + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 1/2,
   x^2 - 105/53*x + 573/265],
  <x^3 - 3/2*x + 1, x^3 - 2*x^2 - 3/2*x - 3, -1/2*x>,
  [ 2, 11 ],
  { 2, 5, 7, 11^2, 61 }>,

// no. 52
<-2*x^6 + x^5 - 3*x^4 + 3*x^3 + 3*x^2 + 3*x - 3, 3, [],
  [x^2 - 1/2*x + 13/2,
   x^2 - 13/11*x + 4/11,
   x^2 - 397/242*x + 122/121],
  <x^3 - 1/2*x^2 + 15/8*x - 3/2, x^3 - 1/4*x - 1, -1/2*x^2 + 7/4*x>,
  [ 2, 3, 5, 11, 2, 2, 2, 3, 2, 5 ],
  { 2^5, 3^3, 5^3, 7, 11^2, 43, 61, 83, 113, 163, 191, 389, 541, 701, 
    719, 919, 1049, 1303, 1399, 2099, 2237, 3271, 4349 }>,

// no. 53
<-3*x^6 + x^5 - 2*x^4 - 3*x^2 - x + 2, 3, [],
  [x^2 - x + 1,
   x^2 - 1/4*x + 1/2,
   x^2 - 85/124*x + 7/62],
  <x^3 - 4/7*x^2 + 13/7*x + 2, x^3 + 5/21*x^2 + 10/21*x - 1/3, 15/7*x^2 + 
9/7*x>,
  [ 2, 2, 3, 3, 3, 2, 11, 5, 5, 13, 7 ],
  { 2^3, 3^4, 5^3, 11^2, 13^2, 29, 31, 71, 73, 79, 83, 109, 173, 227, 229, 
    233, 271, 307, 457, 733, 971, 1153, 1451, 1543 }>,

// no. 54
<2*x^6 + 3*x^5 - x^4 + 2*x^3 + x^2 + 2*x - 3, 3, [],
  [x^2 + 2*x - 2,
   x^2 + 2*x + 2,
   x^2 - 3146/1289*x + 6014/1289],
  <x^3 + 18/7*x^2 + 2*x + 2, x^3 - 15/14*x^2 - 1, 5/7*x^2 + 3*x + 1>,
  [ 5 ],
  { 3, 5^2 }>,

// no. 55
<-3*x^6 - 3*x^5 - x^4 + 2*x^2 + x + 2, 3, [],
  [x^2 + x + 1,
   x^2 - 1/4*x + 1/6,
   x^2 - 131/796*x - 103/398],
  <x^3 + 1/3*x + 2/3, x^3 + x^2 - 1, 2*x>,
  [ 2, 2, 2, 5 ],
  { 2, 3, 5^2, 11 }>,

// no. 56
<-x^6 + 3*x^5 + x^4 - 2*x^2 - x - 3, 3, [],
  [x^2 + 1/2*x + 3/2,
   x^2 + x + 4/5,
   x^2 - 143/34*x + 643/170],
  <x^3 - 2*x^2 + 2*x - 3, x^3 - x^2 - x - 1, -2*x^2 + x>,
  [ 2, 2, 2, 3, 2, 5, 7, 5, 19 ],
  { 2^4, 3^2, 5^3, 7^2, 13, 19^2, 23, 29, 43, 53, 71, 197, 313, 463, 
    1283, 1733 }>,

// no. 57
<3*x^6 + x^5 + 2*x^4 + x^3 + 2*x^2 - x - 3, 3, [],
  [x^2 + 5/2*x + 2,
   x^2 - 2/3*x + 1,
   x^2 - 70/33*x - 79/33],
  <x^3 - 1/2*x^2 - 1/2*x + 2, x^3 + 5/6*x^2 - 1/2*x - 2/3, -5/2*x^2 + 1/2*x + 
1>,
  [],
  { 2^2 }>,

// no. 58
<2*x^6 - 2*x^5 + x^3 + 2*x^2 - 2*x - 2, 3, [],
  [x^2 - x - 1,
   x^2 - 2,
   x^2 + 235/161*x + 577/644],
  <x^3 - 2*x + 3, x^3 - x^2 - 1/2, 2*x^2 - 2*x + 1>,
  [ 2, 2, 2, 5, 3, 3, 7, 13, 11 ],
  { 2^3, 3^3, 5^2, 7^2, 11^2, 13^2, 17, 23, 29, 31, 53, 59, 61, 67, 71, 
    79, 83, 97, 167, 199, 239, 271, 421, 487 }>,

// no. 59
<-3*x^6 + 2*x^5 + x^4 + 3*x^3 + 3*x^2 + 3*x - 1, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 - 32/13*x + 37/13],
  <x^3 - 2/3*x^2 - x - 2/3, x^3 + x - 1, -x^2 + 2*x + 1>,
  [ 2, 2, 2, 2, 2, 5, 3, 11, 3, 3, 13 ],
  { 2^5, 3^4, 5^2, 11^2, 13^2, 29, 53, 61, 67, 79, 83, 127, 157, 163, 191, 
    233, 263, 283, 353, 449, 613, 881, 1721, 1777 }>,

// no. 60
<-x^6 + 3*x^5 - x^4 + 2*x^3 + 2*x - 3, 3, [],
  [x^2 - x + 2,
   x^2 - x + 1,
   x^2 - 2041/1117*x + 926/1117],
  <x^3 + 1/2*x^2 + 13/2*x - 7, x^3 - 7/2*x^2 + 5/2*x - 1, 5/2*x^2 - 11/2*x + 2>,
  [ 2, 7, 5, 2, 5 ],
  { 2^2, 3, 5^3, 7^2, 37, 43, 67, 89, 101, 149, 199, 283, 293, 823 }>,

// no. 61
<2*x^6 - 3*x^4 + 3*x^3 - 2*x^2 - 2*x - 1, 3, [],
  [x^2 - x + 1,
   x^2 - x + 1/2,
   x^2 - 131/47*x + 265/94],
  <x^3 + 2*x^2 + 1/2, x^3 - 2*x^2 - 2*x - 1, 3*x^2 + 2*x>,
  [ 11, 2, 2, 2, 5, 3, 5, 31, 3, 3, 7 ],
  { 2^3, 3^4, 5^3, 11^2, 23, 41, 53, 79, 97, 103, 151, 233, 239, 283, 967, 
    1181, 1439, 1579, 2203, 2671, 2837, 3469 }>,

// no. 62
<-2*x^6 - 2*x^5 - 3*x^3 + x^2 + 3*x + 2, 3, [],
  [x^2 + 1,
   x^2 + 2*x + 7/6,
   x^2 + 30/163*x + 71/326],
  <x^3 + 3*x + 1, x^3 + x^2 - x - 1/2, -2*x^2 - x + 1>,
  [ 2, 3, 3, 2, 2, 2, 5, 17, 7, 11, 19 ],
  { 2^4, 3^3, 5^2, 7^2, 11^2, 17^2, 43, 59, 101, 107, 191, 197, 307, 311, 
    353, 383, 401, 463, 593, 641, 919, 1499, 2027, 3491, 4987 }>,

// no. 63
<-x^6 + 2*x^5 + x^4 + 3*x^3 - x^2 + 3*x + 3, 3, [],
  [x^2 - 2*x - 1,
   x^2 + 1/2,
   x^2 - 470/257*x - 169/257],
  <x^3 - 4*x^2 + 5*x + 2, x^3 + 2*x^2 + 9/4*x - 3/2, -1/2*x^2 - 9/2*x>,
  [ 2, 2, 5 ],
  { 2^2, 5^2, 7, 11, 137 }>,

// no. 64
<3*x^6 - 2*x^5 - 2*x^4 - 3*x^3 + 3*x^2 - 2*x + 2, 3, [],
  [x^2 - x + 1,
   x^2 - 2,
   x^2 + 203/157*x + 569/314],
  <x^3 - 5/3*x^2 + 2/3*x - 2/3, x^3 + x^2 - 1, x^2>,
  [],
  { 5 }>,

// no. 65
<-2*x^6 - 2*x^5 + 2*x^4 - x^3 - x^2 - 3*x + 3, 3, [],
  [x^2 - 1/3,
   x^2 + 2*x + 1/3,
   x^2 + 128/73*x - 1/73],
  <x^3 - x + 2, x^3 + x^2 + 1/2*x - 1/2, x^2 + 1>,
  [ 2, 2, 13, 13, 3, 2, 11, 23, 3, 5, 7, 19 ],
  { 2^3, 3^3, 5^2, 7^2, 11^2, 13^2, 19^2, 41, 53, 59, 71, 73, 109, 151, 
    211, 239, 269, 277,349, 383, 607, 739, 773, 827, 1039, 1499, 1531, 1873, 
    1997, 2029, 2609, 2621, 2713, 2803, 2927, 3221, 3701, 4451 }>,

// no. 66
<2*x^6 + x^5 - 3*x^4 - 3*x - 3, 3, [],
  [x^2 - x + 1,
   x^2 - 7,
   x^2 + 1/6*x + 2/9],
  <x^3 + x^2 + 1, x^3 - 1/2*x^2 - 3/2*x - 3/2, x^2 + 2*x>,
  [ 2, 3, 3, 7, 5, 17 ],
  { 3, 5^2, 7^2, 17^2, 19, 29, 43, 67, 103, 113, 127, 157, 337, 
    929, 1747 }>,

// no. 67
<-x^6 - 3*x^5 + x^4 - x^3 + 3*x^2 + 2*x - 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 2685214/1370065*x + 3216052/1370065],
  <x^3 + 4*x + 28, x^3 + 3*x^2 + 4*x + 3, -3*x^2 - 7*x - 9>,
  [ 2, 3, 3, 11, 2, 13 ],
  { 2^2, 3^3, 5, 11^2, 13^2, 17, 19, 47, 71, 107, 151, 277, 293, 311, 
    859, 2393 }>,

// no. 68
<-3*x^6 + x^3 + 2*x^2 + 3*x - 1, 3, [],
  [x^2 + 1,
   x^2 - 1/2*x + 5/4,
   x^2 + 41/57*x + 169/171],
  <x^3 - x^2 + x - 1/3, x^3 + x^2 - 1, 2*x>,
  [ 2 ],
  { 2, 19 }>,

// no. 69
<-3*x^6 - 2*x^4 + 2*x^3 - x + 2, 3, [],
  [x^2 - 1/2,
   x^2 - 1/2*x - 1/4,
   x^2 - 9/13*x - 2/13],
  <x^3 + x^2 + x + 2/3, x^3 - x^2 + 2*x - 1, 2*x^2 + x>,
  [ 2 ],
  { 2^3, 3 }>,

// no. 70
<3*x^6 - 3*x^5 - 2*x^4 - 3*x^2 - 2*x + 3, 3, [],
  [x^2 + x - 1,
   x^2 - 2*x + 2,
   x^2 + 28/3*x + 4/9],
  <x^3 + 3*x^2 + 1, x^3 - 4*x^2 - 2/3*x + 1, 6*x^2>,
  [ 2, 2, 3, 2, 2, 2, 5, 7, 11 ],
  { 2^5, 3^2, 5^2, 7^2, 11^2, 13, 19, 41, 47, 67, 71, 211, 227, 409, 
    2411, 3271, 7717 }>,

// no. 71
<3*x^6 - 2*x^5 - 2*x^3 - x^2 - 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 1/2,
   x^2 + 1233/2327*x + 196/2327],
  <x^3 + 1/4*x + 1, x^3 - 2/3*x^2 - 1/3*x - 4/3, 1/2*x^2 - 1/2*x + 1>,
  [ 2, 2, 2, 3, 3, 11, 5 ],
  { 2^3, 3^3, 5^2, 11^2, 13, 47, 53, 61, 101, 107, 113, 191, 421, 491, 521 }>,

// no. 72
<-3*x^6 - 3*x^5 - x^4 + 3*x^3 + 2*x^2 + 2*x - 2, 3, [],
  [x^2 + 2*x + 3,
   x^2 - x + 3,
   x^2 - 5/13*x + 3/13],
  <x^3 + 2/3*x - 2/3, x^3 + x^2 - 1, x^2>,
  [ 2, 2, 2, 3, 5, 3, 7, 11, 47, 5 ],
  { 2^3, 3^4, 5^3, 7^2, 11^2, 13, 19, 23, 41, 67, 73, 79, 83, 97, 101, 
    137, 157, 229, 233, 269, 347, 389, 431, 457, 503, 521, 557, 577 }>,

// no. 73
<3*x^6 + x^3 - 3*x^2 - 2, 3, [],
  [x^2 - x + 1,
   x^2 + 2*x + 2,
   x^2 - 3242/3203*x + 16363/6406],
  <x^3 + 4*x^2 - 4*x - 11, x^3 - 4*x^2 - 4/3*x + 6, -8*x^2 + x + 14>,
  [ 2, 2, 11, 7, 17, 3, 5, 19 ],
  { 2^2, 3^2, 5^2, 7^2, 11^2, 17^2, 19^2, 23, 29, 97, 101, 269, 557, 563, 
    967, 1373, 2311, 5101 }>,

// no. 74
<-2*x^6 - 2*x^4 - x^3 + 2*x^2 - x + 3, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 + 10079/24793*x + 28453/24793],
  <x^3 - x^2 + x + 3/2, x^3 + x^2 + x - 1, 3*x>,
  [ 2, 2, 5, 7, 5, 3, 17, 11, 13, 41 ],
  { 2^2, 3^2, 5^2, 7^2, 13^2, 17^2, 23, 41, 47, 61, 71, 73, 83, 97, 113, 
    127, 151, 191, 197, 199, 211, 307, 419, 431, 569, 653, 751, 829, 853 }>,

// no. 75
<2*x^6 - 2*x^5 + 3*x^4 - 3*x^3 - 2*x^2 - 3*x - 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 1544/1097*x + 721/1097],
  <x^3 + x + 1, x^3 - x^2 - 3/2, x^2>,
  [ 2, 7, 5, 2, 2, 13, 3, 3, 11, 3, 5, 17, 23, 29, 41 ],
  { 2^3, 3^4, 5^3, 7^2, 11^2, 13^2, 17^2, 29, 37, 43, 59, 67, 89, 97, 173, 
    191, 211, 227, 239, 269, 281, 337, 367, 379, 383, 521, 541, 647, 653, 659, 
    743, 977, 1009, 1031, 1033, 1171, 1193, 1291, 1979, 2411, 2843, 3079, 
    3347, 3659, 3847, 3907, 4549, 4583 }>,

// no. 76
<-x^6 - 3*x^5 + x^4 - 2*x^3 - x^2 + 3*x - 3, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 + 99/37*x + 81/37],
  <x^3 + 4*x^2 + 3*x + 3, x^3 - x^2 + x + 4, x^2 + 3*x + 3>,
  [ 2, 3, 3, 5, 5, 7, 17, 2, 13 ],
  { 2^2, 3^3, 5^3, 7^2, 13^2, 17^2, 19^2, 29, 37, 41, 53, 67, 83, 89, 149, 173, 
    191, 257, 281, 433, 821, 883, 977, 1697 }>,

// no. 77
<-2*x^6 - 2*x^5 + 2*x^4 - 3*x^3 + 2, 3, [],
  [x^2 - x + 1,
   x^2 - 1/2,
   x^2 - 5/361*x + 8857/3249],
  <x^3 + x^2 + 2, x^3 - x + 1/2, -x + 2>,
  [ 2, 2, 2, 19, 13, 17, 3, 3, 5 ],
  { 2^3, 3^3, 5^2, 13^2, 17^2, 19^2, 29, 47, 71, 79, 149, 241, 337, 373, 439, 
    823, 877 }>,

// no. 78
<3*x^6 + 3*x^5 + x^3 + 2*x^2 + 2*x + 3, 3, [],
  [x^2 + x - 1,
   x^2 - 2*x - 1,
   x^2 - 338/121*x - 793/121],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 - 1/3*x + 1, 2*x^2>,
  [ 2, 2, 2, 2, 3 ],
  { 2^4, 3, 5, 7, 43, 61, 433 }>,

// no. 79
<-3*x^6 + 3*x^5 - 3*x^4 + x^3 + x^2 - 2*x + 2, 3, [],
  [x^2 - x + 1,
   x^2 + 1,
   x^2 - 1004/1183*x + 82/1183],
  <x^3 - 3/4*x^2 + x - 1, x^3 - 1/4*x^2 + 2/3, 3/4*x^2 - 1/2*x>,
  [ 3 ],
  { 3, 7, 17 }>,

// no. 80
<-2*x^6 + 2*x^5 + 2*x^4 + 3*x^3 + 2*x^2 + x - 3, 3, [],
  [x^2 + 1,
   x^2 + 5/3*x + 1,
   x^2 + 167/99*x + 292/297],
  <x^3 - x^2 + 2*x - 3/2, x^3 - x - 1, 2*x^2>,
  [ 2, 3, 3, 3, 5, 3, 2, 11, 7, 17 ],
  { 2^2, 3^4, 5^2, 11^2, 53, 59, 73, 109, 137, 191, 211, 223, 277, 331, 379, 
    401, 691, 877, 1187, 1327, 1531, 1637, 1733 }>,

// no. 81
<-3*x^6 + x^5 - 3*x^4 - 3*x^3 + 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 857471892/3232418371*x - 164208866/248647567],
  <x^3 - 2*x^2 + 5*x - 1, x^3 + 5/3*x^2 + 7/27*x - 37/27, 5/3*x^2 + 4*x - 8/3>,
  [ 2, 2, 2, 2, 7, 11, 3, 19 ],
  { 2^5, 5, 7^2, 11^2, 19^2, 47, 73, 101, 113, 233, 673, 827, 991, 1163, 
    1223, 1783 }>,

// no. 82
<-3*x^6 + 3*x^5 + 2*x^4 + 2*x^2 + 3*x + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 3/4*x + 1/2,
   x^2 + 1050/241*x + 1403/241],
  <x^3 - x^2 + 2*x + 1, x^3 + 1/3*x - 2/3, 3*x^2 + 1>,
  [ 2, 2, 2, 2, 3 ],
  { 2^3, 3^2, 5, 73, 137 }>,

// no. 83
<-3*x^6 + 3*x^5 + 2*x^4 + 2*x^3 + 3, 3, [],
  [x^2 + x + 1,
   x^2 - 3/4*x - 3/4,
   x^2 - 31/84*x - 383/756],
  <x^3 - 2*x^2 + 6*x - 3, x^3 + x^2 + 2/3*x + 1/3, 4*x^2 + x>,
  [ 2 ],
  { 2, 3 }>,

// no. 84
<-3*x^6 + x^5 - 3*x^4 + 2*x^3 + 3*x^2 - x + 3, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 + 33868/8917*x + 62637/8917],
  <x^3 + 3/4*x^2 + 2*x + 2, x^3 - 13/12*x^2 + 1/3*x - 1/3, -5/4*x^2 - 1/2*x + 
1>,
  [ 2, 2, 2, 7, 17, 5, 3, 13 ],
  { 2^3, 3^2, 5^2, 7^2, 13^2, 17^2, 19^2, 41, 47, 71, 73, 97, 167, 227, 263, 
    293, 593 }>,

// no. 85
<-3*x^6 + x^5 - 2*x^4 + 2*x^3 - 3*x^2 - 2*x + 3, 3, [],
  [x^2 + 2*x + 2,
   x^2 - 31/21*x + 23/21,
   x^2 + 2*x + 26],
  <x^3 - 1/3*x^2 + 2/3, x^3 + x - 1, -x^2 + 1>,
  [ 2, 2, 2 ],
  { 2^3, 3, 83 }>,

// no. 86
<3*x^6 + 3*x^5 + 3*x^4 - x^3 - x^2 - 2*x + 3, 3, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 1/3,
   x^2 + 8/3*x + 13/9],
  <x^3 + 2*x^2 + 2*x - 1/3, x^3 - x^2 - 2*x - 2, 3*x^2 + 4*x + 1>,
  [ 2, 3, 5 ],
  { 2, 3, 5^2, 7, 67 }>,

// no. 87
<3*x^6 + 3*x^5 + 3*x^4 - x^3 - 2*x^2 + 3*x - 3, 3, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + x - 4/3,
   x^2 - 1083825/155978*x + 1458777/155978],
  <x^3 + x^2 - 4, x^3 - 13/12*x + 7/12, -5/2*x^2 - 5/2*x + 2>,
  [ 3, 3, 2, 5, 2, 5, 2, 2, 19, 23, 17, 7 ],
  { 2^4, 3^3, 5^3, 7^2, 11, 17^2, 19^2, 23, 41, 43, 53, 61, 191, 239, 269, 
    397, 401, 733, 743, 1039, 1409, 1613, 1627, 1879, 1889, 3907, 4663 }>,

// no. 88
<-3*x^6 + 2*x^5 + x^4 + 3*x^3 + 3*x^2 + x + 3, 3, [],
  [x^2 + 1,
   x^2 - x - 1,
   x^2 + 13/206*x - 313/412],
  <x^3 - 2/3*x^2 - 4/3, x^3 - 1/4*x + 1/2, 1/2*x^2 + x + 1>,
  [ 2, 2, 2, 3, 7, 2, 2, 2, 2, 5, 13 ],
  { 2^6, 3^2, 5^2, 7^2, 11, 13^2, 19, 23, 41, 53, 107, 277, 599, 631, 
    811, 1193, 1217 }>,

// no. 89
<-x^6 - 3*x^5 - 2*x^4 - 3*x^3 - 2*x^2 - 2, 3, [],
  [x^2 + 1,
   x^2 - 2*x + 2,
   x^2 + 6/29*x + 162/145],
  <x^3 + x^2 - x + 1, x^3 + 2*x^2 + 2*x + 2, x^2>,
  [],
  { 11 }>,

// no. 90
<3*x^6 - 2*x^5 - 3*x^4 - 3*x^3 - x^2 - 3*x - 1, 3, [],
  [x^2 - 2*x - 1,
   x^2 + 4/3*x + 5/6,
   x^2 + 221/191*x + 265/191],
  <x^3 + x^2 - x + 1, x^3 - 5/3*x^2 - 4/3*x - 1/3, -3*x^2 + x>,
  [ 2 ],
  { 2, 37 }>,

// no. 91
<3*x^6 - 3*x^5 - x^4 - 2*x^3 - 2*x^2 - x - 3, 3, [],
  [x^2 + x + 1,
   x^2 - 1/2*x - 2,
   x^2 + 292/421*x + 1668/421],
  <x^3 + 2*x^2 - x + 1, x^3 - 3*x^2 - 5/3*x - 4/3, 5*x^2 + 1>,
  [],
  { 3 }>,

// no. 92
<2*x^6 - x^4 + 3*x^3 + 3*x^2 + 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 1,
   x^2 - 70692/36847*x - 163597/36847],
  <x^3 + x^2 - x + 1/2, x^3 - x^2 - 3*x - 3, 3*x^2 + 2*x>,
  [ 2, 2, 3 ],
  { 2, 3^2, 13 }>,

// no. 93
<2*x^6 - x^5 + 3*x^2 - 2*x - 3, 3, [],
  [x^2 - 2,
   x^2 + 2*x + 2,
   x^2 - 2391/2297*x - 2947/2297],
  <x^3 - 1/2*x^2 + 2, x^3 - 1/2*x - 3/4, x^2 - 3/2*x>,
  [ 2, 3, 11, 2 ],
  { 2^2, 3^2, 5, 11^2, 73, 79, 131, 137 }>,

// no. 94
<-2*x^6 - 3*x^5 - x^3 + 2*x^2 - 2*x - 3, 3, [],
  [x^2 + 1,
   x^2 + 1/2*x + 1,
   x^2 + 260/33*x + 1021/33],
  <x^3 + 2*x^2 + 6*x + 4, x^3 - 1/2*x^2 - 1/2*x + 1/2, -3*x^2 + 1>,
  [ 2, 2, 2, 3, 3, 5, 11 ],
  { 2^3, 3^3, 5^2, 7, 11^2, 29, 41, 43, 47, 97, 137, 223, 2131, 2399 }>,

// no. 95
<-3*x^6 + 3*x^3 + 2*x^2 + 3*x - 2, 3, [],
  [x^2 + 1,
   x^2 + 1/2*x + 19/12,
   x^2 - 833/1142*x + 1123/6852],
  <x^3 - x^2 + 1/3*x - 2/3, x^3 + x^2 + x - 1, -x^2 + 2*x>,
  [ 2, 2, 13, 3 ],
  { 2^2, 3, 5, 7, 17, 23, 167 }>,

// no. 96
<2*x^6 - 2*x^5 - 3*x^3 - x + 3, 3, [],
  [x^2 + 1,
   x^2 - 3*x + 1,
   x^2 - 506/223*x + 179/223],
  <x^3 + x^2 - 7*x + 3, x^3 - 2*x^2 + x + 1/2, -4*x^2 + 5*x>,
  [ 2, 5 ],
  { 2, 3, 11, 13 }>,

// no. 97
<-x^6 - 3*x^5 + 3*x^4 - x^3 + x^2 + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 2*x - 1/5,
   x^2 + 462/185*x - 118/185],
  <x^3 + x^2 - 3*x + 3, x^3 + 2*x^2 - x - 1, -x^2 + 3*x>,
  [ 2, 2, 2, 3, 3, 11, 7 ],
  { 2^3, 3^3, 7^2, 11^2, 13, 17, 19, 31, 37, 71, 83, 89, 101, 241, 
    263, 311, 317, 379, 541, 617 }>,

// no. 98
<3*x^6 + 3*x^5 - x^4 - 3*x^3 - x^2 + 2*x - 1, 3, [],
  [x^2 - 5/3,
   x^2 + x + 1/3,
   x^2 + 7/11*x + 5/11],
  <x^3 + 1/2*x^2 - 2/3*x + 1/3, x^3 + 1/2*x^2 - 1, -1/2*x^2>,
  [ 2, 2, 5, 2, 2, 3 ],
  { 2^4, 3^2, 5^2, 13, 19, 31, 43, 109 }>,

// no. 99
<-x^6 - 2*x^5 + 2*x^4 - x^3 - 3*x^2 + 2*x - 2, 3, [],
  [x^2 + x + 3/2,
   x^2 - 8/5*x + 6/5,
   x^2 - 3*x + 3],
  <x^3 + x^2 + 1, x^3 + x^2 - 2*x + 2, x^2>,
  [ 2, 3, 5, 7 ],
  { 2, 3, 5^2, 7, 13, 19, 37, 43, 89, 149, 229, 263 }>,

// no. 100
<2*x^6 - 2*x^5 + 2*x^4 - x^3 - 2*x^2 + x + 2, 3, [],
  [x^2 + 1,
   x^2 - 3*x + 1,
   x^2 - 13/7*x + 1],
  <x^3 - x^2 - 1/2, x^3 - x - 1, -2*x^2 + 1>,
  [ 2, 2, 3, 5, 5, 3, 2, 3 ],
  { 2^3, 3^4, 5^3, 23, 31, 53, 59, 79, 557, 857, 2857, 3121 }>,

// no. 101
<3*x^6 + 3*x^5 - 3*x^4 + x^3 - 3*x^2 - 2*x - 1, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 852/191*x - 1417/191],
  <x^3 + 5/2*x^2 + 2, x^3 - 3/2*x^2 + 2/3*x - 5/6, 5/2*x^2 - 3/2*x + 2>,
  [ 2, 2, 3, 3, 19, 7 ],
  { 2^2, 3^3, 5, 7^2, 11, 19^2, 23, 31, 37, 53, 271, 491 }>,

// no. 102
<3*x^6 - 2*x^5 - x^3 + 2*x^2 + 3*x + 2, 3, [],
  [x^2 + x - 1,
   x^2 - 2*x - 1,
   x^2 - 19/23*x - 1/46],
  <x^3 - 3/4*x - 1/2, x^3 - 2/3*x^2 - 4/3, 3/2*x^2 + x>,
  [],
  { 163 }>,

// no. 103
<3*x^6 - x^5 + 3*x^4 - 3*x^3 - 3*x^2 - 2*x - 2, 3, [],
  [x^2 + 1,
   x^2 + 2,
   x^2 + 372/253*x + 137/253],
  <x^3 + 7/6*x^2 + 2/3*x + 1, x^3 - 3/2*x^2 - 1, 5/2*x^2 + 1>,
  [ 29, 5, 2, 3, 3, 5, 17, 2, 3, 7, 11, 19 ],
  { 2^2, 3^4, 5^3, 7^2, 11^2, 13, 17^2, 31, 37, 41, 61, 73, 83, 101, 107, 
    109, 113, 137, 191, 193, 227, 229, 293, 379, 449, 631, 691, 701, 859, 
    877, 887 }>,

// no. 104
<-3*x^6 + x^4 - 3*x^3 + 3*x^2 + x + 3, 3, [],
  [x^2 - x + 1,
   x^2 - 1/3,
   x^2 - 3121/7141*x + 9841/28564],
  <x^3 - 1/2*x^2 + 2*x + 6, x^3 + 1/2*x^2 - 1/6, -5/2*x^2 - 7/2*x>,
  [ 2, 3, 3 ],
  { 2, 3^2, 11, 17, 23 }>,

// no. 105
<3*x^6 + 2*x^5 - 3*x^4 - 2*x^3 + x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + x - 4,
   x^2 - 13/3*x - 1204/33],
  <x^3 + 2*x^2 - 2*x + 1, x^3 - 4/3*x^2 - 5/3*x - 1, 4*x^2>,
  [ 2, 2, 2, 2, 3, 2, 7, 5 ],
  { 2^4, 3^2, 5^2, 7^2, 11, 13, 17, 43, 71, 127, 163, 601, 769, 977 }>,

// no. 106
<3*x^6 + 2*x^5 - 3*x^4 - x^3 - 2*x^2 - x - 3, 3, [],
  [x^2 + 1/2,
   x^2 + 2/3*x - 7/3,
   x^2 - 201/61*x - 469/61],
  <x^3 - 3/2*x - 2, x^3 + 2/3*x^2 - 5/6*x + 2/3, -2*x^2 - 3/2*x + 1>,
  [ 2, 2 ],
  { 2, 5, 73 }>,

// no. 107
<-2*x^6 + 3*x^5 - 3*x^4 + x^3 - x^2 + 2*x + 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 + 821/569*x + 793/569],
  <x^3 - 5/2*x^2 + 3/2*x + 1/2, x^3 + x^2 + 7*x - 3, -3*x^2 + 6*x>,
  [ 2, 2, 2, 2, 2 ],
  { 2^5, 3, 7, 41 }>,

// no. 108
<2*x^6 + x^5 + 3*x^4 + 3*x^3 + x^2 - 2*x + 3, 3, [],
  [x^2 + 1,
   x^2 - x - 1,
   x^2 + 944/1913*x - 1196/1913],
  <x^3 + 4/7*x^2 - 2/7*x - 2/7, x^3 - 1/14*x^2 + 25/14*x + 11/14, -2/7*x^2 + 
1/7*x - 13/7>,
  [ 2, 2, 3, 3, 3, 2, 7, 2, 2, 2, 5, 11, 37, 13 ],
  { 2^6, 3^4, 5^2, 7^2, 11^2, 13^2, 23, 29, 47, 89, 359, 457, 479, 491, 547, 
    821, 883, 907, 971, 1451, 1481, 1499, 2417, 2699, 2777, 2861, 3767, 3847, 
    4217 }>,

// no. 109
<3*x^6 + 2*x^5 + 2*x^4 + 3*x^3 + 3*x^2 + 2*x - 2, 3, [],
  [x^2 + x + 1,
   x^2 - 2,
   x^2 - 1060/479*x + 502/479],
  <x^3 + 2/3*x^2 - 4/3*x + 2/3, x^3 - x - 1, 3*x^2 + x>,
  [ 2, 2, 3, 19, 5, 2, 2, 2, 2 ],
  { 2^6, 3^2, 5^2, 7, 19^2, 23, 43, 71, 181, 227, 233, 1033, 1039, 1361, 
    1399, 1609 }>,

// no. 110
<-3*x^6 + x^5 + x^4 - 3*x^3 + 2*x^2 - 2*x - 2, 3, [],
  [x^2 - 1/3*x + 1,
   x^2 + 1,
   x^2 + 128/349*x + 113/349],
  <x^3 + 3/4*x^2 + x + 1, x^3 - 13/12*x^2 + 2/3, 5/4*x^2 - 1/2*x>,
  [ 2, 2, 2, 2, 2, 3, 5, 3, 17, 7 ],
  { 2^5, 3^3, 5^2, 11, 17^2, 19, 37, 47, 53, 73, 173, 281, 359, 379, 631 }>,

// no. 111
<-3*x^6 + 2*x^5 - 3*x^4 + x^3 - 3*x^2 - 3*x + 3, 3, [],
  [x^2 + 1/3*x - 1/3,
   x^2 + 1/2*x - 1/4,
   x^2 + 10/57*x + 157/171],
  <x^3 - 5/3*x^2 + 5/3*x + 2/3, x^3 + x^2 + x - 1, -3*x + 1>,
  [ 2, 3, 3, 5, 5, 11, 2, 2, 7, 29, 19 ],
  { 2^3, 3^3, 5^3, 7^2, 11^2, 17, 19^2, 23, 31, 59, 61, 73, 97, 107, 109, 
    149, 151, 179, 197, 199, 211, 283, 307, 367, 547, 607, 619, 883, 1511, 
    2549, 2657, 3181, 4027, 4243, 4517 }>,

// no. 112
<3*x^6 - 2*x^5 - 3*x^4 - 3*x^3 - 2*x^2 - 2*x - 2, 3, [],
  [x^2 + 4/3*x + 2/3,
   x^2 - 2/3*x + 1/2,
   x^2 + 123/47*x + 73/47],
  <x^3 - x^2 - 2*x - 2, x^3 + 1/3*x^2 + 1/3, 2*x^2 + x>,
  [ 2, 5, 3 ],
  { 3, 5^2, 7, 11, 19, 29 }>,

// no. 113
<-3*x^6 + 3*x^5 + x^3 + 2*x^2 + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 2,
   x^2 - 612/541*x + 866/541],
  <x^3 - 2*x^2 + 3*x + 3, x^3 + x^2 + 1/3*x - 1/3, 2*x^2 + 4*x>,
  [ 2, 2, 3 ],
  { 2, 3, 5, 17, 23 }>,

// no. 114
<-2*x^6 + 2*x^5 + x^4 + 2*x^3 + 3*x^2 + 3*x - 3, 3, [],
  [x^2 - x + 1,
   x^2 - 1/3*x + 4/3,
   x^2 - 2190/2057*x + 2089/2057],
  <x^3 - 2*x^2 + 3/2*x - 3/2, x^3 + x^2 - 1, 2*x>,
  [ 2, 2 ],
  { 2^2, 7, 41 }>,

// no. 115
<3*x^6 - 2*x^5 - x^4 + 3*x^3 - x^2 + 3*x - 2, 3, [],
  [x^2 + x - 1,
   x^2 - 3/2,
   x^2 + 366/409*x - 489/409],
  <x^3 - x + 2, x^3 - 2/3*x^2 + 1/3*x - 1/3, -x^2 + 2*x>,
  [ 3, 11, 2 ],
  { 3^2, 5, 7, 11^2, 13, 19, 29 }>,

// no. 116
<-2*x^6 + 2*x^5 - x^4 + 3*x^3 - x^2 - 2*x + 3, 3, [],
  [x^2 - 1/2,
   x^2 - x - 1/3,
   x^2 + 2557/1243*x + 1607/1243],
  <x^3 - x^2 + 1/2*x + 1/2, x^3 + 2*x - 2, 2*x^2 - x + 1>,
  [ 2, 2, 3, 5, 5 ],
  { 2^3, 3^2, 5^3, 7, 53, 61, 67, 103, 3041 }>,

// no. 117
<2*x^6 - x^5 + x^4 + x^3 - 3*x^2 - x - 3, 3, [],
  [x^2 - x + 1,
   x^2 + x + 3,
   x^2 - 1769/3337*x + 4737/3337],
  <x^3 - 12*x^2 + 4*x - 1, x^3 + 23/2*x^2 + 13/2*x + 3/2, 16*x^2 + 2*x>,
  [ 2, 2, 3, 11, 7, 19, 5, 3, 13, 23 ],
  { 2^2, 3^3, 5^2, 7^2, 11^2, 13^2, 17, 19^2, 31, 37, 41, 61, 89, 97, 101, 
    109, 127, 227, 263, 271, 443, 487, 631, 1117, 1163, 1709, 2003, 2819, 3581, 
    4027, 4133, 4507, 4801 }>,

// no. 118
<-2*x^6 - 2*x^5 - 3*x^4 - 3*x^3 + x^2 - 3*x + 2, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 - 33/73*x + 9/73],
  <x^3 + x^2 + 7*x + 2, x^3 - x + 1/2, -3*x^2 + 2>,
  [ 2, 3, 3, 2, 5, 7, 13, 5, 23, 19, 11 ],
  { 2^2, 3^3, 5^3, 7^2, 13^2, 17, 19^2, 31, 37, 41, 43, 47, 53, 59, 89, 101, 
    173, 197, 331, 373, 379, 443, 457, 509, 547, 643, 661 }>,

// no. 119
<-3*x^6 + 2*x^5 + 2*x^4 + 3*x^3 - x^2 + x - 2, 3, [],
  [x^2 + 1,
   x^2 - x + 1/2,
   x^2 + 9/91*x + 1361/2366],
  <x^3 + x^2 + 1/2*x - 3, x^3 - 5/3*x^2 + 5/6*x - 1/3, x^2 - 7/2*x + 1>,
  [ 11, 3, 2, 3, 2, 2, 2, 2, 7, 5, 17 ],
  { 2^5, 3^3, 5^2, 7^2, 11^2, 13, 17^2, 23, 29, 37, 41, 47, 59, 61, 71, 73, 
    79, 83, 89, 101, 109, 113, 179, 317, 349, 389, 467, 631, 1039, 1103, 1151, 
    1171, 1451, 1471, 1657 }>,

// no. 120
<-3*x^6 - x^5 + x^4 + 3*x^3 - x^2 + x + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 1/3*x - 1/3,
   x^2 + 1095/937*x + 1089/937],
  <x^3 - 5/3*x^2 + 1/3*x + 2/3, x^3 + 2*x^2 + 4*x - 1, -2*x^2 + 4*x + 1>,
  [],
  { 2^2 }>,

// no. 121
<-x^6 - 2*x^5 - x^3 + 2*x^2 - 3*x - 2, 3, [],
  [x^2 + 1,
   x^2 + x + 2,
   x^2 - 99/65*x + 38/65],
  <x^3 + 3*x^2 + 2*x + 1, x^3 - x^2 + 5*x + 3, 2*x^2 + 4*x + 1>,
  [ 2, 2, 2, 2, 3, 7, 11, 17 ],
  { 2^4, 3^2, 7^2, 11^2, 17^2, 23, 107, 139, 239, 269, 367, 599, 661, 761, 
    853 }>,

// no. 122
<2*x^6 + 3*x^5 + 2*x^3 - 2*x^2 + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 1/2*x + 1/2,
   x^2 - 703/898*x - 827/898],
  <x^3 + 3/2*x^2 - 3/2*x - 3/2, x^3 + x - 1, x^2 + 2*x>,
  [ 2, 2, 3, 5 ],
  { 2, 3, 5^2, 13, 101, 109 }>,

// no. 123
<2*x^6 - 2*x^5 - 3*x^4 + 3*x^3 - 3*x^2 - 3*x - 3, 3, [],
  [x^2 - 3*x - 7,
   x^2 + 3/7,
   x^2 + 20/49*x + 79/343],
  <x^3 + 4*x^2 + 3*x + 1, x^3 - 5*x^2 + 3*x - 3/2, 5*x^2 + x>,
  [],
  { 7 }>,

// no. 124
<3*x^6 + 3*x^5 + x^4 + 2*x^3 + 2*x^2 + 3*x - 3, 3, [],
  [x^2 - x + 1,
   x^2 + 1/2*x + 2,
   x^2 + 147/61*x + 93/61],
  <x^3 - 2*x^2 - 3*x - 3, x^3 + 3*x^2 + x + 4/3, 5*x^2 + 4*x + 3>,
  [ 2 ],
  { 2, 3, 11 }>,

// no. 125
<2*x^6 - 2*x^5 - 2*x^4 + 2*x^3 - 2*x^2 + x - 3, 3, [],
  [x^2 - x + 1/2,
   x^2 - x - 4,
   x^2 - 89/479*x - 1087/479],
  <x^3 + 2*x^2 + 1/2*x + 1/2, x^3 - 3*x^2 + 4*x - 3, -x^2 + 3*x>,
  [ 3, 2, 2, 2, 17, 5, 2, 2, 2, 3, 3, 5, 7, 11, 19 ],
  { 2^6, 3^4, 5^3, 7^2, 11^2, 17^2, 37, 43, 239, 269, 277, 311, 313, 367, 461, 
    509, 659, 661, 883, 947, 1889, 1901, 2099, 2659, 2693, 2857, 3499, 3529, 
    3533, 3539, 4129, 4133, 4159, 4871 }>,

// no. 126
<3*x^6 - x^5 + 3*x^4 + 2*x^3 - x - 3, 3, [],
  [x^2 + 1,
   x^2 + x + 1,
   x^2 - 10994135/15491857*x + 7460437/15491857],
  <x^3 + 3/2*x^2 - 37/2*x - 39/2, x^3 - 11/6*x^2 - 11/6*x + 19/6, 17/2*x^2 - 
5/2*x - 27/2>,
  [ 2, 2, 3, 5, 19, 7, 13, 23 ],
  { 2^2, 3^2, 5^2, 7^2, 13^2, 19^2, 29, 31, 43, 53, 83, 89, 107, 109, 137, 
    181, 191, 271, 337, 383, 733, 787, 811, 953 }>,

// no. 127
<-2*x^6 + 2*x^5 - 3*x^4 - 3*x^3 + 2*x + 3, 3, [],
  [x^2 - 1/3*x + 1,
   x^2 + 4/3*x + 1/2,
   x^2 - 14/233*x + 467/466],
  <x^3 - x^2 + 2*x + 3, x^3 - 1/2, x^2 + x>,
  [ 2, 2, 2, 3, 5, 3, 13 ],
  { 2^3, 3^3, 5^2, 7, 13^2, 23, 37, 67, 107, 149, 167, 197, 223, 271, 349, 
    1217, 3313 }>,

// no. 128
<2*x^6 + 2*x^5 - 3*x^3 - 2*x^2 + x - 2, 3, [],
  [x^2 - 3/2,
   x^2 - x - 3,
   x^2 + 446/193*x + 339/193],
  <x^3 + 2*x^2 + 7*x + 9, x^3 - x^2 - 7*x - 19/2, -2*x^2 - 10*x - 13>,
  [ 2, 3, 5, 3, 11 ],
  { 2, 3^3, 5^2, 7, 11^2, 61, 211, 271, 17^2, 557, 787 }>,

// no. 129
<-2*x^6 + 3*x^5 + 3*x^3 + 2*x^2 + 2*x + 3, 3, [],
  [x^2 - x + 1,
   x^2 + 2/3*x + 2/3,
   x^2 - 31/267*x - 131/801],
  <x^3 + 2*x + 2, x^3 - 3/2*x^2 - 1/2, -2*x^2 + 1>,
  [ 2, 2 ],
  { 2^2, 11, 47 }>,

// no. 130
<-2*x^6 - 2*x^5 + x^4 + 3*x^3 + x^2 + 3*x - 2, 3, [],
  [x^2 + 1,
   x^2 + 1/6,
   x^2 + 1/9*x + 1/36],
  <x^3 + x^2 + x - 1, x^3 + 1/2*x - 1, 2*x^2>,
  [ 2 ],
  { 2, 5 }>,

// no. 131
<-3*x^6 + 2*x^5 - x^4 - 3*x^3 - 3*x - 2, 3, [],
  [x^2 + 1,
   x^2 - x + 1,
   x^2 + 184/457*x + 129/457],
  <x^3 - x^2 + 1, x^3 + 1/3*x^2 + x + 1, -x^2 + 1>,
  [ 2, 2, 2, 3, 7, 2, 13, 19, 3, 3, 17 ],
  { 2^4, 3^4, 7^2, 11, 13^2, 17^2, 19^2, 43, 53, 59, 79, 103, 113, 127, 
    137, 197, 229, 263, 431, 443, 467, 691, 1303, 1933 }>,

// no. 132
<3*x^6 + 3*x^5 - x^4 + 2*x^3 - 2*x^2 - x - 2, 3, [],
  [x^2 + 1,
   x^2 - 3,
   x^2 + 8672/18959*x + 3603/18959],
  <x^3 - x^2 + 1/4*x - 1/2, x^3 + 2*x^2 + 4/3*x + 4/3, 1/2*x^2 + 2*x>,
  [],
  { 2^2 }>,

// no. 133
<2*x^6 + 2*x^5 + 2*x^4 - 3*x^3 + 2*x^2 - x - 1, 3, [],
  [x^2 + 1,
   x^2 - x - 1,
   x^2 + 716/553*x + 1445/553],
  <x^3 + 9*x^2 - 3*x - 10, x^3 - 8*x^2 + 4*x + 17/2, -12*x^2 + 5*x + 13>,
  [ 2, 3 ],
  { 2, 3^2, 7, 11, 181 }>,

// no. 134
<-2*x^6 - 2*x^4 - 3*x^3 + 3*x^2 - 2*x + 2, 3, [],
  [x^2 - x + 1,
   x^2 + 2/3,
   x^2 - 8/11*x + 16/33],
  <x^3 + 2/3*x^2 + 2/3*x - 1/9, x^3 - 2/3*x^2 + 5/3*x - 7/18, -4/3*x^2 + x - 
13/9>,
  [],
  { 3^2 }>,

// no. 135
<-x^6 + 2*x^5 + 3*x^4 + 3*x^3 + x^2 + 3*x + 3, 3, [],
  [x^2 - x + 1,
   x^2 - 1/2,
   x^2 + 162/173*x + 23/173],
  <x^3 - 3*x - 6, x^3 - 2*x^2 + 1/4*x + 1/2, -1/2*x^2 - 7/2*x>,
  [ 2, 2, 2, 5, 13 ],
  { 2^3, 3, 7, 19, 29, 31, 67, 79, 157, 443 }>,

// no. 136
<-2*x^6 - 3*x^5 - 3*x^3 - 2*x^2 - 3*x + 3, 3, [],
  [x^2 - x + 2,
   x^2 + 7/2*x + 13/2,
   x^2 + 139/66*x + 193/99],
  <x^3 - x^2 + 1, x^3 + 5/2*x^2 + 9/2*x - 1, -2*x^2 + 3*x + 1>,
  [ 2, 2 ],
  { 2^2, 3, 5 }>,

// no. 137
<3*x^6 + 3*x^5 + 3*x^4 + 2*x^3 + x^2 - 3*x + 2, 3, [],
  [x^2 - x + 1,
   x^2 + 2*x - 1,
   x^2 + 6565/2258*x - 8897/1129],
  <x^3 + x^2 + 2/3*x - 1/3, x^3 - x - 2, 2*x^2 + 3*x>,
  [ 3, 2, 2, 2, 2 ],
  { 2^4, 3, 5, 11, 37, 107, 193, 211 }>,

// no. 138
<3*x^6 + x^5 + 3*x^4 + 2*x^3 + 3*x + 3, 3, [],
  [x^2 - x - 1,
   x^2 + 3/2*x + 1,
   x^2 + 66/241*x - 1551/3133],
  <x^3 + 3/2*x^2 + 3/2, x^3 - 7/6*x^2 + 2/3*x + 2/3, 5/2*x^2 - 3/2*x>,
  [ 17, 2, 41, 2, 2, 3, 3, 7, 5, 11, 5, 13 ],
  { 2^3, 3^3, 5^3, 7^2, 11^2, 13^2, 17^2, 19, 37, 47, 59, 109, 157, 211, 
    223, 229, 233, 317, 359, 461, 619, 661, 739, 751, 919, 1031, 1499, 1523, 
    1613, 2957, 3163, 3709, 4493 }>,

// no. 139
<-3*x^6 + 3*x^5 - x^4 + 3*x^3 + x + 3, 3, [],
  [x^2 - x + 1,
   x^2 + x + 1,
   x^2 - 9317/154117*x + 58657/154117],
  <x^3 + x^2 + 2*x + 1, x^3 - 2*x^2 + 5/3*x - 1, -2*x^2 + x>,
  [ 2, 2, 3, 3, 5, 19, 5, 17 ],
  { 2^2, 3^3, 5^3, 13, 17^2, 19^2, 23, 37, 41, 43, 53, 59, 73, 89, 107, 151, 
    223, 449 }>,

// no. 140
<3*x^6 + 2*x^5 - 3*x^4 - x^3 - 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 1,
   x^2 - 19594/2399*x + 43939/4798],
  <x^3 + 5/3*x^2 + 1/3*x + 1/3, x^3 - x^2 - 3, x^2 + 4*x>,
  [ 2, 2, 2, 3, 7, 2, 5 ],
  { 2^4, 3^2, 5^2, 7^2, 13, 23, 29, 41, 59, 191, 257, 487 }>,

// no. 141
<-2*x^6 + 2*x^4 - 3*x^3 + 2*x^2 - 3*x - 3, 3, [],
  [x^2 + 1,
   x^2 - x + 4/3,
   x^2 - 8352/1193*x + 40053/1193],
  <x^3 + x^2 + x + 1/2, x^3 - x^2 + x + 7, 2*x^2 + 3*x + 2>,
  [ 2, 2, 2, 5, 3 ],
  { 2^3, 3^2, 5^2, 11, 19, 37, 43, 59, 61, 79, 137 }>,

// no. 142
<-x^6 - 2*x^5 + 3*x^4 + 3*x^3 + x^2 - 3*x - 3, 3, [],
  [x^2 + x + 1,
   x^2 + 1,
   x^2 - 2790/1313*x + 9091/2626],
  <x^3 + 3*x^2 + x + 1, x^3 - x^2 + 3, x^2 + 3*x>,
  [ 2, 2, 2, 2, 2, 3, 2, 19, 7, 5, 17 ],
  { 2^6, 3^2, 7^2, 19^2, 29, 37, 43, 47, 53, 59, 101, 109, 113, 131, 139, 173, 
    239, 311, 523, 577, 673, 1553, 1627, 1693 }>,

// no. 143
<-2*x^6 - x^4 + 3*x^3 + 2*x^2 + 3*x - 3, 3, [],
  [x^2 + 1,
   x^2 + 273/163*x + 417/326,
   x^2 - 708/449*x + 1281/449],
  <x^3 - x^2 + 3/2*x - 2, x^3 + x^2 - 1, 1>,
  [ 2, 2, 2, 5, 3, 3, 7, 11 ],
  { 2^3, 3^3, 5^2, 7^2, 11^2, 23, 31, 53, 59, 67, 137, 191, 197, 223, 257, 269, 
    461, 523, 619, 967 }>,

// no. 144
<3*x^6 - x^5 + x^4 - 2*x^3 + x^2 - 3*x + 3, 3, [],
  [x^2 + 1,
   x^2 - x - 1,
   x^2 - 413329/373174*x + 37861/186587],
  <x^3 - x^2 + 1/4*x - 1/2, x^3 + 2/3*x^2 - 4/3, -3/2*x^2 - x + 1>,
  [ 2, 3 ],
  { 3, 7, 19 }>,

// no. 145
<2*x^6 + 2*x^5 + 2*x^4 + x^3 + 2*x - 2, 3, [],
  [x^2 + x - 1,
   x^2 - 2,
   x^2 - 16/73*x - 306/73],
  <x^3 + 4*x^2 + x - 9, x^3 - 3*x^2 - 1/2*x + 19/2, 5*x^2 + x - 13>,
  [ 2, 3, 3, 3, 5, 13, 19, 7, 23 ],
  { 2, 3^4, 5^2, 7^2, 11, 13^2, 19^2, 23, 43, 53, 61, 67, 71, 103, 223, 
    463, 479, 733, 883, 1409, 1459, 1733, 1871, 1931 }>,

// no. 146
<-2*x^6 + 2*x^4 + x^3 - x^2 + 3*x - 1, 3, [],
  [x^2 - x + 1,
   x^2 - 20/17*x + 5/17,
   x^2 - 4*x + 5],
  <x^3 - 7/9*x^2 + 7/9*x - 10/9, x^3 + 7/9*x^2 - 7/9*x - 25/18, 8/9*x^2 - 8/9*x 
- 13/9>,
  [ 2, 2, 2, 3, 7, 3, 5, 5, 11 ],
  { 2^3, 3^3, 5^3, 11^2, 23, 47, 73, 83, 89, 109, 173, 179, 193, 269, 313, 367,
    433, 719, 811, 977, 1229 }>,

// no. 147
<-x^6 - 3*x^5 + 3*x^3 + 2*x^2 - 2*x + 3, 3, [],
  [x^2 + 2*x - 2,
   x^2 + 7/5*x - 13/5,
   x^2 + 6/5*x - 9/5],
  <x^3 + 2*x^2 + x + 3, x^3 + x^2 + x - 1, 2*x^2 + 2*x>,
  [],
  { 5 }>,

// no. 148
<-3*x^6 + x^5 - 3*x^4 - 2*x^3 - 3*x^2 + 3*x + 3, 3, [],
  [x^2 - x + 2,
   x^2 - 1/4*x - 1/2,
   x^2 - 6209/33841*x - 15502/33841],
  <x^3 + 6*x + 3, x^3 - 1/3*x^2 + 1/3*x - 1/3, 4*x^2>,
  [ 2, 2 ],
  { 2^2, 3 }>,

// no. 149
<3*x^6 + 2*x^5 - x^3 + 2*x^2 + 3*x - 2, 3, [],
  [x^2 + x - 1,
   x^2 + 2/3*x - 1,
   x^2 + 995/311*x - 1489/622],
  <x^3 - 3/4*x + 1/2, x^3 + 2/3*x^2 - 4/3, 3/2*x^2 + x>,
  [ 2, 2, 2, 3, 7, 5, 29, 13, 5 ],
  { 2^3, 3^2, 5^3, 7^2, 13^2, 17, 19, 73, 109, 139, 151, 193, 227, 263, 
    307, 359, 397, 431, 443, 461, 823, 881 }>,

// no. 150
<2*x^6 - 2*x^5 + 3*x^4 - x^3 + 2*x^2 + 2*x - 3, 3, [],
  [x^2 - x + 2,
   x^2 - 2*x + 2,
   x^2 - 34/7*x + 258/49],
  <x^3 - 5/7*x^2 - 4/7*x - 3, x^3 - 2/7*x^2 - 3/7*x + 1/2, -15/7*x^2 - 5/7*x>,
  [ 2, 3, 3, 17, 11, 2, 3, 7 ],
  { 2^2, 3^4, 5, 7^2, 11^2, 13, 17^2, 47, 53, 73, 83, 109, 191, 269, 353, 
    367, 433, 521, 601, 1223, 1667 }>,

// no. 151
<-2*x^6 + 2*x^5 + 2*x^4 - 3*x^3 + 2*x^2 + 3*x + 3, 3, [],
  [x^2 - x - 1,
   x^2 - 3/2,
   x^2 + 935/13201*x - 3337/13201],
  <x^3 - x^2 + 3/2, x^3 - x - 1, 2*x>,
  [ 2, 3, 5, 7, 3, 2, 3, 17, 11 ],
  { 2^2, 3^4, 5^2, 7^2, 13, 17^2, 23, 29, 31, 53, 67, 79, 89, 103, 131, 227, 
    373, 659, 743, 751, 821, 827, 953 }>,

// no. 152
<-2*x^6 - 3*x^5 + x^4 - 3*x^3 - 2, 3, [],
  [x^2 + 1,
   x^2 + 2*x + 2,
   x^2 - 112/51*x + 209/153],
  <x^3 + 1/3*x^2 + x + 1, x^3 + 7/6*x^2 - x + 1, 4/3*x^2 + x>,
  [ 2, 2, 2, 7, 17, 5, 3, 3, 5, 11, 41 ],
  { 2^3, 3^3, 5^3, 7^2, 13, 17^2, 23, 31, 71, 97, 109, 151, 157, 281, 347, 
    359, 419, 499, 631, 643, 701, 1201, 1229 }>

];
