// Rank4Data is a list of entries
//  <f, rank, tors, bas, deg3, run, primes>, where
// * f is the polynomial defining the curve  C: y^2 = f(x)
// * rank is the Mordell-Weil rank of J(Q), where J is the Jacobian of C
// * tors is the sequence of invariants of the torsion subgroup of J
// * bas is a sequence of polynomials of degree 2 such that
//     [Rep(Points(J, a, 2)) : a in bas]
//   is a sequence of generators of J(Q) modulo torsion
// * deg3 = <a, c, b> specifies a rational degree-3 divisor on C:
//     f(x) - b(x)^2 = l*a(x)*c(x) ,
//   the divisor is given by  a(x) = 0, y = b(x)
// * run = [q1, q2, ..., qn] is a sequence of primes such that
//     B0 = 1, B1 = q1, B2 = q1*q2, ..., Bn = q1*q2*...*qn = B
//   is a suitable sequence for the successive computation of bounds
//   on the image of C(Q) in J(Q)/Bj*J(Q), such that the last bound is empty
// * primes = {p1, p2, ..., pm} is a set of primes or prime powers such that
//   the information coming from J(Z/pj*Z) is sufficient to get the empty
//   bound with B as above

_<x> := PolynomialRing(Rationals());

Rank4Data := [
// no. 1
<-3*x^6 + 3*x^5 + 2*x^4 + 3*x^3 + 2*x + 3, 4, [],
  [x^2 + x + 1,
   x^2 - 1/3,
   x^2 - x + 3/4,
   x^2 - 368/169*x + 193/169], 
  <x^3 - 3/4*x^2 + 3/2*x - 11/4, x^3 - 1/4*x^2 - 11/6*x - 11/12, -5/4*x^2 + 2*x + 13/4>,
  [ 2, 17, 11, 2, 3, 5, 2, 2, 3, 2, 2, 5, 3, 7, 7, 13 ],
  { 2^7, 3^4, 5^3, 7^2, 11^2, 17^2, 19^2, 23, 61, 73, 79, 97, 107, 109, 149, 
    199, 223, 227, 241, 337, 397, 421, 569, 601, 619, 797, 1049, 1123, 1217, 
    1259, 1447, 1511, 1831, 1879, 2297, 3581, 4801, 4919, 5479, 5641, 7699, 
    7723, 7793 }>,

// no. 2
<-2*x^6 + 2*x^4 - 3*x^3 - 2*x^2 - 3*x - 2, 4, [],
  [x^2 + 1,
   x^2 + 4/3*x + 1,
   x^2 + 1/3*x + 1/2,
   x^2 + 5/33*x + 1/11], 
  <x^3 + 2/3*x^2 + 3*x + 3, x^3 - 2/3*x^2 + 1/2, -8/3*x^2 + 1>,
  [ 5, 3, 2, 2, 3, 11, 3, 2, 5, 13 ],
  { 2^8, 3^5, 5^4, 11^3, 13^2, 17^2, 23, 29, 61, 113, 139, 157, 163, 173, 233, 
    281, 347, 601, 887, 1231, 1427, 1493, 1873, 1997, 2797, 3691, 4327, 5659, 
    6977, 9941 }>

];
