// DescentObstruction.m
//
// Produced by Nils Bruin and Michael Stoll
//
// Contains all isomorphism classes from AllCurves that have a 2-Cover descent
// obstruction to rational points (i.e., S^(2) (C/Q) is empty). The data is
// given as pairs
// <f,{p1,...,pr}>
// such that, when computing S^(2) (C/Q) for C: y^2=f(x),
// consecutive local considerations at p1,...,pr each rule out at least one
// 2-cover of C that was not ruled out before.
//
// p=0 is used to indicate that real information makes a contribution.
//
// In particular, <f,{}> indicates that C: y^2=f(x) can already be shown to
// have no points by just considering the norms of possible
// elements in S^(2)(C/Q).

_<x>:=PolynomialRing(Rationals());
DescentObstruction:=[
<2*x^6+2*x^5+3*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x^3-3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-3*x^2+3*x-3,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+2*x^2-3*x+2,{}>,
<-x^6+2*x^5+x^4+3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3+3*x^2-3*x+3,{2}>,
<-2*x^6+x^5+x^4+3*x^3+3*x^2+3*x+3,{2,3}>,
<-x^6+3*x^5+x^4+3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2-3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3-2*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-2*x-1,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-2,{2}>,
<2*x^6-x^5+3*x^3+3*x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2+3*x-3,{2,5}>,
<-3*x^6-3*x^5-3*x^4-3*x^3+x+3,{}>,
<3*x^6+3*x^5+3*x^4+3*x^3-x-3,{}>,
<3*x^6+3*x^5+3*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x^2+3*x-3,{2}>,
<2*x^6+x^5+3*x^3-3*x^2+3*x-3,{}>,
<2*x^6-3*x^5+x^4-3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x-2,{}>,
<3*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x^3+x^2+3*x+3,{2}>,
<-3*x^6-x^5-3*x^3+3*x^2-3*x+3,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-3*x^3+x^2+x+3,{}>,
<-3*x^6+x^5-x^4-3*x^3+3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5-3*x^4+3*x^3-3*x^2-2*x+2,{}>,
<-2*x^6+2*x^5-x^4-3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-x^2-x-2,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x-3,{2}>,
<3*x^6+x^5+x^4+3*x^3-3*x^2+3*x-3,{2}>,
<-x^6-3*x^5+x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-x^2-1,{}>,
<3*x^6-3*x^5+3*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-x^6+x^5-2*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4+3*x^3-2*x^2-x-3,{2,3}>,
<-x^6+3*x^5-2*x^4+3*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-2*x^2+2*x-1,{2,149}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+3*x^2+3*x+3,{}>,
<3*x^6+2*x^5+2*x^4-3*x^3-3*x^2-3*x-3,{}>,
<-x^6-x^5+3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+3*x^2+3*x+3,{}>,
<2*x^6-x^5+3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-3*x^2+x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2-3*x-3,{}>,
<3*x^6+3*x^5-3*x^4-2*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+3*x^2-3*x+3,{2,3}>,
<2*x^6+2*x^4+2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4+2*x^3-3*x^2+3*x-3,{}>,
<3*x^6-3*x^5+3*x^4-3*x^3-2*x^2-x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+2*x^2+x+2,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-2*x^2-3,{2}>,
<-x^6+x^5+2*x^4-2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-3*x^2+3*x-3,{}>,
<-2*x^6+x^5+2*x^4-2*x^3+3*x^2-3*x+3,{}>,
<3*x^6-3*x^5+3*x^4-2*x^3+x^2-2*x-1,{}>,
<2*x^6-2*x^5-x^4-2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5+3*x^4+3*x^3+2*x^2+3*x-2,{2,3}>,
<-2*x^6+2*x^5+x^4+2*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3+3*x^2-3*x+3,{2}>,
<-x^6+x^5+x^4-2*x^3+3*x^2-3*x+3,{2}>,
<2*x^6-x^5-x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5+3*x^4+2*x^3+x^2-2*x+3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5+x^4+2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6+2*x^5-x^4-2*x^3-3*x^2-3*x-3,{2,3,7}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2+x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+3*x^2-1,{}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^4+2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+2*x^2+3*x-3,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2-x-2,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2-x-3,{2,3}>,
<2*x^6+3*x^5-x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-2*x^3+x^2-3*x-2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-x^2+3*x+2,{2,3}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+x^4-2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+3*x^5+2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3-x^2+2*x-1,{2,3}>,
<3*x^6-3*x^5+3*x^4-2*x^3-x-2,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+x+3,{2,3}>,
<3*x^6+2*x^3-3*x^2+3*x-3,{}>,
<3*x^6-3*x^5+3*x^4-2*x^3-3,{}>,
<3*x^6+2*x^5-2*x^3+3*x^2-3*x+3,{}>,
<3*x^6-3*x^5+2*x^3+3*x^2+3*x+3,{2}>,
<2*x^6-3*x^5+2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3-3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+3*x-2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x+3,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3+3*x^2-3*x+3,{2}>,
<2*x^6+x^5+x^4+2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+x^2-x-2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^3+3*x^2+3*x+3,{2,3,5}>,
<3*x^6+x^4+2*x^3+3*x^2+3*x+3,{2,3,5}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+x^2+x+2,{2}>,
<-3*x^6+x^5-x^4+2*x^3+3*x^2+3*x+3,{2,3}>,
<2*x^6-x^4+2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+x^2+2,{2}>,
<-2*x^6-x^4-2*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+x^2+3,{2,3}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4+2*x^3-x^2-x-2,{}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+x^2+x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-x^2+x-3,{2,3}>,
<-x^6-2*x^5-2*x^3+3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-2*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x-2,{2}>,
<3*x^6+x^5+2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-2*x^2+x-2,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x^2-3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+x+3,{}>,
<2*x^6-x^5+2*x^4+2*x^3-3*x^2+3*x-3,{2,3}>,
<-2*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+2*x^2+x+3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3-2*x^2-x-3,{}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+2*x^2+3*x-1,{2,3}>,
<3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+3*x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2-1,{2}>,
<3*x^6+3*x^4-2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2-3,{2}>,
<-x^6+x^5-3*x^4-2*x^3+3*x^2-3*x+3,{2}>,
<2*x^6+x^5+x^4-3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-x^4+3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3+3*x^2-3*x+3,{}>,
<3*x^6+3*x^5+3*x^4+x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3+3*x^2-x-1,{2,3}>,
<-3*x^6+3*x^4-x^3+3*x^2-3*x+3,{2}>,
<3*x^6+x^5-3*x^4-x^3-3*x^2-3*x-3,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-3*x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3+3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3-3*x^2-3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-x^3+3*x^2+3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+3*x^2+3*x+3,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3+3*x^2-x-2,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3+2*x^2+2*x-3,{2}>,
<-x^6+x^5+2*x^4+x^3+3*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-3*x^4+x^3-2*x^2+x+2,{2}>,
<2*x^6+2*x^4-x^3+3*x^2-3*x+3,{2}>,
<-x^6+2*x^4+x^3+3*x^2+3*x+3,{2}>,
<2*x^6-2*x^4+x^3-3*x^2+3*x-3,{}>,
<3*x^6-3*x^5+3*x^4-x^3+2*x^2-2,{}>,
<3*x^6-2*x^4+x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3+2*x^2+x+3,{2,3}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3-2*x^2+2*x+2,{2,7}>,
<-x^6+3*x^5+2*x^4-x^3+3*x^2-3*x+3,{2,3}>,
<2*x^6-3*x^5-2*x^4+x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-3*x^2+3*x-3,{2,3}>,
<-x^6+3*x^5-x^4+x^3-3*x^2+3*x-3,{2}>,
<-x^6-3*x^5+x^4-x^3+3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5-3*x^4+x^3-3*x^2+x+3,{2,3,11}>,
<3*x^6-3*x^5+3*x^4-x^3+3*x^2+2,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3-3*x^2+2,{}>,
<3*x^6+3*x^5+3*x^4+x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+3*x^4-x^3+3*x^2-3*x+3,{}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3+x^2+2*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3-3*x^2+3,{2}>,
<3*x^6+x^5+x^4+x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3+x^2+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3+x^2+2,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-x^2-2*x-3,{2}>,
<-x^6+x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x^2+3*x+3,{}>,
<2*x^6-x^4-x^3-3*x^2-3*x-3,{}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+x^2+3*x-1,{2}>,
<2*x^6+3*x^5+x^4-2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+x^5+x^4-x^3+3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-3*x^4+x^3-x^2-x+2,{}>,
<3*x^6-3*x^5+3*x^4-x^3+x^2+x-2,{}>,
<3*x^6+3*x^5+3*x^4+x^3+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3+2*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x-2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-2*x+2,{2,3,173}>,
<3*x^6+2*x^5+x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5-x^3+3*x^2-3*x+3,{}>,
<3*x^6-x^5-x^3-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-3*x^2-x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-3*x+3,{}>,
<-x^6-2*x^5-3*x^4+3*x^3+3*x^2+3*x+3,{}>,
<-3*x^6+3*x^5-3*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-3*x^6-x^5-x^3+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2+3*x+2,{}>,
<3*x^6+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-2*x+2,{2}>,
<2*x^6+2*x^5-x^3-3*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5-x^3+3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-x^2+2*x-1,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3+x^2-2*x+2,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-x^2+2*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-x^2+x+3,{2,3}>,
<2*x^6+x^5+x^4+x^3-3*x^2+3*x-3,{2}>,
<-2*x^6+x^5-x^4+x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3+x^2-x+3,{2,3,5}>,
<-3*x^6+x^5-x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^3+x^2+2,{2,3}>,
<-2*x^6+x^4+3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2+3*x+3,{}>,
<3*x^6-3*x^5+3*x^4-3*x^3+x^2+2*x+2,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-x^2-2,{2}>,
<3*x^6+x^4-x^3-3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2+x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2+2*x+3,{}>,
<-x^6+2*x^5-x^4-x^3+3*x^2-3*x+3,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2+3*x+3,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-3*x^2+3*x-3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3-x^2+3*x-2,{}>,
<-x^6-3*x^5+3*x^4+2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-3*x^2+3*x-2,{}>,
<2*x^6-3*x^5+x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2-3*x-2,{}>,
<-3*x^6+3*x^5-3*x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2+3*x-1,{2}>,
<2*x^6-3*x^5+x^4+x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3+x^2-3*x+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3-3*x^2-3*x-3,{}>,
<-3*x^6-3*x^5-3*x^4-x^3+2*x^2-x+2,{2,3}>,
<2*x^6-3*x^5+2*x^4-x^3-3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x^2-x-2,{2,5,7}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x^2-x-3,{2,3,11}>,
<3*x^6-2*x^4-x^3+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-2*x^2+2,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4+x^3-3*x^2+3*x-3,{2}>,
<-2*x^6-2*x^4-x^3+3*x^2-3*x+3,{2}>,
<3*x^6+2*x^4+x^3-3*x^2+3*x-3,{2}>,
<-3*x^6-2*x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-2*x^2-x-2,{2}>,
<3*x^6-x^5+2*x^4+x^3-3*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5-3*x^4-x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x^2+3*x+2,{}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2+2*x-2,{2,3,173}>,
<-x^6+3*x^5+2*x^4-x^3-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3+2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3+3*x^2+3*x-1,{2,11}>,
<3*x^6+3*x^5+3*x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-3*x^2-3*x-3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-3*x^2-3*x-3,{2,3}>,
<3*x^6-2*x^5-x^4+x^3-3*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3+x^2+3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3-3*x^2+3*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x^2-x-2,{2}>,
<-3*x^6+3*x^5+x^4-x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^3+3*x^2+x+3,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x-1,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3-3*x+2,{}>,
<3*x^6-3*x^4-x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3+3*x^2+2*x+3,{2,3,5,13}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x^2-1,{}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x-2,{}>,
<-3*x^6+2*x^5-3*x^4-x^3+3*x^2-3*x+3,{2}>,
<2*x^6+3*x^4-x^3-3*x^2-3*x-3,{2}>,
<2*x^6-x^5-3*x^4-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^2-x-2,{2}>,
<3*x^6+x^5-3*x^4-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-3*x^2-2,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^2+x-3,{2}>,
<3*x^6-3*x^4-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^2-2*x-2,{2}>,
<3*x^6+x^5+3*x^4+3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^2-3*x-3,{2,5}>,
<-3*x^6-3*x^5-3*x^4-x^3+3*x^2+3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^2+2*x-3,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^2+3*x-3,{}>,
<-3*x^6-3*x^5-3*x^4-3*x^2+x+2,{2}>,
<3*x^6-x^5+2*x^4+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+3*x^2+2*x+3,{}>,
<2*x^6+x^5-2*x^4-3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4-x^3+3*x^2+2*x-1,{2}>,
<-2*x^6+x^5+2*x^4+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^2-x+2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^2+x+3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^2-x-3,{}>,
<3*x^6+3*x^5+3*x^4+2*x^2-2*x+3,{}>,
<3*x^6+3*x^5+3*x^4+3*x^2+2*x-1,{2,227}>,
<2*x^6-2*x^5-3*x^4-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^2-2*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4+x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^2-x+2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^2+3*x-1,{2}>,
<3*x^6+3*x^5+3*x^4+x^2+3*x-2,{2}>,
<3*x^6+3*x^5+3*x^4+x^2+3*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^2-3*x+3,{2,3,5}>,
<3*x^6-3*x^5+3*x^4+x^2-2,{2}>,
<3*x^6+3*x^5+3*x^4+x^2-x+3,{2,3}>,
<3*x^6-x^5+x^4+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4+x^2-x+2,{2}>,
<-x^6-x^5+x^4+3*x^2-3*x+3,{2}>,
<-2*x^6+x^5+x^4+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+x^3-2*x^2+2*x-2,{2}>,
<3*x^6+x^5-2*x^4+x^3+3*x^2+3*x+3,{2,3}>,
<-x^6+x^5-2*x^4+x^3+3*x^2+3*x+3,{2,5}>,
<-x^6-3*x^5+x^4+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^2+3*x+3,{}>,
<-2*x^6+3*x^5+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+3*x+3,{2}>,
<3*x^6+x^5+3*x^2-3*x+3,{2}>,
<2*x^6-x^5-3*x^2+3*x-3,{2}>,
<3*x^6-x^5-3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+3*x^2+3*x+3,{2}>,
<2*x^6+2*x^5-3*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5+3*x^2-3*x+3,{2}>,
<-x^6+3*x^5-x^4+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^2-3*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-3*x^6+3*x^5-3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6+2*x^5+x^4-3*x^2-3*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^2-3*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^2+2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^2+3*x+3,{}>,
<2*x^6-x^4-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^2-x-1,{2,7}>,
<-3*x^6+3*x^5-3*x^4+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^2+x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^2+3*x+3,{2,3,5}>,
<3*x^6-3*x^5-2*x^4+3*x^2+3*x+3,{2}>,
<-x^6+3*x^5+2*x^4-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^2+3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^2+3*x-2,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^2+3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4-3*x^2-2*x-1,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^2-3*x+3,{}>,
<-x^6+x^5-3*x^4+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^2+3*x+3,{}>,
<-3*x^6-3*x^5-3*x^4+3*x^2+3*x-2,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+3*x^2+3*x+3,{}>,
<3*x^6-3*x^5+3*x^4+x^3+3*x^2-3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-3*x^2-3*x-3,{}>,
<3*x^6+3*x^5+3*x^4-x^3+3*x^2+3*x-2,{}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^4-x^3+3*x^2+3*x+3,{2}>,
<2*x^6-3*x^4+x^3-3*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<3*x^6-3*x^4+x^3-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-3*x^2-x+2,{2,3}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-3*x-3,{2}>,
<-2*x^6+x^5+3*x^4+x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<3*x^6+x^5-3*x^4+x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-3*x^4-x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+3*x^2-3*x+3,{}>,
<2*x^6-3*x^5-3*x^4-x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+3*x^2-3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-3*x^2-2*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+x^3+3*x^2-3*x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-3*x+3,{}>,
<2*x^6+3*x^5-2*x^4-x^3-3*x^2+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-3*x^2-3*x-3,{2,5,13,17}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2-2*x-2,{2,5,13}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2-2*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2-x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2+3*x+3,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2-3*x+3,{2}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2+3*x-3,{2,3}>,
<-x^6-x^5+2*x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-2*x^2+x+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3+3*x^2-3*x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-3*x-3,{2,3,5}>,
<-3*x^6+x^5+2*x^4-x^3+3*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4+x^3-2*x^2+2,{2}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2+x+3,{2,5,13}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x^2+3*x-2,{}>,
<3*x^6+3*x^5+3*x^4+2*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^3+x^2-2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+x^2+2*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+x^3+x^2-2*x-1,{2}>,
<2*x^6+2*x^5-x^4-x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^2-2*x+3,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^2-3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^2+3*x-1,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-x^2-x+3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+x^2+2,{}>,
<2*x^6-x^4-x^3-3*x^2+3*x-3,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+x^2-2,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-x^2+3,{2}>,
<-3*x^6+x^4+x^3+3*x^2-3*x+3,{2,3}>,
<2*x^6+x^5+x^4+x^3+3*x^2-3*x+3,{2}>,
<2*x^6-x^5-x^4-x^3-3*x^2+3*x-3,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^2-3*x-3,{2,5}>,
<-2*x^6-2*x^5-x^4+3*x^2-3*x+3,{2}>,
<-2*x^6-x^5-x^4+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4+x^2+x+3,{2}>,
<3*x^6-3*x^5+3*x^4-x^2-x-3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^2-x+3,{2,3,5}>,
<3*x^6-3*x^5+3*x^4+x^3+3,{}>,
<-x^6+2*x^5-x^4+2*x^3+3*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4+2*x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^3+2*x-3,{2,3}>,
<3*x^6-3*x^5-x^3+3*x^2+3*x+3,{}>,
<3*x^6-3*x^5+3*x^4-2*x^2-x+3,{2}>,
<-x^6-3*x^5-x^3-3*x^2+3*x-3,{2,11,331}>,
<2*x^6-3*x^5-x^3-3*x^2+3*x-3,{2}>,
<-x^6+3*x^5+x^4+x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4-x^3+x^2-3*x-3,{}>,
<-x^6+3*x^5-x^3-3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-3*x+3,{}>,
<-3*x^6-3*x^5+x^3+3*x^2-3*x+3,{}>,
<3*x^6-2*x^5+x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-2*x-3,{2}>,
<3*x^6+x^5-x^3+3*x^2+3*x+3,{2,3,29}>,
<-3*x^6-3*x^5-3*x^4+3*x^2+x+3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^2-x-3,{2}>,
<3*x^6+3*x^5+x^4-x^3-3*x^2+3*x-3,{}>,
<-3*x^6-3*x^5-x^4+x^3+3*x^2-3*x+3,{}>,
<2*x^6+2*x^5-x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3+x^2-2*x-1,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-x^2-2*x-2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3+x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^3-x^2-1,{2}>,
<2*x^6+x^4+x^3-3*x^2-3*x-3,{2}>,
<-x^6-x^5-x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-x^4+x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3+x^2+x+2,{2}>,
<3*x^6+x^5+x^4+x^3-3*x^2-3*x-3,{2,3,7}>,
<3*x^6-3*x^5+3*x^4+x^3-x^2-x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^3-x^2+x-3,{2,3}>,
<-x^6+x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-x^2+3,{}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5-x^4+x^3+3*x^2-3*x+3,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+x^2-3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3+2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-x^3-3*x^2+3*x-3,{2,3}>,
<-2*x^6-2*x^5-2*x^4+x^3+3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-3*x^4-x^3+2*x^2+2*x+3,{}>,
<3*x^6+3*x^5+3*x^4-x^3-2*x^2+2*x-3,{}>,
<-2*x^6-x^5-2*x^4+x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3+x^2-3*x-1,{2,5,101}>,
<3*x^6+3*x^5+3*x^4-x^3-x^2-3*x-1,{2,3}>,
<-3*x^6-2*x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^2+2,{2,3,5}>,
<2*x^6+3*x^5+x^4+x^3-3*x^2-3*x-3,{2,5}>,
<3*x^6-x^5-2*x^4-x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-2*x^2+3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3-2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-x^3-3*x^2+3*x-3,{}>,
<3*x^6+3*x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3+2*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3+2*x^2-3*x-1,{2,3}>,
<-3*x^6-3*x^5-3*x^4+x^3+2*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2-3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2-3*x-2,{}>,
<-x^6+2*x^5-2*x^4+x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-x^3-3*x^2+3*x-3,{2,5,7}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x^2-3*x-3,{}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3-2*x^2-2*x-2,{}>,
<-x^6+2*x^5-3*x^4-x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3-3*x^2+3*x-3,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+3*x^2+3*x+3,{2,5}>,
<3*x^6+3*x^5-2*x^4+x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2-2,{2}>,
<3*x^6+3*x^5+3*x^4-x^3-3*x^2-x+3,{2}>,
<-x^6-x^5+3*x^4-x^3-3*x^2+3*x-3,{2,3,5}>,
<3*x^6-3*x^5+3*x^4+x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-3*x^2+3*x-3,{}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x^2-3*x-3,{}>,
<-2*x^6+3*x^5+3*x^4+x^3-3*x^2-3*x-3,{2}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2-3*x-3,{}>,
<3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+3*x^2+3*x+3,{}>,
<3*x^6+x^5-3*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x^2-3*x+2,{}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x^2+3,{2,5}>,
<3*x^6+3*x^5+3*x^4-2*x^3+3*x^2+2,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-3*x^2+3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3+3*x^2-x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x+3,{}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<3*x^6+3*x^5+3*x^4+x^2-2*x+2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4-x^2+2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3+2*x^2+3*x+2,{2}>,
<3*x^6+3*x^5+3*x^4+x^2-2*x-3,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+3*x^2+3*x+3,{}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4-2*x^3+2*x^2+2*x+3,{2,3}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-2*x^2+2*x+2,{2,3}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-2*x^2+2*x+3,{2,3}>,
<2*x^6+x^5-2*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+2*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<-x^6+2*x^4+2*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3+3*x^2+3*x+3,{}>,
<3*x^6+3*x^5+3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3+2*x^2-2*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-x^3-x^2+3*x+3,{2,3,13}>,
<-3*x^6-3*x^5-3*x^4+x^3+x^2-3*x-1,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3-2*x^2-3*x+2,{}>,
<3*x^6+3*x^5+3*x^4-2*x^3+x^2+2*x+2,{2,3}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-x^2-2*x+2,{2}>,
<3*x^6-x^4+2*x^3-3*x^2-3*x-3,{}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2-3,{}>,
<-2*x^6+x^5+x^4+2*x^3+3*x^2-3*x+3,{2,5}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^4+2*x^3+3*x^2-3*x+3,{2,7}>,
<2*x^6+2*x^5-x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+3*x^2-3*x+3,{2,3}>,
<-2*x^6+x^3+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6+x^3-3*x^2-3*x-3,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+3*x^2-3*x+3,{2,53}>,
<-x^6-3*x^5-x^4-2*x^3-3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-x^2-3*x+2,{2,3}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+2*x^2-2,{2,7}>,
<3*x^6-2*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-2*x^2-x+2,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3+2*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3-x+3,{2}>,
<-2*x^6-3*x^5-x^4+x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+x+2,{2,3}>,
<3*x^6+3*x^5+3*x^4-2*x^3+x-2,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2-x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-x^2-x+2,{2,3,5}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-x^2-x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-2*x^3+x^2+x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2-1,{}>,
<2*x^6-x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+3*x+2,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-2*x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2+2*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2+2*x-3,{2}>,
<-x^6-x^5-x^4+2*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+x^2-x+2,{2}>,
<2*x^6-x^4-2*x^3+3*x^2+3*x+3,{2}>,
<-x^6-x^4+2*x^3+3*x^2-3*x+3,{2,5}>,
<3*x^6+x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3-x^2+x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+x^2-x+2,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2-x-2,{2,11}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-3*x^4+x^3+x+2,{2}>,
<-x^6-3*x^5-2*x^4+x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-x^3+2*x^2+3*x+2,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3+3*x^2-3*x+3,{}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2+3*x-3,{2,3,11}>,
<-3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+3,{2,13}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3-2*x^2+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+2*x^2+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3-2*x^2+x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+x^2+2*x-1,{2}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<2*x^6+2*x^5+x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+2*x^2+2*x-1,{2,3}>,
<3*x^6-3*x^5+3*x^4+x^3-x^2+2*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+2*x^2-2*x+2,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2-3*x+3,{2,3,71}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+x^3+x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-3*x^2+3*x-3,{2,5}>,
<-x^6-3*x^5-x^4-2*x^3+3*x^2+3*x+3,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-3*x^2-3*x-3,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+2*x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-3*x-2,{2,347}>,
<-x^6+2*x^5+3*x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3-3*x^2-3*x-1,{}>,
<3*x^6+3*x^5+3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3-3*x^2+3*x-2,{}>,
<3*x^6+3*x^5+3*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3-3*x-2,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+3*x^2-3*x+3,{}>,
<2*x^6-x^5+3*x^4+3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3-3*x^2-x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+3*x^2-x+3,{}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+3*x^2+x-2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+2,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-2,{}>,
<3*x^6+x^5-3*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-2*x^3+3,{2,5}>,
<3*x^6-3*x^5+3*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6+2*x^5+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-3*x^2+3*x-3,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+2*x^2+2,{2}>,
<3*x^6+2*x^5+2*x^3-3*x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-3*x^4+3*x^3-2*x^2+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-3*x-3,{2,5}>,
<-2*x^6+2*x^4-3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-2*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-x^2+3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-2*x+3,{2,3,97}>,
<3*x^6+3*x^5+3*x^4-3*x^3+x^2+2*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-2*x-2,{2}>,
<-x^6-3*x^5-2*x^3+3*x^2+3*x+3,{}>,
<-3*x^6+3*x^5-3*x^4-2*x^3-3*x+2,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-3*x^2-3*x-3,{2,3,19}>,
<3*x^6+3*x^5+3*x^4-2*x^3-3*x-2,{2}>,
<3*x^6+3*x^5+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-1,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-x^2+2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-2,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+2*x^3+2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+3*x^2+3*x+3,{}>,
<-x^6+2*x^5+2*x^4-2*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+x^2-2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2+3*x+3,{2,3}>,
<2*x^6+3*x^5+x^4+3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3-x^2+3*x-1,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2-3*x+3,{}>,
<3*x^6+3*x^5+3*x^4-2*x^3+x^2+3*x+2,{2}>,
<3*x^6-3*x^5+3*x^4+2*x^3+x^2-3*x-1,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-2*x^3-x^2+3*x-3,{2}>,
<-2*x^6+2*x^5-3*x^3+3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5+3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6+x^5-3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3+3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3+x^2-3*x-1,{2,3}>,
<3*x^6+3*x^5+3*x^4-3*x^3-x^2+2*x+3,{2,3}>,
<2*x^6+2*x^5+x^4-3*x^3-3*x^2+3*x-3,{}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+2*x+2,{2}>,
<-x^6-2*x^5+3*x^3+3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3-2*x+2,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3+x^2+x+2,{2}>,
<3*x^6+x^5+x^4+3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3-x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+x^4-3*x^3-3*x^2+3*x-3,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+2*x^2-x-2,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2-3*x-3,{2,3,5}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-x^2-x+3,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-3*x^2+3*x-3,{}>,
<3*x^6-3*x^5+3*x^4+3*x^3+x^2-x-3,{}>,
<3*x^6+x^4-3*x^3+3*x^2+3*x+3,{}>,
<3*x^6-3*x^5+3*x^4+3*x^3-2*x^2-x+2,{2,5}>,
<2*x^6-2*x^4-3*x^3+3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+3*x^4+3*x^3-2*x^2-1,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3-2*x^2-x+2,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3+3*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2+3*x+3,{}>,
<3*x^6-x^5-3*x^4+3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^4+3*x^3+3*x^2+x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2,3}>,
<-x^6+x^5+x^4+x^3-x^2-x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-2*x^2-3*x-3,{2,5}>,
<-3*x^6+3*x^5-3*x^4-3*x^3+x^2-3*x-1,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3-3*x^2+3*x+2,{2,3}>,
<-3*x^6+3*x^5-3*x^4-x^3-2*x+3,{2,3}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2-3*x-3,{2,3}>,
<-2*x^6+2*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+2*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-3*x+3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x^2-x+3,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-2*x^2-3*x-3,{}>,
<3*x^6-3*x^5+2*x^4-3*x^3+x^2-2*x-3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6+x^5-x^4+3*x^3-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3+x^2-x-2,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3+x^2-x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+x^2+3,{2,3}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<-2*x^6+x^4-3*x^3+2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-x^2+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-x^2+3*x+3,{2,3,13}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3+x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x-2,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-x^6+2*x^5+3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+2*x+3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x-3,{}>,
<-x^6+3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+2,{2,3}>,
<3*x^6+x^5-3*x^3+2*x^2-3*x+3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x+2,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+x+2,{}>,
<-2*x^6-x^5+3*x^3+2*x^2+3*x+3,{}>,
<3*x^6+x^5-3*x^3-2*x^2-3*x-3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x-3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3-2*x+2,{}>,
<-2*x^6+2*x^5-3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+3*x^4-3*x^3+x^2-2*x+2,{2}>,
<3*x^6+3*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-3,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+x^2-2*x+3,{2,3}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3*x+3,{}>,
<3*x^6-2*x^5+2*x^4-3*x^3+2*x^2-3*x+3,{2,3}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-x^4+3*x^3+3*x^2-3*x+3,{2}>,
<2*x^6+x^4+3*x^3-3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+3*x^4+3*x^3-x^2-2,{2}>,
<3*x^6+x^4-3*x^3-3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-3*x+3,{}>,
<3*x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-2*x^2-3*x-3,{}>,
<-3*x^6+x^5-x^4+3*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x^2-2,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+x-1,{2}>,
<-3*x^6+x^5-x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-x^6-3*x^5-3*x^3-2*x^2-3*x-3,{2,557}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-3*x+3,{2,5,13}>,
<3*x^6-3*x^5+2*x^4-3*x^3-3*x-1,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x+2,{2,3}>,
<3*x^6-3*x^5-3*x^3-2*x^2-3*x-3,{}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x+2,{2,13}>,
<2*x^6-x^5+3*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x+2,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+2*x-1,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3+3*x^2-x-2,{2,7}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+x^2-2*x+2,{2}>,
<3*x^6+2*x^5+x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x^2-2*x-3,{2}>,
<-x^6+3*x^5+x^4-3*x^3-2*x^2-3*x-3,{}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x^2-3*x-2,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2,3,7}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2+3*x-3,{2,3}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-2*x^2-x-1,{2,3}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6+x^5+3*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-x^6+x^5+3*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-2*x^2-3*x-3,{2,11}>,
<-2*x^6-2*x^5-2*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+2*x-1,{}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+3*x+3,{}>,
<-3*x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+3*x-1,{2,3}>,
<-x^6+3*x^4-3*x^3-2*x^2-3*x-3,{}>,
<-3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+2,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-3*x^2+x-1,{2,3}>,
<2*x^6-x^5+3*x^4+3*x^3-2*x^2+3*x-3,{}>,
<-3*x^6+3*x^5-3*x^4-3*x^3+2*x^2-3*x-1,{}>,
<-2*x^6-x^5-3*x^4+3*x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+3*x^2+x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-3*x^2-3*x+2,{}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3-3*x^2-2*x-1,{2,5}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3+3*x^2-2*x-2,{2,3}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<-x^6+3*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3-3*x^2+2,{}>,
<3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x+3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+2,{2,3}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+2*x^2+3*x+3,{2,3,5}>,
<2*x^6-3*x^5+3*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+2*x^2-3*x+3,{}>,
<3*x^6+3*x^5+2*x^4+2*x^3+2*x^2+2*x+3,{}>,
<3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-2*x-1,{}>,
<-3*x^6+3*x^5-2*x^4+2*x^3-2*x^2+2*x+2,{}>,
<3*x^6+2*x^5-2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3+2*x^2+x-2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3+x^2+3*x-2,{2}>,
<3*x^6+3*x^5-x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+2*x^2+3*x+3,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3+x^2+2*x-2,{2,3}>,
<-3*x^6+2*x^5+x^4+2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3+x^2+x+3,{2,3}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6-x^5-x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3+x^2-x-3,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+3*x^3-x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3-x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-x+2,{2,3,5,19}>,
<-3*x^6-x^5-2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2,{2}>,
<-2*x^6-2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+2*x-3,{2,3}>,
<-x^6-x^5+2*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3-2*x^2-x+3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3+x-2,{2,3}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+x+3,{2}>,
<-3*x^6+x^5-2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-3*x^2+3*x-3,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3-x^2-3*x+2,{2}>,
<3*x^6+3*x^5+x^4+2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3-x^2-2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+x^2-2*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+x^2+2*x+2,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3-x^2-2*x-3,{2,3}>,
<-2*x^6+x^5-x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+x^2+x+3,{2}>,
<-x^6-x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-2*x^6-x^4+2*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3-x^2+x+2,{2}>,
<-x^6-x^5-x^4+2*x^3+2*x^2+3*x+3,{}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+x^2+x+2,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3-x^2-x-2,{2,3}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+x^2+x+3,{2,3,7}>,
<-3*x^6+x^5-x^4-2*x^3+2*x^2-3*x+3,{2,3}>,
<-2*x^6+x^5-2*x^4+3*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+3*x^3-2*x^2-2,{}>,
<3*x^6+2*x^4+3*x^3-2*x^2+3*x-3,{2,3}>,
<-3*x^6-2*x^4-3*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2*x^2+3*x-3,{2,3}>,
<-x^6+3*x^5-2*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2*x^2+3*x+3,{2,3,5,13,19}>,
<3*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2,3}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2*x^2+2*x+2,{2,3}>,
<-x^6+x^5-x^4+3*x^3+2*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+x^2-x+2,{2,3}>,
<3*x^6+2*x^5+2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-2*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+2*x^2-3*x-1,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3-2*x^2+3*x-2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-3*x^4-3*x^3-x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+2*x^2-3*x+3,{2,3}>,
<-x^6+2*x^5+3*x^3-3*x^2-3*x-3,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-x^6-2*x^5-3*x^3+3*x^2+3*x+3,{2}>,
<2*x^6-2*x^5-3*x^3-3*x^2+3*x-3,{2}>,
<-2*x^6-2*x^5-3*x^3+3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^3-3*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+x+3,{2,3,5}>,
<3*x^6+2*x^5+3*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5+3*x^4+2*x^3+2*x^2+3*x+3,{}>,
<2*x^6-2*x^5-3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+2*x+3,{2,3,5,7}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+3*x^2-1,{2}>,
<-x^6-3*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6+3*x^4+2*x^3-2*x^2+3*x-3,{}>,
<-2*x^6-3*x^4-2*x^3+2*x^2-3*x+3,{}>,
<3*x^6+3*x^4-2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3-3*x^2+3*x+2,{2,3}>,
<-x^6-3*x^5+3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3+2*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6-3*x^5+2*x^4-x^3+3*x^2-3*x-2,{2}>,
<3*x^6-3*x^5+2*x^4-x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3+3*x^2-2*x-3,{2,3,11}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2-3*x-3,{2}>,
<2*x^6+3*x^4+x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^4-x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-x^5+3*x^4+x^3+2*x^2+3*x+3,{2,3}>,
<2*x^6+x^5-3*x^4-x^3-2*x^2-3*x-3,{}>,
<3*x^6+x^5-3*x^4-x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3+3*x^2+x-3,{2,3}>,
<2*x^6-2*x^5-3*x^4+x^3-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+3*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-3*x^2-3*x+2,{2,5}>,
<3*x^6-3*x^5+2*x^4-x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+2*x^2+x+3,{2,3}>,
<2*x^6+2*x^4+x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+2*x^2-x+2,{2,3}>,
<-3*x^6+3*x^5-2*x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3+x^2+3*x-2,{2,3}>,
<3*x^6+2*x^5+2*x^4-x^3+2*x^2-3*x+3,{2,3,5,37}>,
<3*x^6-3*x^5-x^4+2*x^3-2*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+x^3-2*x^2-2*x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3+3*x+2,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x-1,{}>,
<-x^6+3*x^5+2*x^3+2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5+2*x^3-2*x^2+3*x-3,{2}>,
<-x^6-3*x^5+2*x^4+x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-2*x^2+3*x-3,{2,3,47}>,
<-x^6+3*x^5+x^4+x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-x^2+3*x+2,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5+x^4+x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3+x^2-x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3-3*x^2+2*x-3,{2,3,5,227}>,
<3*x^6-x^5-3*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<-x^6-x^5+3*x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<-x^6-x^5-3*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+x^2+3,{2,3}>,
<3*x^6+3*x^5+2*x^4+x^3+x^2-x+3,{2,3}>,
<2*x^6+2*x^5+x^4-x^3+2*x^2-3*x+3,{2}>,
<-x^6-2*x^5+x^4+x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3+x^2+3*x+3,{2,3}>,
<2*x^6-3*x^5-x^4+x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3-x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3-3*x-1,{2,3}>,
<-2*x^6+3*x^5+x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x-1,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^3+3*x^2-2,{2}>,
<-3*x^6-x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3-x-3,{2}>,
<3*x^6+2*x^5-x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+x^3-2*x+2,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+x^2-3*x+2,{2}>,
<3*x^6-3*x^5+x^4-x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+x^3-x^2+2*x-2,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5-x^4+x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6-x^5-x^4-x^3+2*x^2-3*x+3,{2}>,
<-x^6-x^5-x^4-x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+x^2-x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4+x^3-x^2+2,{2}>,
<-x^6-x^4-x^3+2*x^2-3*x+3,{2}>,
<-2*x^6-x^4-x^3+2*x^2-3*x+3,{2}>,
<3*x^6+x^4+x^3-2*x^2+3*x-3,{2}>,
<-2*x^6+x^5-x^4-x^3+2*x^2-3*x+3,{2}>,
<3*x^6+x^5+x^4-x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5-x^4+x^3+2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5-x^4-x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-2*x^2-3*x+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3-2*x^2-3*x-3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-2*x^2-3*x-3,{2,13}>,
<3*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x-2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-2*x^2-x-1,{2}>,
<-2*x^6+x^5-2*x^4+x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+2*x^2-2*x-2,{2,3,5,173}>,
<-3*x^6+3*x^5-2*x^4+x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4+x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4+x^3-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3-2*x^2-1,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+x^3-2*x^2-x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3+2*x^2+2*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+2*x^2+2*x-1,{2,3}>,
<-2*x^6+2*x^5-2*x^4-x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x^2-3*x+3,{2}>,
<-x^6+3*x^5+2*x^4-x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-3*x^2-2*x-3,{2}>,
<-x^6-x^5+3*x^4-x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2-x+2,{2,3,5}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+3*x+3,{2}>,
<-2*x^6+x^5-3*x^4+x^3+2*x^2+3*x+3,{2,5}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2-3*x-2,{2}>,
<3*x^6-x^5+3*x^4-x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4-x^3-3*x^2-1,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3-3*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3-3*x^2-2*x-2,{2,3,5}>,
<3*x^6-2*x^5+3*x^4+x^3-2*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+x^3+3*x^2-3*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4-x^3+3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^2-2*x-1,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-2*x^2+3*x-3,{2,3}>,
<-x^6-x^5+3*x^4+2*x^2-3*x+3,{2}>,
<-2*x^6-x^5+3*x^4+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^2-x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^2+2,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^2-x+2,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^2+2,{2,3}>,
<3*x^6-3*x^4-2*x^2+3*x-3,{2}>,
<2*x^6-x^5-3*x^4-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^2+x-3,{2,3}>,
<2*x^6-3*x^5+3*x^4+2*x^2+3*x+3,{2}>,
<-x^6-3*x^5+3*x^4+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+3*x^2-2*x+3,{}>,
<-x^6-2*x^5+3*x^4+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4-3*x^2+3*x+2,{2,3}>,
<3*x^6+3*x^5-3*x^4-2*x^2-3*x-3,{}>,
<3*x^6+x^5+3*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^2-3*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^2-3*x-3,{2}>,
<3*x^6+2*x^5+x^3+2*x^2+3*x+3,{2}>,
<2*x^6-x^5+2*x^4+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+2*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^2+x-1,{2}>,
<2*x^6+x^5+x^3-2*x^2+3*x-3,{}>,
<-3*x^6+3*x^5-2*x^4-2*x^2+x+2,{2}>,
<3*x^6+3*x^5+2*x^4+x^3+x-2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^2+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4-2*x^2+2,{2}>,
<3*x^6-x^5-x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^2+x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+x^3+x-3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x^2-2*x+2,{2,5}>,
<3*x^6-3*x^5+2*x^4-x^3+2,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^2-2*x+2,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^2+3*x+3,{2,3}>,
<2*x^6+3*x^5-2*x^4-2*x^2-3*x-3,{2,5}>,
<3*x^6-3*x^5+2*x^4+2*x^2+3*x-2,{2}>,
<3*x^6+3*x^5+2*x^4+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^2+x+3,{2}>,
<-x^6-x^5+x^4+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^2+x-2,{2,3}>,
<-3*x^6-3*x^5-2*x^4-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^2+2*x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-x^3+x^2-x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4+2*x^3-3*x-1,{2}>,
<-3*x^6-3*x^5-2*x^4-x^2+2*x+3,{2,3}>,
<2*x^6+2*x^5-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x+3,{2}>,
<3*x^6-3*x^5-x^4-2*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+3*x+2,{2}>,
<3*x^6+3*x^5-2*x^2-3*x-3,{}>,
<-3*x^6+3*x^5+x^4+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<-3*x^6-2*x^5-x^4+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4+2*x+2,{2,3}>,
<2*x^6+x^5-x^4+2*x^2+3*x+3,{2}>,
<3*x^6-2*x^5-2*x^2-3*x-3,{2,3}>,
<-3*x^6-x^5-x^4+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+x^2-x+2,{2,3}>,
<-2*x^6-x^4+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x+3,{}>,
<-2*x^6+x^5-x^4+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x-1,{2,3}>,
<2*x^6-x^5-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^2+x+3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x-1,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^2-2*x-2,{}>,
<-3*x^6+3*x^5-2*x^4+2*x^2+2*x+3,{}>,
<3*x^6+3*x^5+2*x^4-2*x^2+2*x-3,{}>,
<3*x^6-3*x^5+2*x^4-2*x^2-x-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4+2*x^2-x+2,{2}>,
<-3*x^6-x^5-2*x^4+2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4-2*x^2+2*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^2-x-2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^4-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^2+3*x-2,{2,3}>,
<2*x^6+3*x^5-3*x^4+2*x^2+3*x+3,{}>,
<-3*x^6-2*x^4+2*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^2+3*x+2,{2,3}>,
<-2*x^6+x^5-2*x^4+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^2-2*x-1,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+2*x^2-x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^2+2*x+2,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^2-x-1,{2}>,
<-3*x^6+3*x^5-2*x^4+3*x^2+x+3,{}>,
<-3*x^6-x^5-3*x^4+2*x^2-3*x+3,{}>,
<2*x^6+3*x^4-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^2-2,{2}>,
<3*x^6-3*x^5+2*x^4-3*x^2+x+2,{2,3}>,
<3*x^6+2*x^5+3*x^4-2*x^2+3*x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^2-3*x-3,{2,3}>,
<2*x^6-2*x^5-3*x^4+2*x^2+3*x+3,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^2+3*x-3,{2,3}>,
<-x^6+3*x^5+3*x^4-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3+3*x^2-3*x-1,{}>,
<2*x^6-3*x^5-3*x^4+x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3+3*x^2-x+3,{2,3}>,
<2*x^6+x^5-3*x^4-x^3-2*x^2+3*x-3,{}>,
<2*x^6+3*x^4-x^3+2*x^2+3*x+3,{2}>,
<2*x^6-3*x^4-x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-3*x^2+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3+3*x^2-3,{2}>,
<3*x^6+x^5+3*x^4+x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+x^5-3*x^4-x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^2+x+3,{}>,
<-3*x^6-3*x^5-2*x^4+x^3-3*x^2+x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^2+x+2,{2}>,
<3*x^6+3*x^5+2*x^4+x^3-3*x^2-2*x+3,{2,3}>,
<-x^6-2*x^4-2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3+3*x^2+x-2,{2,3}>,
<3*x^6+2*x^4-2*x^3-2*x^2-3*x-3,{}>,
<3*x^6-3*x^5+2*x^4+x^3+3*x^2+2*x+3,{2,3,11}>,
<-x^6-2*x^5+3*x^4-x^3+2*x^2+3*x+3,{}>,
<3*x^6+3*x^5+2*x^4+2*x^3-2*x^2-3,{}>,
<-3*x^6+3*x^5-2*x^4-x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6+x^5-3*x^4+x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+2*x^4+x^3+2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-2*x^2-3*x-3,{2,3,23}>,
<3*x^6-3*x^5-3*x^4-x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6+x^5+2*x^4-x^3+2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4+x^3-2*x^2-x+2,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3+2*x^2-x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5-2*x^4-x^3-2*x^2+x+3,{2,3}>,
<3*x^6-2*x^4+x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2+3*x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+2*x^2+3*x+3,{2}>,
<-x^6-x^5+2*x^4-x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+x^3-2*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+2*x^4-x^3+2*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4+x^3-2*x^2+x+2,{2,3}>,
<2*x^6-3*x^5+2*x^4-x^3+2*x^2+3*x+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3+2*x^2+3*x+3,{}>,
<3*x^6-3*x^5+2*x^4+x^3+x^2-3*x-3,{}>,
<3*x^6-2*x^5+x^4+x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^3-2*x^2+3*x-3,{}>,
<-3*x^6-2*x^5+x^4+x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3+x^2-x+3,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x^2+3*x-3,{2}>,
<3*x^6+x^4-x^3+2*x^2+3*x+3,{2}>,
<2*x^6+x^4-x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3+x^2-1,{}>,
<3*x^6+3*x^5-x^4-x^3-2*x^2+3*x-3,{}>,
<3*x^6+3*x^5+2*x^4-x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3-x^2+2,{2}>,
<3*x^6+3*x^5+2*x^4-x^2-2*x+2,{2}>,
<2*x^6+x^5-x^4+x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3+x^2-x-2,{2}>,
<-2*x^6+x^4+x^3+2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5+x^4-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-x^2-x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3-x^2-2*x+3,{2}>,
<-x^6+3*x^5+x^4-2*x^2-3*x-3,{2,11}>,
<-3*x^6+2*x^5+x^4+x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^2+3*x-2,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-x^2+3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^2-3*x-3,{}>,
<-3*x^6+3*x^5-2*x^4-x^3+3*x+2,{2}>,
<3*x^6-3*x^5+2*x^4+x^3-3*x+3,{}>,
<3*x^6+3*x^5+2*x^4-x^3+3*x-2,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3+3*x+2,{2}>,
<-2*x^6+2*x^5-x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^2-2*x-1,{2,5}>,
<-x^6+3*x^5-x^3-2*x^2+3*x-3,{}>,
<-3*x^6-3*x^5-2*x^4+x^3-2*x+3,{2}>,
<-x^6+x^3+2*x^2-3*x+3,{2}>,
<2*x^6-x^3-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3+2*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3-x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x+2,{}>,
<3*x^6+3*x^5+2*x^4-x^3+x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3-2*x+2,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3-2*x+3,{}>,
<3*x^6+3*x^5+2*x^4-x^3+x-3,{2,3}>,
<2*x^6-3*x^5-x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3+2*x-3,{}>,
<-3*x^6+3*x^5-2*x^4-x^3-3*x+3,{2,3}>,
<-x^6+3*x^5+x^3-2*x^2-3*x-3,{2}>,
<-2*x^6-3*x^5-x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-3*x-1,{2}>,
<3*x^6-2*x^5-x^4+x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^4+x^3+x^2-2*x-1,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-x^2-2*x-3,{2,3}>,
<-x^6+2*x^5-x^4-x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3+x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^4+x^3+x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x^2+3*x-2,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-x^2-2*x-2,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x^2+2*x+3,{2}>,
<-x^6-2*x^5-2*x^4+x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x^2+2,{2}>,
<3*x^6+2*x^5+x^4-x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-x^3-2*x^2-3*x-3,{2}>,
<-2*x^6-2*x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-2*x^2-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+2*x^2+3*x+3,{2,3,5}>,
<3*x^6+x^5-2*x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3+2*x^2+3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5-2*x^4+x^3+2*x^2+3*x-2,{2,3}>,
<-3*x^6-2*x^5-3*x^4+x^3+2*x^2-3*x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-x^3+2*x^2-3*x-1,{2,3,5}>,
<-3*x^6-3*x^5-2*x^4+x^3+3*x^2-x+2,{2,3}>,
<-3*x^6-2*x^5-3*x^4-x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-x^3-3*x^2+x-3,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-3*x^2+2,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-3*x^2-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2+2*x-3,{2,3}>,
<-x^6+x^5-3*x^4+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-3*x^2-x+2,{2,3}>,
<3*x^6+3*x^4+x^3-2*x^2-3*x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x^2+3*x-3,{2,3}>,
<-x^6-x^5+3*x^4-x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3+3*x^2-x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4+3*x^2-x+2,{}>,
<3*x^6+3*x^5+2*x^4-3*x^2-x-2,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-3*x^2+2*x+3,{2}>,
<-x^6+3*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-x^3+3*x^2-2*x-1,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-3*x^2+3*x+3,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-3*x-3,{}>,
<2*x^6-x^5-3*x^4-2*x^3-2*x^2+3*x-3,{2,3}>,
<2*x^6+3*x^5+2*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-2*x^2+3*x-3,{}>,
<-3*x^6+3*x^5-2*x^4-2*x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-2*x^2-2*x+2,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3+2*x^2+2*x-2,{}>,
<-3*x^6-x^5+3*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4+2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6+2*x^4+2*x^3+2*x^2-3*x+3,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3+2*x^2-1,{2}>,
<3*x^6-2*x^4+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<-x^6-x^5+2*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3-2*x^2-x+2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+x-2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+2*x+2,{2,5}>,
<-x^6+2*x^5+2*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3-2*x^2-2*x+3,{}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+2*x-3,{}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+3*x+2,{}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+3*x-2,{2,3}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+x^3-x^2+x+2,{}>,
<-3*x^6-3*x^5-2*x^4+x^3+x^2+x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4-x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x^2-3*x-3,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2+3*x+3,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+x^3-x^2+2*x-2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+x^2-x+3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3+x^2+x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3+x^2-x-1,{2,3}>,
<2*x^6+x^5-x^4-2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4-2*x^3-2*x^2+x-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4-2*x^3+2*x^2+x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4+2*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-x^2+3*x-1,{2,5}>,
<-x^6+3*x^5+x^4+2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-2*x^2+3*x-3,{2}>,
<-x^6+3*x^5-x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4+x^3-3*x+2,{2}>,
<3*x^6-3*x^5+x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-2,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3-3*x^2+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+x+2,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+2,{2}>,
<-x^6+2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+2,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+3,{2}>,
<3*x^6+x^5+2*x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6+x^5+2*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-x^5-2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-x^5-2*x^3-2*x^2+3*x-3,{2,3}>,
<2*x^6+3*x^5-3*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3+3*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^2-x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-2*x^3-2*x-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+2*x+2,{2,3}>,
<3*x^6+2*x^5+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3+2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5-2*x^4+x^3+3*x^2-3*x+2,{2,5}>,
<3*x^6+3*x^5+2*x^4-x^3-3*x^2+3*x-2,{2,5}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2+2*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3-x^2-x-3,{2,3,7}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2-x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2-x-1,{2,3}>,
<2*x^6+x^5+x^4+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2-x-2,{2}>,
<3*x^6+x^5+x^4+2*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+2*x^5+x^4-2*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2-2*x+3,{2}>,
<-x^6+2*x^5+x^4+2*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+x^2-2*x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-3*x-3,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4+x^3-x^2+3*x-1,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3-3*x-1,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3-3*x-2,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3-2*x^2+x-3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^4+2*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+3*x^2+2*x+2,{2}>,
<3*x^6+3*x^5-2*x^3-2*x^2+3*x-3,{2,3}>,
<-2*x^6+2*x^5-3*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+3*x^2-x-1,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x^2+x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+2*x^3+3*x^2-x+3,{2,3}>,
<-x^6+2*x^5+2*x^4+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x^2-x+2,{2}>,
<3*x^6+x^5-3*x^4+2*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+3*x^2-x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x^2-3*x+3,{}>,
<-x^6-3*x^5+3*x^4-2*x^3-2*x^2+3*x-3,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2+3*x+3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3-2*x^2+3*x-3,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3-3*x^2-3*x-2,{}>,
<3*x^6+3*x^5+2*x^4-2*x^3-3*x^2-x-3,{2,3}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-2*x^2+3*x-3,{}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3+3*x^2+x-2,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2+3*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2+3*x+3,{2,7}>,
<3*x^6-2*x^5+3*x^4+2*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3+3*x^2+2*x+2,{2,5,7}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3-2*x^2+3*x-3,{2,3}>,
<2*x^6-2*x^5+2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-2*x^2+2*x+2,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-2*x^2+2,{2}>,
<-2*x^6+2*x^4+3*x^3+2*x^2-3*x+3,{2,5}>,
<3*x^6+3*x^5+2*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2-3*x-3,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^3+2*x^2-3*x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^4-2*x^3-3*x-1,{2,3}>,
<2*x^6+3*x^5+2*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+2*x^2-3*x+3,{2}>,
<-x^6-3*x^5+x^4+2*x^3-2*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-2*x^2-3*x-1,{2,13}>,
<3*x^6+3*x^5+2*x^4-2*x^3-x^2+3*x-1,{}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<3*x^6-x^5-x^4+3*x^3-2*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+x^4+3*x^3+2*x^2-3*x+3,{2,3}>,
<3*x^6+x^5-x^4+3*x^3-2*x^2-3*x-3,{2,5}>,
<3*x^6+3*x^5+2*x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3+x^2+2*x+2,{2,3}>,
<3*x^6+3*x^5+2*x^4-3*x^3+x^2-2*x-1,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-x^2-2*x+2,{2,3}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+3*x-1,{2,3}>,
<-x^6+2*x^5-3*x^3+2*x^2+3*x+3,{2,3,7}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-2*x^3+x^2+3,{2}>,
<3*x^6-3*x^5+2*x^4+2*x^3-2*x-3,{2,3}>,
<2*x^6-x^4-2*x^3-2*x^2+3*x-3,{2}>,
<3*x^6+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3-x+2,{2,3}>,
<3*x^6-2*x^5+x^4-2*x^3+2*x^2+3*x+3,{2}>,
<-x^6-x^5-3*x^3+2*x^2+3*x+3,{2,5}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-x+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+2*x-1,{2}>,
<-x^6+2*x^5+3*x^3+2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+3*x-1,{2,3}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+x^2-3*x-1,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2+3*x+3,{}>,
<3*x^6-x^5-x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3+2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^3+x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5+x^4+3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3-2*x^2+3*x-3,{2}>,
<3*x^6-x^5+x^4+3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6-x^5-x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3+x^2-x-2,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4-3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+3*x^2-3*x-2,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^3-3*x^2-2*x+3,{}>,
<2*x^6-2*x^5-3*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-2*x^2+3*x-3,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3-3*x^2-x+2,{2,3}>,
<-x^6+3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-x^6-x^5+3*x^4-3*x^3-2*x^2+3*x-3,{}>,
<-x^6+3*x^5+2*x^4+2*x^3-2*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+3*x^2-2*x-1,{}>,
<3*x^6-3*x^5+2*x^4+2*x^3-3*x^2-3*x-1,{2,3}>,
<3*x^6+3*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x^2-3*x-3,{2,3,19}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x^2-3*x-3,{2,3,5}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+3*x^2-3*x+2,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2-x-1,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2-3*x-1,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3-3*x^2-x+2,{2,3}>,
<-2*x^6-x^5+3*x^4-3*x^3+x^2-3*x+3,{2,7}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2-3*x-3,{}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x^2+x-3,{}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+x^2+3*x+3,{}>,
<2*x^6+3*x^4+3*x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2-3*x-3,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+x^2-3*x+3,{}>,
<-2*x^6+3*x^4-3*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x^2-3,{}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+2*x^2+3*x+3,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+x^2+3*x+3,{}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-3*x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-3*x^2+x+3,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x^2-x-1,{}>,
<-x^6+3*x^4+3*x^3+2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5-x^4-3*x^3-2*x^2-x+2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x^2+3*x-3,{2,3}>,
<-2*x^6-x^5+2*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3-x^2+3*x-2,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3-2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-3*x^2+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x^2-x-3,{2,3,53}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x^2+3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-3*x^2+x+2,{2}>,
<-2*x^6+2*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6-2*x^4-3*x^3+2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3-x^2+x+3,{2,3}>,
<2*x^6-2*x^5-x^4-3*x^3-x^2-3*x-3,{}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+x^2-x-3,{2,3}>,
<-2*x^6-2*x^5+x^4-3*x^3+x^2-3*x+3,{}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-x^2-2*x+3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3+x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x-2,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+x^2-x-1,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-2*x+2,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-2*x-1,{2}>,
<-x^6+2*x^5+3*x^3+x^2+3*x+3,{2}>,
<-2*x^6+x^5+x^4+3*x^3+x^2+3*x+3,{2,7}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^3+x^2+3*x+3,{}>,
<2*x^6+x^4+3*x^3-2*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3+x^2+3*x+3,{2}>,
<-2*x^6-x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6-2*x^5-3*x^3-x^2-3*x-3,{2,3,5}>,
<3*x^6-3*x^5+2*x^4+3*x^3-x^2+x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3-3*x-2,{2}>,
<3*x^6-3*x^5+2*x^4+3*x^3-x^2+x+2,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+x^2-1,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+x+2,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3-x-1,{2}>,
<2*x^6+x^5+x^4-3*x^3+x^2-3*x+3,{2}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x-2,{}>,
<-x^6+x^5+3*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+x+2,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+3*x-3,{}>,
<3*x^6+2*x^5+3*x^3+x^2+3*x+3,{2,3}>,
<2*x^6-2*x^5+3*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+2*x-2,{2,3}>,
<3*x^6-2*x^5+3*x^3-x^2+3*x-3,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2+3*x-3,{2,13}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2+3*x-3,{}>,
<3*x^6+3*x^5+x^4+3*x^3-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+x^2+3*x+3,{}>,
<3*x^6-3*x^5+x^4-3*x^3+3*x-2,{2,3}>,
<-3*x^6+3*x^5-x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3+x^2-2*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3+x+2,{2,3,5,7,17}>,
<-x^6+x^5-3*x^3+2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3+x^2-2*x-2,{2,3}>,
<3*x^6-3*x^5+2*x^4+3*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-x+2,{2}>,
<3*x^6+3*x^5+2*x^4-3*x^3+2*x^2+x+2,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-x^2+2*x-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3-x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-x^2+x-1,{2}>,
<-2*x^6+x^5-x^4-3*x^3+x^2-3*x+3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^4-3*x^3+2,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3+x^2+x+3,{2}>,
<-2*x^6-3*x^3+2*x^2+3*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-x^2-3*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+x^2-3*x+3,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+x^2+3*x+3,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-2*x^2+x-1,{2,3}>,
<2*x^6+x^5+2*x^4+3*x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+2*x^2+x+3,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-x^2-3*x-3,{2}>,
<-x^6-3*x^5+x^4-3*x^3+x^2-3*x+3,{}>,
<-2*x^6+3*x^5+x^4+3*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2-3*x-3,{}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2+3*x+3,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-3*x-3,{}>,
<-3*x^6-3*x^5-x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2+3*x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+x^2+3*x+3,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-3*x^2-3*x-2,{2,3,29}>,
<3*x^6+2*x^5-3*x^4+3*x^3+x^2+3*x+3,{2,3}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-3,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3+x^2+3*x+3,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2+2*x-1,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-3*x^2-2*x-2,{2,7}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+x^2-3*x+3,{}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2-x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2+x+3,{2}>,
<-3*x^6-3*x^5-2*x^4+3*x^3+x^2+3*x-2,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2-2,{2,3}>,
<-2*x^6-x^5+3*x^4+3*x^3-x^2+3*x-3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+x^2-3*x+3,{2}>,
<-x^6-x^5+3*x^4+3*x^3-x^2+3*x-3,{2}>,
<-x^6-x^5-3*x^4+3*x^3+x^2+3*x+3,{}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2+x+2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-x^2+3*x-3,{}>,
<-3*x^6+x^5-3*x^4-3*x^3+x^2-3*x+3,{}>,
<-3*x^6+3*x^5-x^4+3*x^3+3*x^2-2*x-1,{0,2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-2*x^2-x-2,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x+2,{2,3}>,
<-x^6+2*x^5-2*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-2*x^2+3*x-2,{2,3}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+x^2-3*x+3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2-3*x+3,{}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2-3*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x^2+3*x+3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2-3*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3+x^2+3*x+3,{2,3}>,
<-x^6+2*x^5+3*x^4+2*x^3+x^2+3*x+3,{}>,
<3*x^6-3*x^5+x^4-2*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3+3*x^2-x+2,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+3*x^2-x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3-3*x^2+x+3,{}>,
<3*x^6-3*x^5+x^4-2*x^3+3*x^2-x-3,{}>,
<3*x^6+x^5+3*x^4-2*x^3+x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+2*x^3-x^2+3*x-3,{2,3}>,
<2*x^6+3*x^5+3*x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3+3*x^2-x+2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2+3*x-3,{2,3,7}>,
<-3*x^6-3*x^5-x^4-2*x^3-3*x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3-2*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+x^4+2*x^3+2*x^2+2*x-2,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+x^2+3*x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+x^2-3*x+3,{2,3}>,
<3*x^6+x^5-2*x^4+2*x^3-x^2+3*x-3,{2}>,
<2*x^6+2*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3-2*x^2+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2-3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2+x+3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-x^2+x+2,{2,3}>,
<-x^6-x^5+x^4-3*x^3-x^2-3*x-3,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3+x^2+x+2,{2}>,
<3*x^6-x^5+x^4-3*x^3-x^2-3*x-3,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3-x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-x^2+x-3,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3-x^2-3*x+2,{2}>,
<-2*x^6-x^4+3*x^3+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3+x-3,{2,3}>,
<-2*x^6+3*x^5+x^4+2*x^3+x^2+3*x+3,{}>,
<3*x^6-3*x^5+x^4-3*x^3-3,{2}>,
<3*x^6+x^5-3*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+x^2+3*x+3,{2,3}>,
<-x^6+2*x^5+x^4+2*x^3+x^2+3*x+3,{}>,
<-x^6-x^5+3*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3+x^2+2*x-2,{2}>,
<-3*x^6+3*x^5-x^4+3*x^3-x+2,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-x^2+2*x-1,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-x^2+3*x-3,{2,3}>,
<2*x^6-2*x^5+x^4+3*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-3*x^3+x-3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-x^2-2*x-2,{2}>,
<-x^6-3*x^5-2*x^3-x^2-3*x-3,{2,13}>,
<-x^6+3*x^5+2*x^3+x^2+3*x+3,{}>,
<-3*x^6-3*x^5-x^4-2*x^3-3*x+2,{2}>,
<3*x^6-2*x^5+3*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3-3*x+3,{2,3}>,
<-x^6+2*x^5+2*x^3+x^2+3*x+3,{}>,
<-x^6+2*x^5-3*x^3+x^2-3*x+3,{2}>,
<3*x^6+2*x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^3-x^2+3*x-3,{2}>,
<-2*x^6-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3+x^2+3*x+3,{2,3}>,
<-3*x^6+2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3-x+3,{}>,
<3*x^6+3*x^5+x^4+2*x^3-x-1,{2}>,
<-2*x^6+x^5-2*x^3+x^2-3*x+3,{}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x+3,{2,3}>,
<-x^6-3*x^5+2*x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3-3*x-3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2-3*x+3,{}>,
<3*x^6+x^5-2*x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3+x^2-3*x-2,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3+2*x^2-2,{2}>,
<2*x^6-2*x^4-3*x^3+x^2-3*x+3,{2}>,
<-3*x^6+x^5-2*x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3+2*x^2-1,{2}>,
<-x^6-2*x^4+3*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3-2*x-2,{2}>,
<-2*x^6-2*x^4-3*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2-3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2+x-1,{2}>,
<3*x^6+2*x^5+x^4-2*x^3-x^2-3*x-3,{}>,
<-3*x^6+2*x^5-x^4-2*x^3+x^2-3*x+3,{}>,
<-x^6+3*x^5+x^4-2*x^3-x^2-3*x-3,{2}>,
<-2*x^6+3*x^5-x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-x^2+3*x-3,{}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2+3*x-3,{}>,
<-3*x^6+3*x^5-x^4+2*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3-x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+x^2-3*x+3,{2}>,
<-x^6-2*x^5-2*x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6+2*x^4+3*x^3+2*x^2-3*x+3,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-x^2+3*x-3,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+2*x^2+2*x+3,{2}>,
<-x^6-x^5+2*x^4-2*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+2*x^3-2*x^2+x-1,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2-x+2,{2,3}>,
<3*x^6+3*x^5+x^4+2*x^3-2*x^2+x-2,{2,3}>,
<-3*x^6+3*x^5-x^4+2*x^3-x^2+x+2,{2,3}>,
<-3*x^6-x^5+x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+x^2-3,{2}>,
<-3*x^6-x^5+x^4+2*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3+x^2+2*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+x^2+2*x-3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^3-x^2-3*x-3,{2}>,
<2*x^6+3*x^5+2*x^3+x^2+3*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<-x^6-3*x^5+2*x^4+2*x^3-x^2+3*x-3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+3*x-2,{}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2-3*x+2,{}>,
<-3*x^6-3*x^5-x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2-x-2,{2}>,
<-2*x^6+3*x^4-2*x^3-x^2-3*x-3,{}>,
<3*x^6+3*x^5+x^4+2*x^3-3*x^2+2,{}>,
<-x^6+3*x^4+2*x^3-x^2+3*x-3,{2}>,
<-x^6-3*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2+x+2,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2+x-2,{}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2+2*x-1,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-3*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-3*x^5+x^4-x^3+3*x^2-3*x-1,{}>,
<-3*x^6-3*x^5-x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4-x^3+3*x^2-2*x+2,{}>,
<-2*x^6-2*x^5+x^4-2*x^3-x^2-3*x-3,{2,3,5,271}>,
<3*x^6-3*x^5+x^4-x^3+3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2+3*x-3,{}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2-3*x+3,{}>,
<3*x^6-x^5+3*x^4-x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^4+x^3+x^2+3*x+3,{}>,
<3*x^6+3*x^5+x^4+x^3+3*x^2-1,{}>,
<2*x^6-3*x^4+x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-x^3+3*x^2+x-2,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-x^2-3*x-3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^3+3*x^2-x-2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+x+2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+3*x^2+x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-x^3+3*x^2+3*x+2,{2}>,
<-3*x^6-3*x^5-x^4-x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3+x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2-3*x-1,{2,3,17}>,
<-3*x^6-3*x^5-x^4-x^3-2*x^2-3*x+2,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2-3*x-3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x^2-3*x+3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x^3+2*x^2+2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3-2*x^2-2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-2*x^2+x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2-3*x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3-x^2-3*x-3,{2}>,
<2*x^6-3*x^5-2*x^4+x^3-x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3-x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-x^3+x^2-2*x+3,{}>,
<-x^6-2*x^5+x^4-x^3+x^2-3*x+3,{}>,
<2*x^6-2*x^5-x^4-x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4-x^3+x^2-2*x-3,{2}>,
<2*x^6-x^5-x^4-x^3-x^2-3*x-3,{}>,
<3*x^6-3*x^5+x^4-x^3+x^2-x-2,{}>,
<-2*x^6+x^4-x^3+x^2-3*x+3,{2}>,
<-3*x^6+x^4-x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3+x^2-x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+x^2-3*x+3,{2,3,5}>,
<-3*x^6-3*x^5-x^4-x^3-x^2+2*x+2,{2,5}>,
<2*x^6-2*x^5-x^4-2*x^3+x^2-3*x+3,{2,3,5,271}>,
<-x^6-2*x^5+x^4-2*x^3-x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2-2*x-2,{2}>,
<-3*x^6-2*x^5-2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^3-x-2,{2}>,
<3*x^6+x^5+2*x^3-x^2+3*x-3,{2}>,
<-3*x^6+x^5+2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^3-x^2+3*x-3,{2,3,5}>,
<3*x^6+3*x^5+x^4+x^3+3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2+x-1,{2}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2-x+2,{2}>,
<3*x^6-3*x^5+x^4-3*x^3-3*x^2-x-2,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^3-3*x^2-x-3,{2,3}>,
<-3*x^6+3*x^5-x^4+3*x^3+3*x^2-2,{2}>,
<3*x^6+3*x^5+x^4+3*x^3-3*x^2-1,{2,3}>,
<-3*x^6-3*x^5-x^4-3*x^3+3*x^2+2,{2}>,
<-2*x^6+x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3+3,{2}>,
<3*x^6+3*x^5+x^4+x^3-3,{2}>,
<-2*x^6-x^5+x^3+x^2+3*x+3,{2}>,
<3*x^6-x^5+x^3-x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-2*x-3,{2,3}>,
<3*x^6-3*x^5+x^3+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-3*x+2,{2}>,
<-3*x^6-3*x^5-x^4-x^3+3*x-1,{2}>,
<2*x^6+3*x^5-x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+x^3+x^2+3*x+3,{2}>,
<-x^6-3*x^5+x^4-x^3-x^2-3*x-3,{2,3,5}>,
<-3*x^6-3*x^5-x^4-x^3+x^2-3*x+2,{2}>,
<3*x^6+3*x^5+x^4+x^3-x^2+3*x-2,{2,3}>,
<-3*x^6+3*x^5-x^4+x^3+x^2+3*x+3,{2,3}>,
<-2*x^6+2*x^5-x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3-x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-x^2+2*x-3,{2,3}>,
<-x^6+x^5-x^4+x^3+x^2+3*x+3,{}>,
<3*x^6+3*x^5+x^4+x^3-x^2+x-2,{2}>,
<3*x^6-x^5+x^4-x^3-x^2-3*x-3,{}>,
<3*x^6+3*x^5+x^4+x^3-x^2+x-3,{}>,
<-x^6-x^4-x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3+x^2+2,{2}>,
<3*x^6+3*x^5+x^4+x^3-x^2-2,{2}>,
<-3*x^6-3*x^5-x^4-x^3+x^2+x+3,{2,3}>,
<3*x^6+2*x^5+x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4+x^3-x^2-x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3+2*x-3,{2}>,
<-x^6+x^5+x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^3+x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6+3*x^5+x^4+x^3+3,{2}>,
<-x^6+x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-x^3+2,{2,3}>,
<3*x^6+3*x^5-x^4-x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4-x^3+x^2+3*x-1,{2}>,
<-2*x^6+x^5-2*x^4+x^3+x^2+3*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-x^2-3*x-3,{2}>,
<3*x^6-x^5+2*x^4-x^3-x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-2*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^4-x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4+x^3-2*x^2+2*x-1,{2}>,
<3*x^6+3*x^5+x^4+x^3-2*x^2-x+3,{2,3}>,
<-2*x^6+2*x^5-2*x^4+x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2+3*x-3,{2}>,
<-2*x^6+x^5-2*x^4-x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-x^3-2*x^2-2*x-3,{2}>,
<3*x^6+3*x^5+x^4+x^3-2*x^2-x-3,{2,3}>,
<-x^6-x^5+2*x^4-x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4-x^3-2*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+x^4+x^3-2*x^2+x-1,{2,3}>,
<-x^6-2*x^5+2*x^4+x^3-x^2+3*x-3,{2}>,
<-x^6+2*x^5-2*x^4-x^3+x^2-3*x+3,{2}>,
<2*x^6+x^5+2*x^4+x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4-x^3+2*x^2+2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^3-x^2+3*x-3,{}>,
<-3*x^6+3*x^5+3*x^4+x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+x^2-3*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2+3*x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+x^3-3*x^2+2*x-1,{2,3}>,
<2*x^6+3*x^5-3*x^4+x^3+x^2+3*x+3,{2,11}>,
<-3*x^6-3*x^5-x^4-x^3+3*x^2-2*x+2,{2}>,
<3*x^6-3*x^5+x^4-x^3-3*x^2-2*x-2,{2,5,7}>,
<3*x^6-2*x^5+3*x^4-x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4-x^3+3*x^2-x-2,{2,3}>,
<2*x^6+x^5-3*x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^3-3*x^2+x-1,{2,3}>,
<-3*x^6-2*x^5-x^4-2*x^3+x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^3-x^2-x-3,{2,3,7,11}>,
<3*x^6-3*x^5+x^4-2*x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6+3*x^5+x^4+2*x^3-x^2-1,{2}>,
<-3*x^6+x^5-3*x^4+x^3+x^2+3*x+3,{2,3,13,17,23}>,
<-2*x^6-x^4+2*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-x^3-3*x^2+2,{2}>,
<-3*x^6+3*x^5-x^4+x^3+3*x^2-1,{2,3}>,
<-3*x^6-3*x^5-x^4-x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4+x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^4+x^3-x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^4+x^3+x^2+3*x+3,{2}>,
<-x^6-x^5-3*x^4+x^3+x^2+3*x+3,{2,3}>,
<2*x^6+2*x^5+3*x^4-x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3+x^2-3*x+3,{2}>,
<-x^6+2*x^5-3*x^4-x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^3-3*x^2+3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2-3*x-3,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^3+3*x-1,{2,3}>,
<-x^6-3*x^5-x^3+x^2-3*x+3,{}>,
<-3*x^6+3*x^5-x^4+x^3+3*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5+x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4-3*x^2-x+2,{2}>,
<3*x^6+3*x^5+x^4+3*x^2+3,{2,3}>,
<3*x^6+3*x^5+x^4+3*x^2+2,{2}>,
<2*x^6-3*x^4-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^2-x-3,{2,3,19}>,
<2*x^6+2*x^5+3*x^4+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-3*x^2-2*x+2,{2,3}>,
<-2*x^6+3*x^4+x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4-x^2+3*x-3,{}>,
<-3*x^6+2*x^5+3*x^4+x^2-3*x+3,{}>,
<3*x^6-x^5+3*x^4+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^2-x+2,{}>,
<2*x^6+3*x^5-3*x^4-x^2-3*x-3,{2,5,23}>,
<3*x^6+3*x^5+x^4+3*x^2-3*x-2,{2}>,
<2*x^6+x^5-3*x^4-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5+3*x^4+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4-2*x^2-3*x+3,{2,3}>,
<3*x^6+x^5-3*x^4-x^2-3*x-3,{2,3,19}>,
<-3*x^6+x^5+2*x^4+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^2+x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4-2*x^2+x+2,{2,3,5}>,
<-2*x^6+x^5+2*x^4+x^2-3*x+3,{2}>,
<2*x^6-x^5+x^4+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^2+x-2,{2}>,
<3*x^6+x^5-x^4-x^2+3*x-3,{2,3}>,
<-3*x^6-x^5+x^4+x^2-3*x+3,{2}>,
<-x^6-x^5+x^4+x^2+3*x+3,{2}>,
<2*x^6+x^5-x^4-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^2+2*x+2,{2,3}>,
<-x^6+2*x^5+x^4+x^2-3*x+3,{2}>,
<3*x^6+x^5+3*x^4-x^3-x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4+x^2-3*x+2,{2}>,
<3*x^6-3*x^5+x^4+x^2+3*x-2,{2}>,
<3*x^6+3*x^5+x^4+x-1,{}>,
<2*x^6+x^5-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4-x^2+3*x+3,{2,3}>,
<-2*x^6+x^5+x^2+3*x+3,{2}>,
<-2*x^6-3*x^5+x^2-3*x+3,{2}>,
<3*x^6+x^5-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-2*x+3,{2}>,
<3*x^6-3*x^5+x^4-x-3,{2}>,
<-x^6+2*x^5+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4-2,{2,3}>,
<-3*x^6-3*x^5-x^4-2*x+2,{2}>,
<-3*x^6-x^5+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x-2,{2,3}>,
<3*x^6-3*x^5+x^4+2*x+2,{2,5}>,
<3*x^6-3*x^5+x^4-x+3,{}>,
<-3*x^6-3*x^5-x^4+2*x+2,{2}>,
<3*x^6-3*x^5+x^4-x+2,{2}>,
<-x^6-3*x^5-x^2+3*x-3,{2,7}>,
<3*x^6-3*x^5+x^4+3*x-1,{2,3}>,
<-2*x^6+x^5-x^4+x^2+3*x+3,{}>,
<-3*x^6-3*x^5-x^4+3*x+2,{2}>,
<3*x^6+x^4-x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4-x^2-3,{2,3}>,
<-2*x^6+3*x^5+x^2-3*x+3,{2}>,
<2*x^6+x^5-x^4+x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-x^2+x-2,{2}>,
<-3*x^6+3*x^5-x^4+x^2+3*x+3,{2,3}>,
<3*x^6-x^5+x^4-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-x^2-2*x-1,{2}>,
<-3*x^6-x^5-x^4+x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-x^4+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-x^2+2*x+3,{2,3}>,
<-x^6+2*x^5+x^4-x^2-3*x-3,{2}>,
<3*x^6-x^5-x^4+x^2-3*x+3,{}>,
<3*x^6-3*x^5+x^4-x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5-x^4+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+x^2+3*x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^2-3*x+3,{}>,
<2*x^6+2*x^5+2*x^4-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4-2*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5-x^4+2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+x^4-2*x^2-x-1,{2}>,
<3*x^6-3*x^5+x^4-x^2-x-1,{2,3,7,43}>,
<-3*x^6-3*x^5-x^4+2*x^2-x+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^2-x-3,{2,3}>,
<-3*x^6-3*x^5-x^4+x^2-x+2,{}>,
<-2*x^6-2*x^4+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^2-x+3,{2,3}>,
<3*x^6-3*x^5+x^4-2*x^2+x+2,{2}>,
<-x^6+2*x^5+2*x^4-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-2*x^2-x-1,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^2+3*x-2,{2}>,
<-3*x^6+3*x^5-x^4+3*x^2+3*x-2,{2,3}>,
<-3*x^6-3*x^5-x^4-x^3+3*x^2+3*x-2,{2}>,
<-x^6+3*x^5-3*x^4+x^2+3*x+3,{2}>,
<-x^6-3*x^5+3*x^4+x^3-x^2+3*x-3,{2}>,
<2*x^6+3*x^5+3*x^4-x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-3*x^4+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4+3*x^2+3*x-2,{2,3}>,
<-3*x^6-3*x^5-x^4+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5+x^4+3*x^2+3*x-3,{}>,
<-x^6+2*x^5-3*x^4+x^2+3*x+3,{2,5}>,
<3*x^6+2*x^5+3*x^4+x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-x^4+3*x^2+2*x+2,{2,3}>,
<-x^6-x^5+3*x^4-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4+3*x^2+x+3,{2}>,
<2*x^6-x^5+3*x^4+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^2+x+2,{2,3}>,
<3*x^6-3*x^5+x^4-3*x^2-x-2,{2,3}>,
<3*x^6-x^5+3*x^4-x^2-3*x-3,{2}>,
<-3*x^6+x^5-3*x^4+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4+3*x^2-3*x-1,{2,3}>,
<3*x^6+2*x^4+x^3+x^2+3*x+3,{2}>,
<-2*x^6-3*x^5-3*x^4+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4-x^3+2*x^2-3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+3*x+3,{2}>,
<-x^6-2*x^5+3*x^4+x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4-3*x^2-1,{2,3}>,
<-3*x^6+3*x^5-x^4-x^3-3*x^2+2*x+2,{2}>,
<3*x^6-3*x^5+x^4-3*x^2-2,{2,3}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2-x+2,{2}>,
<3*x^6+3*x^5+x^4+x^3+2*x^2-x+3,{2,3}>,
<3*x^6-x^5-3*x^4+x^2+3*x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3-x^2-3*x-3,{2,3}>,
<2*x^6-x^5+3*x^4-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4+x^3+2*x^2-2*x+3,{}>,
<-x^6-2*x^5+3*x^4-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^2+3*x+3,{2}>,
<-2*x^6+3*x^4-x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^4+x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2+x+2,{2}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2+x-3,{2,3}>,
<-x^6-2*x^5+3*x^4-x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4+x^3+2*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+x^3+3*x^2+3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+x^3-3*x^2+3*x+2,{2,3,5}>,
<-3*x^6-3*x^5-x^4+x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2+3*x+3,{2,3,13}>,
<-2*x^6+2*x^4+x^3+x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-x^3-2*x^2+3,{2}>,
<-3*x^6+3*x^5-x^4-x^3-2*x^2+3*x+3,{}>,
<3*x^6+x^5+2*x^4+x^3+x^2-3*x+3,{}>,
<3*x^6+3*x^5+x^4-x^3+2*x^2+3*x-3,{}>,
<-3*x^6-3*x^5-x^4+x^3-2*x^2+x+2,{2}>,
<3*x^6+3*x^5+x^4-x^3+2*x^2-x-2,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3-x^2-3*x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3+x^2-3*x+3,{2,3,43}>,
<3*x^6+3*x^5+x^4-x^3+2*x^2-2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+x^3+2*x^2+3,{2}>,
<-3*x^6-3*x^5-x^4+x^3-2*x^2+3*x+2,{2,3}>,
<-x^6+2*x^4+x^3+x^2-3*x+3,{2}>,
<2*x^6-2*x^4+x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+x^3-x^2-3*x+2,{}>,
<-2*x^6+3*x^5+x^4-x^3+x^2+3*x+3,{}>,
<-3*x^6-3*x^5+x^4+x^3+x^2-3*x+3,{}>,
<3*x^6-3*x^5+x^4+x^3+x^2-2*x+2,{}>,
<-3*x^6+3*x^5-x^4-x^3-x^2+2,{2}>,
<3*x^6-3*x^5+x^4+x^3+x^2+x+2,{2}>,
<3*x^6+3*x^5+x^4-x^3+x^2-x-1,{2,3,5,17}>,
<-3*x^6+3*x^5-x^4-x^3-x^2-x+2,{2}>,
<3*x^6-x^5-x^4-x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^3+x^2+2*x+3,{2,3}>,
<2*x^6+2*x^5+x^4+x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-x^3-x^2-2*x+2,{2,3}>,
<3*x^6+3*x^5+x^4-x^3+x^2-2*x-2,{2,3}>,
<3*x^6-2*x^5-x^4-x^3-x^2+3*x-3,{}>,
<3*x^6+3*x^5+x^4-x^3+x^2-2*x-3,{}>,
<-x^6-3*x^5-x^4-x^3-x^2+3*x-3,{2,5}>,
<-3*x^6+3*x^5-x^4-x^3-x^2-3*x+2,{2}>,
<3*x^6+3*x^5+x^4-x^3+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+x^3-3*x-1,{2}>,
<-3*x^6+3*x^5-x^4-x^3+3*x+2,{}>,
<-2*x^6-3*x^5+x^3+x^2-3*x+3,{}>,
<-3*x^6+3*x^5-x^3+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-x^3+2*x+3,{2}>,
<3*x^6+3*x^5+x^4-x^3+2*x+2,{2,3}>,
<-x^6+2*x^5-x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4+x^2-3*x-1,{}>,
<3*x^6+3*x^5+x^4-x^3+2*x-2,{2}>,
<3*x^6+2*x^5-x^3-x^2+3*x-3,{2,3}>,
<-3*x^6-2*x^5+x^3+x^2-3*x+3,{2}>,
<3*x^6-x^5+x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-x^3-3,{2}>,
<3*x^6-x^5-x^3+x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-x^3-2*x+3,{2}>,
<2*x^6-2*x^5-x^3+x^2+3*x+3,{2}>,
<2*x^6-2*x^5-x^3-x^2+3*x-3,{2}>,
<-2*x^6-2*x^5-x^3+x^2+3*x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+3*x-3,{2,3,13,229}>,
<3*x^6-2*x^5-x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^3+x^2-3*x+3,{2}>,
<-2*x^6+2*x^5-x^4-x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+x^3+x^2-x+3,{}>,
<3*x^6+3*x^5+x^4-x^3-3*x+2,{2}>,
<-3*x^6+x^5-x^4-x^3+x^2+3*x+3,{}>,
<-3*x^6+3*x^5-x^4-x^2-2*x+3,{2}>,
<3*x^6+x^4-x^3-x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5-x^4-x^3-3*x-1,{2,3}>,
<-3*x^6-x^5-2*x^4+x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^5-x^4-x^3+2*x^2+2,{2}>,
<-3*x^6+3*x^5-x^4-x^3-3*x+2,{2,3}>,
<3*x^6+3*x^5+x^4-x^3-2*x^2-2,{2}>,
<2*x^6-x^5-2*x^4-x^3+x^2+3*x+3,{}>,
<-3*x^6+3*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<-x^6-3*x^5-x^4+x^3+x^2-3*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+x^3+2*x^2+2*x-1,{2}>,
<-3*x^6-3*x^5-x^4+x^3+x^2+3*x-1,{2,3}>,
<3*x^6-3*x^5+x^4+x^3-x^2-3*x-2,{2,3}>,
<-3*x^6-2*x^5-2*x^4-x^3+x^2+3*x+3,{2}>,
<-x^6+2*x^5-x^4-x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+x^3+2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2-3*x-3,{2}>,
<2*x^6-2*x^5+x^4+x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^3-3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-x^2+3*x-3,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-x^3-3*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5-x^4+x^3+3*x^2-2*x+3,{2}>,
<-x^6-3*x^4+x^3+x^2-3*x+3,{2}>,
<2*x^6+3*x^4+x^3-x^2-3*x-3,{2,3}>,
<3*x^6+x^5-3*x^4+x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-x^5-3*x^4-x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+x^3-3*x^2+3*x+3,{}>,
<3*x^6-3*x^5+2*x^4+2*x^3+3*x^2+2*x-2,{2,3,17,461}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-3*x-3,{2,19}>,
<2*x^6-x^5+3*x^4+2*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2+x-2,{2,3,17}>,
<-3*x^6-3*x^5-x^4+2*x^3-3*x^2-x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2+x-3,{2,3}>,
<2*x^6+3*x^4-2*x^3+x^2+3*x+3,{2}>,
<2*x^6-3*x^4-2*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^4-2*x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2-3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2-x-1,{2,3}>,
<-2*x^6+x^5-2*x^4+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3-3*x^2-x+2,{}>,
<3*x^6-x^5+2*x^4-x^2+3*x-3,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+x^2-3*x+3,{}>,
<-3*x^6+3*x^5-x^4-2*x^3-3*x^2-x+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+3*x^2+2*x+2,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4-2*x^3-x^2+3*x-3,{2,3}>,
<2*x^6-2*x^5-2*x^4+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2-x+3,{2,3}>,
<2*x^6-x^5+2*x^4+2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2-x-1,{2,3}>,
<3*x^6+2*x^5-x^4-x^3-x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^3-2*x^2-x+2,{2,3}>,
<3*x^6-3*x^5+x^4+x^3+x^2-2*x-3,{2,3}>,
<-2*x^6+x^5+2*x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6+x^5+x^4-x^3+x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^3-2*x^2-x+3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^3+x^2-x-3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2+3,{2,3}>,
<3*x^6-3*x^5+x^4+x^3+x^2+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6-2*x^4+2*x^3-x^2-3*x-3,{2,3}>,
<2*x^6-2*x^4+2*x^3-x^2-3*x-3,{2}>,
<-2*x^6+2*x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3+x^2+3*x+3,{2,5}>,
<-x^6+x^5+x^4-2*x^3+x^2+3*x+3,{2}>,
<2*x^6+x^5-x^4-2*x^3-x^2+3*x-3,{2}>,
<2*x^6+2*x^5-x^4+2*x^3-x^2-3*x-3,{2}>,
<2*x^6-x^4-2*x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3-x^2+2*x+3,{2,3}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3-x^2+3*x+2,{2}>,
<3*x^6-3*x^5+2*x^3+x^2-3*x+3,{}>,
<-x^6+3*x^5-2*x^3-x^2+3*x-3,{2,3}>,
<2*x^6-3*x^5+2*x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3-x^2+x+3,{2,3}>,
<-2*x^6-3*x^5+2*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3+x^2-x-3,{2,3}>,
<-x^6+2*x^5+x^4+2*x^3+x^2-3*x+3,{}>,
<-2*x^6-2*x^5+2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3-2*x+3,{2,3}>,
<-3*x^6+x^5-2*x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3+3,{2,3}>,
<3*x^6+3*x^5+x^4-2*x^3+2,{2}>,
<2*x^6+2*x^3-x^2-3*x-3,{2}>,
<2*x^6+x^5+2*x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^3+x+2,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-x-2,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3+x+3,{2,3}>,
<3*x^6-2*x^5-2*x^3+x^2+3*x+3,{2,3}>,
<2*x^6-2*x^5-2*x^3+x^2+3*x+3,{2}>,
<-x^6+3*x^5+2*x^3-x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5-2*x^3+x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5-x^4-2*x^3+x^2+3*x+2,{2,3}>,
<-2*x^6-3*x^5-x^4+2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+2*x^3+x^2-3*x+3,{2}>,
<2*x^6+x^5-x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-x^2+x-2,{}>,
<-3*x^6-3*x^5-x^4+2*x^3+x^2-x+3,{2,3}>,
<3*x^6+3*x^5+x^4+x^2+2*x-2,{2,5}>,
<3*x^6-2*x^5-x^4-x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5+x^4+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3-2*x^2-x-1,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^3-x^2+3*x-3,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-2*x^2-x+3,{2,3,5}>,
<-x^6+x^5+2*x^4+2*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-2*x^2-x-3,{2,3,7}>,
<3*x^6+3*x^5+x^4-2*x^3-2*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5-x^4-x^3-3*x^2+2,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<2*x^6-3*x^5+2*x^4-2*x^3-x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3+2*x^2+3*x-2,{2,3,7}>,
<-3*x^6+3*x^5-x^4-2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-x^6-x^5-3*x^4+x^3+x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3-3*x^2-2*x-1,{2,3}>,
<3*x^6-3*x^4+2*x^3+x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^4+2*x^3+3*x^2-1,{2}>,
<-3*x^6-3*x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-3*x^2-x+2,{}>,
<-x^6+x^5+3*x^4+2*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-3*x^2-x-2,{}>,
<-3*x^6-3*x^5-x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3+3*x^2-x+3,{}>,
<-3*x^6+x^5-3*x^4+2*x^3+x^2-3*x+3,{}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2+3*x+2,{}>,
<3*x^6-x^5-3*x^4+2*x^3+x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2-3*x-3,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3+3*x^2-2*x-2,{2}>,
<-x^6+x^5-3*x^4-2*x^3+x^2+3*x+3,{2}>,
<3*x^6+3*x^5+x^4-2*x^3+3*x^2+2*x+3,{}>,
<3*x^6-3*x^5+x^4+2*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+3*x^5+x^4-2*x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6+3*x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x^2-3*x+3,{2,3}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-x^2-3*x-3,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2-3*x-3,{2,11}>,
<-3*x^6+3*x^5-x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5-x^4+2*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6+3*x^5+x^4-x^3-2*x^2+3*x-2,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-3*x-3,{2}>,
<3*x^6+3*x^5+x^4-x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^3+x^2+3*x+3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+x^3+2*x^2-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6-x^4+2*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3-x^2+2*x+3,{}>,
<-x^6+2*x^5+x^4+2*x^3-x^2-3*x-3,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+x^3-3*x^2+2*x+2,{2,3}>,
<-3*x^6+3*x^5-x^4-x^3+3*x^2-2*x-1,{2}>,
<3*x^6-3*x^5+x^4+x^3-3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2+3,{2,3}>,
<-2*x^6+3*x^4-3*x^3+x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-3*x^2+x+2,{2,3}>,
<3*x^6+x^5+3*x^4-x^3-x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+x^4-3*x^3+2*x^2-2*x-1,{}>,
<3*x^6-3*x^4-x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-2*x^2+2*x+2,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-x^2+3*x-3,{2,3}>,
<3*x^6-x^4-3*x^3-x^2+3*x-3,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2-3*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-x^2+x+2,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-x^2+x+3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2-3*x-3,{2}>,
<-x^6+2*x^5+x^4-3*x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4-3*x^3+x^2-2*x-1,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2+x-3,{2}>,
<2*x^6-x^5+x^4+3*x^3+x^2-3*x+3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-x^2+3*x-3,{2,5}>,
<-x^6-x^5+x^4+3*x^3+x^2-3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-3*x-1,{2,3}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2+3*x+3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3-x^2-x+2,{2}>,
<-3*x^6+2*x^5-3*x^3+x^2+3*x+3,{2}>,
<3*x^6-x^5+3*x^3+x^2-3*x+3,{2}>,
<2*x^6-x^5+3*x^3-x^2-3*x-3,{2,3,37}>,
<3*x^6-3*x^3+x^2+3*x+3,{2,3,31}>,
<2*x^6-3*x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-1,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3+x^2+3*x+3,{2,5}>,
<-3*x^6+3*x^5-x^4-3*x^3+2,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3-2*x^2-2*x+2,{}>,
<-2*x^6+3*x^3+x^2-3*x+3,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-x+2,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-x^2-2*x-2,{}>,
<2*x^6-x^5-3*x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3+x^2+2*x+3,{2,3}>,
<-x^6+3*x^5-2*x^4+2*x^3-x^2-3*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3-2*x-1,{2,3}>,
<2*x^6-3*x^5-2*x^4-2*x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3+x^2+3*x-2,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+3*x^5-x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+2*x^3+x^2-3*x-2,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2+2*x-2,{2}>,
<-x^6-2*x^5-2*x^4+3*x^3+x^2-3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2+3*x-3,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2+x+2,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-2*x^2-x+2,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3+2*x^2-x-1,{2,11}>,
<-2*x^6-x^5+2*x^4+3*x^3+x^2-3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2+3*x-3,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+x^2-3*x+3,{}>,
<-3*x^6+3*x^5-x^4-3*x^3+3*x^2+x-1,{2,3}>,
<-3*x^6-3*x^5-x^4+3*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4-3*x^3+x^2+3*x+3,{2,3}>,
<2*x^6-x^5-2*x^4-3*x^3-x^2+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x+3,{}>,
<3*x^6-x^5-2*x^4-3*x^3-x^2+3*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+x^2-3*x+3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x+2,{2,139}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2+3*x-3,{2,3,7}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x-2,{2,3,7}>,
<3*x^6+3*x^5+x^4-2*x^3-x^2-3*x-2,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3+x^2-3*x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4-2*x^3-x^2+3*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^3+2*x^2-x-2,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^3-2*x^2+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3+3*x-3,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-3*x+3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^3+2*x^2-x-3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3+3*x^2+3*x+2,{2,3}>,
<-3*x^6-3*x^5-x^4+3*x^3-3*x^2+3*x+2,{2,3}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+x^2-3*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+x^2-3*x+3,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+x^2-3*x+3,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^3-x^2+3*x-2,{2,7}>,
<-3*x^6-3*x^5-3*x^3-x^2-3*x+2,{}>,
<3*x^6-3*x^5-3*x^3+x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-3*x-3,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^3+x^2-2*x-2,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+3*x-3,{2}>,
<2*x^6-x^5+x^4-3*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^3+x^2-x-1,{}>,
<-3*x^6+3*x^5+3*x^3-x^2+x+2,{2}>,
<3*x^6-x^5-x^4-3*x^3-3*x-3,{2,3}>,
<3*x^6+3*x^5+3*x^3+x^2+x-3,{2}>,
<-2*x^6+x^4-3*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^3+x^2-3,{2}>,
<3*x^6+3*x^5+3*x^3+x^2-x-2,{2}>,
<-3*x^6+x^5+x^4-3*x^3-3*x+3,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^3+x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4-3*x^3-3*x+3,{2}>,
<3*x^6+2*x^5-x^4-3*x^3-3*x-3,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3+3*x+3,{2,5}>,
<-3*x^6+3*x^5+3*x^3+2*x-3,{}>,
<-2*x^6+2*x^5+3*x^3+3*x-3,{2}>,
<-x^6-2*x^5-3*x^3-3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^3-2*x+2,{}>,
<-3*x^6+3*x^5+3*x^3+2*x+3,{}>,
<-3*x^6-2*x^5-3*x^3-3*x+3,{}>,
<3*x^6+x^5+3*x^3+3*x+3,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^3-x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+x^2+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^3-x+2,{2}>,
<-x^6-3*x^5-3*x^4+3*x^3+x^2-3*x+3,{}>,
<-x^6+x^5+3*x^3+3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^3-x+2,{2}>,
<3*x^6+3*x^5+x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-x^6+3*x^5+3*x^3-x^2-3*x-3,{2}>,
<-2*x^6-x^5-3*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^3+x+3,{}>,
<3*x^6-3*x^5-3*x^3-x-3,{}>,
<-2*x^6-3*x^5-3*x^3+x^2+3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-3*x^3-x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^3-2,{2,5}>,
<-x^6+x^5-3*x^3-3*x+3,{2,7}>,
<3*x^6+2*x^5-3*x^3-3*x+3,{2}>,
<-2*x^6-2*x^5+3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-x^2-2*x+2,{2,3}>,
<3*x^6+3*x^5+3*x^3-2*x-1,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3+x^2+3*x+3,{2}>,
<2*x^6+2*x^5-3*x^3-3*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^3-x^2+2,{2}>,
<-x^6+x^4+3*x^3+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^3-x^2-1,{2}>,
<-2*x^6-x^4-3*x^3-3*x+3,{2}>,
<3*x^6+x^4-3*x^3-3*x-3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-x^2-2*x-3,{2}>,
<-x^6+x^5+x^4-3*x^3-3*x-3,{2}>,
<2*x^6-x^5+x^4+3*x^3+3*x-3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-x^2+3,{2,3}>,
<-3*x^6+3*x^5+3*x^3+x^2-x+3,{2}>,
<-3*x^6+3*x^5+3*x^3+x^2-2*x+3,{}>,
<-3*x^6-2*x^5-x^4+3*x^3+3*x+3,{}>,
<-x^6-x^5+x^4-3*x^3-x^2+3*x-3,{2,5,17,23}>,
<-3*x^6-3*x^5-3*x^3+2*x^2-3*x-2,{2,3,7}>,
<-3*x^6+x^5+2*x^4+3*x^3+3*x-3,{2}>,
<-x^6-x^5-2*x^4-3*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^3-2*x^2-x-2,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3+3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^3-2*x^2+3,{}>,
<-2*x^6+2*x^4+3*x^3+3*x-3,{2}>,
<-x^6-2*x^4-3*x^3-3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^4-3*x^3-3*x+3,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^3-2*x^2-x+2,{2}>,
<-x^6+x^5-2*x^4-3*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^3+2*x^2-x+3,{2,3,5}>,
<3*x^6+3*x^5+3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6-3*x^5-3*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-3*x^5-3*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+3*x+3,{2}>,
<-x^6-3*x^5-2*x^4+3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^3-2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5-3*x^3+3*x^2-3*x-2,{}>,
<-2*x^6-3*x^5-3*x^4-3*x^3-3*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+3*x-3,{}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x+3,{}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-3*x-3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-3*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3+3*x+3,{2}>,
<3*x^6+3*x^5+3*x^3-3*x^2+x+3,{}>,
<-2*x^6+x^5+3*x^4+3*x^3+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+x^5+3*x^4-3*x^3-3*x-3,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-3*x-3,{}>,
<-2*x^6+x^5-3*x^4-3*x^3-3*x+3,{}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x-3,{2}>,
<3*x^6+3*x^5+3*x^3-3*x^2-x-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+3*x+3,{}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+3*x-3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-3*x-3,{0,2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3-3*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-3*x-3,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x-3,{2,277}>,
<-3*x^6-3*x^5-3*x^3+x^2-3*x-1,{2}>,
<-3*x^6-3*x^5-3*x^3+x^2-2*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x+3,{2,277}>,
<-x^6-2*x^5+3*x^4-2*x^3-3*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x+3,{2,3}>,
<3*x^6+3*x^5+x^4-3*x^3-3*x^2+2,{2,3}>,
<-3*x^6+3*x^5-x^4-3*x^3+3*x^2-1,{2,3}>,
<-2*x^6-3*x^4-3*x^3+x^2+3*x+3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-x^2-3*x-3,{2}>,
<-x^6+x^5+3*x^4+3*x^3-x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^4+3*x^3-3*x^2+2*x+3,{2,3}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x+3,{}>,
<-3*x^6-3*x^5-2*x^3-3*x^2-x+3,{2}>,
<3*x^6-3*x^5-2*x^3+3*x^2+2,{2}>,
<3*x^6-3*x^4-2*x^3-3*x-3,{}>,
<3*x^6-3*x^5-2*x^3+3*x^2-3,{}>,
<3*x^6-3*x^5-2*x^3+3*x^2+x+3,{}>,
<3*x^6+2*x^5+3*x^4-2*x^3-3*x+3,{2,3}>,
<-x^6-3*x^5+3*x^4+2*x^3+3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5+x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6-3*x^5-x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+2*x+2,{2}>,
<3*x^6+3*x^5+3*x^3+3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+3*x+3,{2}>,
<-2*x^6+3*x^4+3*x^3+3*x+3,{2}>,
<-3*x^6-3*x^5-3*x^3-3*x^2+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+3*x-3,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-3*x+3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-3*x-3,{}>,
<2*x^6+3*x^5+2*x^4+3*x^3+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-3*x+3,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^3-2*x^2+2*x+3,{}>,
<-3*x^6-3*x^5-2*x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6-3*x^5-3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+3*x^5+2*x^3+2*x^2+x+3,{2}>,
<3*x^6+3*x^5+3*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^3-2*x^2-x+2,{2,3,7}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^3+2*x^2-x-3,{2,3}>,
<-3*x^6-3*x^5-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+3*x^5+2*x^3+2*x^2+3,{}>,
<3*x^6+3*x^5+2*x^3+2*x^2+2,{2,3}>,
<2*x^6-2*x^4+2*x^3+3*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^3+2*x^2+2*x-3,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^3-x^2-3*x-2,{2}>,
<3*x^6-3*x^5-2*x^3+x^2-3*x+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x-3,{2}>,
<-x^6-3*x^5+x^4-2*x^3-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^3-x^2+3*x+2,{}>,
<-3*x^6-3*x^5-2*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^3+x^2-2*x+2,{2}>,
<-3*x^6-3*x^5-2*x^3-x^2-2*x-1,{2,3,11}>,
<-x^6+2*x^5+x^4+2*x^3+3*x+3,{}>,
<-3*x^6+3*x^5+2*x^3-x^2+2*x+2,{}>,
<-3*x^6-3*x^5-2*x^3-x^2-2*x+3,{2,5}>,
<-x^6+x^5-3*x^4+3*x^3+3*x+3,{2,5}>,
<-2*x^6+x^5-3*x^4+3*x^3+3*x+3,{}>,
<2*x^6+2*x^5+3*x^4-3*x^3-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3+x^2-2,{2}>,
<3*x^6+3*x^5+2*x^3+x^2-x-1,{2}>,
<2*x^6+x^5-x^4-2*x^3-3*x-3,{2}>,
<-2*x^6-x^5+x^4+2*x^3+3*x+3,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3-3*x+3,{2,3,5}>,
<-3*x^6+3*x^5+2*x^3+3*x-3,{}>,
<3*x^6+3*x^5+2*x^3+x^2+2*x-3,{2,3,157}>,
<3*x^6+3*x^5+2*x^3+3*x+3,{}>,
<3*x^6-3*x^5-2*x^3+x^2-x-2,{2}>,
<3*x^6-x^5-x^4-2*x^3-3*x-3,{2,3,5}>,
<-2*x^6+3*x^5+2*x^3+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3+3*x+2,{2}>,
<3*x^6-3*x^5-2*x^3-3*x-1,{2}>,
<-3*x^6-3*x^5-2*x^3-3*x+2,{2,3,5}>,
<-3*x^6+3*x^5+2*x^3-2*x^2+3,{2,3}>,
<3*x^6+3*x^5+2*x^3+2*x^2-3,{2}>,
<2*x^6+x^5+2*x^4-2*x^3-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^3+2*x^2+x-2,{2}>,
<3*x^6+3*x^5+2*x^3+2*x+3,{}>,
<-3*x^6+3*x^5+2*x^3-2*x^2-x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x-3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+2*x^3+x-2,{2}>,
<3*x^6+x^5+2*x^3+3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^3-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3-3,{2}>,
<3*x^6+3*x^5+2*x^3-3*x-2,{2}>,
<3*x^6+3*x^5+2*x^3-x+3,{2}>,
<-3*x^6+3*x^5+2*x^3-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^3+3*x+3,{2}>,
<2*x^6+x^5-2*x^3-3*x-3,{2,3}>,
<-2*x^6+x^5-2*x^3-3*x+3,{2}>,
<3*x^6+2*x^5-2*x^3-3*x-3,{2}>,
<-2*x^6-x^5+x^4-3*x^3-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3-3*x+2,{2,71}>,
<-x^6+3*x^5-2*x^3-3*x-3,{2}>,
<-3*x^6-3*x^5-3*x^3-2*x^2-3*x-2,{2}>,
<3*x^6+3*x^5+2*x^3-x^2+2*x+3,{}>,
<-3*x^6-3*x^5-3*x^3-2*x^2-3*x-1,{2,3,5}>,
<3*x^6-3*x^5-3*x^3+2*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+3*x-3,{}>,
<-x^6-2*x^5-2*x^4-3*x^3-3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x-3,{}>,
<3*x^6-3*x^5-2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+3*x+3,{2,3}>,
<2*x^6+3*x^5-x^4+2*x^3+3*x+3,{2}>,
<-x^6+3*x^5+x^4+2*x^3+3*x-3,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2+x-3,{}>,
<3*x^6-3*x^5-2*x^3-x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+2*x^3+x^2-2*x+2,{2,3}>,
<3*x^6+3*x^5+2*x^3+x^2+3,{2}>,
<-x^6+x^4+2*x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^3-x^2+2,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6-3*x^5-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+3*x+3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+3*x^5+3*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+3*x-3,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x+3,{2}>,
<-3*x^6-3*x^5-2*x^3+x^2-2*x+2,{}>,
<3*x^6-3*x^5-2*x^3-x^2-2*x-2,{}>,
<-3*x^6+3*x^5+2*x^3+x^2+2*x+3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2-2*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2-x+3,{2}>,
<2*x^6+2*x^4+2*x^3+3*x-3,{2,3}>,
<3*x^6+2*x^4+2*x^3+3*x-3,{2,3}>,
<-3*x^6-2*x^4+2*x^3+3*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-2*x^3-3*x+3,{2,3}>,
<3*x^6+3*x^5+2*x^3-2*x^2-x+2,{2}>,
<3*x^6+3*x^5+3*x^3-3*x^2-3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5-2*x^3+2*x^2+x-1,{2,3,5,11,13}>,
<-3*x^6-3*x^5-3*x^3+x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2+3*x+2,{2,3,5}>,
<-3*x^6-3*x^5-3*x^3+3*x^2+x-3,{2}>,
<3*x^6+3*x^5+2*x^3-2*x^2-x-2,{2}>,
<-3*x^6-3*x^5-2*x^3+x^2+3*x-1,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^3+x^2-3*x+2,{2}>,
<3*x^6-3*x^5-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-3*x^5-3*x^3-x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-3*x+3,{2,3}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^3+2*x^2-3*x+2,{2,3}>,
<3*x^6+3*x^5+2*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-3*x^2-3*x+3,{}>,
<3*x^6-3*x^5-2*x^3-3*x^2-2,{}>,
<-3*x^6-3*x^5-2*x^3+3*x^2+3,{2}>,
<-3*x^6+3*x^5+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-3*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^3+3*x^2+3*x-1,{}>,
<-2*x^6-x^5+3*x^4+2*x^3+3*x-3,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x+3,{2,3}>,
<2*x^6+3*x^5+3*x^4+2*x^3+3*x-3,{2,7}>,
<-x^6+x^5+3*x^4-2*x^3-3*x-3,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^3-3*x^2-x-2,{2}>,
<3*x^6-x^5+3*x^4+2*x^3+3*x-3,{2}>,
<-x^6-3*x^5+3*x^4-x^3-3*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^3-3*x+3,{2}>,
<2*x^6+2*x^5+2*x^3+3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3+2*x-2,{2}>,
<-2*x^6+x^5-x^4+2*x^3+3*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+3*x-3,{2,3}>,
<-3*x^6+3*x^4-x^3-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+3*x+3,{2}>,
<3*x^6+3*x^5+x^3+3*x^2-2*x+2,{2}>,
<3*x^6+3*x^5+2*x^3-x^2+x-1,{}>,
<3*x^6-3*x^5-2*x^3-2*x^2-2*x+2,{2,7}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x-3,{2,3}>,
<2*x^6-2*x^5+2*x^4-2*x^3-3*x-3,{2,3}>,
<3*x^6+3*x^5+2*x^3-2*x^2+2*x-2,{2,7}>,
<-3*x^6-2*x^5-2*x^4-2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^3-x^2-x-3,{2,3}>,
<-3*x^6-3*x^5-2*x^3+x^2-1,{2}>,
<2*x^6-x^5-2*x^4-x^3-3*x-3,{2}>,
<3*x^6-x^5-2*x^4-x^3-3*x-3,{2}>,
<3*x^6+3*x^5+2*x^3-x^2-1,{2}>,
<2*x^6+x^4+2*x^3+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^3+x^2+3,{2}>,
<-x^6+x^5-x^4-2*x^3-3*x+3,{2,3}>,
<3*x^6+x^5+x^4-2*x^3-3*x-3,{}>,
<-3*x^6-3*x^5-x^3-2*x^2+2*x+2,{2}>,
<-x^6+3*x^5+2*x^4-x^3-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+3*x^5+x^3-2*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+x^4-x^3-3*x+3,{2}>,
<-x^6-3*x^5-x^4-x^3-3*x-3,{2}>,
<3*x^6-3*x^5-x^3+x^2-3*x-1,{2,5}>,
<-3*x^6+3*x^5+x^3-x^2+3*x+2,{}>,
<3*x^6+3*x^5-x^4+x^3+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+3*x+3,{2}>,
<3*x^6-3*x^5-x^3+x^2-2*x-2,{2}>,
<-3*x^6+3*x^5+x^3-x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5+x^3+x^2+2*x-3,{2,3}>,
<3*x^6-x^5+x^4-x^3-3*x+3,{2}>,
<-3*x^6-3*x^5-x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+x^4+x^3+3*x+3,{2}>,
<-3*x^6-x^5+x^4-x^3-3*x+3,{2,3}>,
<2*x^6+2*x^4-x^3-3*x+3,{2}>,
<2*x^6+x^4+x^3+3*x+3,{2}>,
<3*x^6+3*x^5+x^3+2*x^2-2,{2}>,
<3*x^6+3*x^5+x^3+x^2-1,{2}>,
<-3*x^6-3*x^5-x^3-2*x^2+3,{2}>,
<-3*x^6-3*x^5-x^3-x^2+2,{2}>,
<-3*x^6+2*x^4+x^3+3*x+3,{2}>,
<-3*x^6-x^5+2*x^4+x^3+3*x+3,{2}>,
<3*x^6-x^4-x^3-3*x-3,{2,3}>,
<3*x^6+3*x^5+x^3+x^2-3,{2,3}>,
<3*x^6+x^5-x^4-x^3-3*x-3,{2}>,
<3*x^6+3*x^5+x^3+x^2-2*x-3,{2}>,
<-3*x^6-3*x^5-x^3-x^2+3*x+2,{2}>,
<3*x^6-3*x^5-x^3-3*x+3,{2}>,
<3*x^6-3*x^5-x^3-3*x+2,{2}>,
<3*x^6-3*x^5-x^3+2*x^2+2*x+3,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+3*x-1,{2,17}>,
<-2*x^6+2*x^5+x^3+3*x+3,{}>,
<-3*x^6+3*x^5+x^3+2*x+3,{2}>,
<-2*x^6+3*x^5+x^3+3*x+3,{2}>,
<-x^6-x^5-x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+x+3,{2}>,
<3*x^6-3*x^5-x^3+3,{}>,
<-x^6-x^3-3*x+3,{2}>,
<-3*x^6-3*x^5-x^3+2,{2}>,
<-2*x^6-x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+3*x+3,{2}>,
<-2*x^6-2*x^5+x^3+3*x+3,{2}>,
<-3*x^6-3*x^5-x^3+2*x+3,{2}>,
<3*x^6+3*x^5-x^3-3*x+3,{}>,
<-3*x^6-3*x^5-x^3+3*x-1,{2}>,
<-3*x^6+3*x^5+x^3+x^2+3*x-3,{2,3,17}>,
<-3*x^6-3*x^5-x^3+x^2-3*x-2,{2}>,
<-x^6+3*x^5-x^4+x^3+3*x+3,{2}>,
<2*x^6+3*x^5+x^4+x^3+3*x-3,{}>,
<-2*x^6+3*x^5-x^4+x^3+3*x+3,{}>,
<3*x^6-3*x^5-x^3-x^2-2*x+3,{2}>,
<-3*x^6-3*x^5-x^3+x^2-2*x-2,{2}>,
<3*x^6-3*x^5-2*x^3-3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5-x^4+x^3+3*x+3,{2}>,
<-3*x^6-3*x^5-x^3+x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5+x^4+x^3+3*x-3,{2,3,7}>,
<-x^6-x^4-x^3-3*x+3,{2}>,
<-3*x^6-3*x^5-x^3+x^2+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-3*x-3,{2}>,
<3*x^6+x^5-x^4-x^3-3*x+3,{2}>,
<2*x^6+x^5+x^4-x^3-3*x-3,{2}>,
<-3*x^6+2*x^5-x^4+x^3+3*x+3,{2}>,
<3*x^6+3*x^5+x^3-x^2-x-2,{2}>,
<-x^6-x^5+x^4-x^3-3*x-3,{2}>,
<-3*x^6-x^5-x^4+x^3+3*x+3,{2,3}>,
<3*x^6-2*x^5-x^4+x^3+3*x+3,{}>,
<3*x^6+3*x^5+x^3-x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+2*x^3+3*x+3,{2}>,
<-x^6+2*x^5+x^4-x^3-3*x-3,{2}>,
<-x^6-2*x^5-x^4+x^3+3*x+3,{2,3}>,
<2*x^6-2*x^5+x^4+x^3+3*x-3,{2}>,
<3*x^6+3*x^5+x^3-x^2-2*x-2,{2}>,
<3*x^6-2*x^5+x^4+x^3+3*x-3,{2,3}>,
<2*x^6+3*x^5-x^4-x^3-3*x+3,{2,3}>,
<-3*x^6-3*x^5-x^3+2*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5+x^3+x^2-3*x-1,{}>,
<-x^6+2*x^5-2*x^4+x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+2*x^2+2*x+2,{}>,
<3*x^6+3*x^5+x^3-2*x^2+2*x-2,{}>,
<-3*x^6-3*x^5-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-3*x^5-x^3+2*x^2-x-1,{2}>,
<2*x^6-2*x^4+x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+2*x^2+3*x-3,{2,3,11}>,
<-x^6+2*x^4+x^3+3*x-3,{2}>,
<-3*x^6-3*x^5-x^3+2*x^2+2,{2,3}>,
<3*x^6-3*x^5-x^3-2*x^2-2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+3*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^3+2*x^2+x-2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-3*x-3,{}>,
<3*x^6+3*x^5+x^3+3*x^2-3*x-2,{}>,
<-x^6+x^5-2*x^4+2*x^3+3*x+3,{2}>,
<-x^6+3*x^5+3*x^4+x^3+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3-3*x+3,{2}>,
<3*x^6+3*x^5+x^3-3*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+3*x-3,{2}>,
<3*x^6-3*x^5-x^3-3*x^2-2*x-3,{2,3}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6+3*x^5+x^3+3*x^2-2*x-2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+3*x-3,{2,3}>,
<3*x^6+3*x^5+x^3-3*x^2+3,{2}>,
<-3*x^6-3*x^5-x^3+3*x^2-2,{2}>,
<3*x^6-3*x^5-2*x^3-3*x^2-x-3,{2,3}>,
<2*x^6-3*x^4+x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+x^3+3*x^2-1,{2}>,
<-x^6-3*x^4-x^3-3*x+3,{2}>,
<2*x^6+3*x^4-x^3-3*x-3,{2}>,
<-3*x^6-3*x^5-2*x^3+3*x^2-3,{2,13}>,
<3*x^6+3*x^5+x^3-3*x^2-2,{2}>,
<-3*x^6-3*x^5-x^3+3*x^2+3,{2}>,
<-2*x^6+3*x^4-2*x^3-3*x-3,{2,7}>,
<3*x^6+3*x^5+2*x^3-3*x^2+2,{2,7}>,
<-3*x^6-3*x^5-2*x^3+3*x^2+2,{}>,
<3*x^6+3*x^5-3*x^4+3*x-3,{2}>,
<3*x^6+3*x^5+3*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5-3*x^2-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^2-2*x-3,{2}>,
<3*x^6+x^5+3*x^4+3*x+3,{}>,
<-3*x^6-x^5+3*x^4-3*x+3,{2}>,
<-2*x^6+x^5+3*x^4+x^3+3*x-3,{2}>,
<2*x^6-x^5-3*x^4-x^3-3*x+3,{2,3}>,
<2*x^6+x^5+3*x^4+x^3+3*x-3,{2}>,
<-2*x^6-x^5-3*x^4-x^3-3*x+3,{2}>,
<3*x^6+3*x^5+x^3-2*x^2-3,{2}>,
<3*x^6-3*x^5-x^3-2*x^2+x-2,{2}>,
<-3*x^6+3*x^5+x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3+3*x-3,{2,3,5}>,
<3*x^6-3*x^5-x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5-x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+x^5+3*x^4-3*x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x-3,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^2+2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x-3,{2}>,
<2*x^6+2*x^5-3*x^4-3*x-3,{2,5,7}>,
<-3*x^6-3*x^5-3*x^2+2*x+3,{2}>,
<3*x^6+3*x^5+2*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^2+x+3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+3*x+3,{2}>,
<3*x^6+x^5+2*x^4-3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^2-x+2,{2}>,
<-3*x^6-3*x^5-x^2-x+3,{2,3}>,
<3*x^6-3*x^5-x^3+x-3,{2,3}>,
<3*x^6+3*x^5+2*x-2,{2}>,
<3*x^6-2*x^5-3*x-3,{2,7}>,
<3*x^6-3*x^5-x+3,{2}>,
<-3*x^6-3*x^5-x+2,{2}>,
<-2*x^6+x^5+3*x+3,{2}>,
<3*x^6+3*x^5-x-2,{2}>,
<-3*x^6-3*x^5+x+3,{2}>,
<3*x^6+3*x^5+x^3+2*x^2+3*x-2,{2}>,
<3*x^6-3*x^5+x-3,{2}>,
<-3*x^6-3*x^5-x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-3*x+3,{2}>,
<2*x^6+x^5+3*x^4-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^2+x-1,{2}>,
<3*x^6+3*x^5+x^3-x^2+x-2,{2}>,
<-3*x^6-3*x^5-x^3+x^2-x+3,{2,3}>,
<3*x^6-3*x^5-x^2+x-2,{2}>,
<3*x^6-2*x^5-2*x^4+3*x-3,{2}>,
<-2*x^6+3*x^5+x^4+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x+3,{}>,
<3*x^6-3*x^5+x^2-2*x+3,{2}>,
<3*x^6+3*x^5+x^2+2*x-2,{2}>,
<3*x^6+3*x^5+x^2+2*x-3,{2}>,
<3*x^6-3*x^5+x^2-x+3,{2}>,
<3*x^6-3*x^5+x^2-x-1,{2}>,
<3*x^6-3*x^5-x^3+2*x^2-2*x-3,{2}>,
<3*x^6-3*x^5+x^2-x-2,{2}>,
<3*x^6-3*x^5-x^3+2*x^2-x+3,{2,3}>,
<-2*x^6-x^5-2*x^4-3*x+3,{2,3}>,
<2*x^6-x^5+2*x^4-x^3-3*x+3,{2}>,
<3*x^6-x^5-3*x^4-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^2+x-2,{2}>,
<-x^6+x^5+3*x^4+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^2-x-2,{2}>,
<-3*x^6-x^5-3*x^4+3*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^2-2*x-3,{2}>,
<3*x^6+3*x^5+x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+3*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3-3*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4+x^3-3*x+3,{2}>,
<3*x^6-3*x^5+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3+3*x+3,{2,3}>,
<3*x^6-3*x^5+x^3+3*x^2+3,{}>,
<3*x^6+3*x^5-x^3+3*x^2+2,{2}>,
<-x^6+3*x^4+x^3-3*x+3,{}>,
<2*x^6-3*x^4+x^3-3*x-3,{2}>,
<-2*x^6+3*x^4+x^3-3*x+3,{2}>,
<-3*x^6-3*x^5+x^3-3*x^2+3,{2}>,
<3*x^6-3*x^5+x^3+3*x^2+x-2,{2,3}>,
<-3*x^6+3*x^5-x^3-3*x^2-x+3,{2}>,
<-3*x^6+3*x^5-x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6-3*x^5+x^3-3*x^2+x+2,{2,3}>,
<-2*x^6+2*x^5+2*x^4-x^3+3*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-3*x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3-3*x+3,{2}>,
<3*x^6+3*x^5-x^3+2*x^2+x-3,{2}>,
<3*x^6-3*x^5+x^3+2*x^2-1,{2}>,
<-2*x^6+x^4+3*x+3,{2}>,
<3*x^6-3*x^5+x^2+x-3,{2}>,
<3*x^6+2*x^5+x^4-3*x+3,{2,3}>,
<3*x^6+3*x^5+x^2-2*x+2,{2}>,
<2*x^6-3*x^5+x^4+3*x+3,{2,3}>,
<-x^6-3*x^5-x^4+3*x-3,{2}>,
<-3*x^6-3*x^5-x^2+3*x+2,{}>,
<-2*x^6+3*x^5+x^4-3*x+3,{}>,
<3*x^6-3*x^5+x^3+2*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5+x^3-2*x^2+2*x+2,{2}>,
<3*x^6-3*x^5+x^3+2*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3-3*x+3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-3*x+3,{2}>,
<3*x^6+3*x^5-x^3+2*x^2-3*x-1,{2}>,
<-3*x^6-3*x^5+x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x-3,{}>,
<3*x^6+3*x^5-x^3+x^2+3*x-3,{2,3}>,
<2*x^6-2*x^4-x^3+3*x-3,{2,113}>,
<2*x^6-x^5+2*x^4-x^3+3*x+3,{2}>,
<3*x^6+3*x^5-x^3+x^2+2*x+2,{2}>,
<3*x^6-3*x^5+x^3+3*x^2-3*x-3,{}>,
<-x^6+2*x^5+x^4-x^3+3*x+3,{2}>,
<2*x^6-2*x^5-x^4+x^3-3*x-3,{2,3}>,
<2*x^6+x^5-2*x^4+x^3-3*x-3,{2}>,
<3*x^6+3*x^5-x^3+x^2+2*x-2,{2}>,
<3*x^6+3*x^5-x^3+x^2+2*x-3,{2,5}>,
<-3*x^6-3*x^5+x^3-2*x^2+x+3,{2,3}>,
<-2*x^6+x^5+x^4-x^3+3*x+3,{2}>,
<2*x^6-x^5-x^4-x^3+3*x-3,{2}>,
<3*x^6-3*x^5+x^3+x^2+2*x+3,{2}>,
<-x^6+2*x^5+x^4+x^3-3*x+3,{2}>,
<3*x^6-3*x^5+x^3+2*x^2+2*x+3,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x-3,{2}>,
<-2*x^6+2*x^5+x^4+x^3-3*x+3,{2}>,
<2*x^6-2*x^5+x^3-3*x-3,{2}>,
<-3*x^6-3*x^5+x^3-x^2+2*x+3,{2,3}>,
<3*x^6+x^5-x^3+3*x-3,{2}>,
<-3*x^6+x^5-x^3+3*x+3,{2,3}>,
<2*x^6-x^3+3*x+3,{2}>,
<-x^6+3*x^5-x^4+x^3-3*x-3,{2,3}>,
<3*x^6+3*x^5-x^3-2,{}>,
<-3*x^6+3*x^5-x^3-x^2-3*x+2,{2}>,
<-3*x^6+3*x^5-x^3+3,{2}>,
<3*x^6-3*x^5+x^3-3*x-1,{2}>,
<-3*x^6-x^3+3*x+3,{2}>,
<3*x^6+3*x^5-x^3-x+3,{2}>,
<3*x^6+3*x^5-x^3+2*x+3,{}>,
<3*x^6+3*x^5-x^3-2*x+3,{}>,
<-x^6+3*x^5-x^4-x^3+3*x+3,{2,3}>,
<-3*x^6-3*x^5+x^3+x^2-3*x+2,{2}>,
<-x^6-3*x^5-x^3+3*x-3,{2}>,
<-2*x^6-3*x^5-x^4+x^3-3*x+3,{2,5}>,
<-x^6-2*x^5-x^4+x^3-3*x+3,{2}>,
<-x^6-2*x^4+3*x+3,{2}>,
<-3*x^6+3*x^5-x^3+x^2+2*x+3,{2}>,
<3*x^6-x^4-x^3+3*x+3,{}>,
<2*x^6-x^4+x^3-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^2-2,{2}>,
<-x^6-x^4+x^3-3*x+3,{2,3}>,
<3*x^6+3*x^5-x^3-x^2+2*x-3,{2}>,
<3*x^6+3*x^5-2*x^2-x-1,{2}>,
<2*x^6+x^4+x^3-3*x-3,{2}>,
<3*x^6-x^5-x^4+x^3-3*x+3,{}>,
<3*x^6+3*x^5-2*x^2-2*x+3,{}>,
<-2*x^6-x^4+x^3-3*x+3,{2}>,
<2*x^6+x^5+x^4-x^3+3*x-3,{2}>,
<-x^6+3*x^5+2*x^4-3*x-3,{2}>,
<3*x^6+x^4+x^3-3*x-3,{2,3}>,
<3*x^6-3*x^5+x^3-x^2-x-2,{2,3}>,
<3*x^6-2*x^5-x^4-x^3+3*x+3,{2}>,
<-3*x^6-3*x^5+x^3+x^2+2*x-1,{2}>,
<3*x^6+3*x^5-2*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x-3,{2}>,
<3*x^6+3*x^5-x^3-x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4-x^3+3*x+3,{2,3}>,
<-2*x^6-3*x^5+x^4-x^3+3*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x-3,{2,3}>,
<2*x^6-3*x^5+x^4-3*x-3,{2,3}>,
<-3*x^6+3*x^5+x^2+2*x-1,{2}>,
<-3*x^6-3*x^5+x^2-2*x+2,{2}>,
<3*x^6-3*x^5-x^2-2*x-2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^3+2*x^2+x+3,{2,3}>,
<-2*x^6+2*x^4-2*x^3-3*x-3,{2}>,
<-x^6+2*x^4-2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^3-2*x^2-1,{2}>,
<3*x^6+3*x^5-x^3-2*x^2-2*x+2,{2}>,
<-3*x^6-3*x^5+x^3+2*x^2+2*x-1,{2}>,
<3*x^6-3*x^5+x^3-2*x^2+2*x-2,{2,7}>,
<-3*x^6-3*x^5+x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5+x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5+x^3-2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5+x^3+2*x^2+3*x-1,{2}>,
<-3*x^6-3*x^5+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5-x^3+3*x^2+3*x-2,{}>,
<3*x^6+3*x^5-x^3-3*x^2+3*x+2,{}>,
<2*x^6+3*x^5+3*x^4-x^3+3*x-3,{}>,
<3*x^6+3*x^5-x^3-3*x^2+3*x-2,{}>,
<3*x^6+2*x^5-3*x^4-x^3+3*x+3,{2}>,
<-3*x^6+3*x^5-x^3+3*x^2+2*x-2,{2}>,
<3*x^6+3*x^5-x^3-3*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+x^3+3*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4-x^3+3*x+3,{2}>,
<-3*x^6-3*x^4-x^3+3*x+3,{2,5}>,
<-x^6-2*x^5+3*x^4+x^3-3*x-3,{2}>,
<3*x^6+3*x^5-x^3-3*x^2-x-2,{2,3}>,
<3*x^6-3*x^5+x^3-3*x^2+x-3,{2,3,5}>,
<3*x^6-3*x^5+x^3-3*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5-x^3+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x-3,{2,3}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-3*x+3,{2,3}>,
<-3*x^6+3*x^5-x^3+3*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^3-3*x^2-x+2,{2}>,
<3*x^6+3*x^4+2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^3-3*x^2+2,{2}>,
<3*x^6-3*x^5+x^3+x^2-3,{2,3}>,
<3*x^6-x^5+x^4-x^3+3*x+3,{2,3}>,
<2*x^6-x^5+x^4-x^3+3*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-3*x-3,{}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-3*x+3,{}>,
<3*x^6+2*x^5-3*x^4+2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^3+2*x^2-2*x+3,{2,3}>,
<-x^6-x^5+2*x^4+2*x^3-3*x+3,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^3+2*x^2+2,{2}>,
<3*x^6+3*x^5-2*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4-2*x^3+3*x-3,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+3*x+3,{}>,
<3*x^6+3*x^5-x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+x^3-3*x-3,{2}>,
<3*x^6-3*x^5+x^3-2*x^2-x-1,{2,3,5}>,
<3*x^6+3*x^5-x^3-2*x^2+x-2,{2}>,
<3*x^6-x^5+2*x^4+x^3-3*x-3,{2}>,
<3*x^6-2*x^4+x^3-3*x+3,{2}>,
<3*x^6+3*x^5-x^3-2*x^2-1,{2}>,
<3*x^6-x^5-2*x^4-x^3+3*x+3,{2,3}>,
<-x^6-x^5+2*x^4-x^3+3*x-3,{2,3}>,
<3*x^6-3*x^5+x^3-2*x^2+x-3,{2,3}>,
<3*x^6+3*x^5-2*x^3+2*x^2-x-2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3+3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^3+2*x^2-x-3,{2,3}>,
<3*x^6+3*x^5-2*x^3+2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3+3*x+3,{2,3}>,
<-3*x^6+3*x^5-2*x^3-3*x^2+3,{2}>,
<-x^6-2*x^5+x^4+3*x-3,{2}>,
<-x^6-3*x^5+x^4+3*x-3,{2,3}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x-3,{2,3}>,
<2*x^6+3*x^5+2*x^4+3*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x-3,{2}>,
<-x^6+2*x^5-2*x^4+3*x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5-2*x^2-x+2,{}>,
<-3*x^6-3*x^5+2*x^3-x^2-3*x-1,{2,3}>,
<-x^6+3*x^5+x^4-2*x^3+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^4+3*x-3,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^3+x^2+3*x-2,{}>,
<3*x^6+3*x^5-2*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+3*x^5-x^2-2,{2}>,
<-3*x^6+3*x^5-2*x^3-x^2+2,{2,3}>,
<2*x^6+x^5+x^4+2*x^3-3*x+3,{2}>,
<-x^6-x^5+x^4-2*x^3+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^3-x^2-x+2,{2}>,
<3*x^6+3*x^5-2*x^3+x^2-x-2,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-x^2+x+3,{}>,
<-3*x^6-3*x^5+2*x^3-x^2+x+3,{2}>,
<-2*x^6-2*x^5+x^4+2*x^3-3*x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3-3*x+3,{2}>,
<2*x^6+x^5+x^4-3*x-3,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^3+x^2-2*x+2,{2}>,
<3*x^6+3*x^5-2*x^3+x^2+3,{2}>,
<-3*x^6+3*x^5-2*x^3-x^2-2*x+2,{2}>,
<-3*x^6+3*x^5-x^3+2*x^2+3*x-2,{2}>,
<2*x^6+x^4+2*x^3-3*x+3,{}>,
<2*x^6-3*x^5-2*x^4+x^3-3*x+3,{2}>,
<-x^6-3*x^5-x^4-2*x^3+3*x-3,{2,3}>,
<-3*x^6-3*x^5+x^3+2*x^2-3*x-1,{2,3,7}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x-3,{2}>,
<-x^6+2*x^5+2*x^3-3*x-3,{2}>,
<-x^6-3*x^5-2*x^3+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^3+3*x-2,{2}>,
<3*x^6-3*x^5+2*x^3-x^2-2*x+3,{2,3,5}>,
<-3*x^6+3*x^5-x^3+2*x^2+2*x-1,{2,3}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x+3,{}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-3*x+3,{2,7}>,
<-3*x^6+3*x^5-2*x^3-2*x^2+3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x-3,{2}>,
<3*x^6-3*x^5+2*x^3-2*x^2-3*x-2,{2}>,
<-x^6+2*x^5-2*x^4-2*x^3+3*x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3+3*x+3,{2,7}>,
<-3*x^6-3*x^5+2*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x+3,{2,3}>,
<-x^6-x^5-2*x^4+2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^3+2*x^2+x+2,{2,3}>,
<3*x^6-2*x^4-2*x^3+3*x+3,{2,3,23}>,
<-3*x^6-2*x^4+2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^3-2*x^2+x+2,{2}>,
<-3*x^6+3*x^5-2*x^3+2*x^2-x-1,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x-3,{2,3,5}>,
<3*x^6+3*x^5-2*x^3-2*x^2-x-3,{2,3}>,
<3*x^6-3*x^5+2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5-2*x^3+2*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5-2*x^3+2*x^2-2*x-1,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3+3*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^3-2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+3*x-3,{2}>,
<3*x^6-3*x^5+2*x^3-3*x^2-3*x+3,{}>,
<-3*x^6-3*x^5+2*x^3+3*x^2-3*x-2,{2,7}>,
<-x^6-3*x^5+3*x^4+2*x^3-3*x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-3*x+3,{}>,
<-x^6+3*x^5-3*x^4-2*x^3+3*x+3,{}>,
<-3*x^6-3*x^5+2*x^3+3*x^2+x-2,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+3*x+3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-3*x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-3*x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+3*x+3,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-3*x-3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+3*x+3,{2}>,
<-2*x^6-3*x^4+2*x^3-3*x+3,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x-3,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5+2*x^3-3*x^2-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x+3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+3*x-3,{}>,
<-2*x^6-x^5+3*x^4+3*x^3-3*x+3,{}>,
<-x^6-2*x^5+3*x^4-3*x^3+3*x+3,{}>,
<-3*x^6-3*x^5+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5+2*x^3-3*x+3,{}>,
<2*x^6-2*x^5-2*x^4+3*x^3-3*x-3,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x-3,{2}>,
<2*x^6+3*x^5-2*x^3+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^3+3*x-2,{2}>,
<3*x^6-3*x^5+2*x^3-x^2-x+3,{2}>,
<3*x^6-3*x^5+2*x^3-x^2-x+2,{2,3}>,
<3*x^6-3*x^5+2*x^3-x^2-x-1,{2}>,
<2*x^6-x^4+2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^3-x^2+x+3,{}>,
<-3*x^6+3*x^5-2*x^3+x^2-x-1,{2}>,
<-3*x^6+3*x^5-2*x^3+x^2+x+2,{2}>,
<-3*x^6+x^5-x^4+2*x^3-3*x+3,{2}>,
<3*x^6-3*x^5+2*x^3-x^2+2*x+2,{2}>,
<-2*x^6-x^5-x^4+2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5-2*x^3+x^2-2*x-1,{2}>,
<3*x^6-2*x^4-3*x^3+3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^3+x^2-3*x-1,{2,5}>,
<-3*x^6-3*x^5+3*x^3-2*x^2+x+3,{2}>,
<3*x^6+3*x^5-2*x^3-x^2-3*x-1,{2,3}>,
<-x^6-3*x^5+2*x^4+2*x^3-3*x-3,{2}>,
<-x^6+x^4-3*x^3+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^3-x^2+2,{2}>,
<3*x^6+3*x^5-3*x^3+x^2-2,{2}>,
<3*x^6-x^5+x^4-3*x^3+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^3-x^2-3*x-1,{2}>,
<3*x^6+3*x^5-3*x^3+2*x+2,{}>,
<3*x^6-3*x^5+3*x^3-2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^3-2*x+3,{2}>,
<3*x^6-3*x^5+3*x^3-2*x-3,{2}>,
<3*x^6+3*x^5-3*x^3-x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-3*x+3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6-3*x^5+3*x^3+x^2+2*x-2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^3+x^2+2*x+2,{2}>,
<3*x^6+3*x^5-3*x^3-x^2-2*x-2,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+3*x+3,{2}>,
<-3*x^6+3*x^5-3*x^3-3*x^2-x+2,{2}>,
<3*x^6-3*x^5+3*x^3+3*x^2+x-2,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-3*x-3,{2}>,
<-3*x^6+3*x^5-2*x^3-2*x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x+3,{2}>,
<2*x^6-3*x^5+x^4+2*x^3-3*x+3,{}>,
<3*x^6+3*x^5-3*x^3+3*x^2-2*x+3,{}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x-3,{2}>,
<-2*x^6-3*x^5-3*x^3+3*x-3,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^3-x^2+3*x-2,{2}>,
<-3*x^6+3*x^5-3*x^3+x^2+2*x-1,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-3*x-3,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3-3*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-3*x-3,{2,5}>,
<-2*x^6-3*x^5+x^4-3*x^3+3*x-3,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+3*x-3,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x+3,{2}>,
<3*x^6-3*x^5+3*x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2-3*x+3,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3+3*x^2+3*x-2,{2,3}>,
<3*x^6+3*x^5-3*x^4+3*x^3+x^2+3*x-3,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+3*x^2+2*x-1,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+3*x^2+x-1,{2,3}>,
<2*x^6+2*x^4-3*x^3+3*x+3,{2}>,
<2*x^6-2*x^4-3*x^3+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^3+2*x^2-2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-2*x^2+3*x-2,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^3-2*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-3*x^3-2*x^2+x-3,{2}>,
<-x^6+2*x^4-3*x^3+3*x-3,{2}>,
<3*x^6-3*x^5+3*x^3-2*x^2-3,{}>,
<3*x^6-3*x^5+3*x^3-2*x^2+x+3,{2}>,
<-3*x^6-3*x^5+3*x^3+2*x^2+2*x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^3-3*x^2-2,{2}>,
<-3*x^6+3*x^5-3*x^3+3*x^2-x-2,{2,5}>,
<-2*x^6-x^5-3*x^4-3*x^3+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x+2,{2,3}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x^2+x+2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+2*x^2-2*x+2,{2,5}>,
<-3*x^6+3*x^5-3*x^3-2*x^2-2*x+2,{2,13}>,
<2*x^6-2*x^5-2*x^4+3*x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-x^2-3*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^4+3*x^3-x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3+2*x^2-3*x-2,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6+3*x^5-x^3-2*x^2+2*x-2,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x-2,{2}>,
<3*x^6-x^4-3*x^3+x^2-3*x-3,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+x^2-3,{2,3}>,
<-x^6+2*x^5-2*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x-1,{}>,
<-3*x^6-3*x^5+x^4-3*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+x^2+3*x-3,{2}>,
<-2*x^6+3*x^5+3*x^3+x^2+3*x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3+x^2+3*x-3,{2,3,19,53}>,
<-x^6+3*x^5+3*x^3+x^2+3*x-3,{2,3}>,
<-x^6-x^5+x^4+3*x^3-x^2+3*x+3,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+x^5+x^4-3*x^3-x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+x^2-x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-2*x+2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x-1,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x+2,{}>,
<-x^6+2*x^5+x^4-3*x^3-x^2-3*x+3,{2,11}>,
<-2*x^6+2*x^5+3*x^3-x^2+3*x+3,{}>,
<2*x^6-2*x^5-x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+x^2+2*x-2,{2}>,
<2*x^6-3*x^3+x^2-3*x-3,{}>,
<-2*x^6-3*x^3-x^2-3*x+3,{}>,
<-3*x^6-3*x^5+x^4-3*x^3+3,{}>,
<-x^6+x^5-3*x^3+x^2-3*x-3,{2}>,
<-x^6+x^5-3*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-x-2,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-2*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3-2*x-1,{2}>,
<-x^6+3*x^4+3*x^3-x^2+3*x+3,{2}>,
<2*x^6-3*x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-2*x+3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+3*x^2-x-2,{2,5}>,
<-2*x^6+3*x^5-3*x^3+x^2-3*x-3,{2,5}>,
<2*x^6-3*x^5+3*x^3+x^2+3*x-3,{}>,
<-2*x^6-3*x^5+3*x^3-x^2+3*x+3,{}>,
<-3*x^6-3*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x+3,{2,3,131}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-x^2+3*x+3,{2}>,
<-x^6+x^5+2*x^4+3*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-2*x^2+x+2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2-2*x-1,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5-x^4-3*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+x^2+x-3,{}>,
<3*x^6+x^5-x^4+3*x^3-x^2+3*x+3,{}>,
<-3*x^6-3*x^5+x^4-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+x^2-x-1,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+x^2-x+2,{2,3}>,
<-2*x^6+2*x^4+3*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2-x-2,{2}>,
<-3*x^6+2*x^4+3*x^3-x^2+3*x+3,{}>,
<3*x^6-3*x^5-x^4-3*x^3+2*x^2+x-1,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-x^4-3*x^3-x^2-3*x+3,{}>,
<-2*x^6+x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3+x^2+2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2+2*x+2,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+x^2-2*x-1,{2}>,
<-2*x^6-x^4+3*x^3-x^2+3*x+3,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+x^2-x-2,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+x^2+2*x+3,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^3-x^2+x+2,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+x^2-x-1,{2,3}>,
<2*x^6+x^5+x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3-x^2+3*x+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2+2*x-3,{}>,
<3*x^6-2*x^5-2*x^4-3*x^3-x^2-3*x+3,{}>,
<3*x^6+3*x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+x^2+3*x-3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-x^2-3*x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-2*x^2+x-2,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2+x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-2*x^2-3,{2,3}>,
<-3*x^6+x^5+2*x^4-3*x^3+x^2-3*x-3,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-2*x^2+x-2,{2,3}>,
<2*x^6-x^5+2*x^3-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-2*x^2-2*x+3,{2,3}>,
<-2*x^6-x^5+2*x^3-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-2*x^2-2*x+2,{2}>,
<3*x^6-3*x^5+2*x^3-x-3,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x-1,{0}>,
<-x^6-2*x^5-2*x^4+3*x^3-x^2+3*x+3,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+x^2-3*x-3,{2,3}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-x^2+3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^3+3,{2,5}>,
<-2*x^6+3*x^5-2*x^4+3*x^3-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+3*x^2-3*x-2,{2,3,5,13}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2+3*x+2,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2+x-1,{2,3,7,53}>,
<2*x^6+3*x^5+3*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+x^5-3*x^4-3*x^3-x^2-3*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+3*x+3,{2,5}>,
<3*x^6+3*x^5-3*x^3+x^2+x+2,{2}>,
<3*x^6+x^4+3*x^3-3*x+3,{2}>,
<3*x^6-3*x^5+3*x^3+x^2+2,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3-3*x^2+3*x-1,{2}>,
<3*x^6-3*x^5-x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-3*x^5+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-3*x^5+3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^4+2*x^3-x^2+3*x+3,{}>,
<2*x^6-3*x^4-2*x^3+x^2-3*x-3,{}>,
<3*x^6-3*x^5-x^4-2*x^3+3*x^2-2,{}>,
<3*x^6+3*x^5-x^4+2*x^3+3*x^2-x-2,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3+3*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2+2*x+2,{2}>,
<-x^6-2*x^5-2*x^4-2*x^3+x^2-3*x-3,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3-2*x^2-2*x+2,{2,3}>,
<3*x^6+2*x^5-2*x^4+2*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5-x^4-2*x^3+2*x^2-x-2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2+x-3,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-3*x-3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-x^2-3*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-x^2-3*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x^2-3*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+x^4+3*x^3+3*x^2-2*x-2,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2-2*x+2,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^3-3*x^2+2*x-1,{2,7}>,
<-3*x^6+3*x^5+x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+x^2-3*x-3,{0,2}>,
<-3*x^6-3*x^5+x^4-3*x^3+3*x^2+3*x-1,{0,2,3}>,
<2*x^6-3*x^5+3*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3-x^2+3*x-2,{2,3,5}>,
<-x^6-3*x^5+x^4-2*x^3-x^2-3*x+3,{}>,
<2*x^6+3*x^5-x^4+2*x^3+x^2+3*x-3,{}>,
<3*x^6+3*x^5-x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3-x^2+2*x-2,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+x^2+2*x+2,{2,3}>,
<-x^6+2*x^5-x^4+2*x^3+x^2+3*x-3,{2,3,11}>,
<2*x^6-2*x^5-x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+x^2+3*x-3,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3-x^2-3*x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3-x^2-3*x+3,{2}>,
<-2*x^6-x^5-x^4-3*x^3+x^2-3*x-3,{2}>,
<-x^6-x^5-x^4-3*x^3+x^2-3*x-3,{2}>,
<-2*x^6+2*x^4-2*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2-x+3,{2,3}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+x^2-3*x-3,{}>,
<3*x^6+3*x^5-x^4+2*x^3+x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3+2*x^2-x-2,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+2*x^3+x^2+x-3,{2}>,
<-x^6+x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6-x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+x^2+x-2,{2,3,5}>,
<3*x^6+x^5+x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3-x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3-x^2+x+2,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-x^2+3*x+3,{2,3}>,
<2*x^6+3*x^5+2*x^3+x^2+3*x-3,{2}>,
<-2*x^6-3*x^5-2*x^3-x^2-3*x+3,{2}>,
<-2*x^6-x^5+x^4+2*x^3-x^2+3*x+3,{2,3}>,
<-2*x^6+2*x^5+2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^3+x^2-x-3,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3-2*x+3,{2,3}>,
<3*x^6+3*x^5-x^4+2*x^3+x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3-x^2-2*x+3,{2}>,
<-x^6+x^5+2*x^3+x^2+3*x-3,{2,3}>,
<2*x^6+x^5+2*x^3+x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+3*x^3+x^2-2,{2,5}>,
<-3*x^6-2*x^5+x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-x-3,{2,3}>,
<2*x^6-3*x^5+x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3-2*x-2,{2}>,
<3*x^6-3*x^5-x^4-2*x^3+3*x+2,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-x^2+3*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+3*x^2-1,{2,3}>,
<-3*x^6+3*x^5+x^4+2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2-2,{2,3}>,
<2*x^6-x^5-3*x^3-x^2-3*x+3,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-x^2+3*x+3,{2,3}>,
<-x^6-x^5+3*x^4-2*x^3-x^2-3*x+3,{}>,
<3*x^6+3*x^4-3*x^3+x^2-3*x-3,{2}>,
<-x^6-x^5-3*x^3-x^2-3*x+3,{2,19}>,
<2*x^6+x^5+3*x^3+x^2+3*x-3,{}>,
<-3*x^6-3*x^5+x^4-2*x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^3-x^2-3*x+3,{}>,
<-3*x^6+3*x^5+x^4+3*x^3-2,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+2*x^5-x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3+2,{2,3}>,
<3*x^6-3*x^5-x^4-2*x^3-x^2-2*x-3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3-1,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^3-1,{2,3,5}>,
<3*x^6+x^4-2*x^3+x^2-3*x-3,{}>,
<-x^6+x^5+x^4-2*x^3+x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4+2*x^3+x^2-x+2,{2}>,
<-2*x^6+x^5-x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+x^2+x+3,{2,3}>,
<3*x^6+3*x^5-x^4+2*x^3-x^2-x-3,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3+x^2+2*x-3,{}>,
<3*x^6-3*x^5-x^4-2*x^3-x^2+2*x-1,{2,3}>,
<3*x^6-3*x^5-x^4-2*x^3-x^2+2*x-2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3+x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+2*x^3-x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+x^2+3*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+x^2+3*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+2*x^2-3*x+2,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-2*x^2-3*x-2,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x^2-3*x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-x^2+3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2+2*x-1,{2,3}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^3-3*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+x^2+3*x-3,{2,3,5}>,
<-2*x^6-x^5+3*x^4-3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^3-3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+3*x^3+x^2+3*x-3,{}>,
<-3*x^6-3*x^5+x^4-2*x^3+2*x^2+x-1,{2}>,
<-x^6-x^5-2*x^4+2*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+2*x^2-x+2,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2-2*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2+2*x-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+x^2-3*x-3,{2,3,7}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2-2*x-1,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-x^2-3*x+2,{2}>,
<3*x^6+3*x^5-x^4+2*x^3-x^2+3*x-2,{2,3}>,
<-3*x^6-2*x^5-3*x^4-2*x^3-x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2+x-2,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+x^2+2*x-3,{}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2+x-1,{2,3}>,
<3*x^6+2*x^5-x^4+2*x^3-x^2+3*x+3,{}>,
<3*x^6+3*x^5-x^4+2*x^3-3*x^2+x-2,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+x^2+2*x-1,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2+x+3,{2,3}>,
<-x^6+2*x^5-x^4+2*x^3-x^2+3*x+3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^4-2*x^3+x^2-3*x-3,{2}>,
<2*x^6-3*x^4-2*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2-x-2,{}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2+x+2,{2,3}>,
<-x^6+x^5+2*x^4+3*x^3+x^2+3*x-3,{2,7}>,
<3*x^6-3*x^5-3*x^4-x^3+x^2-3*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2+2*x-1,{2}>,
<-3*x^6+3*x^5+x^4+x^3-3*x^2+2*x+2,{2}>,
<3*x^6-3*x^5-x^4-x^3+3*x^2-x+3,{2,3}>,
<2*x^6+x^5-3*x^4+x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^3+3*x^2-x-2,{2}>,
<-3*x^6-3*x^5+x^4-x^3-3*x^2-x+3,{2,3}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2+x-3,{2,3}>,
<2*x^6+3*x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2-2,{2}>,
<3*x^6-3*x^4+x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2-x+3,{2,3}>,
<-3*x^6-x^5+3*x^4+x^3-x^2+3*x+3,{2,3}>,
<-x^6+2*x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^3+2*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+x^4+x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+3*x^5+x^4+x^3-2*x^2+3*x+3,{2,3}>,
<2*x^6+3*x^5+2*x^4-x^3-x^2-3*x+3,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-x^3-x^2-3*x+2,{2,3}>,
<3*x^6-3*x^5-x^4-x^3+x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-x^2+3*x+3,{2}>,
<-3*x^6-2*x^5+x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+x^2+x-1,{2}>,
<-2*x^6-x^5+x^4-x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+2*x^2-3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-2*x^2+3,{2,3}>,
<2*x^6+2*x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3-2*x^2-2,{2}>,
<-x^6-3*x^4+2*x^3-x^2+3*x+3,{2}>,
<2*x^6+3*x^4+2*x^3+x^2+3*x-3,{2}>,
<-2*x^6-3*x^4+2*x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^3+3*x^2+x-3,{2,3}>,
<2*x^6-x^5+3*x^4+3*x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^4+x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+x^2-1,{2}>,
<2*x^6-x^4-x^3+x^2-3*x-3,{2,11}>,
<3*x^6-3*x^5-x^4-x^3-3*x-1,{2}>,
<3*x^6-3*x^5-x^4-x^3+x^2-2,{2,3,107}>,
<2*x^6-3*x^5-x^3+x^2-3*x-3,{2,7}>,
<3*x^6-x^5-x^4+x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+x^3+2*x+3,{2}>,
<3*x^6-3*x^5-x^4-x^3+x^2+x-3,{2}>,
<3*x^6-3*x^5-x^4-x^3+x^2+2*x-2,{2,89}>,
<-3*x^6+3*x^5+x^4+x^3-x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-x^3+x^2-3*x-3,{2}>,
<2*x^6-3*x^5-x^3-x^2-3*x+3,{}>,
<-3*x^6+3*x^5+x^4+x^3+x-1,{2,3}>,
<2*x^6+x^5+x^3+x^2+3*x-3,{2,5}>,
<-2*x^6-x^5-x^3-x^2-3*x+3,{2,5,7}>,
<3*x^6+x^5+x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^3-1,{2}>,
<3*x^6+x^3+x^2+3*x-3,{2}>,
<-3*x^6-x^3-x^2-3*x+3,{2}>,
<3*x^6-x^5+x^3-x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5+x^4+x^3-x+2,{}>,
<3*x^6+3*x^5-x^4+x^3-x-2,{}>,
<3*x^6-3*x^5-x^4-x^3+2*x+3,{2}>,
<-3*x^6-3*x^5+x^4-x^3+2*x+2,{2}>,
<-2*x^6-2*x^5+x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3-2*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3+x^2-3*x-3,{2,3,7,97}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2-2*x-2,{2}>,
<-3*x^6+3*x^5+x^4+2*x^3+3*x^2-2*x-1,{0}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2+3*x+2,{0,2}>,
<-x^6+3*x^5+3*x^4-2*x^3+x^2-3*x-3,{0}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2+3*x-2,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-2*x^2+x+2,{2}>,
<3*x^6+3*x^5-x^4+x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^5+x^4+x^3+x^2+2*x-3,{2,3,5}>,
<3*x^6-2*x^5-x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4-x^3-x^2-x-1,{2}>,
<-3*x^6-3*x^5+x^4-x^3+x^2-2*x-2,{2,3}>,
<-3*x^6-3*x^5+x^4-x^3+x^2-x+2,{2,3}>,
<3*x^6-3*x^5-x^4-x^3-x^2-2*x-1,{2,3}>,
<-3*x^6-3*x^5+x^4-x^3+x^2-2*x+2,{}>,
<-3*x^6-3*x^5+x^4-x^3+x^2-x+3,{2,3,5}>,
<3*x^6-3*x^5-x^4-x^3-x^2-2*x-2,{}>,
<-3*x^6-x^5-x^4-x^3-x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4+x^3-x^2+2,{2}>,
<3*x^6-2*x^5+x^4-x^3+x^2-3*x-3,{2,3}>,
<-2*x^6-x^4-x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+x^2+3,{2}>,
<-2*x^6+2*x^3-x^2+3*x+3,{2,5}>,
<-3*x^6-3*x^5+x^4-x^3-2*x^2-2*x+3,{2}>,
<2*x^6+x^5-2*x^4+x^3+x^2+3*x-3,{2,5}>,
<-2*x^6+x^5+2*x^4+x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+2*x^2+x-3,{2}>,
<2*x^6+2*x^4-x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4+x^3+2*x^2-1,{2}>,
<3*x^6-3*x^5-x^4-x^3+2*x^2-2,{2,3}>,
<3*x^6-2*x^4+x^3+x^2+3*x-3,{2,3,5}>,
<-3*x^6+3*x^5+x^4+x^3-2*x^2-x+3,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3+2*x^2+x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+x^2-3*x-3,{2}>,
<-3*x^6-x^5+x^4-x^3-x^2-3*x+3,{2,3}>,
<2*x^6-x^5+2*x^4-x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4+x^3-2*x^2+x-2,{2,3}>,
<3*x^6+3*x^5-x^4+x^3-x^2-x-1,{2,3,7,89}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+x+3,{}>,
<3*x^6-3*x^5-x^4-x^3-2*x^2-x-3,{}>,
<3*x^6-3*x^5-x^4-x^3-x^2+x-2,{2}>,
<3*x^6-2*x^4+x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-x^3+2*x^2-1,{2}>,
<-x^6-2*x^4-x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+2,{2,5}>,
<3*x^6-x^5+x^4+x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+x^3-2*x^2-2,{2,3}>,
<-3*x^6-2*x^5-2*x^4+x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2-3*x-2,{2,3,5}>,
<-2*x^6-3*x^5-2*x^4+x^3-x^2+3*x+3,{}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-x^3+3*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+x^4-x^3+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-x^4+x^3-3*x^2+2*x-2,{2,3}>,
<2*x^6+x^5-x^4+x^3-x^2+3*x+3,{2}>,
<-x^6+x^5+x^4+x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-x^3+3*x^2-3,{2,3,7}>,
<-2*x^6+3*x^4+x^3+x^2+3*x-3,{2}>,
<2*x^6-3*x^4+x^3-x^2+3*x+3,{}>,
<3*x^6-3*x^5-x^4-x^3-3*x^2-1,{2,3}>,
<-3*x^6-3*x^5+x^4-2*x^3+x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+3*x^2+2,{2}>,
<3*x^6+3*x^5-x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6-3*x^5-x^4-2*x^3+x-3,{2,3}>,
<-2*x^6+x^5+3*x^4-x^3+x^2-3*x-3,{2}>,
<-x^6+x^5+3*x^4-x^3+x^2-3*x-3,{0,2}>,
<3*x^6-3*x^5-x^4-2*x^3+2*x+3,{2,3}>,
<-x^6+2*x^5+3*x^4-x^3+x^2-3*x-3,{0,2}>,
<2*x^6-2*x^5+2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^3-3*x^2+2*x-2,{2,3,7}>,
<3*x^6-2*x^5+3*x^4+x^3+x^2+3*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+x^2+3*x-3,{2}>,
<-x^6-3*x^5-3*x^4+x^3-x^2+3*x+3,{}>,
<2*x^6-x^5+3*x^4-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-3*x^2+x+3,{2}>,
<-3*x^6+3*x^5+x^4-3*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5-x^4+3*x^2-x-3,{2}>,
<3*x^6-3*x^5-x^4+3*x^2-2*x+2,{2}>,
<2*x^6-x^5-3*x^4+x^2+3*x-3,{2,5}>,
<2*x^6+2*x^5-3*x^4+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4+3*x^2-2*x+2,{2,3}>,
<3*x^6-3*x^5-x^4+3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-3*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5+x^4-3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^5+x^4-3*x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5-3*x^4+x^2-3*x-3,{}>,
<-3*x^6+3*x^5+x^4+x^3+x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+3*x^4-x^2+3*x+3,{2}>,
<-2*x^6+3*x^5+2*x^4-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+3*x-2,{2,3}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+3*x-1,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^2-3*x-3,{2}>,
<-x^6+3*x^5-2*x^4+x^3-x^2+3*x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3-x^2+3*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+x^4-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+2*x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5-x^4+x^2-2*x-1,{2}>,
<3*x^6+3*x^5-x^4+2*x^2+x+3,{2}>,
<3*x^6-3*x^5-x^4+x^2-2*x-2,{2}>,
<3*x^6-3*x^5-x^4+2*x^2-x-1,{2}>,
<3*x^6-2*x^5-x^4+x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+x^4-2*x^2-x+2,{2}>,
<-3*x^6+2*x^5+x^4-x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^2-x-2,{2}>,
<-3*x^6+3*x^5+x^4-x^2+x+2,{}>,
<3*x^6+3*x^5-x^4+x^2+x-2,{}>,
<-3*x^6+3*x^5+x^4+x^3+x^2+3*x-3,{2,3,5,1031}>,
<-3*x^6+3*x^5+x^4-2*x^2+x+3,{2,3}>,
<3*x^6-x^4+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5-x^4-x^3-x^2-3*x+3,{}>,
<3*x^6+3*x^5-x^4+2*x^2+x-3,{2,3}>,
<-2*x^6+x^5+x^4-x^2-3*x+3,{2}>,
<3*x^6+x^5-x^4+x^2-3*x-3,{}>,
<-3*x^6-x^5+x^4-x^2+3*x+3,{}>,
<3*x^6-2*x^5+x^4-x^2+3*x+3,{}>,
<-3*x^6+3*x^5+x^4+3*x-2,{2,3}>,
<-x^6-3*x^5+x^2-3*x-3,{}>,
<3*x^6+3*x^5-x^4+3*x-1,{}>,
<2*x^6-3*x^5+x^2-3*x-3,{2}>,
<-x^6-x^5-x^4-2*x^3-x^2-3*x+3,{2,3,19,59}>,
<-x^6-2*x^5+x^2-3*x-3,{2}>,
<-2*x^6-3*x^5-x^4-x^3-x^2-3*x+3,{2,3,5}>,
<2*x^6+x^5+x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+2*x+2,{2}>,
<3*x^6-x^5+x^4-2*x^3+x^2-3*x-3,{2}>,
<-x^6+x^5-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-x+3,{}>,
<3*x^6-3*x^5-x^4-x-3,{}>,
<3*x^6+2*x^5+x^2+3*x-3,{2,3}>,
<-2*x^6+x^4+2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4+2,{2,3}>,
<-2*x^6+2*x^5+x^4+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^2-2*x+2,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-x^2+2,{2}>,
<-3*x^6-3*x^5+x^4+x^2-2*x-1,{2,3}>,
<-x^6+2*x^5-x^4-x^2+3*x+3,{}>,
<3*x^6+3*x^5-x^4+2*x^3-x^2-1,{2}>,
<3*x^6+3*x^5-x^4-x^2+x-2,{2}>,
<-3*x^6-3*x^5+x^4+x^2-x+3,{2,3}>,
<-3*x^6-x^5-x^4-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+x^3+2*x-1,{2,3}>,
<-x^6-2*x^5-x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4-x^3-2*x+2,{2,3}>,
<-2*x^6+2*x^5+x^3-x^2+3*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-x^2+3*x+3,{2}>,
<3*x^6+2*x^5+x^3+x^2+3*x-3,{2}>,
<-3*x^6+x^5+3*x^4+x^3+x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4-x^3-3*x^2-x+3,{2,3}>,
<-x^6-x^5+3*x^4-x^3+x^2-3*x-3,{2,3}>,
<-3*x^6-2*x^5-x^3-x^2-3*x+3,{2,3}>,
<2*x^6-x^5+3*x^4-x^3+x^2-3*x-3,{}>,
<3*x^6+3*x^5-x^4+x^3-3*x^2+3*x+2,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+x^3-3*x^2+x-2,{2}>,
<-3*x^6-3*x^5+x^4-x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-2*x^5+2*x^4+x^2-3*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^2-x-1,{2,3}>,
<-x^6+x^5-2*x^4-x^2+3*x+3,{2}>,
<2*x^6-x^5+2*x^4+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4-2*x^2-x-2,{2}>,
<-3*x^6-3*x^5+x^4+2*x^2-x+3,{2,3}>,
<-3*x^6+x^5-2*x^4-x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4+x^3-3*x^2+3*x-1,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^2-2*x-3,{2,3}>,
<2*x^6+3*x^5+3*x^4+x^3+x^2+3*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+x^2-3*x-3,{2,3,13}>,
<3*x^6-3*x^5-x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^2+3*x-1,{2,3}>,
<-2*x^6+3*x^5-3*x^4-x^2+3*x+3,{2}>,
<-x^6+2*x^5+3*x^4+x^2+3*x-3,{2,5}>,
<3*x^6+3*x^5-x^4-3*x^2+2*x-1,{2}>,
<2*x^6-x^5-3*x^4-x^2+3*x+3,{2}>,
<-3*x^6-x^5+3*x^4+x^2-3*x-3,{2,3,13}>,
<-3*x^6+3*x^5+x^4+3*x^2-x+3,{2,3,17}>,
<3*x^6+x^5-3*x^4-x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4-3*x^2+2*x-1,{2,3,17}>,
<3*x^6+3*x^5-x^4-3*x^2-2*x-2,{}>,
<-3*x^6+3*x^5+x^4+3*x^2+x-2,{2}>,
<3*x^6+2*x^5+3*x^4+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4-3*x^2-x+2,{2,3}>,
<-3*x^6+2*x^5-3*x^4-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4+3*x^2-3*x-2,{2}>,
<3*x^6+3*x^5-x^4-3*x^2+x-1,{2}>,
<2*x^6-x^5+3*x^4+x^2-3*x-3,{}>,
<3*x^6+3*x^5-x^4-3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+x^2+3*x-3,{2}>,
<-2*x^6+3*x^4+x^2-3*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+3*x^2-1,{2,3}>,
<3*x^6+3*x^5-3*x^4-x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-x^3+3*x^2+2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4-x^3+3*x^2-2*x+2,{2}>,
<3*x^6+3*x^5-x^4-x^3+3*x^2+x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4+x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6+3*x^5-x^4-x^3+3*x^2-2*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5-x^4-x^2+x-1,{2}>,
<-3*x^6+3*x^5+x^4+x^2-x+2,{2}>,
<3*x^6+2*x^5+x^4+x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-x^2+3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-x^2+3*x+3,{}>,
<2*x^6+2*x^5+2*x^4-x^3-x^2+3*x+3,{2,13}>,
<-x^6-2*x^5+2*x^4+x^3-x^2-3*x+3,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+x^2+3*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3-x^2-3*x+3,{}>,
<3*x^6+2*x^5-2*x^4-x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4-x^3+2*x^2+2*x-3,{2}>,
<3*x^6+3*x^5-x^4-x^3+2*x^2+x-2,{2}>,
<-3*x^6+3*x^5+x^4-x^3-2*x^2+x+3,{2,3}>,
<3*x^6+3*x^5-x^4-x^3+2*x^2-x+3,{2,3,7}>,
<2*x^6-x^5-2*x^4-x^3+x^2+3*x-3,{2,3}>,
<-x^6-2*x^5+2*x^4-x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3-2*x^2-2*x+2,{}>,
<-2*x^6-2*x^5+2*x^4-x^3-x^2+3*x+3,{}>,
<3*x^6+2*x^5-2*x^4+x^3+x^2-3*x-3,{2}>,
<-x^6+3*x^5+x^4-x^3-x^2+3*x+3,{2,3}>,
<-2*x^6+3*x^5+x^4-x^3-x^2+3*x+3,{2,5}>,
<3*x^6+3*x^5-x^4-x^3+x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5-x^4-x^3+x^2+2*x-1,{2}>,
<2*x^6+2*x^5-x^4-x^3+x^2+3*x-3,{2}>,
<-2*x^6+2*x^5+x^4-x^3-x^2+3*x+3,{2}>,
<2*x^6+x^4+x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+x^3+x^2-2,{2}>,
<-3*x^6+3*x^5+x^4-x^3-x^2+3,{2}>,
<-3*x^6+x^4+x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+x^3+x^2+x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3-x^2-3*x-1,{2}>,
<-3*x^6-3*x^5+x^4+x^3-3*x-1,{2}>,
<2*x^6-3*x^5+x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3-3*x-2,{2}>,
<3*x^6+2*x^5-x^3+x^2+3*x-3,{2,3}>,
<3*x^6-x^5+x^3-x^2-3*x+3,{}>,
<2*x^6-x^5+x^3+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+x^3-x-3,{2}>,
<3*x^6-x^3-x^2+3*x+3,{2,3}>,
<2*x^6-x^3-x^2+3*x+3,{2,3}>,
<-x^6+x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+x^3+2,{2}>,
<-2*x^6+x^3-x^2-3*x+3,{2}>,
<3*x^6+x^3+x^2-3*x-3,{2}>,
<3*x^6+2*x^5+x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3-2*x-1,{2}>,
<-3*x^6+2*x^5+x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3-3*x-1,{2,7}>,
<-3*x^6+3*x^5+x^4-x^3+x^2+3*x-2,{2}>,
<3*x^6-3*x^5-x^4+x^3-x^2-3*x+2,{2}>,
<3*x^6+3*x^5-x^4-x^3-x^2+3*x-1,{2}>,
<-3*x^6+3*x^5+x^4-x^3+x^2+2*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3+x^2-3*x-3,{}>,
<-3*x^6+2*x^5-x^4-x^2-3*x+3,{2}>,
<-x^6-3*x^5+x^4+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4-x^2+3*x-2,{2}>,
<3*x^6-2*x^5+x^4-x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3-x^2+2*x-3,{2,3}>,
<3*x^6+3*x^5-x^4+x^3-2*x^2+x+3,{2}>,
<2*x^6+x^5-x^4-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+x^2-x-1,{2}>,
<2*x^6+x^5+x^4+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4-x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-2*x^4-x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6-3*x^5-x^4+x^3+3*x^2-x-3,{2,3,5,173}>,
<-2*x^6+2*x^5-2*x^4-x^3-x^2+3*x+3,{2}>,
<-x^6+3*x^4-x^3-x^2+3*x+3,{}>,
<-3*x^6-3*x^5+x^4+x^3-3*x^2+2,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+x^2+3*x-3,{2}>,
<2*x^6-x^5-3*x^4-x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3-2*x^2-3,{2}>,
<3*x^6+3*x^5-x^4-x^3-2*x^2-x-2,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-3*x^5+x^4+x^3+2*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-x^4+x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-x^5+3*x^4+x^3+x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+x^4+x^3+3*x^2-x-1,{2}>,
<-3*x^6-x^5-3*x^4+x^3-x^2-3*x+3,{2,3}>,
<-x^6+3*x^4+x^3+x^2-3*x-3,{0}>,
<-2*x^6-3*x^4+x^3-x^2-3*x+3,{2,5}>,
<-3*x^6-3*x^5+x^4+x^3+3*x^2+3,{2}>,
<-3*x^6+3*x^5+x^4+2*x^2+2*x+2,{2,3,7,103}>,
<3*x^6-3*x^5-x^4+x^3-3*x^2-3,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^2+2*x-2,{2,3,5}>,
<3*x^6+3*x^5-x^4-x^3-3*x^2-x-2,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^2+3*x-3,{2,3}>,
<3*x^6+x^5+3*x^4+x^3+x^2-3*x-3,{2,3,5}>,
<3*x^6-3*x^5-x^4-2*x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4+x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-x^3-3*x^2-2*x+3,{2}>,
<-2*x^6-x^5+2*x^4+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3-x^2+3*x+3,{2,3}>,
<-2*x^6-2*x^5+3*x^4-x^3+x^2+3*x-3,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-x^3-3*x^2-2*x-1,{2}>,
<-3*x^6-3*x^5+x^4+x^3+3*x^2+2*x+2,{}>,
<-2*x^6+2*x^5-3*x^4+x^3-x^2-3*x+3,{}>,
<3*x^6-3*x^5-x^4-2*x^2-x+2,{2,3}>,
<3*x^6-3*x^5-x^4+x^3-3*x^2+2*x-3,{2,3}>,
<-2*x^6+3*x^5-2*x^4-x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x^2-2*x-3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x^2-x+3,{2,3}>,
<-3*x^6+3*x^5+x^4-2*x^3-3*x^2+x+2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+x^2-3*x-3,{2}>,
<2*x^6+3*x^4-2*x^3-x^2+3*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x^2-1,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3+2*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-x^4+x^3-2*x^2-2*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4+2*x^3-x^2-3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3+x^2+3*x-3,{2,3}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+2*x^2-3*x-1,{2}>,
<3*x^6+3*x^5-x^4-2*x^3+2*x^2+3*x-2,{2,3}>,
<2*x^6-x^5-2*x^4-2*x^3+x^2+3*x-3,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-2*x^2+x+3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4+2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-2*x^2-3*x+3,{2,3,101}>,
<2*x^6-2*x^5-2*x^4-2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+x^2-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+x^2-3*x-3,{}>,
<3*x^6+3*x^5-x^4-2*x^3+x^2+3*x-2,{2}>,
<3*x^6-2*x^5-x^4+2*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3+x^2+2*x-3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+x^2-x-2,{2}>,
<3*x^6-3*x^5-x^4-2*x^3-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4+x^3-x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^3-x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5+x^4-2*x^3+2*x+2,{2}>,
<3*x^6+3*x^5-x^4-2*x^3+2*x-2,{2}>,
<3*x^6-3*x^5-x^4+2*x^3-2*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4-2*x^3+x+2,{2,3}>,
<3*x^6-x^5+2*x^3+x^2-3*x-3,{2,3}>,
<2*x^6+2*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+x+3,{}>,
<-3*x^6-3*x^5+x^4+2*x^3+2*x-1,{2}>,
<-2*x^6-3*x^5-2*x^3+x^2+3*x-3,{2}>,
<2*x^6-x^5-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x+2,{2}>,
<-x^6+3*x^5+2*x^3+x^2-3*x-3,{}>,
<3*x^6-3*x^5-x^4+2*x^3+3*x-1,{2,3}>,
<-3*x^6-3*x^5+x^4+2*x^3+3*x+2,{2}>,
<3*x^6-3*x^5-x^4+2*x^3-x^2-2*x-1,{2}>,
<-3*x^6-3*x^5+x^4+x+3,{2,3}>,
<3*x^6+x^5-x^4-2*x^3-x^2+3*x+3,{2,3}>,
<2*x^6+2*x^5-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3-x^2-x-1,{2}>,
<-x^6+3*x^5+x^2-3*x-3,{2}>,
<2*x^6+x^5+x^4-2*x^3+x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+x^4+x^2-3*x-2,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-x^2-x+2,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+x^2-x-1,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-x^2-x-2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-x^2+3*x+3,{2,3,11}>,
<3*x^6+x^5+x^4+2*x^3+x^2-3*x-3,{2,3}>,
<-x^6-3*x^5+3*x^4+x^3+x^2-3*x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3-x^2+3*x+3,{2,3}>,
<-x^6+3*x^5-3*x^4-x^3-x^2+3*x+3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+x^4+x^3+3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+x^2-2*x-1,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^3-2*x^2+3*x-2,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4+x^3+x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^3-x^2-2*x-3,{2,3}>,
<-2*x^6-2*x^4-2*x^3-x^2+3*x+3,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3+x^2+3*x-3,{}>,
<-2*x^6-2*x^5+3*x^4+x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-x^3+3*x^2+2*x+2,{2,3}>,
<3*x^6+3*x^5-x^4-2*x^3-2*x^2-3,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+x^2-3*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6+3*x^5+x^4-2*x^3+3*x^2+3*x-2,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^3+x^2+3*x-3,{}>,
<3*x^6+3*x^5-x^4-2*x^3-3*x^2+3*x+2,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-2*x^2-x-2,{2,5}>,
<-x^6-3*x^5-3*x^4+2*x^3-x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+x^4+2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6+x^5-3*x^4-x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3-3*x^2-x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3-x^2+3*x+3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3+x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-x^5-3*x^4-2*x^3-x^2+3*x+3,{2}>,
<-3*x^6+x^5-3*x^4+2*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+2*x^3-2*x^2+2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+3*x^2+2*x-1,{2,3}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3+x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4+2*x^3-x^2-3*x+3,{2}>,
<-x^6-3*x^4-2*x^3-x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+2*x^3-3*x^2+3*x+2,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-3*x^2-2,{2,5,11}>,
<3*x^6+3*x^5-x^4-3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+x^2-3*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+3*x^2-x+2,{2,3}>,
<-x^6+x^5+3*x^4-3*x^3-x^2+3*x+3,{2}>,
<2*x^6-3*x^4+3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+x^4-2*x^3+3*x^2+x-1,{2}>,
<3*x^6+3*x^5-x^4-3*x^3+3*x^2-2,{2,3}>,
<2*x^6+x^5-3*x^4+3*x^3+x^2-3*x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+x^2-3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2+3*x+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-x^2-3*x+3,{2}>,
<2*x^6-x^5-2*x^4-3*x^3+x^2+3*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3-x^2-3*x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-x^2+3*x+3,{}>,
<2*x^6-x^5+2*x^4-2*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+x^2+x+3,{2,3}>,
<-3*x^6+3*x^5+x^4-3*x^3-x^2-2*x-1,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3-x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6+3*x^5-x^4-3*x^3+x^2-2*x-3,{2}>,
<-3*x^6+3*x^5+x^4-x^3+x^2+x+3,{2,3}>,
<3*x^6+3*x^5-x^4-x^3-x^2-1,{2}>,
<3*x^6+x^5-x^4+x^3-x^2-3*x+3,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-x^2-3*x+3,{2}>,
<-3*x^6+x^5-x^4+x^3-x^2-3*x+3,{2}>,
<2*x^6+2*x^5-x^4+x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+x^3+x^2+2*x-1,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+x^2+3*x-3,{2}>,
<3*x^6+3*x^5-x^4-3*x^3+x+2,{2,3}>,
<2*x^6+x^5+3*x^3-x^2-3*x+3,{2}>,
<-x^6+3*x^5+2*x^4-x^3-x^2+3*x+3,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-x^2+3*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4-2*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2-3*x+3,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3+x^2+3*x-3,{2,11}>,
<-3*x^6-3*x^5+x^4+3*x^3-x^2-3*x+3,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-x^2-3*x+3,{}>,
<3*x^6-3*x^5-x^4+2*x^3-3*x^2+x-1,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3-x^2-3*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2+3*x-3,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+x^2+3*x-3,{2,3}>,
<-2*x^6+2*x^5+x^4+3*x^3+x^2-3*x-3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+x^2-2*x-3,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2+3*x-3,{}>,
<3*x^6+3*x^5-x^4-3*x^3-x^2-3*x-2,{2,13}>,
<-3*x^6+2*x^5-2*x^4-3*x^3-x^2+3*x+3,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3-x^2-3*x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3-x^2+3*x+3,{2,7}>,
<3*x^6+x^5+x^4-3*x^3-x^2+3*x+3,{2,3}>,
<3*x^6-2*x^4-3*x^3-x^2+3*x+3,{2}>,
<-2*x^6-2*x^4-3*x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3+2*x^2+x-2,{2}>,
<3*x^6-3*x^5-x^4+3*x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+x^2+3*x-3,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3-x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-x^4-3*x^3-2*x^2-2*x-3,{2,3}>,
<-3*x^6+3*x^5+x^4-3*x^3+3*x^2+3*x-2,{2,3}>,
<3*x^6+3*x^5-x^4-3*x^3-3*x^2+x-1,{2,3}>,
<-x^6-3*x^5+3*x^4+3*x^3+x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-x^4+3*x^3-3*x^2-2*x+2,{2,3}>,
<-3*x^6+3*x^5+x^4-2*x^3-3*x^2+3,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-x^2-3*x+3,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+x^2+3*x-3,{}>,
<2*x^6-2*x^5-3*x^4-2*x^3+x^2+3*x-3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3-3*x^2+x-3,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^3-x^2-3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+x^2-3*x-3,{2}>,
<2*x^6+2*x^5+3*x^3-x^2-3*x+3,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+x^2-3*x-3,{2}>,
<3*x^6+x^4+2*x^3-x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+x^4-3*x^3-2*x-1,{2}>,
<-2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-x^5+x^4-2*x^3-x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-x^4+3*x^3+2*x-1,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-x^2+3*x+3,{2,3}>,
<2*x^6-3*x^5+3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<2*x^6+2*x^5+3*x^3+x^2-3*x-3,{2}>,
<-x^6+2*x^5-x^4+2*x^3+x^2-3*x-3,{2,3}>,
<-2*x^6+2*x^5+3*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+2*x^3-x^2+3*x-1,{2,3}>,
<-x^6+3*x^5+3*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-3*x-3,{}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2-3*x-2,{}>,
<3*x^6+3*x^5-x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-3*x^5+2*x^3-x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+x+2,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x-1,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-3*x^2+x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-3*x^2+2*x-2,{2,5}>,
<3*x^6-2*x^5-3*x^4+3*x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3+3*x^2+2*x+2,{2,5}>,
<3*x^6+3*x^5-2*x^4+3*x^3+3*x^2-2*x-3,{2,3}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-3*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2,3}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-x^6-x^5-2*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<2*x^6-3*x^5+3*x^3+x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-2*x^2+x+2,{2,3}>,
<3*x^6-3*x^5-x^4+3*x^3-3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+2*x^2+x-2,{2,3}>,
<-2*x^6+2*x^4+3*x^3-2*x^2+3*x+3,{}>,
<-x^6+2*x^5-3*x^3-x^2+3*x+3,{2}>,
<3*x^6-2*x^4+3*x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^3+x^2+3*x-3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x^2-3*x-3,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+2*x^2-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3+2*x^2-x-2,{}>,
<2*x^6+x^5+x^4+3*x^3-2*x^2+3*x+3,{2}>,
<2*x^6+x^5-x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2-x-2,{}>,
<-2*x^6+3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+3*x^2+x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6-3*x^5-3*x^3+2*x^2-3*x-3,{2}>,
<-x^6+3*x^5+3*x^3+2*x^2+3*x-3,{2}>,
<2*x^6-3*x^5-3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3-x^2+3*x+3,{2,3}>,
<-2*x^6+3*x^4+3*x^3+x^2-3*x-3,{2}>,
<3*x^6+3*x^5-x^4-3*x^3-3*x^2-1,{2,3}>,
<-3*x^6-3*x^5+x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4+3*x^3-x^2-3*x+3,{2}>,
<3*x^6+3*x^5-x^4-3*x^3-3*x^2-x-1,{2,3}>,
<-2*x^6+x^5-3*x^4+3*x^3-x^2-3*x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+x^2+3*x-3,{}>,
<-3*x^6+2*x^5+3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+x^5+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+x+3,{2,3}>,
<2*x^6-x^5-3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3+x-1,{2}>,
<2*x^6+x^5+3*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-x^5-3*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-1,{2,3}>,
<2*x^6+3*x^3+2*x^2+3*x-3,{}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-x^2-2*x-1,{2}>,
<-2*x^6+3*x^3-2*x^2+3*x+3,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-x-1,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x-1,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3+x^2+x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+x+2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-x+3,{}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2-2*x-3,{2,3}>,
<-3*x^6-x^5+3*x^3-2*x^2+3*x+3,{}>,
<2*x^6-2*x^5+3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5-3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-2*x^5+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-3*x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3-3*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+x^2+3*x-2,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-x^2-3*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-x^2+3*x+3,{2,3}>,
<2*x^6+x^5+2*x^4-3*x^3-x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3+x^2-2*x+2,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3-2*x^2-x+2,{2}>,
<3*x^6+3*x^5-x^4-3*x^3-x^2+x+3,{2,3}>,
<3*x^6+2*x^4+3*x^3-x^2-3*x+3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3-x^2-x-3,{2,3}>,
<2*x^6-2*x^4+3*x^3+x^2-3*x-3,{2}>,
<-3*x^6-x^4-3*x^3-x^2+3*x+3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+2*x^2-2,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3+x^2+x-1,{2}>,
<3*x^6-3*x^5-x^4+3*x^3+2*x^2+x+3,{2}>,
<3*x^6-3*x^5-x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-3*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^3-x^2-x+3,{2,3}>,
<-x^6+x^5+x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-x^2-x-1,{2,3}>,
<-x^6-x^4+3*x^3+2*x^2+3*x-3,{2,3}>,
<-x^6+x^4+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-x^2+3,{2,3}>,
<-2*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x^2-2*x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-2*x^2+3*x-2,{2,3}>,
<2*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+2*x^2+3*x-3,{2,3}>,
<-2*x^6+2*x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+2*x^2-2*x-2,{2,3}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3*x-3,{}>,
<3*x^6+3*x^5-2*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2+x-1,{}>,
<2*x^6-x^5-x^4+3*x^3+2*x^2+3*x-3,{}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3-x^2+x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+3*x^3-x^2-2*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+x^2+2*x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+2*x^2-3*x-3,{2,3,5}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3-2*x^2+3*x+3,{2,3}>,
<-2*x^6-3*x^5-x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+x-3,{2,3}>,
<-x^6+x^5+2*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<-x^6-x^5-2*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+3*x-3,{}>,
<3*x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x-3,{}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-2*x+3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-3*x-3,{}>,
<-x^6-x^5+3*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<2*x^6+2*x^5+3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+3*x^2+x+2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x-1,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^3-3*x^2+2,{2,3}>,
<-x^6-3*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<-2*x^6-3*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-2*x^2+3*x+3,{}>,
<3*x^6-3*x^5-2*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-2*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+x^2-3,{2}>,
<-3*x^6-x^4-3*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6+x^5+x^4-3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+x^2-x-2,{2,3}>,
<3*x^6+3*x^5-2*x^4+3*x^3-x^2-x+2,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-x^2-3*x+3,{2,3}>,
<-x^6+2*x^5+3*x^4-3*x^3+2*x^2-3*x-3,{0,2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+2*x^2-3*x-3,{0,2}>,
<-2*x^6-x^5-x^4-3*x^3+2*x^2-3*x-3,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6-x^5-3*x^4-2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+2*x^2-3*x-3,{2,3,5}>,
<-3*x^6-x^5+3*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^3-2*x^2-x+2,{2,3}>,
<-x^6+x^5+2*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-x^6+x^5-2*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+2*x^2+3*x-3,{2,3,5}>,
<3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+2*x^2-3*x-3,{2,3,11}>,
<-x^6-2*x^5+2*x^4+3*x^3-2*x^2+3*x+3,{2,3}>,
<2*x^6-2*x^5-2*x^4+3*x^3+2*x^2+3*x-3,{2,5}>,
<-2*x^6-2*x^5+2*x^4+3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+3*x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6-x^5+3*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<2*x^6+3*x^5-2*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3+2*x^2+2*x+3,{}>,
<2*x^6-2*x^5+2*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-3*x^2+x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2-3*x+3,{2,3}>,
<-2*x^6+x^5+2*x^4+2*x^3-2*x^2+3*x+3,{}>,
<3*x^6-x^5+x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-2*x^2-x+3,{2,3}>,
<-3*x^6-x^5+2*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-2*x^2-3,{2}>,
<-x^6+2*x^4-2*x^3-2*x^2-3*x+3,{}>,
<3*x^6-2*x^4-2*x^3+2*x^2-3*x-3,{2,5}>,
<-3*x^6+2*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6+x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4+2*x^3+2*x^2-x-1,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3-2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3+2*x^2-x-2,{2,3,31,151}>,
<3*x^6+3*x^5-2*x^4+2*x^3+2*x^2-3*x-2,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+x+3,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^3-2*x^2-x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-x^2-2*x-3,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3+2*x^2+3*x-3,{2,5}>,
<3*x^6-3*x^5-2*x^4-2*x^3+x^2-2*x-1,{2,5}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<-x^6-x^5+3*x^4+2*x^3-2*x^2+3*x+3,{}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-x^2+2*x+2,{2,7,53}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6+2*x^5+x^4+2*x^3-2*x^2+3*x+3,{2,7}>,
<3*x^6-2*x^5-x^4-2*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6-2*x^5+x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+x^5+x^4+2*x^3-2*x^2+3*x+3,{}>,
<2*x^6-x^4-2*x^3+2*x^2-3*x-3,{}>,
<3*x^6-3*x^5-2*x^4-2*x^3+x^2-2,{}>,
<-3*x^6+x^5-x^4-2*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-x^2+x-2,{2}>,
<-x^6+x^5+x^4-2*x^3-2*x^2-3*x+3,{2}>,
<2*x^6-x^5+x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-x^6+x^5-x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-x^5+x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4+2*x^3+x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-x^6-2*x^5-2*x^3-2*x^2-3*x+3,{}>,
<3*x^6-3*x^5-2*x^4-2*x^3-2*x-2,{}>,
<3*x^6+3*x^5-2*x^4+2*x^3+2*x-3,{2,3}>,
<-3*x^6+x^5+2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-x-2,{2}>,
<-x^6-x^5-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-x+2,{2}>,
<-2*x^6+2*x^3+2*x^2+3*x-3,{}>,
<2*x^6+2*x^3-2*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-3*x^2+3*x-1,{2,3}>,
<-x^6+2*x^3+2*x^2+3*x-3,{2}>,
<-x^6-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+2,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+x^2-x-2,{2,3}>,
<2*x^6+3*x^5+3*x^4+3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-3*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5+2*x^3+2*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+3*x-1,{0}>,
<2*x^6+3*x^5-2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+x^2-3*x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4+2*x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-x^2-2*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+x^2-2*x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+2*x^2-3*x-3,{2,3,151}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+x^2+3,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3-x^2-3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+x^2-x-1,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+x^2-x+2,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+3*x-3,{2,3}>,
<-2*x^6-x^5-x^4+2*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+x^2-x+3,{2,5}>,
<3*x^6-3*x^5-2*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3-x^2+2*x+2,{2,3}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-x-2,{}>,
<2*x^6-x^5-2*x^4-2*x^3-2*x^2-3*x+3,{}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-x-1,{2,3}>,
<-3*x^6+2*x^5+x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-x^2-3*x-1,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^3-2*x^2-2,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3-2*x^2-x-1,{}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+2*x^2-x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-1,{2,5,7}>,
<3*x^6+3*x^5-2*x^4+2*x^3-2*x^2-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3-2*x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^3+2*x^2-3*x-3,{0,2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3+3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x-1,{2,3}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4+2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x^2-2*x-3,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3-2*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x+3,{2,3}>,
<-3*x^6+x^5+3*x^4+2*x^3+2*x^2+3*x-3,{2,3,5}>,
<-2*x^6+3*x^5+2*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2-2,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+2*x-3,{}>,
<2*x^6-3*x^4+2*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-2*x^2-3*x+3,{2,3,5}>,
<-x^6+3*x^4-2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-2*x+3,{}>,
<3*x^6+3*x^5-2*x^4+2*x^3-3*x^2-1,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x-2,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-2*x+2,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x-1,{2}>,
<-3*x^6-x^5+3*x^4+2*x^3+2*x^2+3*x-3,{}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+2*x-1,{2}>,
<-x^6-x^5-3*x^4-2*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4+2*x^3-3*x^2-x+3,{}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x+2,{}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4+x^3+3*x^2+3*x-3,{2,3}>,
<-2*x^6-2*x^5+3*x^4-x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3+2*x^2+3*x-3,{}>,
<3*x^6+3*x^5-2*x^4+x^3+3*x^2+2*x-3,{}>,
<3*x^6-3*x^4+x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^4+x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3+3*x^2-x-2,{2,7}>,
<3*x^6+3*x^5-2*x^4+x^3+3*x^2+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3+3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+2*x^2-3*x-3,{2,3,7,47}>,
<2*x^6+3*x^4+x^3-2*x^2+3*x+3,{2}>,
<-x^6+3*x^4-x^3-2*x^2-3*x+3,{}>,
<2*x^6-3*x^4+x^3+2*x^2+3*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x+3,{}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3+2*x^2+x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3-2*x^2-x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-3*x-3,{2}>,
<2*x^6+2*x^5+x^4+x^3-2*x^2+3*x+3,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2-3*x-3,{}>,
<2*x^6+2*x^5-x^4+x^3+2*x^2+3*x-3,{}>,
<-2*x^6+x^5+x^4+x^3-2*x^2+3*x+3,{2}>,
<3*x^6+x^5-x^4+x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4+x^3+x^2+2*x-2,{2,3}>,
<3*x^6+2*x^5-x^4+x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3+x^2-3,{2,3,17}>,
<3*x^6+x^5+x^4-x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^3+x^2-2*x-3,{2}>,
<-x^6-x^5-x^4-x^3+2*x^2-3*x-3,{2}>,
<2*x^6-x^5-x^4+x^3+2*x^2+3*x-3,{2,3,13}>,
<3*x^6+3*x^5-2*x^4+x^3+x^2+x-1,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^3+x^2+x-2,{2,3}>,
<2*x^6-x^5-x^4-x^3+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3+x^2-x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3-x^2+3*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3-2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5+x^3-2*x^2+3*x+3,{2}>,
<-x^6-3*x^5-x^3+2*x^2-3*x-3,{2}>,
<-x^6-2*x^5+x^4+x^3-2*x^2+3*x+3,{2}>,
<2*x^6-3*x^5-x^3+2*x^2-3*x-3,{2}>,
<-2*x^6-3*x^5-x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-2*x^5-x^3+2*x^2-3*x-3,{2}>,
<3*x^6-2*x^5-x^3-2*x^2-3*x+3,{}>,
<-2*x^6+2*x^5+x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3-2*x+2,{2,5}>,
<3*x^6-3*x^5-2*x^4-x^3-2*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+2*x+3,{2,3}>,
<-2*x^6+x^5+x^3+2*x^2+3*x-3,{2}>,
<-x^6+x^5+x^3-2*x^2+3*x+3,{2}>,
<3*x^6+x^5+x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-x^5-x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3+2,{2}>,
<-x^6-x^3+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-x^3+2,{2}>,
<-2*x^6+x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3+x-3,{2,3}>,
<-x^6-x^5+x^3-2*x^2+3*x+3,{2,3}>,
<-2*x^6-x^5+x^3-2*x^2+3*x+3,{2}>,
<3*x^6+x^5-x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6-2*x^5+x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-2*x-2,{2}>,
<-x^6+2*x^5-x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+x^2+3*x-1,{2,3}>,
<-2*x^6-3*x^5-x^4-x^3-2*x^2-3*x+3,{}>,
<-3*x^6+2*x^5+x^4+x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^3+x^2+3*x-2,{2}>,
<-3*x^6-2*x^5-x^4-x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+x^2+x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+x^2+x+3,{2,3,5}>,
<3*x^6-3*x^5-2*x^4-x^3-x^2-x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-x^2-x-3,{2}>,
<3*x^6-x^4-x^3-2*x^2-3*x+3,{2}>,
<-2*x^6+x^5+x^4+x^3+2*x^2+3*x-3,{}>,
<-2*x^6+x^4-x^3+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-x^2+x+2,{}>,
<-x^6+x^4-x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-x^2-1,{2}>,
<2*x^6+x^4+x^3+2*x^2+3*x-3,{}>,
<-3*x^6-3*x^5+2*x^4-x^3+x^2-x+2,{2}>,
<-2*x^6+x^5-x^4+x^3-2*x^2+3*x+3,{}>,
<3*x^6+2*x^5+x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-x^2-2,{2}>,
<-3*x^6-x^5+x^4-2*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6-2*x^5-x^4+x^3-2*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5+x^4-x^3+2*x^2-3*x-3,{2}>,
<3*x^6+x^4+x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-x^2+3*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3+x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+2*x^2+3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-2*x^2+x+2,{2,3}>,
<-x^6+x^5+2*x^4+x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-2*x^2-x-1,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-x^3+2*x^2-2,{}>,
<-2*x^6+2*x^5+2*x^4+x^3+2*x^2+3*x-3,{2}>,
<2*x^6+2*x^4-x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+2*x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4+x^3-2*x^2+3*x+3,{}>,
<-2*x^6+x^5+2*x^4-x^3+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-2*x^2+2*x-2,{2,3}>,
<-x^6+x^5+2*x^4-x^3+2*x^2-3*x-3,{0,2}>,
<-3*x^6-x^5-2*x^4+x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+2*x^2+3*x-3,{}>,
<2*x^6+x^5-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+x^5-2*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2+2*x+2,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3+3*x^2-x-2,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^3-3*x^2-x-1,{2}>,
<-3*x^6-3*x^5+2*x^4-x^3+3*x^2-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3-3*x^2+3,{2}>,
<-x^6+3*x^4+x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^4-x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2-x-3,{2,3}>,
<-2*x^6-x^5-3*x^4+x^3-2*x^2+3*x+3,{}>,
<3*x^6+2*x^5-3*x^4-x^3-2*x^2-3*x+3,{}>,
<-x^6-2*x^5-3*x^4+x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^3-3*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3+3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5-3*x^4+x^3-2*x^2+3*x+3,{}>,
<3*x^6-3*x^5-2*x^4+3*x^2-3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^2-2*x+3,{}>,
<2*x^6-2*x^5-3*x^4+2*x^2-3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-x^3+2*x^2+2*x-1,{0}>,
<-2*x^6+2*x^5+3*x^4-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+3*x^2+2*x-3,{2}>,
<3*x^6-x^5+3*x^4-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^2-x+2,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^2+3*x-3,{2}>,
<3*x^6-x^5-3*x^4+2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+3*x^2-2,{2}>,
<-3*x^6-x^5+3*x^4-2*x^2+3*x+3,{2,3,5}>,
<3*x^6-3*x^5-2*x^4+3*x^2+2*x+3,{2,3}>,
<2*x^6-2*x^5+3*x^4-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^2-3*x-3,{}>,
<-2*x^6+3*x^5+3*x^4-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4-2*x^2+3*x+3,{2,3,5}>,
<-x^6+2*x^5+2*x^4-2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4-2*x^2-2*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^2-2*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^2-x+3,{2,3}>,
<2*x^6+x^5-2*x^4+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^2-x-2,{2,3}>,
<3*x^6-2*x^4+2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^2-3,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^2-3*x+3,{2,3}>,
<-2*x^6+x^5+2*x^4-2*x^2-3*x+3,{2}>,
<3*x^6+x^5-2*x^4+2*x^2-3*x-3,{}>,
<3*x^6+3*x^5-2*x^4+2*x^2-x-3,{}>,
<3*x^6+3*x^5-2*x^4+2*x^2-2*x+3,{}>,
<-2*x^6+3*x^5-x^4+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+x^2-3*x-2,{2}>,
<-x^6+2*x^5-x^4+2*x^2+3*x-3,{2}>,
<-x^6-2*x^5+x^4-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4-2*x^2+3*x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+x^2-x-1,{2}>,
<3*x^6+3*x^5-2*x^4+x^2+x-3,{2,3}>,
<-2*x^6+x^4-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4+x^2-x+3,{2}>,
<2*x^6+x^5+x^4-2*x^2-3*x+3,{}>,
<3*x^6+3*x^5-2*x^4+x^2-x-1,{2,3}>,
<2*x^6+x^5-x^4+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^2-x+3,{2}>,
<-3*x^6+x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4+3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x+2,{}>,
<3*x^6+3*x^5-2*x^4+3*x-2,{}>,
<3*x^6-3*x^5-2*x^4-2*x^3-x^2+3,{2}>,
<-x^6-2*x^5+2*x^2-3*x-3,{2}>,
<2*x^6+2*x^5+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4-x-1,{2,3}>,
<2*x^6+x^5+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3+2*x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4+x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4-2*x^3+2*x-2,{2,7}>,
<-x^6-2*x^2-3*x+3,{2}>,
<-2*x^6-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-x^2-2*x+3,{2}>,
<2*x^6+2*x^5+x^4+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-x^2-2*x-2,{2}>,
<3*x^6+3*x^5-2*x^4-x^2+x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^3+3*x^2-3*x-1,{0,2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6+x^5+x^4+2*x^2+3*x-3,{2}>,
<-x^6-x^5+x^4+2*x^2-3*x-3,{}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2-3*x-3,{}>,
<3*x^6-3*x^5-2*x^4-x^2-x-1,{2}>,
<2*x^6+x^5+x^4+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^3-3*x^2+3*x-2,{2,3}>,
<-x^6+3*x^5-3*x^4+x^3+2*x^2+3*x-3,{2}>,
<-x^6+3*x^5+3*x^4+x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-x^2+x-2,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^2+3*x-2,{2,3,5}>,
<-3*x^6+2*x^5+2*x^4+2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4-x^2+x-3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^2-2*x+2,{2,3}>,
<-3*x^6-3*x^5+2*x^4+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4-2*x^2+3*x+3,{2}>,
<3*x^6+x^5-2*x^4-2*x^2+3*x+3,{}>,
<2*x^6+2*x^5+2*x^4+2*x^2+3*x-3,{}>,
<3*x^6+3*x^5-2*x^4-2*x^2+x+2,{2,3}>,
<-2*x^6+2*x^5-2*x^4-2*x^2+3*x+3,{}>,
<3*x^6+3*x^5-2*x^4-2*x^2+x-1,{2,3}>,
<-3*x^6+3*x^5+2*x^4+2*x^2+x+2,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4+x^3+2*x^2+3,{2,3}>,
<-x^6+2*x^4+x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-2*x^2+2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-3*x^5+2*x^4-x^3-2*x^2-3*x+3,{}>,
<3*x^6-3*x^5-2*x^4-2*x^2+2*x-1,{2,3}>,
<-2*x^6+2*x^5-2*x^4-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^2-2*x+3,{2,3,5}>,
<3*x^6+3*x^5-2*x^4-2*x^2-2*x-3,{2,3}>,
<2*x^6+3*x^5+3*x^4+2*x^2+3*x-3,{}>,
<-2*x^6-3*x^5-3*x^4-2*x^2-3*x+3,{}>,
<2*x^6-2*x^5-2*x^4-2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3-2*x^2+3*x+3,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+3*x-3,{2}>,
<-x^6+x^5-2*x^2-3*x+3,{2}>,
<2*x^6+x^5+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^2-2,{2}>,
<-2*x^6-3*x^4-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^2-x+3,{2,3}>,
<-2*x^6+x^5+3*x^4+2*x^2-3*x-3,{2}>,
<-x^6+x^5+3*x^4+2*x^2-3*x-3,{0,2}>,
<3*x^6-3*x^5-2*x^4-3*x^2+x-1,{2,11}>,
<2*x^6-x^5+3*x^4+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^2+x-2,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^2-x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^2+2*x-1,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^2+2*x-2,{2,3}>,
<3*x^6+3*x^5-2*x^4-3*x^2-2*x-3,{2}>,
<3*x^6-3*x^5-2*x^4-3*x^2+3*x-1,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^2-3*x-2,{2,7}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2+3*x-1,{2}>,
<3*x^6+3*x^5-2*x^4+2*x^3-x^2+2,{2,3}>,
<2*x^6+x^4-2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6-x^4+2*x^3-2*x^2+3*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-2*x^2+3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<-2*x^6-x^5+3*x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2-x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3-3*x^2-2*x+2,{2}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+2*x^4+x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4-x^3-3*x^2-3*x+2,{2}>,
<3*x^6-3*x^5-2*x^4+x^3+2*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3-2*x^2+3*x+3,{2,3,5,7,11}>,
<3*x^6-2*x^5+2*x^4+x^3-2*x^2-3*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+2*x^2-3*x-3,{2,3}>,
<-2*x^6+2*x^5+2*x^4-x^3-2*x^2+3*x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3+2*x^2-x-3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3+2*x^2-2,{2,3}>,
<3*x^6-x^5+2*x^4-x^3-2*x^2+3*x+3,{}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2-3*x-3,{2,7}>,
<2*x^6-3*x^5-x^4+x^3+2*x^2-3*x-3,{2}>,
<3*x^6+2*x^5-x^4-x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5+x^4-x^3-2*x^2+3*x+3,{2}>,
<-3*x^6-x^5+x^4+x^3-2*x^2-3*x+3,{2,3,17}>,
<3*x^6+x^4-x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+2*x^4+x^3-x^2+2,{2}>,
<-2*x^6+x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3+x^2+x+2,{2,3}>,
<3*x^6+3*x^5-2*x^4-x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5-x^4-x^3+2*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3+3*x-1,{2}>,
<-3*x^6-3*x^5+2*x^4+x^3-3*x+2,{2}>,
<2*x^6+2*x^5-x^3-2*x^2+3*x+3,{}>,
<-2*x^6+2*x^5-x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3+2*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3+2*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+x^3-x-1,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^2-x+2,{2,3}>,
<3*x^6-3*x^5-2*x^4+x^3-x-2,{2}>,
<-3*x^6+3*x^5+2*x^4+2*x^2-x-1,{0,2}>,
<3*x^6-x^5+x^3+2*x^2-3*x-3,{2}>,
<3*x^6+x^3-2*x^2-3*x+3,{2,3}>,
<-x^6-x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4-2*x^2+x-2,{2}>,
<2*x^6+x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6-x^5-x^3-2*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-x^3-2*x^2+3*x+3,{}>,
<3*x^6+3*x^5-2*x^4-x^3-x-3,{2,3}>,
<2*x^6-2*x^5-x^3-2*x^2+3*x+3,{}>,
<-x^6+2*x^5+x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3-2*x+3,{}>,
<-3*x^6-3*x^5+2*x^4+2*x^2+x+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4-2*x^2+3*x+3,{}>,
<-3*x^6-3*x^5+2*x^4+2*x^2+2*x-3,{2,3,5}>,
<-2*x^6-2*x^5-x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+x^4+x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6-x^4+x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-x^3+2*x^2+3*x-1,{}>,
<-3*x^6-3*x^5+2*x^4+3*x^2-3*x-2,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-x^2+x-3,{2,3,29}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2-3*x+3,{}>,
<-2*x^6+2*x^5-x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3+2*x^2-3*x-3,{2,3}>,
<2*x^6+3*x^5-3*x^4-2*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4+x^3+2*x^2-2*x-2,{2}>,
<3*x^6-2*x^5+x^4-x^3+2*x^2+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-x^2+2*x-3,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-3*x-3,{2}>,
<-x^6-3*x^5+3*x^4+2*x^2-3*x-3,{2,7}>,
<3*x^6-3*x^5-2*x^4+x^3-2*x^2-x+3,{2}>,
<-2*x^6-3*x^5+x^4-x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3-2*x^2+3*x+3,{}>,
<3*x^6+3*x^5-2*x^4-3*x^2+3*x-1,{2,3}>,
<-3*x^6-x^5-2*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<-x^6+2*x^4+x^3+2*x^2-3*x-3,{2}>,
<-2*x^6-2*x^4-x^3-2*x^2+3*x+3,{}>,
<3*x^6+3*x^5-2*x^4-x^3-2*x^2-3,{2,3}>,
<3*x^6+3*x^5-2*x^4-x^3-2*x^2-x-1,{2,3}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x^2-3*x-3,{2,3,11}>,
<-2*x^6-2*x^5-2*x^4-x^3-2*x^2+3*x+3,{2,11,181}>,
<3*x^6-3*x^5-3*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<-2*x^6+2*x^5+3*x^4+2*x^2+3*x-3,{2,5}>,
<3*x^6-3*x^5-2*x^4-x^3-3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4-3*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4+x^3+2*x^2+3*x-3,{2,3}>,
<-x^6+2*x^5-3*x^4-2*x^2+3*x+3,{2}>,
<-2*x^6+x^5+3*x^4-x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3-3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4-x^3-2*x^2+3*x+3,{}>,
<-3*x^6-x^5+3*x^4+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+x^3+3*x^2-x+3,{}>,
<-x^6-x^5+2*x^4+x^3+2*x^2-3*x-3,{2,5}>,
<3*x^6+3*x^5-2*x^4-x^3-3*x^2+x-3,{}>,
<3*x^6-3*x^4+x^3-2*x^2-3*x+3,{2}>,
<-x^6-x^5-3*x^4-x^3-2*x^2+3*x+3,{2}>,
<-x^6+3*x^4+x^3+2*x^2-3*x-3,{0,2}>,
<3*x^6-x^5-3*x^4-2*x^2-3*x+3,{2}>,
<-2*x^6-x^5-3*x^4-x^3-2*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+2*x^2+3*x-3,{2}>,
<-x^6+2*x^5-3*x^4+x^3-2*x^2-3*x+3,{2}>,
<-x^6-3*x^4-x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4+3*x^2+x-1,{2,3}>,
<2*x^6+3*x^4-x^3+2*x^2+3*x-3,{2}>,
<-2*x^6-3*x^4-x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3+3*x^2-3*x-1,{}>,
<2*x^6-3*x^5-3*x^4+2*x^3+2*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4+2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3+3*x^2-2*x+2,{2,3}>,
<-3*x^6+3*x^5+2*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<2*x^6-3*x^5-2*x^4+2*x^3+2*x^2-3*x-3,{2,3}>,
<2*x^6+3*x^4+2*x^3-2*x^2-3*x+3,{}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3+2*x^2+x-2,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3+3*x^2-x+2,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3+3*x^2+x-1,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3+2*x^2+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3-2*x^2+3*x+3,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3+x^2-2*x+3,{}>,
<2*x^6-2*x^5-x^4+2*x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3+x^2+2*x-2,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3+x^2-2*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3+x^2+x+2,{2,3}>,
<-3*x^6-3*x^5+2*x^4+2*x^3-x^2-x+2,{}>,
<3*x^6+3*x^5-2*x^4-2*x^3+x^2+x-2,{}>,
<2*x^6-2*x^5+x^4-2*x^3-2*x^2+3*x+3,{2}>,
<-x^6+2*x^5-x^4+2*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+2*x^4-2*x^3-x^2-3*x-1,{}>,
<-3*x^6+3*x^5+2*x^4-2*x^3-x^2+x+3,{2,3}>,
<3*x^6+x^5+x^4+2*x^3-2*x^2-3*x+3,{2,3,5}>,
<3*x^6+3*x^5-2*x^4-2*x^3+x^2-x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4+2*x^3-2*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3+x-1,{2}>,
<-x^6-2*x^5+2*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3+3,{2}>,
<-3*x^6+2*x^3-2*x^2-3*x+3,{2}>,
<-x^6+3*x^5+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+x-1,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3-x-2,{2}>,
<-2*x^6-3*x^5-2*x^2+3*x+3,{2}>,
<3*x^6-x^5-2*x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5+2*x^4+x^2+2*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3+x-3,{2,3}>,
<2*x^6-3*x^5-2*x^3+2*x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+2*x^2-3*x-3,{}>,
<3*x^6-3*x^5-2*x^4+2*x^3+2*x+3,{}>,
<3*x^6+3*x^5-2*x^4-2*x^3-x^2+3*x+2,{2,3}>,
<-x^6-3*x^5+3*x^4+x^3+2*x^2-3*x-3,{2,3}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5+2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+x^3-3*x^2-3*x-1,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3+2*x^2+3*x-3,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4+x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3-x^2+2*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3-2*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3-2*x^2+x+2,{2}>,
<3*x^6-3*x^5-2*x^4+x^3+3*x^2-2*x+2,{2}>,
<-3*x^6-x^5+3*x^4+x^3+2*x^2-3*x-3,{}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+2*x^2-x-1,{2}>,
<3*x^6+3*x^5-2*x^4-x^3+3*x^2+2*x-1,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+2*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3-2*x^2-x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3-2*x^2-2,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+x-2,{2,7}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<-x^6-3*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-2*x^2+x-1,{}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3-2*x^2-x-3,{2,3}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+2*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-2*x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6-3*x^5-2*x^4+2*x^3-3*x^2+3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-2*x^2+3*x+3,{2,3}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3-3*x^2+x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+3*x^2-2*x-3,{2,3}>,
<-x^6-x^5-3*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4+3*x^3-3*x^2+3*x-1,{2,3}>,
<-3*x^6-3*x^5+2*x^4+3*x^3-3*x^2-x+2,{2,3}>,
<3*x^6+3*x^5-2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+3*x^2+2,{2,3}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-2*x^2+3*x+3,{2,7,11}>,
<3*x^6+3*x^5-2*x^4-3*x^3+3*x^2-1,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^4+3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+2*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+2*x^2+2*x-2,{2,3}>,
<-2*x^6+3*x^5+x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-2*x^5+x^4+3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+2*x^2+3,{2,3}>,
<3*x^6+3*x^5-2*x^4-3*x^3+x^2+2*x+2,{2,3}>,
<3*x^6-3*x^5-2*x^4+3*x^3+x^2-2*x-1,{2,3}>,
<2*x^6-x^5+x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3-x^2+2*x+2,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3+x^2-2*x-1,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5-x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+2*x^4+3*x^3-x^2+2*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4-3*x^3-x^2+2*x+3,{2,3}>,
<-3*x^6+3*x^5+2*x^4-x^3+x^2+3*x-2,{2,3}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5-x^4-x^3-2*x^2+3*x+3,{2}>,
<2*x^6-x^5+x^4+3*x^3-2*x^2-3*x+3,{2,3,5}>,
<3*x^6+3*x^5-2*x^4-x^3-x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+x^4+x^3+2*x^2-3*x-3,{2}>,
<-x^6-2*x^5-x^4+x^3-2*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^3+2*x^2+3*x-3,{}>,
<-3*x^6+3*x^5+2*x^4-x^3+x^2+2*x+2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3+2,{2,3}>,
<-2*x^6-3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+3*x-2,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3-x-1,{2}>,
<3*x^6-x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<-3*x^6-x^5-3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-x^2-2,{}>,
<3*x^6+x^4+3*x^3+2*x^2-3*x-3,{2,3}>,
<-2*x^6-x^5+x^4-3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6-2*x^5-3*x^3-2*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-3*x^5-2*x^4+3*x^3+2*x-1,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<2*x^6-2*x^5-3*x^3+2*x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+2*x^2-3*x-3,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-2*x^4+3*x^3-2*x^2-x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3+2*x^2+x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+2*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-2*x^2+x-3,{2}>,
<-x^6-2*x^4+3*x^3-2*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-2*x^2-x-2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2+3*x-3,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+2*x^2-3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4+3*x^3-3*x^2-x-1,{}>,
<3*x^6+3*x^5-2*x^4-x^3-3*x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+2*x^4-3*x^3+3*x^2+x+2,{2,3,13}>,
<-3*x^6-3*x^5+2*x^4+x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-2*x^2+3*x+3,{}>,
<-x^6-3*x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4+3*x^3-3*x^2-3,{2}>,
<-x^6-x^5-3*x^4-3*x^3-2*x^2+3*x+3,{2}>,
<-3*x^6-x^5-3*x^4-3*x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-2*x^2-3*x+3,{2,3}>,
<2*x^6-x^5+3*x^4-3*x^3+2*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-3*x^2-x-2,{2,3}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-2*x^3-x^2-3,{2,3}>,
<3*x^6+3*x^5-2*x^4-2*x^3-x^2-x-2,{2}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+x^2-x+3,{2,3}>,
<3*x^6-3*x^5-2*x^4+2*x^3-x^2+x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-3*x^2-x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+3*x^2+x-1,{2}>,
<-3*x^6-x^5-2*x^4-x^3-2*x^2+3*x+3,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2-3*x+3,{2,3}>,
<3*x^6+3*x^5-3*x^4+3*x^3+3*x^2-x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+2*x^2+3*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-x^3-2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3+3*x-2,{2}>,
<2*x^6-2*x^4-3*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-2*x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2,5}>,
<-2*x^6-x^5+2*x^4+3*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-2*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^3-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^3+2*x^2-3*x-3,{2,3}>,
<2*x^6-3*x^5+2*x^3+2*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5-2*x^3-2*x^2+3*x+3,{2}>,
<-x^6-2*x^5+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-x+3,{2,3}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-x-2,{2}>,
<-3*x^6+x^5+x^4+3*x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-x^2-2,{2,5}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-1,{2}>,
<-x^6-x^5+x^4+3*x^3-3*x^2+3*x+3,{2,5}>,
<-2*x^6+2*x^5+x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+3*x^2+3*x-3,{2,3}>,
<2*x^6-2*x^5-2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-3*x^2-2*x-1,{}>,
<-3*x^6-2*x^5+x^4+3*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x^2+x-2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+x^2-3*x-2,{2}>,
<-3*x^6-3*x^5+2*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-3*x-2,{2,7}>,
<3*x^6+3*x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x^2+x+3,{2,3,19}>,
<-2*x^6+3*x^5-3*x^4+3*x^3-2*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x^2-2,{2}>,
<-3*x^6+2*x^5+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-2*x^2-1,{2}>,
<-x^6+2*x^4+3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+2*x-1,{2}>,
<2*x^6+2*x^5+3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+2*x+3,{2}>,
<-2*x^6-2*x^5-3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-2*x-2,{2}>,
<-3*x^6+2*x^5+3*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-2*x-1,{2}>,
<-3*x^6+x^5-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-x+3,{2}>,
<-2*x^6+x^5-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<2*x^6+x^5-3*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-x^5+3*x^3-3*x^2+3*x+3,{}>,
<-x^6+2*x^5-3*x^3+3*x^2-3*x-3,{2}>,
<-x^6+2*x^5-3*x^3-3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+3*x^3-2*x+2,{2,17}>,
<3*x^6+x^5-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x-2,{2,17}>,
<3*x^6-2*x^5+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-x^2-3*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x-3,{2,29}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+x^2-3*x+2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-x^6+x^5-3*x^4+3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+3*x^2+x-3,{2}>,
<-2*x^6+3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-x^6-3*x^5-x^4-3*x^3+3*x^2-3*x-3,{2,13}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-3*x-2,{}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-2*x+3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x-2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+x^2+2*x+2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3+x^2+2*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+x^2-2*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-x^2-x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+x^2-1,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-x^2-2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-3*x+3,{}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+x^2+x-1,{2}>,
<2*x^6+x^5+x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-x^2-2*x+3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2-2*x+2,{2}>,
<-x^6+3*x^5+x^4-3*x^3+3*x^2-3*x-3,{0}>,
<-x^6-2*x^5-3*x^4+3*x^3-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<3*x^6+3*x^5-2*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+2*x^2+x-2,{2,7}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-x+3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3+2*x+2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x^2-x+3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+2*x^2+x-2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x^2-x-1,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x-3,{2,5}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-2*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-2*x^6+x^4+3*x^3-3*x^2+3*x+3,{2,7}>,
<3*x^6+3*x^5-3*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-x^6+x^4+x^3+x^2+x-1,{2}>,
<-2*x^6+3*x^4-3*x^3+3*x^2-3*x-3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x^2-3*x-3,{}>,
<3*x^6-x^5-3*x^4+3*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+3*x^2-x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+3*x^2+x-1,{0}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+3*x^2-2*x-2,{}>,
<2*x^6+2*x^5-3*x^4-3*x^3-3*x^2-3*x+3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-3*x^2+3*x+3,{}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+3*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2,5}>,
<3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-2*x-3,{2,3}>,
<-2*x^6+x^5+3*x^4+2*x^3-3*x^2+3*x+3,{}>,
<3*x^6+x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+3*x^2+x+3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+3*x^2-x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2-3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^4+2*x^3+3*x^2+3*x-3,{2,11}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-3*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2-1,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2-2,{2,7}>,
<3*x^6-3*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-2*x^3+3*x^2+3*x-3,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x^2-3*x-1,{}>,
<3*x^6-3*x^5-2*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-2*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-3*x-2,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+2*x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6+x^5+2*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x^2-x-1,{2,3}>,
<-x^6-x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2,19}>,
<3*x^6+x^5-2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+3*x^2-3*x-3,{2,3}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+3*x^2+3*x-3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2+x-2,{2,3}>,
<-3*x^6+3*x^5+3*x^4+3*x^3+x^2+x-1,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3-x-1,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+2*x^2-1,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+2,{}>,
<3*x^6-3*x^5-3*x^4-2*x^3+2*x^2-2,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x^2+x-3,{2}>,
<-x^6+x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+2*x^2+x-3,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2,5}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2-3*x-2,{0}>,
<-x^6+3*x^5-2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+2*x^2+3*x-1,{0,2}>,
<2*x^6+3*x^5-2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-x^6-2*x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-x^6-2*x^5+x^4-2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<-2*x^6+2*x^5+x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2+3*x+3,{2,3,7}>,
<2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+3*x-3,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2*x+3,{2,3}>,
<-2*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-3*x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-x^6-x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x^2-1,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-x^2+2,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x^2-x+2,{2}>,
<-x^6-x^5-x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2-3*x-3,{}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-x^2-x+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6+x^5+x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+x^2+2*x-1,{2,3}>,
<-3*x^6+2*x^5-x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x^2-2*x-2,{2}>,
<3*x^6+2*x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+x^2+3*x-1,{0,2}>,
<2*x^6+3*x^5-x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x-1,{}>,
<3*x^6-3*x^5-3*x^4-2*x^3-3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+x^2-3*x+2,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+2*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3+x^2-3*x-2,{2,3}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+2,{2}>,
<2*x^6+2*x^3+3*x^2+3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2,{}>,
<-x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-x^2-2*x-3,{2,3}>,
<3*x^6+2*x^3+3*x^2+3*x-3,{}>,
<-3*x^6+2*x^3-3*x^2+3*x+3,{}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+x^5-2*x^3-3*x^2-3*x+3,{2,3,5}>,
<3*x^6-2*x^5+x^4-2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x-1,{2}>,
<-2*x^6-x^5+2*x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x^2-3*x-2,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-x^2+3*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x^2+2*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x^2+2,{2}>,
<-2*x^6-x^4-2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+x^5+x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+x^5-x^4-2*x^3-3*x^2-3*x+3,{2,3}>,
<-2*x^6-x^5+x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-x^2-x-1,{2,3}>,
<2*x^6-x^5+x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-x^2-2*x+3,{2}>,
<3*x^6-x^5-3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x^2-2*x-2,{2}>,
<-3*x^6+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x^2-2*x-1,{0,2}>,
<-3*x^6-2*x^5-x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x^2-3*x-1,{0,2}>,
<3*x^6-3*x^5-3*x^4-2*x^3-x^2+3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+2*x^2+2*x-1,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+3*x-3,{}>,
<-3*x^6-2*x^5-2*x^4-2*x^3-3*x^2-3*x+3,{}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-x^6-2*x^5-2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x-1,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-x-2,{2,3}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3-2*x+3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+3,{2}>,
<-2*x^6-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<-x^6+2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3+x^2+x-1,{2}>,
<2*x^6-x^5-x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-x^5+x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5-2*x^4+2*x^3-3*x^2+3*x+3,{0,2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+2*x^2-2,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2+3*x-1,{0,2}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<3*x^6+3*x^5-3*x^4+3*x^3-2*x^2+2,{2}>,
<-3*x^6-3*x^5+3*x^4-3*x^3+2*x^2-1,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x^2-x-2,{2}>,
<-x^6-2*x^4+3*x^3-3*x^2+3*x+3,{2,3}>,
<-x^6+x^5+x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+2*x^3-x^2+x-2,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x^2-x+3,{}>,
<2*x^6+2*x^4+3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3-3*x^2-3*x+3,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+3*x^2-3*x-1,{}>,
<-3*x^6+x^4-2*x^3+3*x^2-3*x-3,{2,3}>,
<-2*x^6-2*x^4-3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6-x^4+2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-x^6+x^4-2*x^3+3*x^2-3*x-3,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+3*x^2-x-2,{2}>,
<-x^6-x^4-2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-3*x^2+3,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+3*x^2-3*x-3,{}>,
<-3*x^6+x^5-3*x^4-2*x^3-3*x^2-3*x+3,{}>,
<3*x^6+3*x^5-3*x^4+2*x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+3*x^2+3*x-3,{}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+3*x^2-3*x-2,{0,2}>,
<-3*x^6+3*x^5+3*x^4+x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2-3*x+3,{}>,
<3*x^6+3*x^5-3*x^4+x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3-3*x^2-x-3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+3*x^2-x-2,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+3*x^2-2,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-3*x^2-x+3,{}>,
<3*x^6+3*x^5-3*x^4+x^3+3*x^2+x-3,{}>,
<3*x^6+3*x^5-3*x^4+x^3+3*x^2-x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3-3*x^2-2,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6-3*x^4+x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+x^2-2*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2-3*x+2,{2,3}>,
<-x^6-2*x^5-x^4-2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+x^3-2*x^2+2*x-1,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+2*x-2,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2-2*x-3,{}>,
<-x^6+x^5-2*x^4+x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+x-1,{2}>,
<3*x^6-2*x^5+x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-2*x^2-x+2,{2,5}>,
<-3*x^6+3*x^5+3*x^4+x^3-2*x^2-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2-1,{2}>,
<3*x^6-2*x^4-x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-2*x^2+x+3,{2}>,
<-3*x^6+2*x^4-x^3-3*x^2-3*x+3,{2}>,
<-2*x^6+x^5-2*x^4-x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3-3*x^2+3*x+3,{}>,
<3*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x-3,{2,3}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-3*x^4+x^3+x^2+3*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+x^3-x^2+3*x+2,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-x^2+2*x-3,{2,3}>,
<2*x^6-2*x^5+2*x^4+x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2-2*x-2,{2}>,
<-x^6+2*x^5-2*x^4-x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-x^2+2*x+2,{}>,
<2*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-x^3+x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2-2*x+3,{2}>,
<-2*x^6-x^5-x^4-x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+x^2-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2-x-1,{2}>,
<-3*x^6+x^5-x^4-x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+x^2+x-1,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2+x+3,{2,3}>,
<-3*x^6+x^5+2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+x^3-3*x^2+3*x+3,{2,3}>,
<-2*x^6+2*x^5-x^4-x^3+3*x^2-3*x-3,{2,7}>,
<-x^6+2*x^5+x^4-x^3-3*x^2-3*x+3,{2}>,
<2*x^6-2*x^5-x^4+x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2+3*x-1,{0,2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3-3*x-2,{}>,
<-3*x^6-3*x^5+3*x^4-x^3-3*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-3*x-1,{}>,
<3*x^6-3*x^5-3*x^4-x^3-3*x-2,{2,3}>,
<-x^6-x^5-2*x^4-2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6+x^5-2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^3+2*x^2-x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3-3*x-2,{2}>,
<-x^6+3*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-2*x^2-x-3,{2,3,5}>,
<3*x^6+3*x^5-3*x^4+x^3-3*x-2,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+3*x^2+3*x-3,{2}>,
<-2*x^6+3*x^5+x^4+x^3+3*x^2+3*x-3,{2}>,
<-2*x^6+2*x^5+2*x^4-2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-x^2-3*x+2,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+x^2+3*x-1,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^3-2*x^2-2*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6+3*x^5+3*x^4+x^3+x^2+2*x-1,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2-3*x+2,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-x^3-3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-3*x+3,{2,3,17}>,
<-2*x^6+2*x^5+x^4+x^3+3*x^2+3*x-3,{2,5}>,
<-3*x^6+3*x^5+3*x^4+x^3+x^2-2,{}>,
<3*x^6+3*x^5-3*x^4+x^3-x^2+2,{}>,
<3*x^6-3*x^5-3*x^4-x^3-x^2-1,{2,3}>,
<2*x^6+x^4+x^3+3*x^2+3*x-3,{2}>,
<3*x^6-x^5-x^4+x^3-3*x^2+3*x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3+3*x^2+3*x-3,{2}>,
<-2*x^6+2*x^5-x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3+3*x^2-3*x-3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4+x^3-2*x^2+3*x-2,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+3*x^2+3*x-3,{}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x-3,{2,3}>,
<-3*x^6-x^5-x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-2*x^2-2*x+3,{}>,
<3*x^6-x^5-x^3-3*x^2-3*x+3,{2}>,
<2*x^6-x^5-x^3-3*x^2-3*x+3,{2,3}>,
<2*x^6+x^5+x^3+3*x^2+3*x-3,{}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2+3*x-3,{2,7}>,
<-3*x^6+3*x^5+3*x^4+x^3+2*x^2+2*x-1,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-x^3+3*x^2-3*x-3,{2}>,
<2*x^6-x^3-3*x^2-3*x+3,{2}>,
<-x^6+2*x^4-x^3+3*x^2-3*x-3,{2}>,
<-x^6+x^3+3*x^2+3*x-3,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2-3*x-3,{2,5,11,19}>,
<-3*x^6-2*x^4-x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3-1,{2}>,
<-3*x^6-x^5+2*x^4+x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-2*x^2-2*x-2,{2,5,11,13}>,
<-3*x^6+3*x^5+3*x^4+x^3+2,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+2*x^2+2*x+3,{2}>,
<-2*x^6+x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+2*x^2+x-2,{2}>,
<3*x^6+x^5-2*x^4+x^3-3*x^2+3*x+3,{2,3}>,
<-2*x^6+x^5+2*x^4+x^3+3*x^2+3*x-3,{}>,
<3*x^6+3*x^5-3*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3-2*x^2+x+2,{}>,
<-2*x^6+2*x^5-2*x^4+x^3+3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+2*x^2+x-1,{2,3}>,
<3*x^6-x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-3*x^6+2*x^5-x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-2*x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2-3*x-3,{2,5,7}>,
<3*x^6-2*x^5-3*x^4-x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2-2*x-2,{}>,
<-3*x^6+3*x^5+3*x^4+x^3+3*x^2+3*x-2,{2}>,
<3*x^6+3*x^5-3*x^4+x^3-3*x^2+3*x+2,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-3*x^2-3*x-1,{2,7}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5-3*x^4-x^3-3*x^2-3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4+x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2+2*x-3,{2,3,5}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2-3*x+3,{2,3,13}>,
<-3*x^6+3*x^5+3*x^4+x^3+3*x^2-2*x-2,{0,2}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2+x-1,{2,3}>,
<-x^6-3*x^5-3*x^4+x^3-3*x^2+3*x+3,{2}>,
<2*x^6+x^5-x^4+x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^3+3*x^2+x-1,{0,2}>,
<3*x^6-x^5-3*x^4-x^3-3*x^2-3*x+3,{2,3,5}>,
<3*x^6-x^5-3*x^4+3*x^2+3*x-3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^2+3*x+3,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^2-3*x-3,{2,5}>,
<-3*x^6-3*x^5+3*x^4-2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^2+3*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^2-3*x+3,{2}>,
<-x^6-2*x^5-2*x^4+3*x^2-3*x-3,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^2+3*x-3,{2,5}>,
<-3*x^6-x^5-2*x^4+3*x^2-3*x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^2-x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^2+2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^2-2,{2}>,
<3*x^6+x^5+2*x^4-3*x^2-3*x+3,{2,3}>,
<2*x^6-x^5-2*x^4+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4+2*x^2-x-2,{2}>,
<-3*x^6-3*x^5+3*x^4-2*x^2+x+3,{2}>,
<-x^6+3*x^5-2*x^4+3*x^2-3*x-3,{2}>,
<-2*x^6+3*x^5-x^4+3*x^2+3*x-3,{2}>,
<-x^6+3*x^5+x^4-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^2+3*x+2,{2}>,
<2*x^6+2*x^5-x^4-x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2+2*x-1,{0}>,
<-3*x^6-x^5+x^4-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4+x^2-1,{2}>,
<-3*x^6-2*x^5-3*x^2-3*x+3,{}>,
<-2*x^6+x^5+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-x-1,{2}>,
<3*x^6+3*x^5-3*x^4+x-1,{}>,
<-x^6+x^5+3*x^4+x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2-3*x+3,{2}>,
<-2*x^6-2*x^5-x^4+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^2-2*x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-3*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^2+3*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+x^2+3*x-1,{2}>,
<-x^6-2*x^5+x^4+3*x^2-3*x-3,{2}>,
<-3*x^6-x^5+x^4+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^2-x+3,{2}>,
<-2*x^6-x^5+x^4+3*x^2-3*x-3,{}>,
<2*x^6-x^5+x^4+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^2-2,{2}>,
<3*x^6+x^5+2*x^4-x^3+3*x^2-3*x-3,{2,3}>,
<-x^6+x^4+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-x^3-2*x^2+x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^2-x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+x^2+x-1,{0,2}>,
<-3*x^6-3*x^5+3*x^4-x^3+2*x^2+2*x-1,{0,2}>,
<3*x^6+3*x^5-3*x^4-x^2-x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+x^2+x+3,{2}>,
<-x^6-2*x^5-2*x^4+x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^2+3*x-1,{2,3}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4-2*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^2+x+3,{2}>,
<-x^6-x^4-x^3+3*x^2-3*x-3,{2,3}>,
<2*x^6-x^4+x^3+3*x^2+3*x-3,{2,3}>,
<-2*x^6+x^4+x^3-3*x^2+3*x+3,{2,5}>,
<-2*x^6-x^5-3*x^2-3*x+3,{2}>,
<3*x^6-x^5+3*x^2-3*x-3,{2}>,
<-3*x^6-x^5+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4-x^3-x^2+3,{2}>,
<-x^6+x^5+x^4+x^2+x-1,{2}>,
<3*x^6+3*x^5-3*x^4-x-3,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^2+3*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^2-3*x-3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^2+x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^2-2,{2}>,
<-3*x^6-3*x^5+3*x^4+3*x^2+x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^2+2*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^2+x+3,{2}>,
<-2*x^6-x^5+3*x^4+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+3*x^2+x+2,{2,7}>,
<3*x^6-3*x^5-3*x^4-3*x^2+x-3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4-3*x^2+2*x-3,{}>,
<-3*x^6-3*x^5+3*x^4+x^2+2*x+3,{2}>,
<3*x^6-3*x^5-3*x^4-3*x^2+3*x-2,{2,5}>,
<3*x^6+3*x^5-3*x^4-x^2-2*x-3,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4+x^2-3*x-2,{0,2}>,
<-2*x^6+3*x^5+3*x^4-x^3-3*x^2+3*x+3,{2,7}>,
<-3*x^6+3*x^5+3*x^4+2*x^2+3*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3-3*x^2-3*x+3,{2,149}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2-3*x+3,{}>,
<-x^6+3*x^5+2*x^4+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-3*x^2-3*x+3,{2}>,
<2*x^6-x^5-2*x^4-3*x^2+3*x+3,{2}>,
<-x^6+3*x^5-2*x^4-x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2-3*x-1,{2,3}>,
<-x^6+x^5-2*x^4-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3-2*x^2-3*x+2,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2-3*x-2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+x^5-2*x^4-3*x^2-3*x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+2*x^2+2*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x^2-x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2-x+3,{2,3}>,
<2*x^6+x^5-2*x^4-x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^2+x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4-2*x^2+2*x-1,{}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2-x-2,{2}>,
<-3*x^6+x^5+2*x^4-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2+2,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^2+2*x-2,{2}>,
<-x^6+2*x^4+x^3-3*x^2-3*x+3,{2}>,
<3*x^6-2*x^4-x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4-x^3-3*x^2+2,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+2*x^2-x+2,{2,3,5}>,
<3*x^6-3*x^5-3*x^4-2*x^2+3*x-2,{2}>,
<-x^6+3*x^4-x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3-x^2-3*x-2,{}>,
<3*x^6+3*x^5-3*x^4-x^3+2*x^2-2*x-3,{2,3}>,
<2*x^6+3*x^5+x^4-x^3-3*x^2+3*x+3,{}>,
<-3*x^6-3*x^5+3*x^4+x^3-x^2-3*x-1,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x^2+3*x+2,{}>,
<-x^6-3*x^5-2*x^4-x^3+3*x^2+3*x-3,{2}>,
<2*x^6-3*x^5-x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+x^2+2*x+2,{}>,
<-x^6+2*x^5-x^4-x^3+3*x^2+3*x-3,{2,3}>,
<-2*x^6+x^5+x^4-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-x^5-x^4+x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3-x^2-2*x+2,{2}>,
<3*x^6+x^4-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+x^2-1,{2}>,
<-2*x^6-2*x^5+x^4+x^3-3*x^2-3*x+3,{2,3}>,
<-x^6-3*x^5-x^4-x^3+3*x^2+3*x-3,{2,3}>,
<2*x^6-x^4+x^3+3*x^2-3*x-3,{2,5}>,
<3*x^6-x^5+x^4-x^3-3*x^2+3*x+3,{}>,
<-3*x^6+3*x^5+3*x^4-x^3+3*x-2,{2,13}>,
<2*x^6+3*x^5-x^3+3*x^2+3*x-3,{}>,
<-2*x^6+3*x^5-x^3-3*x^2+3*x+3,{}>,
<3*x^6-2*x^5-x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3+2*x+2,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4-3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^2-3*x-3,{}>,
<-3*x^6+2*x^5+3*x^4-3*x^2+3*x+3,{}>,
<-x^6+2*x^5-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^2-3*x+3,{2,5}>,
<3*x^6-3*x^5-3*x^4+x^3-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-2*x-2,{2,3}>,
<-2*x^6+x^5+x^3-3*x^2-3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^2-x-1,{2}>,
<-3*x^6-x^5-x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^2+x+2,{2}>,
<3*x^6-2*x^5-x^3-3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5+x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+2*x-2,{}>,
<3*x^6-3*x^5-3*x^4+3*x^2-x-2,{2}>,
<-3*x^6-x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^2+x-2,{}>,
<-3*x^6-3*x^5+3*x^4+x^3+2*x+3,{2}>,
<2*x^6+3*x^5+x^4-x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+x^4-x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4+x^3+3*x-2,{2,7}>,
<-3*x^6+x^5-x^4-x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+x^3+x^2+x-3,{2,3,269}>,
<3*x^6+3*x^5-3*x^4-x^3-x^2+2,{2,3}>,
<-x^6+x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+x^2+2*x+2,{2}>,
<-2*x^6-x^4+x^3-3*x^2-3*x+3,{2}>,
<-x^6+2*x^5-x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+x^4-x^3+3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-x^5+x^4-x^3+3*x^2+3*x-3,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4+x^3-x^2+x-2,{2}>,
<3*x^6-3*x^5-3*x^4+x^3+3*x-2,{2}>,
<-x^6-3*x^5+x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5-x^4-x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+x^3-x^2-3*x-1,{2,3}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2-3*x-3,{}>,
<-3*x^6-3*x^5+3*x^4+x^3+x^2-x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3+3*x^2-3*x-3,{2}>,
<-2*x^6+2*x^5-x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+x^2-x-1,{2,3}>,
<3*x^6+3*x^5-3*x^4-x^3-x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+2*x^2-2*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+2*x^2+x-3,{2,3,11}>,
<3*x^6-3*x^5-3*x^4+x^3-2*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-2*x^2+3,{2,3}>,
<-2*x^6+2*x^4+x^3+3*x^2-3*x-3,{}>,
<3*x^6-3*x^5-3*x^4+x^3-2*x^2+2,{}>,
<-x^6+2*x^4+x^3+3*x^2-3*x-3,{0,2}>,
<-x^6-2*x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+2*x^2+2,{2,3}>,
<-2*x^6-2*x^4+x^3-3*x^2-3*x+3,{2,3}>,
<3*x^6+2*x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-2*x^2-3,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-3*x-3,{2,3}>,
<-3*x^6-x^5-2*x^4-x^3-3*x^2+3*x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x^2-3*x+3,{}>,
<3*x^6+3*x^5-3*x^4+x^2-2*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x-2,{2}>,
<-3*x^6+3*x^5+3*x^4+2*x+3,{}>,
<3*x^6+3*x^5-3*x^4-x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+3*x^2+3*x-3,{2}>,
<-x^6+3*x^5+3*x^4-x^3+3*x^2+3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4-3*x^2+3*x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^2+3*x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^2+3*x+3,{2}>,
<-2*x^6+2*x^4+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^2-2,{2}>,
<-3*x^6-3*x^5+3*x^4+3*x^2-x+3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x^2-1,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-3*x^2-3,{2}>,
<-x^6-x^5-3*x^4-x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x^2+x-2,{2}>,
<3*x^6-3*x^5-3*x^4-2*x^2-3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-3*x-1,{}>,
<2*x^6-3*x^5-3*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x^2+x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-3*x^2+3*x+3,{}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+3*x^5-3*x^4-2*x^3+3*x^2+x+2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x^2-x-2,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+3*x-3,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+3*x^2+x-3,{2}>,
<3*x^6+3*x^4+2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+3*x^2-2*x+3,{}>,
<2*x^6+3*x^5+3*x^4+2*x^3-3*x^2-3*x+3,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3+2*x^2-2*x-3,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3-3*x^2+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+2*x^2+x-1,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<2*x^6+2*x^4+2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^4+x^3-3*x^2-3*x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2-3*x+3,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+x^4+2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5-x^4-2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+x^2+x+3,{2}>,
<2*x^6-x^5-x^4+2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6+x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<-2*x^6-x^5+x^4-2*x^3-3*x^2+3*x+3,{}>,
<-x^6+x^5-x^4+x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4-x^3+x^2-x+2,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+x^2-2*x-2,{0,2}>,
<3*x^6+3*x^5-3*x^4+x^3-x^2+x-2,{2}>,
<-3*x^6+x^4-x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3-x^2-3*x+2,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^3-3*x^2-3*x+3,{2}>,
<-x^6-3*x^5+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-3*x-1,{}>,
<3*x^6-x^4-x^3-3*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+x^5+2*x^3-3*x^2-3*x+3,{}>,
<-2*x^6+2*x^5+2*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-2*x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6+x^5-2*x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^3-3*x^2-3*x+3,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-3*x^2+3*x+3,{2,3}>,
<3*x^6+3*x^5-3*x^4-2*x^3-2,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-3*x^2-3*x+3,{}>,
<-2*x^6-2*x^5+x^4+2*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+2*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+x^2+2*x-1,{2,3}>,
<3*x^6+x^5+2*x^3+3*x^2-3*x-3,{}>,
<-3*x^6-2*x^5-x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<3*x^6-3*x^5-3*x^4+2*x^3-x^2-x-2,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+x^2+x-1,{2}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-x^2+x-3,{2}>,
<-x^6-2*x^5-2*x^4-x^3-3*x^2+3*x+3,{2}>,
<-x^6+2*x^5-x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<-x^6-x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+x^2+2*x+3,{2,3}>,
<-2*x^6-x^4-2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-x^2-x+3,{2}>,
<-x^6-x^5-x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-x^2-3*x+2,{2}>,
<-x^6+3*x^5-2*x^4+x^3-3*x^2-3*x+3,{2,7}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-x^5+x^4-2*x^3+3*x^2+3*x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3-3*x^2+3*x+3,{2,3,13}>,
<-2*x^6-x^5-x^4-2*x^3-3*x^2+3*x+3,{2,3}>,
<2*x^6-2*x^5-2*x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-x^2+x-3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3-3*x^2+3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4+x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-2*x^2-x+2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-2*x^2-2,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2,3}>,
<-x^6-x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2,3}>,
<3*x^6-3*x^5-3*x^4+2*x^3-2*x^2-3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-2*x^2+x-1,{2}>,
<-x^6+x^5-2*x^4+2*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-2*x^2-x-2,{}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+x+3,{}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-2*x^2-x-3,{}>,
<-2*x^6+x^5-2*x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-3*x^2-3*x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3-3*x^2-3*x+3,{2,3}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+3*x^2-3*x-2,{}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+3*x+3,{}>,
<-3*x^6-x^5+3*x^4+x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+x^3-3*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-3*x^2+x-3,{2,3}>,
<-3*x^6-3*x^5+3*x^4+x^3+3*x^2-2,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3+x^2-3*x-2,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-3*x^2-3*x+3,{2}>,
<-x^6+2*x^5+x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+x^4+3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3+x-2,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-x-3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3+x-2,{2,5}>,
<-3*x^6+2*x^5+3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+x^2+3*x-2,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+3*x^2+x-2,{2,3}>,
<3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+3*x-1,{2}>,
<-3*x^6-3*x^5+3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x^2+3*x+3,{2,5,7}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+3*x+3,{}>,
<-3*x^6+x^5-x^4-3*x^3-3*x^2+3*x+3,{}>,
<3*x^6+3*x^5-3*x^4-3*x^3-x^2-1,{2}>,
<2*x^6+x^4-3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-x^2-2,{2,3}>,
<-2*x^6+x^5-x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3+3*x^2+3*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-x^2-x-3,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-3*x-3,{2,3,17,41}>,
<-3*x^6-2*x^5-x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+x^2-3*x-1,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+2*x^2+3*x-2,{2,5}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+2*x^2+2*x-2,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2-2*x-1,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-3*x^6-3*x^5+3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2-3*x-3,{2,3}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-2*x^5-2*x^4-3*x^3-3*x^2+3*x+3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-3*x^2-x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x^2+3*x-3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<-2*x^6-3*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-3*x^2-x-1,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<-3*x^6-x^5-3*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+3*x^2-3*x-3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-3*x^2+3*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-x+3,{2,3}>,
<2*x^6+x^5+3*x^4+3*x^3+3*x^2+2*x+3,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+3*x^2+x-1,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3-3*x^2-x+2,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+3*x^2-1,{2}>,
<3*x^6-3*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+x-2,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5-3*x^4+3*x^3-3*x^2+2*x-3,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x-3,{}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+x-3,{2,3}>,
<2*x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x-3,{}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+2,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-1,{2,3}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2+2*x-3,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2*x^2-x+3,{2,3}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-2*x+3,{2}>,
<-x^6+2*x^5-x^4+3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-1,{}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-x^2+2*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-x+2,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-x^2+x+3,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3+x^2-x-3,{}>,
<3*x^6+x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2-2*x+3,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+x^2-x+2,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3-x^2+x+2,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2+2*x+3,{2,7}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3+2*x^2-3*x+2,{2,3}>,
<3*x^6+2*x^5+3*x^4+3*x^3+x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x-3,{}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2-3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x-1,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2+2*x+3,{}>,
<2*x^6+2*x^5+3*x^3-3*x^2+2*x-3,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2*x-2,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+3*x^2-3*x-3,{}>,
<3*x^6+3*x^5-3*x^4-3*x^3-3*x^2+2*x+3,{}>,
<-x^6-x^5-3*x^3-3*x^2-2*x-3,{2}>,
<-x^6+x^5+3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2,{2}>,
<3*x^6-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-3,{2}>,
<3*x^6-x^5+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-x^5+3*x^3+3*x^2+2*x+3,{2,3}>,
<-x^6+2*x^5-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-2*x+2,{2}>,
<-x^6+3*x^5-3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6-3*x^5+3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5-3*x^3+3*x^2-2*x+3,{2}>,
<-x^6-3*x^5+x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+x^2-3*x+2,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-2,{2,5}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-x^2+2*x-2,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-x^2+x+3,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2-x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-x^4-3*x^3+3*x^2-2*x+3,{}>,
<2*x^6-x^4-3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2-2,{2,3}>,
<-x^6-2*x^5+x^4+3*x^3+3*x^2-3*x-3,{2}>,
<3*x^6+x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-3*x^2+3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2+x-2,{2}>,
<3*x^6+x^5+x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+x^5-x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-x^6-3*x^5+x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-x^6+3*x^5-x^4-3*x^3+3*x^2+2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-2*x+2,{}>,
<-x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3+3*x^2+2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-x-2,{2}>,
<-x^6-x^5-2*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3+2*x^2+x+3,{2}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-2*x^2+x-3,{2,3}>,
<-x^6-2*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-1,{2,3}>,
<-3*x^6-2*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-x^6+3*x^5-2*x^4-x^3-3*x^2+3*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3+3*x^2-3*x-3,{2,5}>,
<3*x^6+3*x^4-2*x^3+3*x^2+3*x-3,{2,7}>,
<3*x^6+3*x^5-3*x^4-2*x^3-3*x^2-x-2,{2}>,
<3*x^6+3*x^5-3*x^4-x^3-2*x^2+2*x+3,{2,3}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{}>,
<-x^6+3*x^5-3*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-3*x+2,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+3*x^2-x+3,{2,3}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2-2*x-3,{}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-3*x^5-3*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6+3*x^5-3*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<-x^6+x^5+3*x^4+3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x-1,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-x+2,{}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x-2,{}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-1,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-3*x^2-x-2,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+3*x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x+2,{2,31}>,
<3*x^6+2*x^5+3*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+3*x-1,{}>,
<3*x^6+2*x^5+3*x^4+2*x^3+3*x^2+2*x+2,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3-3*x^2-x-1,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-2*x^2-x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-2*x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-x^6-3*x^5-x^4-2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3+x^2+3*x-1,{}>,
<3*x^6+2*x^5+3*x^4+3*x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2-3,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+3*x^5-3*x^4-3*x^3-2*x^2-x-1,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3+x^2-3*x-2,{}>,
<-3*x^6-2*x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4-2*x^3+3*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-2*x^2-2*x+2,{2,3,17}>,
<3*x^6-3*x^5-3*x^4+3*x^3-2*x^2+x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-3*x^2-3*x+3,{2}>,
<3*x^6-x^5-x^4+2*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3-x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-2*x^3-x+3,{}>,
<3*x^6+2*x^5+3*x^4+2*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-x-3,{}>,
<2*x^6-3*x^5-2*x^4+3*x^3-3*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4+2*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-x^5+x^4-2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-x^2-x-2,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-x+3,{2,3}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+x^2+x+3,{2}>,
<2*x^6+x^5-2*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3+x-1,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-x^2-3,{2,3}>,
<2*x^6-x^5+2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-x^2-3*x+2,{2,3}>,
<-x^6-3*x^5+x^4+2*x^3-3*x^2+2*x-3,{2}>,
<-x^6+3*x^5-x^4-2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+x^5-x^4-2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-x^2-x-3,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^3-2*x^2+x-2,{2,3}>,
<-3*x^6-2*x^5-3*x^4-2*x^3+2*x^2+x+3,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-3*x^2+2*x-3,{2}>,
<-x^6+x^5-3*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3-3*x^2+x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+x^5-3*x^4-2*x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+2*x^4-2*x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+3*x^2-x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3-3*x^2+2*x-3,{}>,
<2*x^6+3*x^5+2*x^4-2*x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4+2*x^3-2*x^2+2*x-3,{2,3}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+3*x^2+2*x+3,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2-2*x+3,{}>,
<2*x^6+3*x^5-3*x^4+x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x^2+2*x-1,{2}>,
<-3*x^6-2*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6-3*x^4-x^3-3*x^2-2*x-3,{2,3}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5+3*x^4+x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+x+3,{2,3}>,
<-x^6+x^5+3*x^4-x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+2*x-3,{2,3}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+3*x+2,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+3*x-1,{2,3}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6-x^5-3*x^4+x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+2*x^2-2*x+2,{2,3,5}>,
<3*x^6+x^5-3*x^4-x^3-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3-3*x^2-x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-2*x+3,{2,3}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2-2*x-3,{}>,
<3*x^6+2*x^5+3*x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+2*x^2+x-1,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x^2+x-3,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x^2-2*x-3,{}>,
<-3*x^6-2*x^5-3*x^4-x^3-2*x^2-x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^4-x^3+2*x^2-x-2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x^2-1,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3-2*x^2-x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3-2*x^2+2,{2}>,
<2*x^6-3*x^4-x^3-3*x^2-2*x-3,{2}>,
<2*x^6-x^5+2*x^4+x^3+3*x^2+2*x+3,{2}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-2*x^2-2*x+2,{2,5}>,
<2*x^6+x^5-2*x^4-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4+x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4+x^3+2*x^2-2*x-2,{2}>,
<3*x^6+x^5-2*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+x^2-x+2,{2}>,
<2*x^6-x^5-x^4-x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6+x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+x^2+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+3*x^2+2*x+3,{2}>,
<-x^6-x^5-2*x^4+3*x^3+3*x^2+2*x+3,{}>,
<-3*x^6+x^5+2*x^4-x^3+3*x^2-2*x+3,{2}>,
<-x^6+3*x^5+2*x^4-x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-x^2+2,{2}>,
<-3*x^6+2*x^5-3*x^4+3*x^3+2*x^2-x+2,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+x^4+x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6-x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^3-2*x^2-x-3,{2}>,
<-x^6-3*x^5-x^4-x^3-3*x^2-2*x-3,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2+2*x+3,{2,7}>,
<3*x^6-2*x^5+3*x^4-x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-x^5-3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+3*x-1,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3*x-1,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+3*x+2,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-1,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-3*x^3+x^2+x+3,{}>,
<-3*x^6-2*x^5-3*x^4-x^3+2,{2}>,
<2*x^6+2*x^5+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3-2*x-1,{2}>,
<3*x^6-x^5+x^3+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x+2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-3*x+2,{2,3}>,
<-x^6-3*x^5+x^3-3*x^2+2*x-3,{2}>,
<-x^6+3*x^5-x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x+2,{2,3}>,
<2*x^6-3*x^5+x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x-2,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<-3*x^6+2*x^5+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x^2-3*x+2,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+2*x-2,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3-2*x+2,{2}>,
<-3*x^6+x^5+x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4+x^3+3*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+x^3+3*x^2+2*x+3,{}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+x+2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+2*x+2,{2}>,
<-2*x^6+x^5-x^4+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<3*x^6-2*x^5+x^3-3*x^2+2*x-3,{2}>,
<3*x^6-x^5+x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3+3,{2,3}>,
<-x^6+x^5-x^4-x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+x^2-x+2,{}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-x^2+2*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2-2*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3+x^2+2*x-1,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-3*x^2-2*x-3,{}>,
<2*x^6-2*x^5-x^4+x^3-3*x^2+2*x-3,{2}>,
<-x^6+2*x^5-2*x^4+x^3+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2+3,{}>,
<3*x^6-2*x^5-x^4+x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-x-1,{2}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2+2*x+3,{2,3}>,
<2*x^6-2*x^5+2*x^4-x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4+x^3+2*x^2+x+2,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2-2*x+3,{2}>,
<-x^6+3*x^5+x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-x-2,{2}>,
<3*x^6+x^5+2*x^4+x^3-3*x^2+2*x-3,{2,3}>,
<2*x^6-3*x^5-x^4+x^3-3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+x^4+x^3-3*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5-x^4-2*x^3+3*x^2+3*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4+x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4+x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-2*x^4+x^3+3*x^2+2*x+3,{2}>,
<2*x^6+3*x^5+x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-x^2-3*x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-2*x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-2*x^2-2*x+3,{2,3}>,
<-x^6+3*x^5-2*x^4-x^3+3*x^2-2*x+3,{}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2+2*x-3,{}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2+3*x-2,{}>,
<3*x^6+2*x^5+3*x^4+x^3-2*x^2-2*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+x^3-3*x^2-x+2,{}>,
<3*x^6+2*x^5+3*x^4+x^3-3*x^2-x-2,{2,3}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6-x^5+3*x^4+x^3-3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+3*x^4-x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^2-2*x-3,{2}>,
<-3*x^6-x^5-3*x^4+x^3+3*x^2+2*x+3,{2}>,
<-x^6+3*x^5-3*x^4+x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^2-3*x-2,{2,3}>,
<-3*x^6-2*x^5-3*x^4-x^3+2*x^2+2*x-1,{2}>,
<3*x^6+2*x^5+3*x^4+3*x^2+x+2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^2-x-1,{}>,
<2*x^6-3*x^5+3*x^4-x^3-3*x^2-2*x-3,{2}>,
<2*x^6+x^5-3*x^4-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^2+x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+3*x^2-2*x-1,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5-3*x^4-3*x^2-x+3,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2-2*x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^2-2*x-3,{2}>,
<2*x^6-x^5+2*x^4+3*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-3*x^4-3*x^2+3,{2}>,
<2*x^6+x^5-2*x^4-3*x^2+2*x-3,{2,3}>,
<-x^6+3*x^5-3*x^4-x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^2-x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+3*x^2-2*x+3,{2,5,7,569}>,
<3*x^6+2*x^5+3*x^4+3*x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-2*x^2+3,{2,3}>,
<-3*x^6-2*x^5-3*x^4-x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2-x+3,{2,3}>,
<2*x^6+x^5+3*x^4+3*x^2-2*x+3,{2}>,
<-x^6+3*x^5+3*x^4+3*x^2+2*x+3,{2}>,
<2*x^6-x^5-3*x^4-3*x^2+2*x-3,{2}>,
<-x^6+3*x^5+2*x^4+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4-x^3+3*x^2-x+2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2-x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+x^3+3*x^2-1,{2}>,
<3*x^6-x^5+2*x^4+3*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-3*x^2-1,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^2+x-1,{2}>,
<-x^6-3*x^5-x^4-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4-2*x^2+x+2,{}>,
<3*x^6+2*x^5+3*x^4+x^2+x+3,{2,3}>,
<2*x^6-x^5+x^4+3*x^2-2*x+3,{2}>,
<-2*x^6-x^5+2*x^4+3*x^2+2*x+3,{}>,
<2*x^6+3*x^4+x^3-3*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^2-3,{2,3}>,
<2*x^6+x^5+x^4+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^2+x-1,{2}>,
<3*x^6-2*x^5+3*x^4+x^2-x-2,{2}>,
<2*x^6-x^5+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4+x-1,{2}>,
<-3*x^6+2*x^5-3*x^4+x+2,{2}>,
<3*x^6-x^5-2*x^4-3*x^2+2*x-3,{2}>,
<2*x^6+x^5-3*x^2-2*x-3,{2}>,
<-2*x^6+x^5+3*x^2-2*x+3,{2}>,
<2*x^6-x^5-x^4-3*x^2+2*x-3,{2}>,
<3*x^6+x^5-x^4-3*x^2+2*x-3,{2,3}>,
<3*x^6-x^5-x^4-3*x^2+2*x-3,{2,3,5}>,
<3*x^6-x^5-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+x^2-3*x+2,{2,5}>,
<2*x^6+2*x^5-3*x^2-2*x-3,{}>,
<-3*x^6+2*x^5+2*x^4+3*x^2-2*x+3,{2,3}>,
<2*x^6-x^4-3*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^2-2*x-3,{}>,
<-x^6-3*x^5+x^4-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^2+2*x+3,{2}>,
<-x^6+3*x^5+x^4+3*x^2-2*x+3,{2}>,
<3*x^6+x^5-x^4+3*x^2+2*x+3,{2}>,
<-3*x^6-x^5-x^4+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4-x^2+x+2,{2,3}>,
<2*x^6-x^5+x^4-3*x^2+2*x-3,{2}>,
<-x^6-3*x^5-x^4+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x-2,{2}>,
<-3*x^6+2*x^5-3*x^4+x^2-3*x+2,{2}>,
<3*x^6+x^5+x^4-3*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^2-2*x-3,{2}>,
<2*x^6-x^5+2*x^4-3*x^2+2*x-3,{}>,
<3*x^6+2*x^5+3*x^4-x^2-3*x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-x^2-3*x+2,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^2+3*x+2,{2,3}>,
<-x^6+3*x^5+2*x^4-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4+2*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5-3*x^4-3*x-1,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^4+3*x^2-2*x+3,{2,7}>,
<2*x^6+3*x^5+2*x^4-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^2+x+2,{2}>,
<-3*x^6-2*x^5-3*x^4+x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4-3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^2-2*x+3,{2}>,
<-x^6+x^5-3*x^4+3*x^2+2*x+3,{}>,
<3*x^6+2*x^5+3*x^4-3*x^2+x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4+x+3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^2-2*x+3,{2,3}>,
<-2*x^6-x^5-2*x^4+3*x^2-2*x+3,{2}>,
<-x^6+x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+3*x^2+3,{2}>,
<3*x^6-x^5+2*x^4-3*x^2-2*x-3,{2}>,
<2*x^6+3*x^4+x^3+3*x^2-2*x+3,{2}>,
<2*x^6+x^5-3*x^4+x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3-3*x^2+2,{2}>,
<3*x^6-2*x^5+3*x^4-2*x^2+x+3,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-2*x^2-2*x+2,{2}>,
<2*x^6-x^5-2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+2*x^2+3,{2}>,
<-x^6+2*x^4-x^3+3*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+x^3-2*x^2+2,{}>,
<-2*x^6+2*x^4-x^3+3*x^2+2*x+3,{}>,
<-3*x^6+2*x^5-3*x^4-x^3-2*x^2+3,{2,3}>,
<-x^6-x^5+2*x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+3*x^5+3*x^4-2*x^3+2*x^2+2,{2}>,
<2*x^6+x^5-2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+2*x^2+x-3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+3*x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-3*x^2-2*x-3,{2}>,
<-x^6-3*x^5+x^4+x^3+3*x^2-2*x+3,{2,5}>,
<3*x^6-2*x^5+3*x^4+x^3+2*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-x^4-x^3-3*x^2+2*x-3,{2,3}>,
<2*x^6+2*x^5+x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3-x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+x^5+x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+x+2,{2}>,
<2*x^6-x^5-x^4+x^3-3*x^2-2*x-3,{}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+3*x+2,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+x-2,{}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+2,{2}>,
<-x^6+x^4+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-x^5-x^4+x^3-3*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-x^3-x^2+2,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-x^2+3,{2,3}>,
<3*x^6-2*x^5+3*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6+x^5-x^4-x^3-3*x^2+2*x-3,{2,3,7}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2-3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3-x^2-3*x-1,{2}>,
<3*x^6-2*x^5+x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^4+x^3-2*x+2,{}>,
<-x^6-2*x^5+x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-2*x+2,{2}>,
<3*x^6+x^5+x^4+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-x+2,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+x^2+2*x+2,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+x-1,{2,3}>,
<-x^6-2*x^5+x^4-x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+x^2+x-3,{2,3,7}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-x^3+2,{2}>,
<-2*x^6+x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3+2*x+3,{2}>,
<2*x^6-3*x^5-x^3+3*x^2+2*x+3,{2}>,
<-x^6-3*x^5-x^3-3*x^2+2*x-3,{}>,
<2*x^6+3*x^5+x^3-3*x^2-2*x-3,{}>,
<-2*x^6-3*x^5-x^3+3*x^2+2*x+3,{}>,
<2*x^6-x^4+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-x^2-1,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+3*x^2+2*x+3,{2,149}>,
<2*x^6+x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6+x^4+x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4-x^3-x^2-x+3,{2}>,
<2*x^6-x^5-x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2-x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4-x^3-2*x^2-x+3,{2,3}>,
<-2*x^6-x^5-x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6-x^5-2*x^4-x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4+x^3+2*x^2+x-1,{2,3}>,
<-x^6-2*x^5+x^4-x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+x^5-x^4+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4+x^3-2*x^2+3,{2}>,
<-x^6+2*x^5-x^4+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-2*x^2+2,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3+2*x^2+2,{2}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-2*x^2-x+2,{2}>,
<-x^6+x^5-2*x^4+x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2-3*x-1,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3+2*x^2+x+2,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6-x^5-2*x^4-x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-2*x^2-3*x-2,{2,3}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-2*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-2*x^2-2*x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3-3*x^2-x-2,{2}>,
<-x^6+3*x^5+2*x^4+x^3-3*x^2-2*x-3,{}>,
<3*x^6-3*x^4-x^3+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-3*x^2-x+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-3*x^2-x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+3*x^2-x-1,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-3*x^2-x-1,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+3*x^2+2*x+3,{2,3}>,
<-x^6+2*x^5-3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x^2-2*x-3,{}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-3*x^2-3*x-2,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+3*x+2,{2,3}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5-3*x^4+2*x^3-3*x^2+x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x+2,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2+x-2,{2,3}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x-2,{2,3}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+x+3,{}>,
<3*x^6+2*x^5+3*x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x-3,{}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-3*x^2-2*x-3,{}>,
<-3*x^6+3*x^4-2*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2+x+3,{2}>,
<-x^6-x^5+2*x^4+2*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2-2*x-3,{}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^4+2*x^3+x^2-2*x+3,{2,3}>,
<2*x^6-2*x^5-x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-x^6+x^5+x^4-2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3-x^2-x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-x^2+x+3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+x^2-x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4+2*x^3+x^2+x+2,{}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-x^2-x+2,{2,3}>,
<3*x^6+x^5-x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6-x^5+x^4-2*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-x^2-2*x+2,{2,3}>,
<2*x^6+3*x^5+x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3-2*x^2+x+3,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4-2*x^3+2*x^2-x-1,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3-2*x^2+x+2,{2,5}>,
<3*x^6-3*x^4+x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3+2*x^2+3*x+2,{}>,
<3*x^6+2*x^5+3*x^4+2*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4-x^3+3*x^2-3,{2}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+2*x+3,{2,3}>,
<-x^6-x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+3*x^5-2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3+2,{2,3}>,
<2*x^6-2*x^3-3*x^2+2*x-3,{2}>,
<2*x^6+x^5+2*x^3-3*x^2-2*x-3,{}>,
<-2*x^6-x^5-2*x^3+3*x^2+2*x+3,{}>,
<3*x^6+x^5+2*x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4-2*x^3-3*x+2,{2}>,
<3*x^6+2*x^5+3*x^4+2*x^3+2*x^2+x-1,{2,3}>,
<-x^6+3*x^5+2*x^3-3*x^2-2*x-3,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2+2*x+3,{2}>,
<-x^6+3*x^5+x^4-2*x^3-3*x^2+2*x-3,{2,3}>,
<2*x^6-x^5-x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+x^2-2*x-1,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3-x^2-x-1,{2,3}>,
<-x^6+3*x^5+x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+x^2+x+2,{2}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2+2*x-3,{2,5}>,
<3*x^6+2*x^5+3*x^4-2*x^3-x^2-3,{2}>,
<2*x^6+x^5-x^4+2*x^3+3*x^2-2*x+3,{2}>,
<-x^6-x^5-x^4-2*x^3+3*x^2+2*x+3,{2,11}>,
<3*x^6+2*x^5+3*x^4-x^3-x^2+3*x-2,{}>,
<2*x^6+x^5+x^4+2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-2*x^3+x^2-3*x-2,{2,11}>,
<3*x^6+2*x^5+3*x^4-2*x^3+3*x+2,{2,3}>,
<-x^6-3*x^5+2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-x^3-x^2+2*x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3-3*x-1,{2}>,
<-x^6+x^5-x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-x^3+x^2+x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+2*x^2-2*x-1,{2,3}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4-2*x^3-3*x^2+x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3-3*x^2+x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+x^5+3*x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+3*x^4-2*x^3-3*x^2-3*x-1,{}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3+3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+3*x^2-3*x-1,{}>,
<2*x^6-3*x^5+3*x^4+2*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6+3*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^4-3*x^3-3*x^2+2*x-3,{}>,
<-2*x^6+3*x^4-3*x^3+3*x^2+2*x+3,{}>,
<2*x^6+3*x^5-3*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-3*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<-x^6+x^5+3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+3*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2-2*x+3,{}>,
<2*x^6-2*x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5+3*x^4-3*x^3+3*x^2+2*x+3,{}>,
<2*x^6+2*x^5-3*x^4+x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-x+3,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2-2*x+3,{}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+2*x^2+x-2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+3*x^2+2*x+3,{2,3}>,
<2*x^6+2*x^5-2*x^4+3*x^3-3*x^2-2*x-3,{}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-x+3,{2,3}>,
<2*x^6+2*x^5-2*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2+2*x-3,{}>,
<3*x^6+2*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5+3*x^4-x^3+3*x^2-3*x-1,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x-3,{2}>,
<-x^6+2*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-x^2+3*x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-2*x^2+3,{2,3}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x^2-2*x-1,{2}>,
<-x^6+x^4+3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6-x^4+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-3*x^2+2*x-3,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6-x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+x^2-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x^2+x+2,{}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x^2-x-1,{2,3}>,
<2*x^6-x^5-x^4-3*x^3-3*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4-3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-x^5+x^4-3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-3*x^2+2*x-3,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3+x^2+x-2,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-x^2+x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3-x^2+x+3,{2,3}>,
<3*x^6+2*x^5+3*x^4-3*x^3+x^2+2,{2}>,
<-x^6+3*x^5-3*x^3+3*x^2+2*x+3,{}>,
<3*x^6+2*x^5+3*x^4-3*x^3+3*x-2,{2}>,
<3*x^6-2*x^5+3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5-3*x^3-3*x^2+2*x-3,{}>,
<-2*x^6+2*x^5-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-x^5+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x^2+x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4+3*x^3+3,{}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+2,{}>,
<-2*x^6+3*x^3+3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x+2,{2,3}>,
<-x^6+x^5+3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+x+2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+x-2,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+x+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3+2*x+3,{2,3}>,
<2*x^6+2*x^5+3*x^3+3*x^2-2*x+3,{}>,
<-x^6+2*x^5+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-2*x^5-3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3-3*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-3*x^2+2*x-3,{}>,
<3*x^6-2*x^5+3*x^4+3*x^3-x^2-3*x-1,{2}>,
<2*x^6+x^5-3*x^3-3*x^2+2*x-3,{}>,
<3*x^6-x^5+3*x^3-3*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+3*x^4+3*x^3-x-3,{2,3}>,
<-x^6-2*x^5-x^4+3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+x^2-2*x+3,{2}>,
<2*x^6-x^5+x^4+3*x^3-3*x^2-2*x-3,{}>,
<-2*x^6+x^5-x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-x^2+x-3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3+2*x^2-2*x-1,{2,3}>,
<2*x^6-x^4+3*x^3+3*x^2-2*x+3,{2}>,
<2*x^6+x^4+3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+3*x^2-2*x+3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3+3*x^2+2*x+3,{2}>,
<2*x^6+x^5+2*x^4-2*x^3-3*x^2+2*x-3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+3*x^2+2*x+3,{2}>,
<3*x^6+x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-x^2-x+3,{2,3}>,
<-x^6-x^5-x^4-3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2+2*x-3,{}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+x^2-2*x-1,{2}>,
<-3*x^6+2*x^5-3*x^4-2*x^3+2*x^2-x-1,{2,3}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-2*x^6+3*x^5+x^4+3*x^3-3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+x+2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-3*x^2-2*x-3,{}>,
<3*x^6+2*x^5+3*x^4-x^3-x-1,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+2*x^2-2*x+2,{2,3}>,
<2*x^6-x^5-2*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-x^2-3*x-2,{2}>,
<-3*x^6-2*x^5-3*x^4+x^3+x+3,{2}>,
<-x^6-x^5-2*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<-3*x^6+x^5+x^3+3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-3*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+3*x^4-3*x^3-2*x^2-x-3,{2,3}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2-2*x-3,{2,3}>,
<-x^6+2*x^5+2*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-3*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x+3,{}>,
<3*x^6-2*x^5+3*x^4+2*x^3+x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2-2*x-3,{}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x+3,{}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+3*x^2-2*x+3,{}>,
<-x^6+2*x^5+3*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+3*x^2-2*x+3,{}>,
<3*x^6-x^5-3*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-3*x^2-x-2,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x^2-2*x-3,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+3*x^2+2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^2+3*x-2,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^2-3*x+2,{2,3}>,
<3*x^6+2*x^5+3*x^4+2*x^2+3*x-1,{2,3}>,
<-3*x^6-2*x^5-3*x^4-2*x^2-3*x+2,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-3*x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+3*x^4+2*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2-x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2-2*x+2,{}>,
<-x^6+2*x^5+2*x^4+3*x^3+2*x^2+2*x+3,{}>,
<-3*x^6-2*x^5-2*x^4-3*x^3-3*x^2+2*x+2,{2,3}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+2*x^2+2*x+3,{}>,
<-3*x^6-2*x^5-2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-x^6+3*x^5+x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x^2-2*x-2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x^2-x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x^2-x+2,{2,3,5}>,
<3*x^6+2*x^5+2*x^4+3*x^3+x^2+x-1,{2}>,
<2*x^6+x^5-x^4+3*x^3-2*x^2+2*x-3,{2}>,
<-2*x^6-x^5+x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+x^2-x-3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+2*x^2+2*x+3,{}>,
<-x^6-2*x^5+x^4+3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x^2+2*x-3,{2}>,
<2*x^6-3*x^5+x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-3*x+2,{2}>,
<-x^6-3*x^5-3*x^3+2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+3*x+2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2+2*x+2,{2,3}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-2*x^2+2,{2}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+2*x^2+2,{2}>,
<-x^6-x^5+2*x^4-3*x^3-3*x^2+2*x-3,{2}>,
<3*x^6+x^5+3*x^3+2*x^2+2*x+3,{}>,
<-x^6+x^5+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+2,{2}>,
<2*x^6-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+3*x^3-2*x^2+2*x-3,{2}>,
<-3*x^6-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x+2,{2}>,
<3*x^6-2*x^5+3*x^4+x^3+2*x^2-3*x-1,{}>,
<-2*x^6-x^5+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+x-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-3*x^3+x+3,{2,3}>,
<-x^6+2*x^5-x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-2*x^6-x^5-x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-x^6-x^4-3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+x^4+3*x^3-2*x^2+2*x-3,{}>,
<3*x^6-2*x^5+2*x^4-3*x^3-x^2-2,{}>,
<-3*x^6-x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2-x+3,{2}>,
<2*x^6+x^5-x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2-x-1,{2}>,
<2*x^6+x^5+x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2-x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2-2*x-2,{2}>,
<3*x^6-2*x^5+3*x^4+3*x^3-3*x^2-x-1,{2}>,
<3*x^6+2*x^5+3*x^4-3*x^3-x^2+2*x+2,{2}>,
<-3*x^6+2*x^5-3*x^4-3*x^3+3*x^2+x+2,{}>,
<2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2+x+2,{}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-2*x^2-x-1,{2,3}>,
<-3*x^6-2*x^5-2*x^4-3*x^3+x^2+2*x+3,{2,3}>,
<3*x^6-3*x^4-3*x^3+3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3+2*x^2+2*x+3,{}>,
<-3*x^6-2*x^5-3*x^4+3*x^3+3*x^2-1,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2-2,{2,3}>,
<2*x^6+3*x^5-2*x^4+3*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2-1,{2,3}>,
<3*x^6+2*x^4+3*x^3-2*x^2+2*x-3,{2}>,
<-3*x^6-2*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2-2*x-3,{}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2-x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-2*x^2+3*x-2,{2}>,
<-x^6+x^5-2*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+2*x+3,{2,3,11}>,
<2*x^6-x^5+2*x^4+3*x^3-2*x^2+2*x-3,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-2*x^2-2*x-3,{2,31}>,
<3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-2*x-3,{}>,
<-2*x^6-x^5+3*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+2*x^2+2*x+3,{2,5}>,
<-3*x^6+x^5-3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-x^6-3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-3*x^2+x+2,{2}>,
<-3*x^6-2*x^5-2*x^4-3*x^3+3*x^2+2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-3*x^2-2,{}>,
<3*x^6+2*x^5+2*x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+3*x^2-3*x-1,{}>,
<-x^6+3*x^5-3*x^4-3*x^3+2*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+3*x^3+3*x^2+3,{2}>,
<-x^6+x^5-3*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-3*x-1,{2,3}>,
<2*x^6+2*x^5+3*x^4-3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3-2*x^2-2*x-3,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3-x^2-3*x-1,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-2*x^2+3*x+2,{}>,
<-2*x^6+3*x^5-x^4+3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-2*x^2+2*x-3,{}>,
<3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+2*x-3,{}>,
<3*x^6+2*x^5+2*x^4+3*x^3-x^2+2*x+2,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+x+3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-2*x^3-2*x^2+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2+2*x-3,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3+2*x^2+3*x+2,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3+2*x^2-2*x+3,{}>,
<-x^6-2*x^5-x^4-2*x^3-2*x^2-2*x-3,{2}>,
<2*x^6-2*x^5-x^3-3*x^2+2*x-3,{2,13}>,
<2*x^6-2*x^5-x^4-2*x^3-2*x^2-2*x-3,{}>,
<3*x^6-2*x^5+2*x^4-2*x^3+x^2-3,{2,3}>,
<3*x^6-2*x^5+3*x^4+x^3+2*x-2,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3+x^2+x+3,{2}>,
<2*x^6-x^5-x^4+2*x^3-2*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-x^2-2*x+2,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3-3*x-2,{2}>,
<-3*x^6-2*x^5-2*x^4-2*x^3-2*x+2,{2,3}>,
<2*x^6+2*x^5-2*x^3-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3+x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^3+2*x^2-2*x+3,{2}>,
<-x^6-x^5+x^4+2*x^3+2*x^2+2*x+3,{}>,
<-3*x^6+2*x^5+2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3+3*x-1,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-x^5-2*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x^2-x-3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+x^2+3*x-1,{2}>,
<-3*x^6-2*x^5-2*x^4-2*x^3+x^2+2,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x-2,{2}>,
<-2*x^6-x^5-x^4+2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x^2-2*x-2,{2,3}>,
<3*x^6-x^5+x^4+2*x^3-2*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+x+3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x^2-x+3,{2,3}>,
<3*x^6+2*x^3-2*x^2+2*x-3,{2,3,5}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x^2-x-1,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^3-x^2-x-2,{2}>,
<-3*x^6-x^5+2*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+2*x^3-2*x^2+2*x-3,{2,3}>,
<-x^6+x^5-2*x^4+2*x^3+2*x^2+2*x+3,{2}>,
<-2*x^6+x^5-2*x^4+2*x^3+2*x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4-2*x^3-2*x^2-x-3,{2}>,
<-3*x^6-2*x^5-2*x^4-2*x^3+3*x^2-2*x-1,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^3-3*x^2-x-1,{}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+3*x^2+x+2,{}>,
<3*x^6+2*x^5+2*x^4+2*x^3-3*x^2+x-2,{}>,
<2*x^6+x^5-2*x^4-2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+3*x^2+3,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3-2*x^2-x-1,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+2*x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+3*x^4+2*x^3-2*x^2+2*x-3,{}>,
<-3*x^6-x^5-2*x^4+2*x^3+2*x^2+2*x+3,{2,3}>,
<-x^6+3*x^5-3*x^4+2*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3+2*x^2+2*x+3,{}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2+2*x-1,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3+3*x^2+2*x-1,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+2*x^2-2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2-3*x-2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+2*x^2-3*x+2,{2,3}>,
<-2*x^6+3*x^5+2*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-x^5+2*x^4-x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+3*x^3+3*x^2+x+3,{}>,
<3*x^6-2*x^5+2*x^4-x^3+2*x^2-x+2,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-x^6-x^5+2*x^4-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4-x^3-2*x^2-x+2,{}>,
<2*x^6+2*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^4+x^3-2*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^4+3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^4+3*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3+2*x^2+2*x+3,{2,3,29}>,
<3*x^6+2*x^5+2*x^4+x^3+2*x^2-x+2,{2}>,
<-3*x^6-2*x^5-2*x^4-x^3-2*x^2+2*x+2,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+2*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+x^3-2*x^2-x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3+2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3+2*x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2-3*x+2,{2}>,
<-3*x^6+x^5+2*x^4-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4-x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3+2*x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+x^3+2*x^2-2*x+2,{2}>,
<-3*x^6+2*x^5-2*x^4+x^3-x^2+3*x+2,{2}>,
<-x^6+2*x^5+2*x^4-x^3+2*x^2-2*x+3,{2}>,
<-2*x^6+3*x^5+x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2-2*x+2,{}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2-x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2+x-1,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+x^2-x-2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2-x-3,{2}>,
<-3*x^6-2*x^5-2*x^4-x^3-x^2+x+3,{2,3}>,
<3*x^6+x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2+2,{2}>,
<3*x^6-2*x^5-x^4+x^3-2*x^2+2*x-3,{2,3}>,
<2*x^6-3*x^5+x^4+x^3+2*x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4+x^3+2*x^2+2*x+3,{2}>,
<-x^6+x^4-x^3+2*x^2-2*x+3,{}>,
<2*x^6-x^4-x^3-2*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4+x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<-x^6+3*x^5+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^3+2*x^2+2*x+3,{}>,
<2*x^6+x^5+x^4-x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3+2*x+2,{2}>,
<2*x^6+2*x^5+x^3-2*x^2+2*x-3,{}>,
<-2*x^6-2*x^5-x^3+2*x^2-2*x+3,{}>,
<3*x^6+2*x^5+x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3+x+2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-x-2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+x+3,{2,3}>,
<-x^6+x^5-x^3+2*x^2-2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+x^3+x-3,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3+2*x+2,{2}>,
<3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+x-1,{2,3,5}>,
<-x^6-2*x^5+x^3+2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4+x^3-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-3*x+2,{2}>,
<2*x^6-3*x^5+x^3-2*x^2+2*x-3,{}>,
<-2*x^6+3*x^5-x^3+2*x^2-2*x+3,{}>,
<-3*x^6-x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4-2*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+x^3+x^2+2*x+2,{2,3}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-2*x+3,{2,3}>,
<-x^6+2*x^5-x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2+x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-2*x^3-2*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-x^3+x^2+3,{2}>,
<2*x^6+x^5-x^4+x^3+2*x^2+2*x+3,{2}>,
<-x^6-x^5-x^4-x^3+2*x^2-2*x+3,{}>,
<2*x^6+x^5+x^4+x^3-2*x^2+2*x-3,{2}>,
<3*x^6+x^5+x^4+x^3-2*x^2+2*x-3,{2,3}>,
<-3*x^6+x^5-x^4+x^3+2*x^2+2*x+3,{2}>,
<-2*x^6-x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2-x-3,{2,3,61}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2-2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x-3,{2}>,
<-x^6-2*x^5-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6+2*x^5-x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5-x^4+x^3+2*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-2*x^2-x+3,{2}>,
<-x^6-3*x^5-x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-x^2-3*x-2,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3-2*x^2+3*x+2,{}>,
<-3*x^6-2*x^4-x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3+2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x-1,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-3*x^2+2*x-2,{2}>,
<-x^6+x^5-3*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3-2*x^2-2*x-3,{2,3}>,
<-3*x^6-x^5-3*x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3-3*x^2-3,{2,3}>,
<3*x^6+2*x^5+2*x^4+x^3-3*x^2-x+3,{}>,
<-x^6+x^5-3*x^4-x^3+2*x^2-2*x+3,{2}>,
<2*x^6-x^5+3*x^4+x^3-2*x^2+2*x-3,{2}>,
<-2*x^6+x^5-3*x^4-x^3+2*x^2-2*x+3,{2,13}>,
<3*x^6+2*x^5+2*x^4+x^3-3*x^2-2*x+2,{2,3}>,
<-2*x^6+3*x^5+3*x^4-x^3-2*x^2-2*x-3,{2}>,
<-x^6-3*x^5+3*x^4+x^3-2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^2+3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-3*x^2+2*x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^2-2*x+3,{2,3,11}>,
<2*x^6-x^5+3*x^4+2*x^2-2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2+x+3,{2}>,
<2*x^6-x^5+3*x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2+x-1,{2}>,
<3*x^6+2*x^5+2*x^4+x^3+3*x^2+x-2,{2}>,
<3*x^6-x^5-3*x^4-x^3-2*x^2-2*x-3,{2,3}>,
<3*x^6+3*x^4+x^3+2*x^2+2*x+3,{2}>,
<2*x^6+3*x^4-x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3+3*x^2-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-3*x^2+3,{3}>,
<3*x^6-2*x^5+2*x^4+3*x^2+x+3,{2,3}>,
<-x^6+x^5+3*x^4+2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-2*x^4-3*x^2-x+2,{}>,
<3*x^6-2*x^5+2*x^4+3*x^2+x-2,{}>,
<3*x^6+2*x^5-3*x^4-2*x^2-2*x-3,{2,3}>,
<-x^6-3*x^5+3*x^4+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^2-3*x-2,{}>,
<2*x^6+2*x^5-2*x^4-2*x^2+2*x-3,{2}>,
<2*x^6+2*x^4-x^3-2*x^2+3*x-1,{}>,
<2*x^6+x^5+2*x^4+2*x^2+2*x+3,{2}>,
<-2*x^6+x^5+2*x^4+2*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6+x^5-2*x^4-2*x^2+2*x-3,{2,3}>,
<-3*x^6-2*x^5-2*x^4-2*x^2+3,{2,3}>,
<2*x^6+x^5+2*x^4+2*x^2-2*x+3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4-2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+2*x^2-x-2,{}>,
<3*x^6+2*x^5+2*x^4+x^2+x+3,{2}>,
<3*x^6+2*x^5+2*x^4+x^2+x+2,{2,3}>,
<-3*x^6-2*x^5-2*x^4-3*x^3-2*x^2-x+3,{2}>,
<3*x^6-2*x^5+2*x^4-3*x^3+2*x^2-x-3,{2,3}>,
<-x^6+x^5+x^4+2*x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+3*x^3+2*x^2+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-x^2+x+2,{2}>,
<-3*x^6+2*x^5-2*x^4-x^2+2,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3+2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5-2*x^4-x^2-x+2,{2}>,
<3*x^6-2*x^5+2*x^4+x^2+x-2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^3+2*x^2-x+2,{2}>,
<-3*x^6+2*x^5-2*x^4-x^2-2*x+2,{2}>,
<-x^6+x^5+2*x^4-3*x^3+2*x^2-2*x+3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+2*x+3,{2,3}>,
<2*x^6-3*x^5+2*x^2-2*x+3,{2}>,
<3*x^6-x^5+2*x^2-2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+x-3,{2}>,
<-x^6+3*x^5+2*x^2-2*x+3,{}>,
<2*x^6+x^5+2*x^2-2*x+3,{2}>,
<2*x^6-2*x^5+x^4-2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-2*x^4+x^2-2*x+3,{}>,
<3*x^6+2*x^5+2*x^4-x-1,{2}>,
<-3*x^6-2*x^5-2*x^4+x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-x+2,{2}>,
<3*x^6-x^5-2*x^2+2*x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4+3*x+2,{2,3}>,
<-3*x^6+2*x^5-2*x^4-3*x-1,{2}>,
<-x^6+3*x^5+x^4-2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4-2*x^2-3*x-1,{2}>,
<2*x^6+x^5-2*x^4+2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4+2*x^2+x-1,{2,3}>,
<3*x^6-2*x^5+2*x^4-2*x^2-x-1,{2,3}>,
<-3*x^6-2*x^5-2*x^4+2*x^2+3,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3-2*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+2*x^3-3*x^2-3*x+2,{2,3,5}>,
<3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+3*x-1,{}>,
<3*x^6-2*x^5+2*x^4-3*x^2-3*x-1,{2,3}>,
<-2*x^6+3*x^5-3*x^4+2*x^2+2*x+3,{2}>,
<3*x^6+x^5-3*x^4+2*x^2+2*x+3,{2,3}>,
<2*x^6+x^5+3*x^4-2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^2+x-3,{2,3}>,
<3*x^6-2*x^5+2*x^4-3*x^2+x+2,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5-3*x^4+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+x^3+2*x^2-2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2+3*x-2,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3-3*x^2-x+2,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3-3*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2+x-3,{2,3,29}>,
<-x^6+3*x^4+x^3+2*x^2-2*x+3,{}>,
<3*x^6-3*x^4+x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2-x+2,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3-3*x^2-x+2,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2-x-2,{2,3}>,
<3*x^6+x^5+3*x^4+x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-x^5+3*x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+3*x^2+2*x-1,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2-2*x-2,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2-x+2,{}>,
<3*x^6+2*x^5+2*x^4-x^3+3*x^2-2*x-2,{2,5}>,
<-3*x^6-x^5+2*x^4+x^3+2*x^2-2*x+3,{2,3}>,
<2*x^6+2*x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+2*x^2-1,{2,3}>,
<-3*x^6+2*x^5-2*x^4-x^3-3*x^2-2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+2*x^2-2*x+3,{}>,
<2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x+3,{2,11}>,
<-3*x^6+2*x^4-x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x+2,{2,3}>,
<3*x^6+2*x^5+2*x^4-x^3+2*x^2-x-1,{2,3}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2+x-2,{2,3}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2,7}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2-2*x-3,{2,3}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3-2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x^2+2*x-3,{2,3}>,
<2*x^6-3*x^5+2*x^4-x^3+2*x^2+2*x+3,{}>,
<-3*x^6+2*x^5-2*x^4-x^3-x^2+x+3,{2,3}>,
<3*x^6+x^4-x^3+2*x^2+2*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+2*x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4-x^3+2*x^2+2*x+3,{2}>,
<2*x^6-x^4-x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4-x^3+x^2-2,{2,3}>,
<-x^6+x^5+x^4+x^3+2*x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+x^4-x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5+x^3+2*x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+x^3+2*x^2-2*x+3,{}>,
<3*x^6+x^5-x^4+x^3-2*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+2*x^4+x^3-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-2*x-3,{2}>,
<-x^6+x^5-x^3+2*x^2+2*x+3,{}>,
<-3*x^6-x^5+x^4-x^3+2*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5-2*x^4+x^3-x+2,{}>,
<3*x^6+2*x^5+2*x^4-x^3+2,{2,3}>,
<-x^6-x^3+2*x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^4+x^3-2*x^2+x-2,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+x^2-2*x+3,{2,3}>,
<3*x^6+x^3-2*x^2-2*x-3,{2,3}>,
<2*x^6-2*x^4+x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+x+3,{2}>,
<2*x^6-x^5-x^3+2*x^2+2*x+3,{}>,
<-x^6-2*x^4-x^3+2*x^2-2*x+3,{}>,
<2*x^6-3*x^5+3*x^4-x^3-2*x^2-2*x-3,{2,3,173}>,
<3*x^6+x^5-x^4+2*x^2-2*x+3,{2,3}>,
<-2*x^6+x^5+x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3-x^2+2*x+3,{2,3}>,
<2*x^6-x^5-x^4+2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3-x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+x-3,{2}>,
<3*x^6-2*x^5+2*x^4-x^3-3*x^2-3*x-2,{2,3}>,
<-3*x^6+2*x^5-2*x^4+x^2-x+2,{2}>,
<-3*x^6+2*x^5-2*x^4+x^3+2*x^2+2,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+2*x+2,{2}>,
<3*x^6-2*x^5+x^4-2*x^2+2*x-3,{2}>,
<-x^6+2*x^5+x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3+x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4-x^3-3*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+2*x^4-x^2-3*x+2,{}>,
<-3*x^6-2*x^5-2*x^4+x^3+x^2+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-x^2-x+2,{2}>,
<-x^6-x^5-x^4-x^3+2*x^2+2*x+3,{2}>,
<-2*x^6+x^5-x^4+x^3+2*x^2-2*x+3,{2}>,
<-x^6-2*x^5-2*x^4+x^3+2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3+2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-x^2+2*x+2,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-3*x-1,{2,3}>,
<-x^6+3*x^5-2*x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+2*x^2+2*x+3,{}>,
<-x^6-3*x^5-3*x^4+x^3+2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-3*x^2-2*x+3,{}>,
<-2*x^6-2*x^5+3*x^4+x^3-2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3+2*x^2-2*x+3,{2}>,
<2*x^6+2*x^5+2*x^4-x^3-2*x^2+2*x-3,{}>,
<3*x^6-2*x^5+2*x^4+x^3-3*x^2-2*x-2,{2,3}>,
<3*x^6+2*x^5+2*x^4-x^3-3*x^2+2,{2}>,
<3*x^6-x^5-3*x^4-x^3+2*x^2+2*x+3,{2}>,
<2*x^6+x^5-3*x^4-x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-3*x^2-x-1,{2}>,
<2*x^6-x^5-2*x^4+x^3+2*x^2-2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+x^3-2*x^2-x-2,{}>,
<-3*x^6-2*x^5-2*x^4+x^3+2*x^2-x+3,{}>,
<3*x^6-2*x^5+2*x^4+x^3-2*x^2-x-3,{}>,
<3*x^6+x^5+3*x^4-x^3-2*x^2+2*x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3+2*x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5-2*x^4+2*x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4+2*x^3+3*x^2-2*x+2,{2}>,
<-x^6+x^5+3*x^4-2*x^3+2*x^2+2*x+3,{}>,
<-3*x^6+2*x^5-2*x^4-2*x^3-3*x^2+x+3,{2}>,
<2*x^6+x^5-2*x^4+x^3+2*x^2-2*x+3,{2,7}>,
<3*x^6-2*x^5+2*x^4+2*x^3+3*x^2-3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-2*x^2-x-1,{}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+2*x^2-2*x+3,{}>,
<2*x^6-x^5+2*x^4-x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-2*x^2-2*x-3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3+2*x^2-x-1,{}>,
<-3*x^6-2*x^5-2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+2*x^5-2*x^4-2*x^3-2*x^2-x+2,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2-2*x-3,{2,3,5}>,
<-3*x^6+2*x^5-2*x^4-2*x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4-2*x^3+2*x^2-x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4-2*x^3+2*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^4-2*x^3+2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4-2*x^3+2*x^2+x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-x^6+x^5+2*x^4-2*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x^2-2*x+3,{2}>,
<-x^6-3*x^5+x^4+2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3+2*x^2+x-3,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^3-2*x^2-2*x-3,{2,7}>,
<-3*x^6+2*x^5-2*x^4-2*x^3-2*x^2+2,{2}>,
<3*x^6+2*x^5+2*x^4+3*x^2+2,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^2+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3-2*x^2+2*x-3,{}>,
<3*x^6-x^5+x^4+2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3+x^2-x-2,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3-x^2-x+3,{2}>,
<2*x^6-x^4+2*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3+2*x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5-2*x^4+2*x^3-x^2+x+2,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3+x^2+x-2,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-2*x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5+x^4+2*x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+2*x^3+x^2+3*x+2,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3+x-1,{2,3}>,
<2*x^6+x^5+2*x^3-2*x^2-2*x-3,{2,5}>,
<2*x^6+2*x^5+2*x^3-2*x^2-2*x-3,{2}>,
<-x^6+3*x^5+2*x^3-2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-x^2-x+2,{}>,
<-3*x^6+2*x^5-2*x^4-2*x^3+x^2-2*x-1,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-x^2+x+3,{2,3}>,
<3*x^6-2*x^5+2*x^4+2*x^3-x^2-x+2,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+x^2-x+2,{2,3}>,
<3*x^6+x^4+2*x^3-2*x^2-2*x-3,{2,3}>,
<2*x^6-3*x^5-3*x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6-x^5-x^4-2*x^3+2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^4-2*x^3+x^2-3*x-2,{2,3,11,61}>,
<-x^6+3*x^5+3*x^4+x^3-2*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+2*x^2-2*x+3,{}>,
<-x^6+3*x^5-3*x^4+x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3-3*x^2-3*x-2,{2,3,5}>,
<3*x^6-2*x^5+2*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3-3*x^2-3,{2,3}>,
<3*x^6-2*x^5+2*x^4+2*x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5+x^4+x^3+2*x^2-2*x+3,{}>,
<2*x^6-x^5-x^4+x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-x^3+x^2+x-2,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+2*x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+3*x^3+3*x^2-x-1,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+3*x^2+x-3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+3*x^2+3,{}>,
<-x^6+3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x^2-2*x+3,{2,5}>,
<-3*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x+2,{2,3}>,
<3*x^6+2*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-2*x^2+2*x-3,{}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-2*x^2+2*x-3,{2}>,
<2*x^6+x^5-2*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3-x-1,{2}>,
<-3*x^6+2*x^5-2*x^4-2*x^3+x+2,{2}>,
<3*x^6+x^5-2*x^3-2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4-2*x^3+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2-x-3,{2}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+2,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6+x^5+2*x^3+2*x^2-2*x+3,{}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2-3*x+2,{}>,
<-x^6-3*x^5+2*x^4-3*x^3+2*x^2+2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+3*x^3+x^2-3*x-2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+x^2-2*x+3,{2,3,5}>,
<2*x^6+2*x^5-x^4-3*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+x^2-2*x-2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+x^2-x-1,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^3-x^2+x+2,{2}>,
<3*x^6+x^4-3*x^3+2*x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-2,{2,3}>,
<-3*x^6+2*x^5-2*x^4-3*x^3-x^2+3,{2}>,
<3*x^6-x^5+x^4-3*x^3+2*x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-x+2,{2}>,
<-x^6+x^5+x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-x-2,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x^2-2*x+2,{}>,
<-x^6+2*x^5+x^4+3*x^3+2*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-2*x^2-2*x-3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-2*x^2+2*x-3,{}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2*x^2+2*x-3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+2*x^2-2*x+3,{}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-2*x-1,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3-2*x+2,{2}>,
<3*x^6-x^5+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+x+2,{}>,
<2*x^6+x^5-3*x^3-2*x^2+2*x-3,{2,3}>,
<-2*x^6+x^5-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2-x-2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+2*x^2+2,{}>,
<3*x^6+2*x^5+2*x^4-3*x^3+2*x^2-1,{2}>,
<-3*x^6+2*x^4+3*x^3+2*x^2-2*x+3,{2,3}>,
<3*x^6-x^5-3*x^3+2*x^2+2*x+3,{2}>,
<-x^6-x^5-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3+2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3+3*x+2,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+x^2-3*x-1,{2}>,
<3*x^6-2*x^5+2*x^4+x^3-x^2-3*x+2,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+x^3+x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5+2*x^4+x^3-x^2-3*x-1,{}>,
<-2*x^6+3*x^5-x^4-x^3+2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+2*x^2-2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4-x^3-2*x^2+2*x-3,{2}>,
<-3*x^6-x^5-x^4+x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2+x+3,{2}>,
<2*x^6-x^5-x^4+3*x^3+2*x^2-2*x+3,{}>,
<3*x^6-2*x^5+2*x^4+x^3-x^2+3,{2,3}>,
<3*x^6-2*x^5+2*x^4+3*x^3-x^2-x-1,{2,3}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2+x-2,{2}>,
<3*x^6-x^5+x^4+3*x^3-2*x^2-2*x-3,{2}>,
<2*x^6-x^4-x^3+2*x^2+2*x+3,{2}>,
<3*x^6-x^4-3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+x^2+2,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+x^2+3*x-2,{2}>,
<-x^6+x^5+x^4+3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^3+x^2-3*x-1,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2-3*x-1,{}>,
<2*x^6+3*x^5+x^4+3*x^3-2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-2*x^2-3*x-1,{}>,
<3*x^6+2*x^5+2*x^4-3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-2*x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5+2*x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-2*x^2-3*x-2,{}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+3*x^2-3*x-2,{2,5}>,
<3*x^6-2*x^5+2*x^4+3*x^3-x^2+2*x-2,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-3*x^2+3*x-2,{2,3}>,
<3*x^6+2*x^5+2*x^4-2*x^3-3*x^2+x+2,{2}>,
<-x^6+3*x^4-2*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-2*x^2-x-1,{2,3}>,
<-3*x^6+2*x^5-2*x^4-3*x^3+2*x^2+x+2,{2}>,
<3*x^6-2*x^4-3*x^3+2*x^2+2*x+3,{2,7}>,
<3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-x-2,{2}>,
<-3*x^6-2*x^5-2*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+2*x^2+2*x+3,{}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x^2+2*x-3,{2,3}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-x-3,{2}>,
<-x^6-3*x^5-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2*x^2+2*x-3,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-2*x^2+2*x-3,{}>,
<-3*x^6-x^5-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<-x^6+3*x^4+3*x^3-2*x^2-2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x^2-2*x-3,{2,13,23}>,
<2*x^6-x^5-3*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+2*x^4-3*x^3-3*x^2-x-1,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3-2*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-3*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2+3*x-2,{2,3}>,
<-x^6+2*x^5+3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3-3*x^2+2*x+2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-2,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2+x+2,{2}>,
<3*x^6-2*x^5+2*x^4+2*x^3-2*x^2-3*x-1,{}>,
<-3*x^6-2*x^5-2*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+2*x^4-2*x^3-2*x^2+2*x-3,{2}>,
<2*x^6+2*x^4-2*x^3-2*x^2+2*x-3,{}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x+2,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-x^2-2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+x^2+2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-x^2-2*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x-2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3-2*x^2+2*x+2,{2,3}>,
<-3*x^6-2*x^5-2*x^4+3*x^3-3*x+2,{2}>,
<3*x^6-2*x^5+2*x^4+3*x^3-2*x+2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+2*x^2+2*x-2,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3-2*x^2+x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+2*x^2+2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+2*x^2-x+2,{2,3}>,
<-3*x^6+2*x^5-x^4+3*x^3-2*x^2+3,{2,3}>,
<-x^6-x^5+2*x^4-3*x^3+x^2-2*x+3,{}>,
<-3*x^6+2*x^4+3*x^3+x^2+2*x+3,{2,3}>,
<2*x^6+3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3-2*x^2+x+2,{}>,
<3*x^6-2*x^5+x^4-3*x^3+2*x^2+x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-x^6-3*x^5+2*x^4+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-2*x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+x^2+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2-2*x-3,{2}>,
<-x^6-2*x^5+2*x^4-2*x^2+2*x-3,{2}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+2*x+3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-x^2-2*x-3,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^2+2*x-3,{}>,
<-x^6+2*x^5+2*x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6+3*x^3-2*x^2-2*x-3,{2,3,5}>,
<3*x^6+2*x^5+x^4+3*x^3+x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-2*x^2+2*x-3,{2,5}>,
<2*x^6+2*x^5-2*x^4-3*x^3-x^2-2*x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+x^2+x-3,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3+x^2-2*x-2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+x^2+2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-x^2+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-3*x-2,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3-x^2-x+2,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+x^2-x-2,{}>,
<3*x^6-2*x^5+x^4-3*x^3-3*x+2,{2}>,
<3*x^6+x^5-x^4-3*x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x-1,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+x^2-x-3,{2,3}>,
<3*x^6+x^5-3*x^3+x^2-2*x+3,{2,3}>,
<2*x^6+x^5-3*x^3+x^2-2*x+3,{}>,
<2*x^6-x^5+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+x-2,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-x^2-3*x-1,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+x^2+3*x+2,{}>,
<-3*x^6+2*x^5-x^4+3*x^3-x+3,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+x^2-2*x-2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^3+x^2-2*x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+x^2-2*x+3,{}>,
<3*x^6-2*x^5+3*x^3-x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2+2*x-3,{2}>,
<-x^6-x^5+x^4-3*x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-x^2-3*x+2,{2}>,
<-x^6+x^5-x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3-x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3-x^2-1,{2}>,
<-2*x^6-x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2-2*x-3,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6+x^4-3*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+x^2+3*x-1,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+x^2+x+2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-x^2+3*x-2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+3*x+2,{2}>,
<-x^6+2*x^5-x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+x^2+2*x+2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+2*x-2,{2,3,7}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+2*x+2,{2,3,7}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+x+2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+x-2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3+x^2+2*x+3,{2,3}>,
<-x^6+2*x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2-1,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x^2+x-2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2+x+2,{2}>,
<-x^6-x^5+2*x^4-3*x^3-x^2-2*x-3,{}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x^2-2*x+3,{2,3}>,
<3*x^6-3*x^4+3*x^3-2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+2*x^2+2*x+2,{2,3}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5-x^4-3*x^3+2*x^2+3*x-1,{}>,
<3*x^6+2*x^5+x^4+3*x^3-2*x^2-3*x-1,{}>,
<-3*x^6-2*x^5-x^4-3*x^3+2*x^2+3*x+2,{}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x^2+3*x-2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x-3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+x^2+2*x+3,{}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-3*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x^2-2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-3*x^2+2,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x^2-1,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x^2-2*x-3,{2}>,
<-x^6-3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x^2+2,{2}>,
<3*x^6+3*x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6-3*x^4+3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^3-3*x^2-x-3,{2,3}>,
<3*x^6-2*x^5+x^4-3*x^3-3*x^2+x+2,{2}>,
<-x^6-x^5+3*x^4+3*x^3-x^2+2*x-3,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+x^2-2*x+3,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+x^2-2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2-2*x+3,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-2*x^3+3*x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-x^4+3*x^3+3*x^2-3*x+2,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^3+x^2-2*x+3,{2,3,7}>,
<-x^6-3*x^5-3*x^4+2*x^2+3*x-1,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-x^2-2*x-3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+x^2-2*x+3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+x^4+2*x^3+2*x^2+3*x-2,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+2*x^2+x+2,{}>,
<-3*x^6+2*x^5-x^4+2*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3-2*x^2-x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+2*x^2+x-3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6+x^5+2*x^4-2*x^3+x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+x^4-2*x^3+2*x^2+x-1,{}>,
<-3*x^6+2*x^5-x^4+2*x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5-x^4-2*x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3+x^2+2*x+3,{2,5}>,
<2*x^6-3*x^5-2*x^4+2*x^3-x^2+2*x-3,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3+x^2+2*x+3,{2,17,83}>,
<2*x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-x-3,{}>,
<3*x^6-2*x^5+x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+x^2+2*x-3,{2,3,11}>,
<2*x^6-x^5+x^4-2*x^3+x^2-2*x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+3*x+2,{2,3}>,
<3*x^6+x^5-x^4+2*x^3-x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-x-2,{2,3}>,
<-x^6-3*x^5-2*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3-3*x+2,{2}>,
<-3*x^6-2*x^5+2*x^3+x^2+2*x+3,{2,3}>,
<-3*x^6-x^5+x^4-2*x^3+x^2-2*x+3,{2}>,
<2*x^6+3*x^5-2*x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3+2*x+3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-3*x^2-x-1,{2}>,
<3*x^6-2*x^5+x^4-2*x^3+x^2+x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3+x+3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3+x+2,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+3*x^2-x+2,{2}>,
<-3*x^6-x^5+x^4+2*x^3+x^2+2*x+3,{2}>,
<-x^6-3*x^5+2*x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3-3*x+2,{2}>,
<-3*x^6-x^5-2*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5+x^4-2*x^3-x^2-2*x-3,{}>,
<-3*x^6-2*x^5-x^4-2*x^3+x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5-x^4-2*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-x^2-2*x-1,{2}>,
<3*x^6+2*x^5+x^4+2*x^3-2*x^2+3*x+2,{2,3}>,
<-x^6+3*x^5-2*x^4+2*x^3+x^2+2*x+3,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-x^2-2*x-3,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2+2*x+3,{2}>,
<-x^6+x^5+2*x^4+2*x^3-x^2+2*x-3,{2}>,
<-x^6+x^5-2*x^4+2*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+2*x^2-x+2,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-2*x^2-x-2,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-x^2-2*x-3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3+x^2-2*x+3,{2,3}>,
<2*x^6-x^5+2*x^4+2*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+2*x^3-2*x^2-x-2,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3+x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+x^2+2*x+3,{2,11}>,
<-3*x^6+2*x^5-x^4+2*x^3+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+2*x+3,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4-2*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-x^2-2*x-3,{}>,
<2*x^6+x^5-3*x^4+2*x^3+x^2+2*x+3,{}>,
<-3*x^6+2*x^5-x^4+2*x^3+3*x^2+x-1,{2}>,
<-x^6-x^5-3*x^4-2*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+x^2-x+3,{}>,
<3*x^6-2*x^5+x^4-2*x^3-x^2-x-3,{}>,
<2*x^6+x^5-x^4-2*x^3+x^2-2*x+3,{2}>,
<-x^6-x^5-x^4+2*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+x^2+x+2,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3+x^2-x+3,{2,3}>,
<3*x^6-2*x^5+x^4-2*x^3-x^2+x-3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3+3*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5-x^4-2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2+3*x-2,{}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+x^3-3*x^2+x+2,{2,3}>,
<2*x^6+3*x^5+x^4-3*x^3+2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2+3,{2}>,
<3*x^6-2*x^5+x^4-x^3+3*x^2+2,{2}>,
<-x^6-3*x^5+x^4+3*x^3+2*x^2-2*x+3,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-x^2-2*x-3,{2,131}>,
<2*x^6-3*x^4+x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+2*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-x^3-3*x^2+3,{2}>,
<2*x^6-x^5+3*x^4+x^3+x^2+2*x+3,{2}>,
<-3*x^6-3*x^4+2*x^3+x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5-x^4-x^3-3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5+x^4-x^3+3*x^2-2,{2}>,
<3*x^6+2*x^5+x^4+2*x^3-3*x^2-x-1,{2,3}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2-x-3,{2,3}>,
<3*x^6+2*x^5+x^4+2*x^3-3*x^2-x-2,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2+2*x+3,{}>,
<2*x^6+3*x^5-2*x^4+x^3-x^2+2*x-3,{}>,
<2*x^6-2*x^5+3*x^4+x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3+2*x^2-2*x+2,{2}>,
<3*x^6-2*x^5+x^4-x^3+2*x^2+x+2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-x^2+2*x-3,{2}>,
<-x^6+x^5+2*x^4-x^3+x^2-2*x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3+x^2+2*x+3,{2}>,
<2*x^6-x^5-2*x^4+x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3+2*x^2+x-3,{2,5}>,
<2*x^6+2*x^5-2*x^4-x^3-x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5+x^4+x^3+2*x^2-2*x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4+x^3-x^2+2*x-3,{2,3,5,17}>,
<3*x^6+2*x^5+x^4+x^3+2*x^2+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3-x^2-2*x-3,{2}>,
<2*x^6+2*x^4+x^3+x^2+2*x+3,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-x^3-3*x^2+2*x+3,{2}>,
<-x^6+2*x^4-x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-x^3-2*x^2+3*x+2,{2}>,
<2*x^6-2*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3+3*x^2-2*x-3,{2}>,
<2*x^6+3*x^5-x^4+x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3+x^2+2*x+3,{}>,
<2*x^6-2*x^5+x^4-x^3+x^2-2*x+3,{2}>,
<2*x^6-2*x^5-x^4-x^3-x^2-2*x-3,{}>,
<3*x^6-2*x^5+x^4-x^3+x^2-2*x-2,{}>,
<3*x^6-2*x^5-x^4-x^3-x^2-2*x-3,{2,3,5}>,
<2*x^6+3*x^5-3*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3+x^2+x-3,{2,3}>,
<3*x^6-2*x^5+x^4-x^3+x^2+3,{2}>,
<-x^6-3*x^5-2*x^4-x^3-x^2-2*x-3,{}>,
<-3*x^6+x^4-x^3+x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4-x^3+x^2-2*x+3,{2}>,
<2*x^6+x^5-x^4-x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-x^3-x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5+x^4+x^3+x^2-2*x+2,{2}>,
<-2*x^6+3*x^5+x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+x^2-2*x+3,{2,3,7,19}>,
<-x^6-2*x^5+x^4+x^3+x^2+2*x+3,{2}>,
<-x^6-2*x^5-x^3+x^2-2*x+3,{2}>,
<2*x^6+2*x^5-x^4-x^3-x^2-2*x-3,{2}>,
<2*x^6+x^5+x^4+x^3+x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^3-x^2-2*x-3,{2}>,
<-2*x^6-x^5+x^4-x^3+x^2-2*x+3,{}>,
<-2*x^6-2*x^5-x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3+x^2-3*x+2,{}>,
<-3*x^6-2*x^5-x^4-x^3-x^2-x+3,{2}>,
<3*x^6+x^5+x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3+x-1,{}>,
<3*x^6+2*x^5+x^4+x^3+x-2,{2,7}>,
<-3*x^6-2*x^5-x^4-x^3-x+3,{2,3}>,
<-3*x^6+2*x^5-x^4+x^3-3*x+2,{2}>,
<-2*x^6+3*x^5-x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6-x^5-x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+x^3+x^2+3*x-1,{2}>,
<3*x^6-2*x^5+x^4-x^3-x-3,{2,3}>,
<-x^6+3*x^5-x^4+x^3+x^2+2*x+3,{2}>,
<-2*x^6+x^3+x^2+2*x+3,{}>,
<3*x^6-x^5-x^4-x^3+x^2-2*x+3,{2}>,
<-x^6-x^5-x^4-x^3+x^2-2*x+3,{2}>,
<3*x^6-x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4+x^3+x^2+x+2,{2}>,
<-2*x^6-x^5-x^4-x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-x^2+2,{2}>,
<3*x^6-2*x^5+x^4-x^3+x-3,{2}>,
<3*x^6-2*x^5+x^4-x^3+2*x+2,{2}>,
<-x^6-x^4-x^3+x^2-2*x+3,{2}>,
<2*x^6+2*x^5-x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-x^3+x^2+2,{2}>,
<3*x^6-2*x^5+x^4-2*x^3+x^2+3*x-1,{2}>,
<-3*x^6-2*x^5-x^4-x^3+3*x-1,{2}>,
<-3*x^6+2*x^5-x^4+x^3+x^2+3,{2,3,5}>,
<3*x^6+2*x^5+x^4+x^3-x^2-x-2,{2}>,
<-3*x^6-2*x^5-x^4-x^3+x^2+x+3,{}>,
<3*x^6+2*x^5+x^4+x^3-x^2-x-3,{}>,
<3*x^6-2*x^5+x^4-x^3+3*x-1,{2}>,
<3*x^6+2*x^5+x^4+x^3-x^2-2*x+3,{2}>,
<-3*x^6-x^4-x^3+x^2-2*x+3,{2,3}>,
<-x^6-3*x^5-x^4+x^3+x^2+2*x+3,{2}>,
<2*x^6+3*x^5+x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2+3*x-2,{2,3}>,
<3*x^6+2*x^5+x^4+x^3-x^2-x+2,{2}>,
<-3*x^6-2*x^5-x^4-x^3+2*x^2-3*x-2,{2}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2-3,{2}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2+3*x+2,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x^2+x+2,{2}>,
<-x^6+x^5-2*x^4-x^3+x^2-2*x+3,{}>,
<-x^6+3*x^5+2*x^4+x^3-x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-x^3+2*x^2+x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+2*x^5-x^4+x^3+2*x^2-2*x-1,{2}>,
<-3*x^6+2*x^5-x^4+x^3+2*x^2+3*x+2,{2,3}>,
<-3*x^6-2*x^5-x^4-x^3+2*x^2+3*x-1,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2+3*x-2,{2}>,
<3*x^6+2*x^5+x^4+3*x^3+x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-x^2+2*x-3,{}>,
<-3*x^6-2*x^5-x^4-3*x^3-x+3,{}>,
<-2*x^6-3*x^5+3*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-x-3,{}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2+2*x+2,{2}>,
<3*x^6-2*x^5+x^4-3*x^3+3,{2}>,
<-x^6+3*x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+x^3+3*x^2+2*x-1,{2,19}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2-2*x-1,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+2,{2}>,
<-3*x^6-2*x^5-x^4-x^3+3*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-x^4-x^3+3*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2+x+2,{2}>,
<-x^6-x^5+3*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2+x-3,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+2*x-3,{2}>,
<-x^6-3*x^4+x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2-2,{2}>,
<-2*x^6+x^5-3*x^4+x^3+x^2+2*x+3,{2}>,
<3*x^6+3*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-3,{2}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2+x+3,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2+3*x+2,{2}>,
<-x^6+x^5-3*x^4-x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4+x^3-x^2+2*x-3,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-x^3-3*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5-x^4+x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4+x^2-2*x+3,{2}>,
<-3*x^6+3*x^4+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^2-x+2,{}>,
<3*x^6-2*x^5+x^4+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+x^2-2*x+3,{2}>,
<-2*x^6-x^5+3*x^4+x^2-2*x+3,{}>,
<-3*x^6+2*x^5-x^4-3*x^2-x+2,{2}>,
<3*x^6+2*x^5+x^4+x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+x^5+2*x^4+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^2+x+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^2+x+3,{2,3}>,
<-x^6+2*x^5+3*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+2*x^2-x-1,{2}>,
<-3*x^6+x^5+3*x^4+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-2*x^2+x+2,{2}>,
<3*x^6+3*x^4+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4+2*x^2-x+3,{2}>,
<3*x^6+2*x^5+x^4+3*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+x^4+x^2+3*x-2,{2,5}>,
<-2*x^6-x^5+2*x^4+x^2+2*x+3,{2}>,
<3*x^6-x^5+x^4+x^2-2*x+3,{2,3}>,
<3*x^6+x^5-2*x^4-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4+x^2+x-3,{2,3}>,
<2*x^6-3*x^4-x^2+2*x-3,{2,3,5}>,
<2*x^6-3*x^5-2*x^4-x^2+2*x-3,{2,3}>,
<2*x^6-x^5+x^4+x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^2-x+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^2+3*x-2,{2}>,
<3*x^6+x^5-2*x^3-x^2-2*x-3,{2}>,
<-x^6-3*x^5-x^4-x^2-2*x-3,{}>,
<-x^6+3*x^5-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4-x^2+3*x+2,{2}>,
<3*x^6+x^5-x^4-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^2+x+2,{2,3}>,
<-x^6+3*x^5+2*x^4-x^2+2*x-3,{2}>,
<-x^6+3*x^5-2*x^4+x^2+2*x+3,{}>,
<3*x^6+2*x^5+x^4-x^2+x-1,{2}>,
<2*x^6+3*x^5+2*x^4-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4-2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5-x^4+x^2-x+2,{2}>,
<3*x^6+2*x^5+x^4+x^2-3*x+2,{2,13}>,
<-3*x^6-2*x^5-x^4+2*x^2-x+2,{2,3}>,
<3*x^6+x^5+x^4-x^2+2*x-3,{2,3}>,
<-x^6+3*x^5-x^4-x^2-2*x-3,{2,5}>,
<3*x^6-2*x^5+x^4-2*x^2-x-2,{2,3}>,
<3*x^6+2*x^5+x^4-x^2-3,{}>,
<3*x^6+2*x^5+x^4-2*x^2+x-3,{2}>,
<3*x^6+2*x^5+x^4-2*x^2-x+2,{2}>,
<3*x^6-x^5-x^4+x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4-x^2+2*x-3,{}>,
<-3*x^6-2*x^5-x^4+3*x^2-3*x-1,{2,3,7}>,
<2*x^6-3*x^5+3*x^4-x^2-2*x-3,{2}>,
<-x^6+3*x^5-3*x^4+x^2+2*x+3,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4+x^3+3*x^2-x+3,{2,3}>,
<2*x^6-x^5-3*x^4+x^3-x^2-2*x-3,{}>,
<3*x^6+2*x^5+x^4-x^3+3*x^2+x-2,{2}>,
<-3*x^6+2*x^5-x^4-x^3-3*x^2+x+3,{2,3}>,
<-3*x^6+x^5+3*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+3*x^2+2,{2}>,
<-x^6+3*x^4-x^3+x^2+2*x+3,{}>,
<-3*x^6-2*x^5-x^4+x^3-3*x^2+2,{2}>,
<-3*x^6-2*x^5-x^4+x^3-3*x^2+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+3*x^2-3,{2,3,7}>,
<-3*x^6+2*x^5-x^4-x^3-3*x^2-x+2,{2}>,
<3*x^6+x^5-3*x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4-x^3+3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^3+2*x^2+x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4-3*x^3-2*x^2+x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+2*x^4+x^3+x^2-2*x+3,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4+x^3+3*x^2+3*x+2,{2}>,
<3*x^6+x^5+2*x^4-x^3+x^2+2*x+3,{2,3,7}>,
<3*x^6-2*x^5+x^4+x^3+2*x^2-2*x+2,{2}>,
<3*x^6-2*x^5+x^4+x^3+2*x^2-x+2,{2}>,
<-x^6-x^5+2*x^4+x^3+x^2-2*x+3,{2}>,
<-2*x^6+2*x^4+x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^4+x^3-x^2-2*x-3,{2}>,
<2*x^6+x^5+2*x^4+x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+x^3-2*x^2-x+2,{2}>,
<-x^6-x^5+2*x^4-x^3+x^2+2*x+3,{2}>,
<-2*x^6-x^5+2*x^4+x^3+x^2-2*x+3,{}>,
<-3*x^6-2*x^5-x^4+x^3-2*x^2+x+2,{}>,
<3*x^6-x^5-2*x^4-x^3-x^2+2*x-3,{2,3}>,
<3*x^6+x^5-2*x^4-x^3-x^2+2*x-3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3-2*x^2-2*x+2,{2}>,
<3*x^6+2*x^4+x^3+x^2-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+x^3-2*x^2+2,{2,3}>,
<-3*x^6-2*x^5-x^4+x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+x^2+x-1,{2,3}>,
<3*x^6-2*x^5+x^4+x^3+x^2+2,{2}>,
<3*x^6+2*x^5+x^4-x^3+x^2-1,{2}>,
<-3*x^6+2*x^5-x^4-x^3-2*x^2-3*x+2,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3-x^2+2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6-x^4-x^3-x^2+2*x-3,{2}>,
<2*x^6-3*x^5+x^4+x^3+x^2-2*x+3,{}>,
<3*x^6+2*x^5+x^4-x^3+x^2-x+3,{}>,
<-3*x^6+2*x^5-x^4-x^3-x^2-x+2,{}>,
<-x^6+3*x^5-x^4-x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4-x^3+x^2-x-2,{2}>,
<3*x^6+2*x^5+x^4-x^3+x^2-2*x+2,{2}>,
<-x^6-2*x^5+x^4-x^3+x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4-x^3-x^2+2*x-3,{2}>,
<-x^6-3*x^5-x^4-x^3-x^2+2*x-3,{}>,
<2*x^6+3*x^5+3*x^3-x^2+2*x-3,{2}>,
<-2*x^6-3*x^5-3*x^3+x^2-2*x+3,{2}>,
<2*x^6-2*x^5-3*x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4+3*x^3+2*x-1,{2,3}>,
<3*x^6+2*x^5+x^4+3*x^3+2*x-1,{}>,
<2*x^6-2*x^5-3*x^3-x^2-2*x-3,{2}>,
<-3*x^6-x^5+x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3+3,{2}>,
<3*x^6-2*x^5+x^4+x^3+2,{}>,
<2*x^6+x^3-x^2-2*x-3,{2,3}>,
<-x^6+x^5+x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3-x+3,{2,3}>,
<3*x^6-2*x^5-x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+x^3+2*x+2,{2,3}>,
<2*x^6+2*x^5+x^3-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-x^2-3*x-1,{}>,
<-3*x^6+2*x^5-x^4-x^3+x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-x^2-3*x-2,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4-x^3-x^2+2*x-3,{2}>,
<-x^6+2*x^5-x^4-x^3+x^2+2*x+3,{2}>,
<2*x^6-2*x^5+x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+x^3-x^2-2*x-3,{2,3}>,
<2*x^6-x^5-x^4+x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4-x^3+x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-x^2+3,{2}>,
<3*x^6-2*x^5+x^4+x^3-x^2+x+3,{2}>,
<3*x^6-2*x^5+x^4+x^3-x^2+x+2,{2}>,
<-x^6+x^5-x^4+x^3+x^2-2*x+3,{2}>,
<2*x^6+x^5+x^4+x^3-x^2-2*x-3,{}>,
<3*x^6+2*x^5-x^4+x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+x^2-2*x-1,{2,3}>,
<2*x^6-3*x^5-x^4-x^2+2*x-3,{2}>,
<-x^6+3*x^5-2*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3+x^2-2*x+3,{2,3}>,
<-x^6+x^5+2*x^4-x^3-x^2+2*x-3,{2}>,
<-x^6-x^5-2*x^4+x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+x^3+x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3+2*x^2+x+2,{2}>,
<-3*x^6-2*x^5+x^4+x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+2*x^2+x+3,{2,3}>,
<3*x^6-2*x^5+x^4+x^3+x^2-x+3,{}>,
<2*x^6-2*x^4-x^3+x^2+2*x+3,{2}>,
<2*x^6-3*x^5-x^2-2*x-3,{2}>,
<-2*x^6-3*x^5+x^2-2*x+3,{}>,
<2*x^6-2*x^5-2*x^4-x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+2*x^2-2*x-1,{}>,
<-3*x^6+2*x^5+x^2+2*x+3,{2,3}>,
<-2*x^6+x^5+x^2+2*x+3,{}>,
<-3*x^6-2*x^5-x^4+x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6-x^5-2*x^4-x^3+x^2+2*x+3,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+x^2+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<3*x^6+x^5-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4+x^3-3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-x^2+2*x-3,{}>,
<3*x^6+2*x^5+x^4-x+3,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-2*x^2+x-3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3+3*x^2+3*x+2,{2}>,
<2*x^6-x^5+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-x^3-3*x^2+3,{2}>,
<-x^6-2*x^5-3*x^4+x^3+x^2-2*x+3,{2}>,
<-3*x^6-3*x^4+x^3+x^2-2*x+3,{2}>,
<-x^6+x^5+3*x^4+x^3-x^2-2*x-3,{}>,
<-3*x^6-2*x^5-x^4+x+2,{2,3}>,
<3*x^6-2*x^5+x^4+x^3-3*x^2+x-2,{2}>,
<-x^6-x^5-3*x^4+x^3+x^2-2*x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2-2*x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x+2,{}>,
<3*x^6-2*x^5+x^4+x^3-3*x^2+2*x+3,{2}>,
<2*x^6+x^5+3*x^4-x^3-x^2+2*x-3,{}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5+3*x^4-2*x^3+x^2+2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2-2*x-3,{}>,
<3*x^6+2*x^5+x^4-2*x^3+3*x^2+3*x-2,{}>,
<-2*x^6+2*x^5+3*x^4+x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4+2*x^3-3*x^2-2*x+2,{2,3}>,
<3*x^6+2*x^5+x^4-2*x^3+3*x^2+x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-x^2+2*x-3,{2,7}>,
<-3*x^6-2*x^5-x^4+2*x^3-3*x^2-x+2,{2}>,
<-x^6-3*x^5-3*x^4-x^3+x^2+2*x+3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-x^2+2*x-3,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-x^2+2*x-3,{}>,
<-3*x^6+2*x^5-x^4-2*x^3-2*x^2+x+3,{2}>,
<2*x^6+2*x^4+2*x^3+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-2*x^3-2*x^2+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+x^2+2*x+3,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-x^2-2*x-3,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+x^2+2*x+3,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+x^2+2*x+3,{2}>,
<2*x^6+3*x^5-x^4+x^3-x^2-2*x-3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^3+x^2+2*x+3,{}>,
<-3*x^6+2*x^5-x^4-x^3+3*x-1,{}>,
<-3*x^6+2*x^5-x^4-2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6-2*x^5+x^4+x^3-3*x-1,{2}>,
<3*x^6+2*x^5+x^4-2*x^3+x^2+x+2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-x^2-2*x-3,{2,7}>,
<-3*x^6+2*x^5-x^4-x^3+3*x+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3+x^2-x-1,{2}>,
<3*x^6+2*x^5+x^4-2*x^3+2*x^2-3*x-1,{}>,
<-2*x^6+2*x^5-x^3+x^2+2*x+3,{2}>,
<2*x^6-x^5-x^4+2*x^3-x^2-2*x-3,{2}>,
<3*x^6-x^5-x^4+2*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-x^4-2*x^3-x^2-3*x-1,{2,3}>,
<-x^6+3*x^5-2*x^3-x^2+2*x-3,{2,5}>,
<-3*x^6-2*x^5-x^4+x^3-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-3*x-2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-2*x-3,{2,3}>,
<-3*x^6+x^4+2*x^3+x^2-2*x+3,{2,3}>,
<3*x^6+x^5-2*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-x+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3+x^2+x+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-x^2-3*x+2,{2}>,
<-3*x^6+2*x^5-x^4-2*x^3+x+2,{2}>,
<-x^6-x^5+x^4-2*x^3+x^2+2*x+3,{}>,
<-x^6+3*x^5+x^4-2*x^3-x^2+2*x-3,{2}>,
<-3*x^6-2*x^5-x^4+2*x^3+x+2,{}>,
<-x^6-3*x^5-x^4+2*x^3+x^2-2*x+3,{2}>,
<2*x^6+x^5-x^4+2*x^3-x^2-2*x-3,{2}>,
<-x^6+2*x^5+2*x^3-x^2-2*x-3,{2,5}>,
<2*x^6+3*x^5+x^4-2*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3-2*x-3,{2,3}>,
<3*x^6+2*x^5+x^4-2*x^3-x^2-x+3,{2,3}>,
<-2*x^6+3*x^5+x^4+2*x^3-x^2-2*x-3,{2}>,
<3*x^6+x^5-x^4+2*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5-x^4+2*x^3+2*x^2-3*x+2,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+x^2+2*x+3,{2}>,
<-x^6-3*x^5+x^4-2*x^3-x^2+2*x-3,{2}>,
<-x^6+x^5+2*x^4+2*x^3-x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4-3*x^2+3*x+2,{2,37}>,
<-x^6+3*x^5-x^4+2*x^3+x^2-2*x+3,{2}>,
<-2*x^6-x^5-3*x^4+x^2-2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-2*x^3+2*x^2-3*x+2,{2,3}>,
<-3*x^6+2*x^5-x^4+3*x^2+x+3,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-2*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5+x^4+2*x^3-3*x^2-3*x-1,{2}>,
<3*x^6+2*x^5+x^4-3*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+x^4+2*x^2+2*x-3,{2}>,
<-x^6+x^5+3*x^4-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^2-2*x-3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-3*x^2+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2-3,{2,3}>,
<2*x^6-3*x^5+3*x^4+x^3+x^2-2*x+3,{}>,
<3*x^6+x^5+3*x^4+3*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3-3*x^2+x+3,{2,3}>,
<3*x^6+x^5+3*x^4-3*x^3+x^2+2*x+3,{2}>,
<-x^6+x^5+3*x^4-2*x^3-x^2+2*x-3,{}>,
<3*x^6-2*x^5+x^4+x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2-x-1,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4-x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3+3*x^2+x-2,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+2*x^2-x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^4+3*x^3+x^2-2*x+3,{2,3,19}>,
<2*x^6+2*x^5-2*x^4-3*x^3-x^2+2*x-3,{2}>,
<-x^6+3*x^4+3*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-2*x^2+2,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^4+3*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-3*x^2+2,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x^2-x+3,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2+2*x+3,{2,5}>,
<3*x^6-2*x^5+x^4+3*x^3+2*x^2+x-1,{}>,
<2*x^6+x^5-2*x^4-3*x^3-x^2+2*x-3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-x^2+2*x-3,{2,37}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+x^2-3*x-1,{2,3}>,
<2*x^6-3*x^5-x^4+3*x^3-x^2-2*x-3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-2*x^2+x+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6+x^5-x^4-3*x^3-x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5+x^4+3*x^3+x^2-2*x+3,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2+2*x-3,{}>,
<3*x^6+2*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<-x^6+3*x^5-3*x^3-x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+2*x+2,{2,7}>,
<2*x^6-2*x^5+3*x^3-x^2-2*x-3,{2}>,
<-x^6+x^5-3*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-x+2,{2}>,
<-2*x^6+x^5-3*x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3-x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+2,{2}>,
<3*x^6+2*x^5+x^4-3*x^3-x-3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-2*x-1,{2}>,
<-2*x^6+2*x^5+3*x^3+x^2-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-x^4-x^3+x^2-3*x-1,{2,3}>,
<-2*x^6+3*x^5-x^4+x^3+x^2+2*x+3,{2}>,
<-x^6+2*x^5-x^4+x^3+x^2+2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+3*x+2,{2}>,
<3*x^6+2*x^5+x^4-3*x^3-3*x-2,{}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+x^2+2*x+3,{2,3}>,
<-x^6-3*x^5+x^4+3*x^3-x^2-2*x-3,{}>,
<-2*x^6+3*x^5-x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x^2-2*x-1,{2,3}>,
<3*x^6-2*x^5+x^4-x^3-x^2-2*x-3,{2,3,5}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2+2*x-2,{2}>,
<-x^6+x^5-2*x^4+x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2-2*x+3,{2}>,
<3*x^6-x^4+3*x^3+x^2-2*x+3,{2,3}>,
<3*x^6-x^5+2*x^4-x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2+x+2,{2,3}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2-x+3,{2,3}>,
<-3*x^6+2*x^5-x^4-3*x^3+x^2-x-1,{2,3}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2+x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2+x-2,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+x^2+x+3,{2}>,
<3*x^6-2*x^5+x^4-x^3-2*x^2+3,{2,3}>,
<2*x^6+2*x^4-x^3-x^2-2*x-3,{}>,
<2*x^6-x^5-x^4+3*x^3+x^2-2*x+3,{2,43}>,
<-3*x^6-x^5-x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2-x-1,{2}>,
<3*x^6+2*x^5+x^4+x^3-2*x^2-2,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+x^2+2*x-2,{2,5}>,
<-3*x^6+2*x^5-x^4-3*x^3+x^2+x+2,{2,3}>,
<-3*x^6-2*x^5-x^4+3*x^3+x^2+2*x+2,{2,3}>,
<-2*x^6+3*x^5+x^4+3*x^3-x^2-2*x-3,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+x^2+3*x+2,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-x^2+3*x-2,{2,3}>,
<3*x^6-x^5-2*x^4+3*x^3+x^2-2*x+3,{2,3}>,
<2*x^6+3*x^5+3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3-2*x^2+2,{2,3}>,
<-3*x^6-2*x^5-x^4+3*x^3+3*x-1,{2,3}>,
<-3*x^6+2*x^5-x^4-3*x^3+x^2-2*x-1,{2,3}>,
<-3*x^6+2*x^5-x^4-3*x^3+2*x^2-1,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+2*x^2+x+3,{2}>,
<-x^6-2*x^5-x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-2*x^2+x+3,{}>,
<2*x^6+x^5-2*x^4+3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-3*x^2-x-2,{}>,
<-3*x^6-2*x^5-x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+x^2+2*x+3,{2,3}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+2*x^2+2*x-2,{2}>,
<3*x^6-3*x^4+3*x^3+x^2-2*x+3,{2}>,
<-x^6+3*x^4+3*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-x^4+3*x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6+2*x^5-x^4-3*x^3+2*x^2-x-1,{}>,
<-x^6-3*x^5-2*x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-3*x^2-3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-x^2+2*x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3-2*x^2-x-1,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-x^2-2*x-3,{}>,
<3*x^6+2*x^5+x^4-3*x^3-2*x^2-x-2,{}>,
<-3*x^6-3*x^4+2*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+2*x^3-3*x^2+x+3,{2,3}>,
<-x^6-x^5+3*x^4-2*x^3-x^2+2*x-3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3-3*x^2-x-3,{2,3}>,
<-x^6-3*x^5-3*x^4-2*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-3*x^2+3*x+2,{}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5+3*x^3+3*x^2+2*x-3,{2,3}>,
<-x^6+x^5+3*x^4+3*x^3+2*x+3,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+2*x+3,{2}>,
<2*x^6+3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3+3*x^2-x-3,{2,3}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-2*x+3,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3+2*x^2+3*x-1,{2}>,
<3*x^6-2*x^5-3*x^3+2*x^2-3*x-2,{2}>,
<3*x^6+2*x^5+3*x^3+2*x^2+2*x-2,{}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x+3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+2*x-3,{2,3}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x+3,{2,3}>,
<3*x^6+2*x^4+3*x^3+2*x+3,{2}>,
<2*x^6+2*x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+2*x^2-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^3-2*x^2+3,{}>,
<3*x^6-2*x^5-3*x^3+2*x^2-3,{}>,
<3*x^6-2*x^5-3*x^3+2*x^2+x+2,{2}>,
<3*x^6-2*x^5-3*x^3+2*x^2+x-2,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+2*x-3,{2,3}>,
<3*x^6-2*x^5-3*x^3+2*x^2+x-3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-2*x+3,{2,3}>,
<3*x^6+2*x^5+3*x^3+x^2+3*x+2,{2}>,
<-3*x^6+2*x^5+3*x^3-x^2+3*x-1,{2}>,
<-3*x^6+2*x^5+3*x^3-x^2+3*x+2,{2}>,
<3*x^6+2*x^5+3*x^3+x^2+2*x+2,{2}>,
<3*x^6-2*x^5-3*x^3+x^2-2*x-1,{}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^3+x^2+x-2,{2}>,
<3*x^6+x^4+3*x^3+2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^3+x^2-1,{2}>,
<-2*x^6+x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+x^2-3,{2,3}>,
<3*x^6-x^5+x^4+3*x^3+2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^3+x^2+x+2,{2}>,
<-x^6+x^5+x^4-3*x^3-2*x+3,{2}>,
<-2*x^6+x^5+x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+x^2+x-3,{2}>,
<3*x^6-2*x^5-3*x^3+x^2+2*x-2,{2}>,
<-3*x^6+2*x^5+3*x^3-x^2-2*x+3,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^3-x^2+2*x-3,{2}>,
<2*x^6-2*x^5-3*x^3-2*x-3,{2,5,7,13}>,
<-2*x^6+2*x^5+3*x^3+2*x+3,{2,5,7,13}>,
<3*x^6-2*x^5-3*x^3-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^3-x-1,{2}>,
<-x^6-x^5-3*x^3-2*x+3,{}>,
<-3*x^6-2*x^5-3*x^3-x+2,{2}>,
<-3*x^6-2*x^5-3*x^3-x+3,{2,3}>,
<3*x^6+2*x^5+3*x^3+x-3,{2,3}>,
<3*x^6-2*x^5-3*x^3-1,{2}>,
<3*x^6+2*x^5+x^4-3*x^3-3*x^2-x-1,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^3-2,{2}>,
<-3*x^6+3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3+x-1,{2,3}>,
<3*x^6+2*x^5+3*x^3-x-2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5-x^4-3*x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x+3,{}>,
<-x^6-2*x^5-x^4-3*x^3-2*x+3,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-2*x+3,{2}>,
<-x^6+x^5-x^4+3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3-x^2-x-2,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2-1,{2}>,
<-x^6-x^4-3*x^3-2*x+3,{2}>,
<-2*x^6-x^4+3*x^3+2*x+3,{2}>,
<3*x^6+x^4+3*x^3+2*x-3,{2,3}>,
<-x^6+x^5-x^4-3*x^3-2*x+3,{2}>,
<2*x^6+x^4-3*x^3+x^2+2*x+3,{}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3+x^2-1,{2}>,
<3*x^6-x^5+x^4+3*x^3+2*x-3,{2}>,
<2*x^6-x^4-3*x^3-x^2+2*x-3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-x^2+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2+x-3,{2,3}>,
<-3*x^6-x^5-x^4+3*x^3+2*x+3,{2,3}>,
<3*x^6+2*x^5+x^4-3*x^3+x^2-x+3,{2,3}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3+x^2-x-1,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+2*x+3,{2}>,
<-3*x^6+2*x^5-x^4-3*x^3-x^2-x+2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-x^2-2*x-3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x-3,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3+x^2+2*x+3,{}>,
<-3*x^6+2*x^5-x^4-3*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5-3*x^3+x^2+3*x-1,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+x^2-2*x+3,{2}>,
<-x^6+3*x^5-x^4-3*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^3+x^2-3*x+2,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2-2*x-3,{2}>,
<-3*x^6-2*x^5-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3+2*x+3,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-2*x+3,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x-3,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+2*x-2,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^3-2*x^2-3*x-1,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+x+3,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+3*x-2,{2}>,
<-x^6-x^5-2*x^4-3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^4+3*x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^3+2*x^2-1,{2,3}>,
<-x^6-2*x^4-3*x^3-2*x+3,{2}>,
<2*x^6+2*x^4-3*x^3-2*x-3,{}>,
<3*x^6-2*x^5-3*x^3+2*x-1,{2,5}>,
<-x^6-2*x^5-3*x^4-3*x^3+x^2+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+x^2+2*x+3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2+2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x-3,{}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+x^2+2*x+3,{}>,
<-x^6-3*x^5+3*x^4-3*x^3-2*x+3,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x+3,{}>,
<3*x^6-2*x^5-3*x^3-2*x^2+2*x-2,{2}>,
<-x^6-3*x^5-2*x^4+3*x^3+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+2*x^5+3*x^3+3*x^2+3*x-1,{2,3}>,
<3*x^6-2*x^5-3*x^3-3*x^2-3*x-1,{2,3}>,
<3*x^6+2*x^5+3*x^3-3*x^2+3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x^2+2*x-2,{2,3}>,
<-x^6+3*x^5+3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3-2*x+3,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3+2*x+3,{2}>,
<-2*x^6+2*x^4+3*x^3+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^3-3*x^2-2,{}>,
<3*x^6+3*x^4-3*x^3-2*x-3,{}>,
<3*x^6-2*x^5-3*x^3-3*x^2-3,{}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3-2*x^2-3,{2,3}>,
<-3*x^6+2*x^5+3*x^3+2*x^2-x+2,{2}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-x-2,{2}>,
<3*x^6-2*x^5-3*x^3-2*x^2+x-2,{2}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-x-1,{2,3}>,
<-x^6+x^5-3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^3-2*x^2+x-3,{2,3}>,
<-2*x^6+x^5-3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-2*x^2-2*x-1,{2,3}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-2*x-1,{}>,
<3*x^6+2*x^5+3*x^3-3*x^2-2*x-1,{}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x-3,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x-3,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^3+3*x^2-3*x-2,{2,3}>,
<3*x^6+2*x^5+2*x^3+3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-2*x+3,{2}>,
<3*x^6+2*x^5+2*x^3+2*x^2+x+2,{2,3}>,
<-3*x^6+2*x^5+2*x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-2*x^3-2*x^2-x+3,{2,3}>,
<3*x^6-2*x^5-2*x^3+2*x^2-x-3,{2,3}>,
<3*x^6-2*x^4-2*x^3-2*x-3,{2,3}>,
<3*x^6+2*x^5+2*x^3+2*x^2-x+3,{2}>,
<3*x^6+2*x^5+2*x^3+2*x^2-x-3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x+3,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+x^2+2*x+3,{}>,
<3*x^6+2*x^5+2*x^3+x^2+x-1,{2}>,
<2*x^6+x^5-x^4+2*x^3+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^3+x^2-x-2,{2,7}>,
<3*x^6-2*x^5-2*x^3+x^2-x-3,{2}>,
<2*x^6-x^4+2*x^3+2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^3-2*x+3,{2,3}>,
<2*x^6-3*x^5+3*x^3+2*x+3,{2}>,
<3*x^6+2*x^5+x^4-2*x^3+3*x^2-x-3,{2,3}>,
<2*x^6+2*x^5-3*x^4+2*x^3-x^2-2*x-3,{}>,
<3*x^6-2*x^5-3*x^3-x^2-3*x+2,{2,3,5}>,
<2*x^6+3*x^5+3*x^4+2*x^3+x^2-2*x+3,{2}>,
<-3*x^6-2*x^5-3*x^3+x^2-3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2+2*x-3,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^3+2*x-3,{2}>,
<2*x^6+3*x^5+2*x^3+2*x+3,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2+2*x+3,{2}>,
<-2*x^6-3*x^5-2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^3+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^3+2*x-3,{}>,
<3*x^6+2*x^5+2*x^3+2*x-3,{2,3}>,
<-x^6+x^5+2*x^3+2*x+3,{2}>,
<-2*x^6-x^5-2*x^3-2*x+3,{2}>,
<3*x^6+x^5+2*x^3+2*x-3,{}>,
<3*x^6+2*x^5+2*x^3+x-3,{}>,
<2*x^6-2*x^3-2*x-3,{2}>,
<2*x^6+x^5-2*x^3-2*x+3,{2}>,
<-x^6-x^5+2*x^3+2*x+3,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-2*x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-2*x^5-x^4+3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5+2*x^3+3*x^2+x-3,{2}>,
<3*x^6-2*x^5-2*x^3-x^2-3*x-1,{2,3}>,
<-3*x^6+2*x^5+2*x^3+x^2+2*x-2,{2}>,
<-x^6-2*x^5+x^4-2*x^3-2*x-3,{2}>,
<-x^6+x^5-x^4+2*x^3+2*x+3,{}>,
<-3*x^6+2*x^5+2*x^3+x^2+x+2,{}>,
<3*x^6-2*x^5-2*x^3+3*x^2+x+3,{2,3}>,
<-2*x^6+x^5-x^4+2*x^3+2*x+3,{}>,
<3*x^6-2*x^5-2*x^3-x^2+x-2,{2}>,
<-3*x^6+x^5-x^4-2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^3+x^2+x+3,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x+3,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+2*x-3,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^3-2*x^2-x+2,{2,5}>,
<-3*x^6-2*x^5-2*x^3+2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5+2*x^3-x^2-3,{2,3}>,
<3*x^6-2*x^5-2*x^3-2*x^2-3*x-2,{2,3}>,
<3*x^6-2*x^5-2*x^3-x^2+x+3,{2,3}>,
<2*x^6+x^5+x^4-2*x^3-2*x-3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x-3,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3-2*x-3,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^3+2*x^2-3*x-1,{2,3,79}>,
<-3*x^6+2*x^5+2*x^3+3*x^2+3*x-1,{2,3}>,
<-x^6-3*x^5-3*x^4-2*x^3-2*x+3,{}>,
<-2*x^6-3*x^5-3*x^4-2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+2*x-3,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^3-2*x-3,{}>,
<3*x^6-2*x^5-2*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^3+x^2-2*x-2,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+2*x-3,{}>,
<3*x^6+x^5+x^4+2*x^3+2*x+3,{2,3}>,
<-x^6-x^5-3*x^4+2*x^3+2*x+3,{2,5}>,
<2*x^6-x^5+3*x^4+2*x^3+2*x-3,{2}>,
<-3*x^6-2*x^5-2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-x^3+3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-x^3-2*x+3,{}>,
<-3*x^6+2*x^5+x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5+x^3+3*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+x^3-3*x^2+2*x+3,{}>,
<3*x^6+2*x^5+x^3+3*x^2+2*x-3,{}>,
<3*x^6+2*x^5+x^3+3*x^2+x+3,{2,3}>,
<-3*x^6+x^5+3*x^4+x^3+2*x+3,{2}>,
<3*x^6+2*x^5+x^3+3*x^2+3,{}>,
<3*x^6+2*x^5+x^3+3*x^2+2,{2}>,
<-x^6+3*x^4+x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+x^3-3*x^2+2,{2,3}>,
<3*x^6+x^5+3*x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5+x^3+3*x^2-x+2,{2}>,
<-x^6-x^5+3*x^4+x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5+3*x^4+x^3+2*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-2*x-3,{2,3,53}>,
<3*x^6+2*x^5+x^3+3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3-3*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5-x^3-2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x+3,{2}>,
<3*x^6-2*x^5-x^3+2*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5+x^3+2*x^2+x-2,{2}>,
<-x^6+x^5-3*x^4+3*x^3+2*x+3,{2}>,
<3*x^6+x^5-2*x^4+x^3+2*x-3,{2}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x-3,{2}>,
<3*x^6+2*x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5+3*x^3-3*x^2+x-3,{2,3}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-3,{}>,
<3*x^6-3*x^4+3*x^3+2*x+3,{}>,
<-3*x^6+2*x^5+3*x^3+3*x^2-2,{2,3}>,
<-3*x^6-2*x^5-3*x^3+3*x^2+2,{}>,
<-3*x^6+2*x^5+x^3-2*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5-x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+x^4+2*x^3+2*x^2-3*x-1,{}>,
<-3*x^6+2*x^5+x^3-x^2+x+2,{2}>,
<3*x^6+2*x^5+x^3+x^2+x-2,{2,3}>,
<-3*x^6-2*x^5-x^3-x^2-x+3,{2,3}>,
<-3*x^6-x^5+x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3-x^2+3,{2}>,
<3*x^6-2*x^5-x^3+x^2+x-3,{2}>,
<2*x^6+2*x^5-x^4-x^3-2*x-3,{2}>,
<3*x^6+2*x^5+x^3+x^2-3*x+2,{2}>,
<-x^6+3*x^5+x^4-x^3-2*x+3,{2}>,
<3*x^6-2*x^5-x^3+x^2+3*x-2,{2}>,
<-3*x^6+x^4+2*x^3+2*x+3,{2,3}>,
<-2*x^6-x^5+x^4+2*x^3+2*x+3,{}>,
<3*x^6-2*x^5-x^3-3*x+2,{2}>,
<-3*x^6+2*x^5+x^3+3*x-1,{2}>,
<2*x^6-3*x^5-x^3-2*x-3,{2}>,
<-2*x^6+3*x^5+x^3+2*x+3,{2}>,
<-x^6+2*x^5+x^3+2*x+3,{}>,
<3*x^6+x^5-x^4-2*x^3-2*x-3,{2}>,
<3*x^6-2*x^5-x^3-2*x-3,{2}>,
<-x^6-x^5-x^3-2*x+3,{2}>,
<-2*x^6-x^5-x^3-2*x+3,{}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x+3,{2}>,
<2*x^6+x^3+2*x-3,{2}>,
<-3*x^6+2*x^5+x^3+3,{2,3}>,
<2*x^6+x^3+2*x+3,{2}>,
<-x^6-x^3-2*x+3,{2}>,
<-3*x^6+x^3+2*x+3,{2,3,23}>,
<2*x^6+x^5-x^3-2*x+3,{2}>,
<-2*x^6+x^5-x^3-2*x+3,{2,3}>,
<-3*x^6-2*x^5-x^3+3*x+2,{2,3}>,
<-3*x^6+x^5-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+x^2-3*x-1,{2,3}>,
<-x^6+3*x^5-x^4+x^3+2*x+3,{}>,
<3*x^6+2*x^5-x^3-2*x+3,{2}>,
<2*x^6-3*x^5+x^4-x^3-2*x-3,{2,3}>,
<3*x^6-2*x^5-x^3+3*x+2,{2,3,5}>,
<-2*x^6+3*x^5-x^4+x^3+2*x+3,{2}>,
<-x^6-2*x^5-x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+3*x-1,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x-3,{}>,
<3*x^6-2*x^5-x^3-x^2-2*x-2,{}>,
<-x^6-3*x^5+x^3+2*x+3,{2}>,
<-x^6+x^5-x^4+x^3+2*x+3,{2}>,
<3*x^6-x^5+x^4-x^3-2*x-3,{2,3}>,
<3*x^6-2*x^5-x^3-x^2-x-3,{2}>,
<3*x^6-2*x^5-x^3-x^2+3,{2}>,
<2*x^6+x^4-x^3-2*x-3,{2}>,
<-3*x^6-2*x^5-x^3+x^2+3*x-1,{2,3}>,
<-x^6+3*x^5-2*x^4+x^3+2*x+3,{2}>,
<-2*x^6-x^4+x^3+2*x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3+2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6-2*x^5-x^3-x^2-3,{2,3}>,
<-x^6-2*x^5-2*x^4-x^3-2*x+3,{}>,
<2*x^6+x^5-2*x^4+x^3+2*x+3,{}>,
<2*x^6+x^5+2*x^4+x^3+2*x-3,{2}>,
<2*x^6+x^5-x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+2*x^2-x+3,{2,3}>,
<3*x^6+2*x^5+x^3-x^2-x-1,{2}>,
<-3*x^6-x^5-2*x^4-x^3-2*x+3,{2}>,
<-x^6-2*x^4-x^3-2*x+3,{2,3}>,
<3*x^6-2*x^5-x^3-2*x^2-2,{2}>,
<3*x^6-2*x^5-x^3-x^2+2*x+2,{2}>,
<-3*x^6-2*x^5-x^3+2*x^2+3,{2}>,
<3*x^6+x^5-2*x^4-x^3-2*x+3,{2,3}>,
<3*x^6+2*x^5+x^3-2*x^2-x-1,{2}>,
<2*x^6-3*x^5-2*x^4+x^3+2*x+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4+x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+x^3+2*x^2-x+2,{2}>,
<3*x^6-2*x^5-x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6+2*x^5+x^3+3*x^2+3*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3-2*x+3,{2,3}>,
<-x^6+3*x^5-3*x^4+x^3+2*x+3,{2}>,
<-x^6+2*x^5+2*x^4-x^3-2*x-3,{2}>,
<-3*x^6-2*x^5-x^3+3*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5-x^3+2*x^2+3*x-2,{2,3}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x-3,{}>,
<-3*x^6+2*x^5+3*x^4+x^3+2*x-3,{2,3}>,
<-2*x^6-2*x^5-3*x^4-x^3-2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-2*x-3,{2}>,
<3*x^6-2*x^5-x^3-3*x^2-x+3,{2,19}>,
<3*x^6-2*x^5-3*x^4-x^3-2*x+3,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3-2*x-3,{2}>,
<-3*x^6+2*x^5+x^3+3*x^2+x-2,{2,3,5}>,
<-x^6-3*x^4-x^3-2*x+3,{2}>,
<-3*x^6-2*x^5-x^3+3*x^2+2,{2,3}>,
<-3*x^6+2*x^5+x^3+3*x^2+2*x-2,{2,3}>,
<-3*x^6+x^5-3*x^4-x^3-2*x+3,{2}>,
<-x^6-x^5-3*x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5+x^3-3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+2*x^5+x^3+3*x^2+x+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^3-2*x^2-2*x-2,{2,3}>,
<-x^6-3*x^5-3*x^4+x^3+2*x+3,{2}>,
<3*x^6+2*x^5+x^3-3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+2*x-3,{2}>,
<-2*x^6-x^5-3*x^4-x^3-2*x+3,{2}>,
<3*x^6-2*x^5-x^3-3*x^2+3*x-2,{}>,
<3*x^6-x^5+3*x^4-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^2-3*x+2,{2}>,
<3*x^6-2*x^5+3*x^2-x+2,{2}>,
<-3*x^6+2*x^5+x^3+3*x^2+x+3,{2,3}>,
<3*x^6+2*x^5+3*x^2+x-1,{2}>,
<3*x^6-2*x^5+2*x^2+x+2,{2,3}>,
<3*x^6+2*x^5+2*x^2-x-1,{2}>,
<-3*x^6-2*x^5-3*x^2-x+2,{2}>,
<-3*x^6+2*x^5-2*x^2-x+3,{2}>,
<-x^6-3*x^5+2*x^4+2*x+3,{2}>,
<-x^6+3*x^5+x^4+2*x+3,{2}>,
<3*x^6-3*x^4+2*x-3,{2}>,
<3*x^6+2*x^5+x^2+3*x-2,{2}>,
<2*x^6+2*x^5-x^4+2*x-3,{}>,
<-3*x^6+x^4+2*x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x+3,{2}>,
<3*x^6-x^5+x^4+2*x+3,{2}>,
<3*x^6-2*x^5-x^4-2*x-3,{2,3}>,
<2*x^6+x^5+x^4-2*x+3,{2}>,
<2*x^6+2*x^5-3*x^4-2*x-3,{2}>,
<3*x^6-2*x^5+x^2-x-2,{2}>,
<-3*x^6-2*x^5-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5+x^3-3*x^2+2,{2,5}>,
<2*x^6-3*x^5-x^4+2*x-3,{2}>,
<3*x^6+2*x^5+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x-2,{2}>,
<-3*x^6-2*x^5-x^3+3*x^2-1,{2,3}>,
<3*x^6+2*x^5+x+2,{}>,
<3*x^6+x^5-x^4+2*x-3,{2,3}>,
<-x^6-x^5-2*x+3,{2}>,
<3*x^6-2*x^5+2*x^2-x-3,{2}>,
<3*x^6-2*x^5+x+3,{2}>,
<2*x^6+2*x^5-2*x-3,{2}>,
<2*x^6+3*x^5-x^4-2*x+3,{2}>,
<2*x^6+x^5+2*x-3,{2}>,
<3*x^6-2*x^5-x^2-3*x-1,{2}>,
<2*x^6-2*x^4+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^3-3*x^2-x+3,{2,3}>,
<2*x^6-3*x^5+x^4-2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+2*x-3,{2,3}>,
<-x^6+3*x^5+x^4-2*x-3,{2}>,
<3*x^6+2*x^5-x^2+x+3,{2,5}>,
<-2*x^6-x^5-3*x^4-2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^2-x-1,{2,3}>,
<3*x^6+2*x^5-2*x^2-x-3,{2,3}>,
<-3*x^6+2*x^5+x^2+x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^2+3*x-2,{2,3}>,
<-3*x^6+2*x^5+3,{}>,
<-x^6-3*x^5+2*x^4-2*x-3,{2}>,
<-x^6+3*x^5+2*x^4-2*x-3,{}>,
<3*x^6-2*x^5-2*x^2-3*x-1,{2,3}>,
<-2*x^6-x^5-x^4-2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-2*x-3,{}>,
<2*x^6-2*x^5+3*x^4+x^3-2*x+3,{}>,
<3*x^6+2*x^5-x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-2*x-3,{2}>,
<3*x^6+2*x^5-x^2+x-3,{2}>,
<3*x^6-2*x^5+x^3+3*x^2-x+3,{2}>,
<2*x^6-x^5+3*x^4+x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^3-x+3,{2,3}>,
<3*x^6-2*x^5+x^3+3*x^2-x-1,{2}>,
<-3*x^6-2*x^5+x^2+2,{2,3}>,
<3*x^6+2*x^5+2*x^3-x-3,{2,3,5}>,
<3*x^6+3*x^4-x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^3-2*x^2-x-1,{2}>,
<3*x^6+x^4+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^3+2*x-3,{2}>,
<-3*x^6-2*x^5-2*x^3+2*x^2-x+2,{2,3}>,
<-x^6+x^5+3*x^4+x^3-2*x+3,{2}>,
<-2*x^6+3*x^4+x^3-2*x+3,{2}>,
<-3*x^6+2*x^5-x^3-3*x^2-x+2,{2}>,
<3*x^6+2*x^5+2*x^3-2*x^2+x-3,{2,5}>,
<3*x^6-2*x^5+x^3+3*x^2+2*x-2,{}>,
<3*x^6+2*x^5+2*x^3-x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+x^3-3*x^2+2*x+3,{2}>,
<-x^6+2*x^4-2*x^3-2*x-3,{2,3}>,
<3*x^6+2*x^5-x^3+3*x^2-3*x-1,{2}>,
<3*x^6-x^5+2*x^4+x^3-2*x+3,{2,3}>,
<2*x^6+2*x^4+2*x^3+2*x-3,{}>,
<-x^6-x^5+2*x^4+x^3-2*x+3,{2}>,
<3*x^6-3*x^4-x^3+2*x-3,{2,3}>,
<3*x^6+2*x^5-x^3+2*x^2+2,{2}>,
<3*x^6-2*x^5+x^3+2*x^2-1,{2,3}>,
<-3*x^6+2*x^5-x^3-3*x^2-3*x+2,{2}>,
<2*x^6-2*x^4+x^3-2*x-3,{2}>,
<3*x^6-2*x^5+x^3+2*x^2+2*x-1,{2}>,
<3*x^6+2*x^4+2*x^3+2*x-3,{2}>,
<3*x^6-2*x^4+x^3-2*x-3,{2,3}>,
<-x^6-3*x^5+2*x^4-x^3+2*x+3,{2,3}>,
<3*x^6-2*x^5+x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5-x^3-2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5-x^3+2*x^2-x+3,{2}>,
<3*x^6+2*x^5-x^3+x^2+3*x+2,{2}>,
<-x^6+x^5-2*x^4-2*x^3-2*x+3,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x+3,{2}>,
<-x^6-3*x^5+x^4+x^3-2*x+3,{2}>,
<2*x^6+x^5-2*x^4+x^3-2*x-3,{2,3}>,
<2*x^6+3*x^5-x^4-x^3+2*x-3,{2}>,
<-2*x^6-2*x^5+x^4+x^3-2*x+3,{}>,
<3*x^6-x^5+x^4-x^3+2*x+3,{2}>,
<3*x^6+2*x^5-x^3+x^2-x-1,{2,3}>,
<-3*x^6-2*x^5+x^3-x^2+x+2,{}>,
<-3*x^6-x^5+2*x^4-x^3+2*x+3,{2,3}>,
<-3*x^6+2*x^5-x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^3+x^2-x-2,{}>,
<3*x^6-x^5-x^4-x^3+2*x-3,{2}>,
<-3*x^6-x^5+x^4+x^3-2*x+3,{2}>,
<2*x^6-2*x^5+x^4-x^3+2*x+3,{}>,
<3*x^6-2*x^5+x^3+2*x^2+2*x+2,{2,3}>,
<2*x^6+2*x^5-x^4+x^3-2*x-3,{2}>,
<-2*x^6+3*x^5-x^3+2*x+3,{2}>,
<2*x^6+2*x^5-x^3+2*x+3,{}>,
<-x^6+3*x^5-x^4+x^3-2*x-3,{2}>,
<-3*x^6-2*x^5+x^3-2*x-1,{2}>,
<2*x^6-2*x^5+x^3-2*x-3,{}>,
<3*x^6+x^4+x^3-2*x+3,{2,3}>,
<3*x^6+2*x^5-x^3+2*x-3,{2,3}>,
<3*x^6-2*x^5+x^3-3*x-1,{2,3}>,
<3*x^6+2*x^5-x^3+x+2,{2}>,
<3*x^6+x^5+x^3-2*x+3,{2,3}>,
<2*x^6+x^5+x^3-2*x+3,{2}>,
<3*x^6+2*x^5-x^3+x-2,{2,3}>,
<-x^6-x^5-x^3+2*x+3,{2}>,
<2*x^6-3*x^5+x^3-2*x-3,{2}>,
<3*x^6+x^5-x^3+2*x-3,{2,3}>,
<3*x^6-2*x^5+x^3-x^2-x+2,{2}>,
<3*x^6-2*x^5+x^3-x^2-x-1,{2}>,
<3*x^6-2*x^5+x^3-x^2-x-2,{2}>,
<3*x^6-x^5+x^4+x^3-2*x-3,{2,3}>,
<3*x^6-2*x^5+x^3-x^2+2,{2}>,
<3*x^6+2*x^5-x^3+x-3,{2}>,
<3*x^6-x^5-x^4-x^3+2*x+3,{2}>,
<3*x^6+2*x^5-x^3-x^2-x-3,{2}>,
<3*x^6+2*x^5-x^3+3,{}>,
<2*x^6-2*x^5-x^4-x^3+2*x+3,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x-3,{}>,
<3*x^6+2*x^5-x^3-x^2-3*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3+2*x+3,{}>,
<2*x^6-3*x^5+x^4-x^3+2*x-3,{}>,
<-2*x^6-3*x^5-x^4-x^3+2*x+3,{}>,
<3*x^6+2*x^5-x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+x^3+x^2+3*x-2,{2}>,
<-3*x^6+2*x^5-x^3+2*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-x^3-2*x^2+3*x-2,{2,31}>,
<-x^6-x^5-2*x^4+x^3-2*x+3,{2}>,
<-x^6-2*x^5-2*x^4+x^3-2*x+3,{2}>,
<2*x^6-x^5+2*x^4+x^3-2*x-3,{2}>,
<3*x^6+2*x^5-x^3-2*x^2-3,{2,3}>,
<3*x^6+2*x^5-x^3-2*x^2+2*x-2,{2}>,
<3*x^6+x^5-2*x^4-x^3+2*x+3,{2}>,
<3*x^6-2*x^5+x^3-2*x^2+x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x-3,{2}>,
<-x^6-3*x^5-3*x^4+x^3-2*x+3,{2}>,
<-3*x^6+2*x^5-x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^3-3*x^2+3*x-2,{2}>,
<-x^6+3*x^5-2*x^4+x^3-2*x+3,{2}>,
<-3*x^6-2*x^5+x^3+2*x^2+3*x+2,{2}>,
<3*x^6-2*x^5+x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+x^3-2*x-3,{2}>,
<-x^6-x^5+3*x^4-x^3+2*x-3,{2}>,
<-x^6-x^5-3*x^4-x^3+2*x+3,{2}>,
<-3*x^6-2*x^5+x^3+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-2*x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+2*x-3,{2,3}>,
<3*x^6-2*x^5+x^3-3*x^2+x-3,{2}>,
<-3*x^6-2*x^5+x^3+3*x^2+2*x-2,{2,3}>,
<-2*x^6+2*x^5-3*x^4+x^3-2*x+3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-2*x+3,{2}>,
<3*x^6-2*x^5-x^3+2*x^2+x+3,{2}>,
<-x^6-x^5+2*x^4+x^3+2*x+3,{}>,
<-x^6-3*x^5+3*x^4+2*x^3-2*x+3,{}>,
<2*x^6-x^5-2*x^4+x^3+2*x-3,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2*x-3,{2}>,
<3*x^6-2*x^5-x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^3-3*x^2-2*x+3,{2}>,
<-x^6+2*x^5+2*x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^3+3*x^2+x+3,{2,3}>,
<-3*x^6+2*x^5-2*x^3-3*x^2+x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^3-3*x^2+2*x+3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+2*x+3,{}>,
<-3*x^6+2*x^5-2*x^3-3*x^2+2,{2,3}>,
<-x^6+3*x^5+3*x^4+2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^3-3*x^2-3*x+2,{2}>,
<3*x^6-3*x^4+2*x^3-2*x-3,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3+2*x-3,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^3+2*x^2-x-1,{}>,
<-3*x^6+3*x^4+2*x^3-2*x+3,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x-3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+2*x-3,{2}>,
<3*x^6-2*x^5+2*x^3+3*x^2+x+3,{2,3}>,
<3*x^6+2*x^5-2*x^3+3*x^2-x-2,{}>,
<3*x^6-2*x^5+2*x^3+2*x^2+x+2,{2,3}>,
<-x^6-x^5+2*x^4-2*x^3+2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^3-2*x^2-x+3,{2}>,
<2*x^6+x^5-x^4-2*x^3+2*x-3,{}>,
<3*x^6-x^4-2*x^3+2*x-3,{2}>,
<3*x^6-x^5+x^4-2*x^3+2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^3+x^2-x+2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^3-x^2+x+2,{2,3}>,
<-2*x^6-3*x^5+x^4-2*x^3+2*x+3,{2}>,
<3*x^6-2*x^5+2*x^3-3*x+2,{2}>,
<-x^6-3*x^5+2*x^3-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^3+3*x+2,{2,3}>,
<-2*x^6+3*x^5-x^4-2*x^3+2*x+3,{2,3}>,
<2*x^6-2*x^5+x^4+2*x^3-2*x-3,{2}>,
<2*x^6-x^5-x^4+2*x^3-2*x+3,{}>,
<3*x^6+2*x^5-2*x^3-x^2-3,{2,3}>,
<-3*x^6+2*x^5-2*x^3+x^2-x-1,{2}>,
<-3*x^6-2*x^5+2*x^3+x^2+2*x+2,{2}>,
<-3*x^6+2*x^5-2*x^3+x^2-3*x-2,{2}>,
<-3*x^6+2*x^5-2*x^3+x^2-3*x+2,{2,3}>,
<-2*x^6+3*x^5-2*x^4-2*x^3+2*x+3,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3-2*x-3,{}>,
<3*x^6-2*x^5+2*x^3-2*x^2-x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^3+2*x^2+3,{2,3}>,
<3*x^6+2*x^5-2*x^3-2*x^2-x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-2*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2*x+3,{}>,
<-x^6-3*x^5+3*x^4+2*x^3-2*x-3,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+2*x+3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-2*x-3,{2}>,
<3*x^6-2*x^5+2*x^3-3*x^2-x-2,{2,3}>,
<-3*x^6+2*x^5-2*x^3+3*x^2-1,{2}>,
<2*x^6+3*x^4+2*x^3-2*x-3,{}>,
<3*x^6-2*x^5-x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5+x^3+x^2+2*x-1,{2}>,
<-3*x^6+2*x^5+x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-x^3-2*x+3,{2}>,
<3*x^6+2*x^5+x^3+x^2+x+3,{2,3}>,
<2*x^6-x^5+x^4-x^3-2*x+3,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+3*x^2-2*x-2,{2}>,
<-3*x^6+2*x^5-3*x^3-3*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^3+3*x^2-x+2,{2}>,
<3*x^6+2*x^5-3*x^3+3*x^2+x-1,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-2*x-3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+3*x^2+3,{2}>,
<2*x^6-3*x^4+3*x^3-2*x-3,{}>,
<-2*x^6+3*x^4+3*x^3-2*x+3,{}>,
<3*x^6-2*x^5+3*x^3+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+3*x^2+2*x+2,{}>,
<3*x^6+2*x^5-3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+2*x^5-3*x^3-3*x^2-2*x+2,{2}>,
<3*x^6-2*x^5+3*x^3+2*x^2-3*x-1,{2}>,
<3*x^6+2*x^5-3*x^3+2*x^2+2*x+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x-3,{2,3}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3+2*x^2+x+2,{2,3}>,
<3*x^6+2*x^5-3*x^3+2*x^2+x-2,{2,3}>,
<-3*x^6-x^5+2*x^4+3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3+2*x^2+2,{2}>,
<3*x^6-2*x^5+3*x^3+2*x^2-1,{}>,
<2*x^6-2*x^4-3*x^3+2*x-3,{2}>,
<3*x^6-2*x^4+3*x^3-2*x-3,{2,3}>,
<-x^6+2*x^5+2*x^4+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^2+x-1,{2,3}>,
<-2*x^6+x^5-2*x^4+2*x+3,{2}>,
<-x^6-x^5+2*x^4-3*x^3+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^2+x+3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^3-2*x^2+3*x-1,{2,3,5}>,
<3*x^6-2*x^5+3*x^3+x^2-2*x+2,{}>,
<3*x^6+x^4+3*x^3-2*x+3,{2}>,
<3*x^6-x^5+x^4+3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3+x^2+2,{2}>,
<2*x^6-x^4+3*x^3-2*x-3,{}>,
<3*x^6+2*x^5-3*x^3+x^2+x+2,{2,3}>,
<-3*x^6-x^5+x^4-3*x^3+2*x+3,{2}>,
<-x^6+x^5+x^4-3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+x^2+2*x-2,{2}>,
<3*x^6+2*x^5-3*x^3+x^2+x-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3-2*x-3,{2}>,
<-x^6-2*x^5-3*x^4+x^3-2*x+3,{}>,
<2*x^6-2*x^5+3*x^4+x^3-2*x-3,{2}>,
<-3*x^6+2*x^5-3*x^3-x^2+x+3,{2}>,
<3*x^6+2*x^5-x^3-3*x^2+x-3,{2}>,
<-2*x^6-3*x^4+x^3-2*x+3,{}>,
<3*x^6-2*x^5+x^3-3*x^2+x+3,{2}>,
<2*x^6-3*x^5+3*x^3-2*x+3,{2}>,
<3*x^6-2*x^5+x^3-3*x^2+x+2,{2}>,
<3*x^6-x^5+3*x^3-2*x+3,{2,3}>,
<2*x^6+x^5-3*x^3+2*x+3,{}>,
<-3*x^6+2*x^5-3*x^3-2*x-1,{2}>,
<-x^6-2*x^5-3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3-x-1,{2}>,
<3*x^6-3*x^3+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3-x+2,{2}>,
<3*x^6+2*x^5-2*x^3-3*x^2-x-2,{2,3,13,19,43}>,
<-2*x^6+3*x^4-2*x^3-2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^3+3*x^2+2,{2,3}>,
<3*x^6+3*x^4+2*x^3+2*x-3,{2,3}>,
<2*x^6-x^5-3*x^4+2*x^3+2*x+3,{2}>,
<3*x^6+2*x^5-x^3+2*x^2+2*x-3,{2}>,
<-x^6-x^5+3*x^4+2*x^3+2*x-3,{2}>,
<2*x^6+x^5-x^4+3*x^3-2*x+3,{2}>,
<2*x^6+x^5+x^4+3*x^3-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3-x^2-x-2,{2}>,
<-3*x^6-2*x^5+3*x^3+x^2+x+3,{2,3}>,
<-3*x^6+2*x^5-3*x^3+2*x^2+x+3,{}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3-2*x^2+x-3,{}>,
<3*x^6-2*x^4+3*x^3-2*x+3,{}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x+3,{2,5}>,
<-x^6+3*x^5-x^4+3*x^3-2*x+3,{2}>,
<-x^6-3*x^5-2*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6-x^5-3*x^3+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x+3,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+2*x+3,{2}>,
<3*x^6+x^5+3*x^3-2*x-3,{2,3,5}>,
<-x^6+x^5-3*x^4-3*x^3+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3-3*x^2+x-3,{2}>,
<3*x^6+2*x^5-3*x^3-x-3,{2,3}>,
<-3*x^6+2*x^5-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+3*x^4-3*x^3+2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3-3*x^2-3*x-1,{2}>,
<3*x^6-2*x^5+3*x^3-3*x^2-2,{2,3}>,
<3*x^6-2*x^5-x^4-3*x^3+3*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3-3*x^2-3*x-1,{2}>,
<-3*x^6+x^5-3*x^4+3*x^3-2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+x^2+2*x-3,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^3-3*x^2-2*x-1,{}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-x^4+3*x^3+3*x^2+x-1,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+x^2-2*x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-x^2-2*x+3,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^3-2*x+3,{2}>,
<3*x^6-x^5+2*x^3-2*x+3,{2}>,
<-3*x^6+2*x^5-2*x^3+2,{2,3}>,
<3*x^6-2*x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<3*x^6-2*x^5+2*x^3+x+3,{}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x^2-x+3,{}>,
<-3*x^6+x^5+2*x^4+3*x^3-x^2+2*x+3,{}>,
<-3*x^6-2*x^5+2*x^3+3*x-2,{2,3}>,
<3*x^6-2*x^5+2*x^3+3*x+2,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^3+3*x-1,{2}>,
<-x^6+2*x^4+3*x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^3-3*x-1,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x^2+2,{2,5}>,
<2*x^6+x^5-2*x^4-3*x^3+x^2-2*x-3,{}>,
<3*x^6+2*x^5-x^4+3*x^3+2*x^2-x-2,{2}>,
<-2*x^6+2*x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3-2*x^2-x+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+2*x^2+x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+2*x^2-2*x-2,{2,7}>,
<3*x^6-2*x^5-x^4-3*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+3*x-2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+2*x^2+x+3,{2}>,
<-x^6-x^5+2*x^4+3*x^3-x^2+2*x+3,{}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2-2*x+2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2-3*x-1,{2,3}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+2*x-1,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+3*x+2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2-2*x-2,{2,3}>,
<-3*x^6+2*x^5-3*x^3-3*x-2,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+x^2-1,{2,3,7}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+2*x+3,{}>,
<-2*x^6+x^4+3*x^3-x^2+2*x+3,{2}>,
<2*x^6-x^5+x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2-3,{2}>,
<3*x^6-x^5+x^4+3*x^3-x^2+2*x+3,{2}>,
<-x^6+x^5+x^4+3*x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+x^2-x-1,{2,3}>,
<2*x^6+x^5-x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5+3*x^3+3*x-2,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3-x^2+x+2,{2}>,
<-x^6-3*x^5-x^4+3*x^3-2*x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x+3,{2}>,
<-2*x^6-x^5+x^4+3*x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3-x^2-x-3,{2}>,
<-x^6-3*x^5-x^3+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2+2*x+2,{2}>,
<3*x^6-2*x^5+x^3+3*x-2,{}>,
<3*x^6-2*x^5+3*x^3-x^2+2,{2}>,
<-x^6-3*x^5-x^4+x^3-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x-3,{2}>,
<3*x^6-2*x^5+x^3-x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5+3*x^3-x^2+x+3,{2,3}>,
<-x^6+2*x^5+x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-x-1,{}>,
<3*x^6+2*x^5-x^4+3*x^3+x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-x+2,{2,3}>,
<2*x^6-2*x^5-x^4+3*x^3+x^2+2*x-3,{2}>,
<-2*x^6-x^5-3*x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+3*x+2,{2}>,
<3*x^6-2*x^5+x^3-x^2-2*x-2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+x+3,{2,3}>,
<-3*x^6+2*x^5+x^4+3*x^3+2*x-2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+x-1,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3+x+3,{2,3}>,
<3*x^6-x^5-x^4+x^3-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-2*x+2,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-3*x+2,{2}>,
<-x^6+3*x^5-3*x^3+x^2-2*x-3,{}>,
<3*x^6-x^5-3*x^3-x^2-2*x+3,{2,3,7}>,
<-2*x^6-3*x^5-x^4-3*x^3-x^2-2*x+3,{}>,
<3*x^6+2*x^5-x^4+3*x^3-3*x-1,{0,2}>,
<-3*x^6-2*x^5+x^4-3*x^3+x^2-2*x-3,{2}>,
<2*x^6-3*x^5+3*x^3+x^2+2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3-x-2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-x^2-2*x+3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+x^2-2*x-3,{2}>,
<2*x^6-x^5-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-x^2+2*x-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2+2*x-3,{}>,
<-3*x^6+2*x^5+x^4+3*x^3+x-1,{2,3}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+2*x-3,{2}>,
<2*x^6+x^5+x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-x^2-2*x-2,{2}>,
<-2*x^6+x^5-x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+x^2-x+3,{2}>,
<-2*x^6+x^4+3*x^3+x^2+2*x-3,{2}>,
<2*x^6-x^4-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+x^2-x-1,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+x^2-x+2,{2}>,
<3*x^6+x^5+x^4-3*x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+x^2-x-3,{2,3,5}>,
<3*x^6-2*x^5-x^4-3*x^3-x^2+x-3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+x^2-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-x^2-2*x-1,{2}>,
<-x^6-x^4+3*x^3-x^2+2*x+3,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-x^2-2*x+3,{2}>,
<2*x^6+x^4+3*x^3+x^2+2*x-3,{2}>,
<-x^6+3*x^5-x^4-3*x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^5+x^4-3*x^3+x^2-2*x-3,{2}>,
<3*x^6+x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-x^2-x+3,{2,3,5}>,
<3*x^6-2*x^5-x^4-3*x^3-x^2+x+2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+2*x^2-x-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-2*x^2+x-1,{2,3}>,
<-3*x^6-x^5-2*x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-3*x^6+2*x^4-3*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-2*x^2-x-2,{2,3}>,
<-3*x^6+2*x^5+x^4+3*x^3+2*x^2+2,{2,3}>,
<3*x^6-x^5+2*x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-2*x^2+x+3,{2}>,
<2*x^6-3*x^4-3*x^3+x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+2*x^2-x-2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+2*x^2+2*x-1,{0,2}>,
<3*x^6-2*x^5-x^4-3*x^3-2*x^2+2*x-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^3+3*x^2-2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3+3*x^2+x+2,{2,3}>,
<2*x^6+x^5+2*x^4-3*x^3+x^2-2*x-3,{2,5}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-x^2-2*x+3,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+2*x-3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3-2*x^2-x-1,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5+3*x^3+x^2+3*x+2,{2,3}>,
<-x^6+3*x^5-x^4+3*x^3-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^3+x^2-3*x-1,{2}>,
<3*x^6+2*x^5-3*x^3+x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+3*x^2-1,{2}>,
<-x^6-3*x^4-3*x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2-2,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5-2*x^3+3*x^2-2*x-3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+2*x-3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^2-x+2,{2}>,
<-3*x^6+2*x^5-2*x^3+3*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x-1,{0,2}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2+3*x+2,{0,2}>,
<-3*x^6+2*x^5+x^4+3*x^3+3*x^2-3*x-1,{0}>,
<3*x^6-2*x^5-x^4-3*x^3-3*x^2+3*x-2,{2,7}>,
<3*x^6-2*x^5-x^4-2*x^3+3*x^2-3*x-1,{2,3,11}>,
<-3*x^6-2*x^5+3*x^4-2*x^3-x^2-2*x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-x^2-2*x+3,{2,3}>,
<2*x^6+x^5-3*x^4+2*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3+3*x^2-x-2,{2}>,
<3*x^6-2*x^5-x^4-2*x^3+3*x^2-3,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3-x^2+2*x+3,{}>,
<-3*x^6-x^5+3*x^4+2*x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4+2*x^3+3*x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6+3*x^5-3*x^4-2*x^3+x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+2*x^2+x+3,{2,3}>,
<3*x^6+2*x^5-x^4+2*x^3+2*x^2+x-1,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3-2*x^2+x+2,{2,3}>,
<3*x^6-2*x^5-x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2+2*x+3,{2,3}>,
<-x^6-3*x^5-x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x^3-3*x^2-x+2,{2,3}>,
<3*x^6+2*x^5-x^4+3*x^3-3*x^2-x-1,{2,3}>,
<2*x^6-x^5+3*x^4+3*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-x^4-2*x^3+x^2+x-1,{}>,
<-3*x^6+2*x^5+x^4+2*x^3-x^2-x+2,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3-x^2+x+3,{2,3}>,
<-3*x^6-x^5-3*x^4-3*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^4-3*x^3+x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5+x^4-3*x^3-1,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3-x+2,{2}>,
<3*x^6-2*x^5-x^4-3*x^3-1,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-x+3,{2,3}>,
<2*x^6-x^5+2*x^3+x^2+2*x-3,{2}>,
<2*x^6-3*x^3+x^2-2*x-3,{2}>,
<-2*x^6-x^5+2*x^3-x^2+2*x+3,{2}>,
<-2*x^6-3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3+x-3,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2-2*x+3,{}>,
<2*x^6-3*x^5+2*x^3-x^2+2*x+3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5+x^4+2*x^3-3*x-1,{2}>,
<3*x^6-3*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-x^2+3*x+2,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-x^2-2*x-2,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+x^2+x-2,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+x^2+3*x-1,{2,3}>,
<-x^6-x^5+x^4-2*x^3+x^2-2*x-3,{2}>,
<-x^6-x^5-x^4-2*x^3-x^2-2*x+3,{2}>,
<2*x^6-x^5+x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-x^2-3*x-1,{2,3}>,
<-3*x^6+x^5-x^4+2*x^3-x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+x^4-2*x^3+2*x^2-3*x-2,{2,3}>,
<-3*x^6-x^4-2*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5+x^4+2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-2*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-x^6+x^5-x^4-2*x^3-x^2-2*x+3,{2,3}>,
<-2*x^6+x^5-x^4-2*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3+x^2+3*x-1,{2,3}>,
<-x^6+x^5-2*x^4-2*x^3-x^2-2*x+3,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-x^2+2*x+3,{}>,
<-3*x^6-3*x^4-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^2-x-2,{2}>,
<3*x^6+2*x^5-3*x^2-x-3,{2,3}>,
<-3*x^6+2*x^5+x^4+2*x^3+3*x^2+x-3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+3*x^2+x+2,{2,3}>,
<-2*x^6+x^5-3*x^4+2*x^3-x^2+2*x+3,{2}>,
<-3*x^6+3*x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6+x^5+3*x^4-2*x^3+x^2-2*x-3,{0,2}>,
<-3*x^6+x^5-3*x^4-2*x^3-x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4+2*x^3-3*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x^2+3*x-2,{2,3}>,
<-x^6-3*x^5+3*x^4-x^3-x^2-2*x+3,{}>,
<2*x^6+2*x^5+3*x^4+x^3-x^2+2*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+x^2+2*x-3,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+2*x^2-x-2,{2,3,5}>,
<3*x^6+x^5-2*x^4-2*x^3+x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-x^3-x^2-2*x+3,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^3+2*x^2+2*x-3,{2,3}>,
<-2*x^6-x^5+3*x^4-x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+2*x^2-3*x+2,{2,3,5}>,
<3*x^6+x^5-3*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3+3*x^2+x-3,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3+3*x^2+3,{2}>,
<-3*x^6+3*x^4-x^3-x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4+x^3+3*x^2-x-1,{2}>,
<-3*x^6-2*x^5+x^4-x^3-3*x^2+x+2,{}>,
<-3*x^6-2*x^5+x^4-2*x^3-x^2-3*x-2,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-x^2+2*x+3,{2}>,
<-x^6-2*x^5+x^4-2*x^3-x^2-2*x+3,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-x^2-2*x+3,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+x^2+x-1,{2,3}>,
<-x^6-2*x^5+3*x^4+x^3-x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^3+x^2-x-2,{}>,
<-3*x^6+2*x^5+x^4+x^3-3*x^2-2*x+3,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+x^2+2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3-x^2-x+3,{}>,
<-3*x^6-2*x^5+x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+x^2+x-3,{}>,
<2*x^6+2*x^5-2*x^4+x^3+x^2+2*x-3,{}>,
<2*x^6+x^5-2*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3+x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5-x^4+x^3+2*x^2+2*x-2,{}>,
<2*x^6+x^5+x^4-2*x^3-x^2-2*x+3,{2}>,
<-3*x^6-x^5+2*x^4-x^3-x^2-2*x+3,{2,3}>,
<-2*x^6+2*x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^4+x^3+x^2+2*x-3,{2,3}>,
<2*x^6+3*x^5-2*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3+2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5-x^4+x^3+2*x^2-3*x-2,{2}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2+x-3,{2,3}>,
<2*x^6+3*x^5+x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2+2*x+2,{2}>,
<-3*x^6+2*x^5+x^4+x^3-x^2+3*x-1,{2}>,
<3*x^6-2*x^5-x^4-x^3+x^2-3*x-1,{}>,
<2*x^6-2*x^5-2*x^4+x^3+x^2+2*x-3,{}>,
<-3*x^6+2*x^5+x^4+x^3-x^2+3*x+2,{}>,
<-x^6+2*x^5+x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5-x^4-x^3+x^2-2*x-2,{2,3}>,
<3*x^6-x^5+2*x^4-x^3-x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4-x^3+2*x^2+3*x-1,{2,3}>,
<-3*x^6+2*x^5+x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3+2*x^2+x+2,{2,3,5}>,
<3*x^6-x^5+x^4-x^3-x^2-2*x+3,{2,3}>,
<-x^6-x^5+x^4-x^3-x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5+x^4-x^3-x^2-x+2,{2,3}>,
<-x^6+x^5+2*x^4+x^3-x^2+2*x+3,{2}>,
<-2*x^6+x^5+x^4+x^3-x^2+2*x+3,{2}>,
<-x^6-3*x^5-x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-x^3+x^2+3*x-1,{}>,
<3*x^6-2*x^5-x^4-x^3+x^2+2,{2}>,
<3*x^6-2*x^5-x^4-x^3-x-1,{2}>,
<-2*x^6+3*x^5+x^3+x^2+2*x-3,{2,7}>,
<-x^6+x^4-x^3-x^2-2*x+3,{2}>,
<3*x^6+x^5+x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3+3*x-1,{2}>,
<3*x^6+2*x^5-3*x^3-3*x^2+x+2,{2}>,
<-3*x^6-2*x^5+x^4-x^3-x^2+2,{2}>,
<-3*x^6+2*x^5+x^4+x^3+3*x+2,{2,3}>,
<-2*x^6-x^5+x^3-x^2+2*x+3,{2}>,
<3*x^6+x^5-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3+3,{2}>,
<2*x^6+2*x^5-x^3-x^2-2*x+3,{2}>,
<2*x^6-x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x-2,{2,3}>,
<-x^6+3*x^5-x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+x^2-3*x-2,{2}>,
<3*x^6-2*x^5-x^4-x^3-2,{2,3}>,
<-x^6-2*x^5-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2+3*x-1,{2}>,
<-3*x^6+2*x^5+x^4+x^3-x^2+3,{2,3}>,
<3*x^6+2*x^5-x^4+x^3-3,{2}>,
<-2*x^6-3*x^5-x^4-x^3-x^2-2*x+3,{2}>,
<-x^6+2*x^5+x^3-x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+x^4-x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-x^3-2*x+2,{}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2+2*x+3,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-x^3+x^2-3,{2,3,5}>,
<2*x^6-2*x^5-x^4-x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4-x^3-2*x-2,{}>,
<3*x^6-x^5+x^3-x^2+2*x+3,{}>,
<-3*x^6-2*x^5+x^4-x^3+x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2+2*x-1,{}>,
<-2*x^6+x^5+x^4-x^3-x^2-2*x+3,{2}>,
<2*x^6-2*x^5+x^4-x^3+x^2-2*x-3,{2}>,
<2*x^6-x^5+x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x+2,{2,3}>,
<-3*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2-x-1,{2}>,
<2*x^6-x^5+x^4+x^3+x^2+2*x-3,{2}>,
<-x^6+x^5-x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2+x-2,{2}>,
<3*x^6+2*x^5-x^4-x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^5+x^4-x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+x^3+x^2-2*x-1,{2}>,
<3*x^6-2*x^5-x^4-x^3-x^2+3*x+2,{}>,
<-3*x^6-2*x^5+x^4-x^3+x^2-x+3,{2,3}>,
<-x^6+3*x^5+x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6+x^5-x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2+x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-x^3-2*x^2-3*x+2,{2}>,
<-x^6-x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2+x-1,{2}>,
<3*x^6-2*x^5-x^4-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2-2*x-2,{}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2-x+2,{2}>,
<-3*x^6+2*x^5+x^4+x^3+2*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2-2,{2}>,
<-2*x^6-x^5-2*x^4-x^3-x^2-2*x+3,{2}>,
<-x^6+3*x^5-2*x^4+x^3-x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2-x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2+2,{}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2-3*x+2,{2}>,
<3*x^6-2*x^5-x^4-x^3-2*x^2-2*x+2,{}>,
<3*x^6+x^4+x^3+x^2+2*x-3,{2}>,
<-x^6+2*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+x^3+3*x^2+2*x-1,{2}>,
<3*x^6-2*x^5-x^4-x^3-2*x^2-1,{2}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-x^2-x+3,{2,3}>,
<-2*x^6+2*x^5-3*x^4+x^3-x^2+2*x+3,{2}>,
<2*x^6-x^5+3*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6-3*x^4+x^3-x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2+2,{2}>,
<-3*x^6-2*x^5+x^4-x^3+3*x^2-2,{2}>,
<-3*x^6-2*x^5+x^4-x^3+3*x^2-1,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-3,{2}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2-x+2,{2}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2-x-3,{2}>,
<-x^6+x^5+3*x^4-x^3+x^2-2*x-3,{0,2}>,
<-2*x^6+x^5-3*x^4-x^3-x^2-2*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2+2*x-1,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2+2*x-2,{2}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2-x-3,{2,5}>,
<3*x^6-2*x^5-x^4+3*x^2+x-1,{2,3}>,
<-3*x^6+2*x^5+x^4-3*x^2-x+3,{2,3}>,
<2*x^6-3*x^5+3*x^4-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^2+3*x-1,{}>,
<2*x^6+3*x^5-3*x^4+x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+2*x^2+x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^2+3*x-1,{2,11}>,
<3*x^6-x^5-2*x^4-2*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^2-2*x-3,{}>,
<2*x^6+x^5+2*x^4+2*x^3+x^2+2*x-3,{}>,
<-2*x^6-x^5-2*x^4-2*x^3-x^2-2*x+3,{}>,
<3*x^6+2*x^5-x^4+2*x^2+x-2,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4+x^2-2*x-3,{}>,
<-3*x^6-2*x^5+x^4-2*x^2-x+3,{2}>,
<2*x^6-3*x^5+2*x^4-x^2+2*x+3,{2}>,
<-2*x^6-3*x^5+x^4-x^2-2*x+3,{2}>,
<2*x^6+x^5+x^4-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^2+x+2,{2}>,
<-3*x^6+x^5-x^2+2*x+3,{2}>,
<2*x^6+x^5-x^2-2*x+3,{}>,
<-2*x^6+3*x^5+x^4+x^2+2*x-3,{}>,
<2*x^6-3*x^5-x^4-x^2-2*x+3,{}>,
<-3*x^6-2*x^5+x^4+x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4-x^2-2*x+3,{}>,
<-3*x^6+2*x^5+x^4+x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5-x^4-x^2-x-1,{2,3}>,
<3*x^6-2*x^5-x^4-x^2-x-2,{2}>,
<3*x^6+x^5-x^4-x^2-2*x+3,{2,3}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-x^2-2*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4+3*x^3+2*x^2+x-3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+x^5-2*x^4-x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4+x^2+2*x-3,{}>,
<3*x^6+2*x^5-x^4-2*x^2-3*x-2,{2,3}>,
<3*x^6-2*x^5-x^4-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2-2*x+3,{}>,
<-x^6+3*x^5+3*x^4+2*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x^2-3*x-1,{}>,
<2*x^6-3*x^5+3*x^4-2*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+2*x^3-3*x^2+2*x+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-2*x^3+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2+3*x-2,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5-x^4+x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-x^4-x^3+3*x^2+x-1,{2,3}>,
<3*x^6+2*x^5-x^4+3*x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5-x^4+x^3+3*x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4-x^3+3*x^2-1,{2}>,
<3*x^6+2*x^5-x^4+3*x^2+x+3,{}>,
<-3*x^6+2*x^5+x^4-x^3-3*x^2+2,{2,11}>,
<-3*x^6+2*x^5+x^4-x^3-3*x^2+3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2-2*x+3,{2,3}>,
<2*x^6+x^5+3*x^4+x^3-x^2-2*x+3,{2}>,
<2*x^6-x^5-3*x^4-x^3+x^2+2*x-3,{2}>,
<-2*x^6-x^5+3*x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6-x^5-3*x^4-x^3+x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^3-3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-x^2+2*x+3,{2}>,
<-x^6-3*x^5-2*x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3+3*x^2-2*x-1,{2,3}>,
<2*x^6+3*x^5+2*x^3+x^2+2*x-3,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3+3*x^2-3*x-1,{2,3}>,
<-3*x^6+2*x^5+x^4-x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+x^3-2*x^2-3*x+2,{2}>,
<3*x^6-x^5-3*x^4-x^3-x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5+x^4+x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3-x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+2*x^4+x^2-2*x-3,{}>,
<-3*x^6+2*x^5+x^4+2*x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3+x^2+2*x-3,{2,3}>,
<-2*x^6-x^5+3*x^4-x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4-2*x^2+3*x-2,{2}>,
<-3*x^6+x^5+2*x^4-x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-2*x^2+x+2,{2}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-x+2,{2}>,
<3*x^6-x^5-2*x^4-x^3-x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4+x^3+2*x^2+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-3*x^2+x-1,{2,3}>,
<-3*x^6+2*x^5+x^4+2*x^2+x-1,{2}>,
<3*x^6+2*x^5-x^4-x^3+2*x^2+2,{2}>,
<-x^6+x^5-2*x^4-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+x^3-2*x^2+x+2,{2,7}>,
<2*x^6-2*x^4-x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4-x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5+2*x^4+x^2-2*x-3,{2,3}>,
<2*x^6-x^5-2*x^4-x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3+2*x^2+x-2,{2,3}>,
<3*x^6-2*x^5-x^4-2*x^2+x-2,{2}>,
<-3*x^6-2*x^5+x^4-x^3+2*x^2-x-1,{2}>,
<3*x^6-x^5-2*x^4-x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3+2*x^2+2*x+2,{}>,
<-2*x^6+3*x^5+x^4-x^3-x^2+2*x+3,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+x^2+2*x-3,{2}>,
<-x^6+2*x^5+x^4-x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5+x^4+x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+x^3-2*x^2+3*x-1,{2,3}>,
<-2*x^6-x^5+x^4+x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3+2*x^2-x+3,{2,5}>,
<3*x^6+x^5-x^4-x^3+x^2+2*x-3,{2}>,
<-x^6-3*x^5-x^4-x^3+x^2+2*x-3,{}>,
<3*x^6-2*x^5-x^4+x^3+x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5-x^4+x^3+x^2-x-3,{2}>,
<-2*x^6-3*x^5+x^4-x^3-x^2+2*x+3,{2,7}>,
<3*x^6-2*x^5-x^4+x^3-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3+x^2+3,{2}>,
<2*x^6+2*x^5-x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3+x^2+x+2,{}>,
<3*x^6+2*x^5-x^4-x^3+2*x-2,{2}>,
<3*x^6-x^5-x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-x^3+x^2-x-1,{2}>,
<-3*x^6+x^5+x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3+x+2,{2,3}>,
<3*x^6+2*x^5-x^4-x^3-2*x+2,{2}>,
<-x^6+x^5-x^3-x^2+2*x+3,{2}>,
<-x^6+2*x^5+x^3+x^2-2*x-3,{2}>,
<2*x^6+3*x^5+x^4-x^3+x^2+2*x-3,{2}>,
<-x^6-3*x^5-2*x^4+x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-x^2+2*x+3,{2}>,
<2*x^6-x^5+x^3+x^2-2*x-3,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x^2+2*x-3,{2}>,
<-x^6-3*x^5-x^3+x^2+2*x-3,{2}>,
<-3*x^6-2*x^5+x^4-x^3+3*x^2-3*x-2,{}>,
<2*x^6+3*x^5+x^3+x^2-2*x-3,{}>,
<-2*x^6+x^5-x^4+x^3-x^2-2*x+3,{2}>,
<3*x^6-x^5+x^4-x^3+x^2+2*x-3,{}>,
<3*x^6-2*x^5-x^4+x^3-x-2,{2}>,
<3*x^6-2*x^5-x^4+x^3+3*x-2,{}>,
<3*x^6+2*x^5-x^4-x^3-x^2-x-3,{}>,
<3*x^6-2*x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+x^4-x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5-x^4-x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-x^3+x^2-3*x-2,{2,3}>,
<3*x^6-2*x^5-x^4+x^3-x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-x^4-x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-x^3+x^2-3*x+2,{2}>,
<3*x^6+2*x^5-x^4-x^3+2,{2,3}>,
<-3*x^6-2*x^5+x^4-x^3+3*x^2-3*x-1,{2,3}>,
<-x^6-3*x^5+x^4+x^3+x^2-2*x-3,{2}>,
<3*x^6+x^5-x^4-x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-x^3-2*x^2+3*x+2,{2,3}>,
<-x^6+x^5-x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+x^3-2*x^2-3*x-2,{2}>,
<3*x^6+2*x^5-x^4-x^3-2*x^2+2*x+2,{}>,
<-3*x^6+2*x^5+x^4-x^3+x^2+x+2,{2}>,
<-x^6-3*x^5+2*x^4+x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4-x^3-2*x^2-x-1,{2}>,
<3*x^6-x^4-x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-x^3+2*x^2-x+2,{2}>,
<3*x^6-2*x^5-x^4+x^3-2*x^2-3*x-1,{2,3,7}>,
<3*x^6+2*x^5-x^4-x^3-x^2-x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x^2-2*x-3,{}>,
<-3*x^6+2*x^5+x^4-x^3+x^2-x-1,{2,3}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2+x+2,{2,3}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2-x-1,{2,3}>,
<3*x^6+x^5-3*x^4+x^3-x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2+x-2,{2}>,
<-2*x^6+x^5-3*x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2-x-1,{2}>,
<-3*x^6+2*x^5+x^4-x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4+x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2+x-3,{2,3}>,
<-x^6-3*x^4+x^3-x^2-2*x+3,{2,3}>,
<-2*x^6-3*x^4+x^3-x^2-2*x+3,{2}>,
<3*x^6+3*x^4-x^3+x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2-3,{2,3}>,
<-x^6-3*x^5+3*x^4-x^3+x^2+2*x-3,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-2*x^3+3*x^2+x+2,{2,3}>,
<3*x^6-2*x^5-x^4+2*x^3+3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3-3*x^2+x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^3+3*x^2+x-1,{2}>,
<-3*x^6-2*x^5+x^4+2*x^3-3*x^2+x+2,{2}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-x^2+2*x+3,{2,3}>,
<3*x^6+x^5-x^4+x^2+2*x-3,{2,3,17}>,
<3*x^6+2*x^5-x^4+x^2-3,{}>,
<-x^6+3*x^5-x^4+x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-x^4-2*x^3+2*x^2+x+3,{2}>,
<-x^6-3*x^5+x^2-2*x-3,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4+3*x-2,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-x^2+2*x+3,{2,3}>,
<2*x^6-x^5+2*x^4-2*x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-x^4-2*x^3+x^2-3*x+2,{}>,
<-x^6+3*x^5-x^4+2*x^3+x^2-2*x-3,{2}>,
<-x^6+3*x^5+x^4+2*x^3-x^2-2*x+3,{}>,
<-x^6+3*x^5-2*x^4+2*x^3+x^2-2*x-3,{2,13}>,
<-3*x^6+2*x^5+x^4-2*x^3-x^2-3*x+2,{2}>,
<2*x^6+x^5-2*x^3-x^2+2*x+3,{}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-x^2-2*x+3,{}>,
<2*x^6+x^5+2*x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^5+x^4-2*x^3-x^2+2*x+3,{}>,
<-2*x^6-3*x^5-2*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3-x^2+3*x-1,{}>,
<2*x^6-3*x^5-2*x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4-2*x^3+x^2+3*x-1,{}>,
<3*x^6-2*x^5-x^4+2*x^3-x^2-3*x-2,{2}>,
<3*x^6-x^5+x^4+2*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6-x^5-x^4+2*x^3-x^2-2*x+3,{2}>,
<3*x^6+x^5-x^4+2*x^3-x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5+x^4-2*x^3+x^2-x-1,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-x^2+x-3,{2,3}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-x^4-2*x^3+x^2-x+3,{2}>,
<-x^6-3*x^5-2*x^4+2*x^3-x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+2*x^3+2*x^2+x-2,{2,3}>,
<2*x^6-3*x^5+2*x^4+2*x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-2*x^2+x-2,{2,3}>,
<-2*x^6+x^5-2*x^4-2*x^3-x^2+2*x+3,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x^2-2*x+3,{}>,
<-3*x^6-2*x^5+x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-x^2-2*x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+2*x^3+2*x^2+3*x+2,{2}>,
<3*x^6-2*x^5-x^4+2*x^3-3*x^2-x-2,{}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2+x+3,{2}>,
<3*x^6+2*x^5-x^4-2*x^3-3*x^2-3,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-x^4-2*x^3-3*x^2+x-1,{2,3}>,
<-x^6+x^5-3*x^4+2*x^3-x^2-2*x+3,{}>,
<3*x^6+2*x^5-x^4-2*x^3-3*x^2-x-2,{}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2-x+3,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+x^2-2*x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3-3*x^2-x+2,{2}>,
<-3*x^6+2*x^5+x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2-2*x+3,{2}>,
<2*x^6+3*x^4+3*x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-3*x^2+3*x+2,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+3*x^2+3*x+2,{2,3}>,
<-3*x^6-2*x^5+x^4+3*x^3-3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+3*x^2-1,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3+x^2-2*x-3,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+2*x^2+3,{2,3,7}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2-2*x+3,{}>,
<3*x^6+2*x^5-x^4-3*x^3+2*x^2+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+x^2+2*x-3,{2}>,
<2*x^6-2*x^4-3*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4+x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3+2*x^2+x-3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3-2*x^2+2*x-1,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2-2*x-3,{2,3}>,
<2*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x+3,{2,5}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2+x-1,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-2*x^2-3*x-1,{2}>,
<2*x^6-x^5-x^4+3*x^3+x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3+2*x^2+3*x-1,{}>,
<-3*x^6-2*x^5+x^4+3*x^3-x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-x^2-3*x+2,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3+2*x^2+3*x-2,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+3*x+2,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3+3*x-1,{}>,
<3*x^6-2*x^5-x^4+3*x^3+x^2+3,{2}>,
<2*x^6-3*x^5+3*x^3+x^2-2*x-3,{}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^3-x^2+2*x+3,{}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-2*x+2,{2}>,
<3*x^6-x^5-x^4-3*x^3+x^2+2*x-3,{2,3}>,
<2*x^6+x^5+x^4-3*x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-3*x^3+x+3,{}>,
<3*x^6-2*x^5-x^4+3*x^3+x^2+x-3,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2-2*x+3,{2}>,
<2*x^6-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-x^3+2*x^2-x+3,{2,3}>,
<-x^6+3*x^5-3*x^4-x^2+2*x+3,{2}>,
<-x^6-2*x^5-x^4-3*x^3+x^2+2*x-3,{2}>,
<3*x^6+2*x^5-x^4-3*x^2+x+3,{}>,
<-3*x^6-2*x^5+x^4+x^3+2*x^2+2*x-2,{2}>,
<3*x^6+2*x^5-x^4-x^3-2*x^2-2*x-2,{2,5}>,
<-x^6-x^5+3*x^4+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-x^4+x^3-3*x^2-3*x+2,{2}>,
<3*x^6-x^5-3*x^3-x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<3*x^6+2*x^5-x^4-3*x^3-x+2,{2}>,
<-x^6-x^5-3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+x-1,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3+x-3,{2,3}>,
<-3*x^6-2*x^5+x^4+x^3+3*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+x^4+3*x^2-x+3,{2}>,
<2*x^6-x^5-3*x^3+x^2+2*x-3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2+2*x-3,{2}>,
<-2*x^6+x^5+3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3+3*x-1,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2-3*x-1,{2}>,
<2*x^6+3*x^5+x^4-3*x^3+x^2+2*x-3,{}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3-x+3,{2}>,
<-x^6-2*x^5+x^4+3*x^3+x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-x^2-2*x+3,{}>,
<-3*x^6+2*x^5+x^4-3*x^3-2*x-2,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2-x+2,{2}>,
<-2*x^6+x^5-x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-x^4+3*x^3-x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3+2*x-2,{2,3}>,
<-3*x^6-x^5-3*x^4-x^2+2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2+x+3,{2,3}>,
<-2*x^6+2*x^5+3*x^4-x^3+x^2+2*x-3,{2}>,
<-x^6+x^5-x^4+3*x^3-x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+x^2+x+3,{2}>,
<2*x^6-x^5+x^4-3*x^3+x^2+2*x-3,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-x^2-2*x+3,{2}>,
<-x^6+2*x^5-x^4+3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-x^2-x-3,{2,3}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2+2*x+3,{2}>,
<-x^6+x^4+3*x^3+x^2-2*x-3,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+x^2-2*x-3,{2}>,
<3*x^6+2*x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-2*x^2-x-2,{2}>,
<3*x^6+2*x^5-x^4-3*x^3-2*x^2-3*x-2,{2,3}>,
<-3*x^6-x^5-3*x^4+3*x^3-x^2-2*x+3,{2}>,
<-x^6-3*x^4+3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^4+3*x^3-x^2-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+x^2-2*x-3,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3+3*x^2+3,{2}>,
<-3*x^6-2*x^5+x^4+3*x^3+3*x^2+2*x-2,{2,23}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+x^2+2*x-3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-3*x^2-2*x-1,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-3*x^2+x+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^4+3*x^3-x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-x^2-2*x+3,{}>,
<-x^6-x^5+3*x^4-3*x^3+x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+3*x^2-3*x+2,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-2*x^2+x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3-x^2-2*x+3,{2,5}>,
<2*x^6+2*x^5+2*x^4+3*x^3+x^2-2*x-3,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-x^2+2*x+3,{}>,
<-3*x^6-2*x^5+x^4+3*x^3+3*x^2+x+3,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+3*x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2-2*x+3,{2}>,
<3*x^6-2*x^5-x^4+3*x^3-3*x^2+x-3,{2,3}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x-3,{2,3,11}>,
<-3*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5-x^4+3*x^3-3*x^2-x-2,{2,3}>,
<3*x^6+2*x^5-x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4-3*x^3-2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5+2*x^4+3*x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-x^5+3*x^4+3*x^3-2*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-2*x^2-x-1,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+2*x^2+x-1,{2,3}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4+3*x^3+2*x^2-1,{2}>,
<-2*x^6+2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^4+3*x^3+2*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^4+3*x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4+3*x^3+2*x^2-x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-2*x^2+x+2,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x-1,{0,2,3}>,
<2*x^6-2*x^5-2*x^4+3*x^3+2*x^2+2*x-3,{}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x^2+2*x-3,{2,3}>,
<2*x^6-3*x^5+x^4-3*x^3-2*x^2-2*x+3,{}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2+2*x+2,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2+2*x-1,{2}>,
<-3*x^6-x^5-3*x^4-x^3-x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+x^4-x^3+3*x^2-2*x-3,{2}>,
<-x^6-2*x^5-3*x^4-x^3-x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4+3*x^2-x+2,{2,3}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2-2*x-2,{2}>,
<-x^6-x^5-x^4-3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2+x-1,{2}>,
<2*x^6+x^5-x^4+3*x^3+2*x^2+2*x-3,{2}>,
<-2*x^6-x^5+x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-x^2-1,{2}>,
<2*x^6-x^4-3*x^3+2*x^2-2*x-3,{}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2-2,{}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2-x-3,{}>,
<3*x^6-2*x^5-2*x^4-3*x^3+x^2+2*x-2,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+x^2-3*x-2,{2}>,
<-x^6+3*x^5+3*x^3+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-3*x-1,{2}>,
<3*x^6-x^4-3*x^3+2*x^2-2*x-3,{2,3}>,
<2*x^6+2*x^5+3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+2*x-1,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^3-2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+x^2+x-1,{2,3,7,13}>,
<3*x^6-2*x^5-2*x^4-3*x^3-x-1,{2,3}>,
<3*x^6+x^5+3*x^3+2*x^2+2*x-3,{2}>,
<3*x^6-x^5-x^4+3*x^3+2*x^2+2*x-3,{}>,
<-2*x^6-x^5+3*x^3-2*x^2+2*x+3,{}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+x+3,{2,3}>,
<-3*x^6-x^5+3*x^3-2*x^2+2*x+3,{2,3}>,
<-x^6-2*x^5+3*x^3-2*x^2+2*x+3,{2}>,
<-2*x^6+2*x^5-3*x^3-2*x^2-2*x+3,{2}>,
<-x^6+3*x^5-3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-x^6+2*x^5-x^4+3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-x^4-3*x^3-x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+x^2-2*x-3,{2}>,
<-2*x^6-x^4-3*x^3-2*x^2-2*x+3,{2,5}>,
<3*x^6+x^4+3*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2-x+2,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+2,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3-1,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+x^2-x-1,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-1,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-x^6+x^5-x^4-3*x^3-2*x^2-2*x+3,{2}>,
<2*x^6-3*x^3+2*x^2-2*x-3,{2}>,
<2*x^6+x^5+x^4-3*x^3+2*x^2-2*x-3,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-2*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2-x-2,{2}>,
<-3*x^6+3*x^3-2*x^2+2*x+3,{2,13}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+x^2-2*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2-2*x-1,{2}>,
<2*x^6+x^5-3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2+3*x-1,{2}>,
<3*x^6+x^5+x^4-3*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-x^2+2*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6-x^5-2*x^4-3*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+x^4+2*x^3+x-1,{2,3,107}>,
<3*x^6+2*x^5-2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+2*x^5-x^4+2*x^3+x-1,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x-3,{0,2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+3*x^2+x-3,{}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x^2-2*x+3,{}>,
<2*x^6-3*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-3*x^2+x-1,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-3*x^2-x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-3*x^2-2*x-2,{2,3}>,
<3*x^6-3*x^4-3*x^3-2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+3*x^2-1,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-3*x^2-1,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+x^5+3*x^4-3*x^3+2*x^2-2*x-3,{0,2}>,
<-x^6+x^5-3*x^3+2*x^2-2*x-3,{2,3,47}>,
<-3*x^6-x^5-3*x^4+3*x^3-2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+3*x^3-x+2,{}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+3*x^2-2*x-2,{}>,
<2*x^6-2*x^5-3*x^4+3*x^3-2*x^2+2*x+3,{}>,
<2*x^6-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-2*x^2+2*x+3,{2,7}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+3*x^2+3*x-1,{0,2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3-3*x^2+2*x+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-x^6-x^5+2*x^4+2*x^3-2*x^2+2*x+3,{}>,
<3*x^6-2*x^5-2*x^4-2*x^3+3*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-2*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-x^2-3*x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x-2,{2,3}>,
<3*x^6+2*x^5-2*x^4+2*x^3+x^2+3*x+2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3+x^2+3*x-1,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-3*x^2+2,{2,3,5}>,
<-2*x^6+2*x^5-x^4+2*x^3+2*x^2+2*x-3,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-x^6+x^5-x^4+2*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2+x+2,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3+x^2-x-1,{2,3}>,
<-3*x^6+3*x^4+2*x^3-2*x^2+2*x+3,{2,3}>,
<-x^6-x^5-x^4-3*x^3-2*x^2-2*x+3,{2,5}>,
<-2*x^6-x^5+x^4-2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3-2*x^2+2*x+3,{2,5}>,
<3*x^6-x^5+x^4+2*x^3-2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+x^2+x+2,{}>,
<2*x^6+3*x^5+2*x^3+2*x^2+2*x-3,{}>,
<-2*x^6+x^5+x^4-2*x^3-2*x^2-2*x+3,{2,3,7}>,
<3*x^6+2*x^5-2*x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-3*x-2,{2}>,
<-3*x^6-x^5+x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-2*x-2,{2,3}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-x^2+2*x+2,{}>,
<3*x^6+2*x^5-2*x^4+2*x^3+2*x-2,{2}>,
<-3*x^6+x^4-3*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-x^5-2*x^3+2*x^2-2*x-3,{}>,
<2*x^6+3*x^5+x^4-2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x+2,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-x^2+3,{2}>,
<2*x^6-3*x^5-2*x^3-2*x^2-2*x+3,{}>,
<-x^6+x^5+2*x^3+2*x^2+2*x-3,{2,7}>,
<3*x^6+2*x^5-2*x^4+2*x^3+x-1,{}>,
<-x^6+3*x^5+2*x^3+2*x^2+2*x-3,{2,3,5}>,
<3*x^6-x^5-2*x^3+2*x^2-2*x-3,{}>,
<3*x^6+2*x^5-2*x^4+2*x^3+3*x-1,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3-1,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+2,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x-3,{}>,
<3*x^6-2*x^3+2*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4+2*x^3-x-2,{2,13}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x^2-2*x+2,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3+x+3,{2}>,
<2*x^6-2*x^5+2*x^3+2*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3-3*x-1,{2,3,47}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+x^2+3*x-1,{2,3}>,
<-x^6-3*x^5-x^4-2*x^3-2*x^2-2*x+3,{}>,
<-2*x^6-3*x^5-x^4-2*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-x^5+x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x^2+2*x-3,{2,3}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+2*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3+3*x^2-x-2,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^3-3*x^2-x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+3*x^2+x-3,{2}>,
<-x^6+3*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+2*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-2*x^2-x-1,{2,3}>,
<-3*x^6-2*x^5+2*x^4-2*x^3+2*x^2-3,{2}>,
<2*x^6+2*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-2*x^3+2*x^2+x-2,{2,3}>,
<-3*x^6-2*x^5+2*x^4-2*x^3+2*x^2+x-1,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-2*x^2+x-3,{2,3}>,
<-x^6+2*x^5+2*x^4-2*x^3+2*x^2-2*x-3,{0,2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-2*x^2-3*x-2,{}>,
<-x^6-2*x^5-x^4-2*x^3-2*x^2-2*x+3,{}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+x^2+2*x+2,{2}>,
<-3*x^6+x^5+x^4+2*x^3+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x^2-x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+x^2+x-2,{}>,
<2*x^6+x^5-x^4+2*x^3-2*x^2+2*x+3,{}>,
<2*x^6+x^5+x^4+2*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-x^2+x-2,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+x-2,{2,3}>,
<2*x^6+x^5-3*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-x^6+x^5+3*x^4+2*x^3+2*x^2+2*x-3,{2}>,
<-x^6-x^5-3*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+3*x^4-2*x^3+2*x^2-2*x-3,{}>,
<2*x^6-x^4+3*x^3-2*x^2+2*x+3,{2,3}>,
<-2*x^6+x^5-3*x^4-2*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3+2*x^2-2*x-3,{0,2}>,
<-2*x^6-3*x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^3-3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6-3*x^4+x^3+2*x^2+2*x-3,{2}>,
<-3*x^6+x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4-x^3+3*x^2+2*x+2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+3*x^2+x-1,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+x^5-3*x^4+x^3+2*x^2+2*x-3,{}>,
<2*x^6+3*x^5+3*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+3*x^2-x-2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3+3*x^2-3*x-2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+2*x-3,{}>,
<-3*x^6-2*x^5+2*x^4-x^3-3*x^2-x+3,{2,3}>,
<-x^6-3*x^5+2*x^4-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-2*x^2+2*x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+2*x^2-x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3+2*x^2-3*x+2,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+2*x^2+3*x-1,{}>,
<2*x^6+3*x^5-2*x^4-x^3+2*x^2-2*x-3,{}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+2*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-2*x^2-2*x+3,{2}>,
<2*x^6-3*x^5+x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+2*x^2+x+3,{2,3,7}>,
<-x^6+3*x^5-x^4+x^3+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+2*x^2-x-1,{2}>,
<-x^6-3*x^5+x^4-x^3-2*x^2-2*x+3,{2}>,
<-2*x^6-3*x^5+x^4-x^3-2*x^2-2*x+3,{2}>,
<-x^6-2*x^5+x^4-x^3-2*x^2-2*x+3,{}>,
<2*x^6+x^5-2*x^4+x^3+2*x^2+2*x-3,{2}>,
<-2*x^6-x^5+2*x^4-x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3+2*x^2-1,{}>,
<3*x^6+x^5-2*x^4-x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+x^2-2*x+2,{2,3}>,
<-x^6+x^5+2*x^4+3*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2+x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^3-2*x^2-x-3,{2,3}>,
<2*x^6-2*x^4-3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^3-2*x^2-1,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^3+2*x^2-x-2,{2,5}>,
<3*x^6+2*x^5-2*x^4+3*x^3-2*x^2-x+2,{2}>,
<-x^6-x^5-2*x^4+3*x^3-2*x^2+2*x+3,{2}>,
<2*x^6+x^5+x^3+2*x^2+2*x-3,{}>,
<3*x^6-2*x^5-2*x^4-x^3-x-2,{}>,
<-3*x^6+2*x^5+2*x^4+x^3+x+3,{2,3}>,
<-3*x^6-x^5-x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4-x^3-1,{2,3}>,
<-2*x^6+x^4+2*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-2,{2}>,
<-x^6+x^4+2*x^3+2*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+3,{2}>,
<3*x^6+x^4-2*x^3+2*x^2-2*x-3,{2,3}>,
<3*x^6+x^5-x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4-x^3+x-1,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3-x+2,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3+x^2-x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3+x^2-x+2,{2,3}>,
<-2*x^6-x^5-x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-x^2+2,{}>,
<-3*x^6+2*x^5+2*x^4+x^3+x^2+3*x-1,{2}>,
<-x^6+x^4-x^3+2*x^2-2*x-3,{2}>,
<-x^6-x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-x^2-3*x-1,{2}>,
<-3*x^6+x^5-x^4-x^3-2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+x^4+x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+2*x^5-x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3+2*x^2-x-1,{2}>,
<-2*x^6+3*x^5+x^4-x^3+2*x^2-2*x-3,{2}>,
<-2*x^6+2*x^5+x^4+x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-x^2+2*x+2,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+x^2-3*x-1,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2-2*x-3,{2}>,
<3*x^6-x^5-2*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-x^4+x^3-2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-x^2-2*x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4-x^3-x^2-x+3,{}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2+2*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4+2*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6-2*x^5+2*x^4-x^3+2*x^2-2*x+2,{}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2+2*x-2,{}>,
<-3*x^6-2*x^5+2*x^4-x^3+2*x^2-x-3,{2,3}>,
<-x^6+x^5+2*x^4-x^3+2*x^2-2*x-3,{0}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x^2+x-2,{2}>,
<-2*x^6+x^5+2*x^4+x^3+2*x^2+2*x-3,{2}>,
<2*x^6-x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-x^5+2*x^4+x^3+2*x^2+2*x-3,{2,3}>,
<-x^6+2*x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3+2*x^2-3*x-2,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x^2+3*x-1,{2,5}>,
<-2*x^6+3*x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3+3*x^2-3*x-2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3+x^2+x-1,{2}>,
<-3*x^6+x^5+x^4+x^3-2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+x^2+3,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3-x^2+2,{2,3}>,
<-2*x^6+x^4+x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3+x^2+x-1,{2}>,
<3*x^6-x^5-x^4+x^3+2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x^2-2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x^2-x+2,{2,3,109}>,
<3*x^6-2*x^5-2*x^4-x^3-3*x^2+x-1,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3+3*x^2+x+2,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x^2-x-2,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^3-x^2+x-1,{}>,
<2*x^6+x^5+x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+2*x^2+2*x-3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^2+3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^2+x-2,{2}>,
<-3*x^6-2*x^5+2*x^4-3*x^2-x+3,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^2-3,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4+2*x^2-2*x-3,{}>,
<3*x^6+2*x^5-3*x^4+2*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^4-x^3+2*x^2-1,{2,3}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2-3,{2}>,
<2*x^6-x^5-2*x^4+x^3-2*x^2+2*x+3,{}>,
<3*x^6+2*x^5-2*x^4+x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4+x^2+3*x-2,{2}>,
<3*x^6+x^5+x^4-2*x^2+2*x+3,{2,3}>,
<-2*x^6-x^5+x^4-2*x^2-2*x+3,{2}>,
<-3*x^6+x^5+x^4-2*x^2+2*x+3,{2,3}>,
<3*x^6-x^4+2*x^2-2*x-3,{2,3}>,
<2*x^6+x^5+x^4-2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+x^4-2*x^2-2*x+3,{2}>,
<-x^6+3*x^5-x^4+2*x^2-2*x-3,{}>,
<-x^6-3*x^5+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x-1,{2}>,
<2*x^6-3*x^5+2*x^2-2*x-3,{2}>,
<2*x^6+2*x^5+2*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-x^5-2*x^2-2*x+3,{2}>,
<-x^6-2*x^5-3*x^4+x^3-2*x^2+2*x+3,{2,13}>,
<-3*x^6-2*x^5+2*x^4-x^3+2*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3-2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x^2-2*x+2,{2}>,
<3*x^6-2*x^5-2*x^4-2*x^2-3*x+2,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^2-2*x-2,{}>,
<2*x^6+2*x^5+2*x^4+2*x^2+2*x-3,{}>,
<-2*x^6-x^5+2*x^4+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-3*x^2-3*x-2,{2,5}>,
<3*x^6-2*x^5-2*x^4-x^3-3*x^2-2*x+3,{2,3}>,
<2*x^6-2*x^5-3*x^4-x^3-2*x^2-2*x+3,{2,5}>,
<-3*x^6-2*x^5+2*x^4-x^3+3*x^2-2*x-1,{2}>,
<3*x^6+2*x^5-2*x^4+x^3-3*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3+3*x^2+x-3,{2}>,
<-x^6-x^5+3*x^4-x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-2*x^2-2*x+3,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+3*x+2,{}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+2*x^4+2*x^3+3*x^2+2*x+2,{}>,
<3*x^6-2*x^5-2*x^4-2*x^2+3*x-1,{2,3}>,
<3*x^6-2*x^5-2*x^4-2*x^2+3*x-2,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^2+3*x-1,{}>,
<3*x^6-2*x^5-2*x^4-3*x^2-3*x-1,{2}>,
<3*x^6+2*x^5-2*x^4+2*x^2+3*x-2,{}>,
<-3*x^6-2*x^5+2*x^4+3*x^2-2*x-3,{2,3}>,
<-x^6+2*x^5+3*x^4+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^2-x+2,{2}>,
<-x^6+x^5+2*x^4-2*x^2+2*x+3,{2}>,
<2*x^6-x^5-2*x^4+2*x^2-2*x-3,{2,3}>,
<-3*x^6+2*x^5+2*x^4-2*x^2+x+3,{}>,
<3*x^6+2*x^5-2*x^4+2*x^2+x-3,{}>,
<3*x^6-x^5+2*x^4-2*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^4-2*x^2+2*x+2,{}>,
<-2*x^6+x^5-3*x^4-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^2-x+3,{2,3}>,
<-3*x^6+x^5-3*x^4-2*x^2+2*x+3,{2,3}>,
<-2*x^6+3*x^4+2*x^2-2*x-3,{}>,
<-3*x^6+2*x^5+2*x^4+3*x^2-1,{0,2,3}>,
<-3*x^6-2*x^5+2*x^4+3*x^2+2,{2,3}>,
<3*x^6+3*x^4+2*x^2+2*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^2-x-1,{2}>,
<-2*x^6+x^5-3*x^4-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-3*x^2+x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^2-3*x-1,{}>,
<-3*x^6-2*x^5+2*x^4+3*x^2+3*x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4-3*x^2+3*x-2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-2*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3+3*x^2-x-3,{2,3}>,
<3*x^6+3*x^4-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+x^3+2*x-2,{2,3}>,
<2*x^6+3*x^4-x^3-2*x^2+2*x+3,{2}>,
<2*x^6+x^5+3*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3+3*x^2+x-2,{2}>,
<3*x^6+x^5-3*x^4+x^3+2*x^2-2*x-3,{2,3}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2+2*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+2*x^2-2*x-3,{}>,
<3*x^6-2*x^5-2*x^4+x^3+2*x^2-3*x-1,{}>,
<3*x^6+2*x^5-2*x^4-x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4+x^3+2*x^2-2*x-1,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^2-1,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3-2*x^2-2*x+2,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^2-x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4-2*x^2-x-2,{2}>,
<-2*x^6+x^5+2*x^4-x^3-2*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5+2*x^4+2*x^2+2*x-3,{}>,
<2*x^6-x^5+2*x^4-x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3+2*x^2-x-1,{2}>,
<3*x^6+2*x^5-2*x^4-x^3+x^2-x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3+x^2+x-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2+2*x-3,{2}>,
<2*x^6+3*x^5+x^4+x^3-2*x^2-2*x+3,{}>,
<3*x^6+2*x^5-2*x^4-x^3+x^2-3*x-1,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3+3*x-1,{2}>,
<-2*x^6-3*x^5+x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3+2*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3+2*x-2,{2}>,
<3*x^6+x^5-x^3-2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-x-1,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3-x+2,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^3+3,{}>,
<3*x^6+2*x^5-2*x^4-x^3-3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-x+2,{2}>,
<-2*x^6-x^5-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3-3*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^4+x^3+x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^4+x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-x^2+3*x+2,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x^2+2*x+3,{2}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2+2*x-3,{}>,
<3*x^6+2*x^5-2*x^4-x^3-x-3,{2}>,
<-2*x^6+3*x^5-x^4-x^3-2*x^2+2*x+3,{}>,
<2*x^6-2*x^5-x^4+x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+x^4+x^3+2*x^2-2*x+2,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3+x^2-2*x-1,{2}>,
<3*x^6-2*x^5-2*x^4+x^3+3*x-1,{2,3}>,
<-3*x^6+x^5-2*x^4-x^3-x^2+2*x+3,{2,3}>,
<-2*x^6-2*x^4-x^3-x^2+2*x+3,{}>,
<-x^6-2*x^5-x^4+x^3-2*x^2-2*x+3,{2,23}>,
<3*x^6-2*x^5-2*x^4+x^3-x^2-2,{2,3}>,
<-3*x^6-x^4+x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+x^5-x^4+x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^4+x^3-x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-x^2-x+2,{2}>,
<3*x^6-2*x^5-x^4+x^3-2*x^2+x+2,{}>,
<-3*x^6-x^5-x^4+x^3-2*x^2-2*x+3,{2,5}>,
<-3*x^6+2*x^5+x^4-x^3+2*x^2-x-1,{2}>,
<-2*x^6+2*x^5-x^4+x^3-2*x^2-2*x+3,{2}>,
<2*x^6-3*x^5-2*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-2*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-2*x^2+x-3,{2,3}>,
<-x^6-2*x^4-x^3-2*x^2+2*x+3,{}>,
<2*x^6-3*x^5+2*x^4+x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-2*x^4-x^3-2*x^2+2*x+3,{}>,
<3*x^6+2*x^5-2*x^4-x^3-2*x^2-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2-2*x+3,{}>,
<-2*x^6-2*x^5+2*x^4+x^3+2*x^2-2*x-3,{2}>,
<-x^6-x^5-2*x^4-x^3-2*x^2+2*x+3,{2}>,
<-x^6-2*x^5+2*x^4+x^3+2*x^2-2*x-3,{2,3}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2+2*x+3,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-2*x^2-x-2,{}>,
<3*x^6-2*x^5-2*x^4+x^3-2*x^2+x-2,{2,3}>,
<-3*x^6-x^5-2*x^4-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4+x^3+2*x^2-x+3,{2}>,
<-x^6-2*x^5-2*x^4-x^3-2*x^2+2*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-2*x^2-3*x+2,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3+2*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-3*x^2+x+3,{2}>,
<2*x^6+3*x^4-x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-x^3-3*x^2-2,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3+3*x^2+x-1,{0,2,3,7,17}>,
<3*x^6+2*x^5-2*x^4-x^3-3*x^2-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-3*x^2-x-1,{2}>,
<-x^6-x^5-3*x^4-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3-2*x^2+2*x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-3*x^2-x-2,{2,3}>,
<-3*x^6+x^5-3*x^4+x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-3*x^2-1,{}>,
<3*x^6+2*x^5-2*x^4-x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+2*x^2+2*x-3,{2,3,5,89}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-3*x^2+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-2*x^3+3*x^2-x+3,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3+3*x^2+x+2,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3+2*x^2-3*x+2,{}>,
<-x^6-3*x^5+2*x^4+2*x^3-2*x^2-2*x+3,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3+2*x^2-2*x-3,{}>,
<2*x^6-2*x^4+2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-x^2+x-1,{2,3,17}>,
<2*x^6+x^5+x^4+2*x^2+2*x-3,{2}>,
<-3*x^6-x^4-2*x^2-2*x+3,{2,3}>,
<-2*x^6+x^5-x^4-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+x^3-x^2+x-1,{}>,
<-3*x^6+2*x^5+2*x^4-x^3+x^2-x+2,{2}>,
<-3*x^6+2*x^5+2*x^4-x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4+3*x^2+x-2,{2,3}>,
<2*x^6+x^5-3*x^4-2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+2*x^2+2*x-3,{2,11}>,
<-2*x^6+3*x^5-x^4+2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3-3*x-1,{2,3}>,
<-2*x^6+3*x^5-2*x^3-2*x^2+2*x+3,{2}>,
<2*x^6-x^5+x^4+x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-2*x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4+x^3+x^2-x-1,{2}>,
<-x^6-3*x^5-2*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6-x^5-x^4+x^3+2*x^2-2*x-3,{}>,
<-x^6-3*x^5+x^4+2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-x^2+3*x-1,{}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6+x^5+x^4-x^3-2*x^2+2*x+3,{}>,
<3*x^6-2*x^5-2*x^4+2*x^3-x^2-x-2,{2,3}>,
<-3*x^6-2*x^5+2*x^4+x^3-x^2-x+3,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3-x^2-x-3,{2,5}>,
<-x^6+x^4+2*x^3+2*x^2-2*x-3,{2}>,
<2*x^6+x^4+2*x^3+2*x^2-2*x-3,{}>,
<2*x^6+x^4+x^3-2*x^2-2*x+3,{}>,
<3*x^6+2*x^5-2*x^4-2*x^3-x^2-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-2*x^3-x^2-x-2,{2}>,
<-3*x^6+x^5-x^4+2*x^3-2*x^2-2*x+3,{2,3}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-x^6+x^5-2*x^4+2*x^3-2*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-x^2-3*x-1,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+2*x^2+x+3,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3-2*x^2-2*x+3,{2,3}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+x^2+3*x+2,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3+x^2-x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+2*x^2-2*x-3,{2,5}>,
<-3*x^6+x^4+2*x^3-2*x^2-2*x+3,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^3+2*x^2+2*x-3,{}>,
<-x^6+x^5-2*x^4-2*x^3-2*x^2+2*x+3,{}>,
<3*x^6+2*x^5-2*x^4-2*x^3+x^2-x+2,{2}>,
<3*x^6-2*x^5-2*x^4+2*x^3-3*x^2-3,{2}>,
<3*x^6+2*x^5-2*x^4-2*x^3-3*x^2-x-1,{2,3}>,
<3*x^6-2*x^5-2*x^4+2*x^3-3*x^2+x-3,{2,3,17}>,
<3*x^6-x^5+2*x^4+2*x^3+2*x^2-2*x-3,{2,3}>,
<-x^6+2*x^5+3*x^4+2*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+3*x^2+2*x+2,{}>,
<2*x^6+3*x^4-3*x^3-2*x^2+2*x+3,{}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-3*x^2+2,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-2*x-2,{}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x^2-3*x+2,{}>,
<3*x^6-2*x^5-2*x^4+2*x^3-3*x^2+3*x-2,{2,131}>,
<-x^6-3*x^5+3*x^4-3*x^3-2*x^2+2*x+3,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-3*x^2+2*x+2,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x^2+x-1,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2+2*x-3,{2,3}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6+3*x^4-3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2+3*x+2,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x^2-x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2+x+2,{}>,
<-3*x^6+2*x^5+2*x^4+x^3+2*x-1,{2,3}>,
<-x^6-x^5+2*x^4+3*x^3-2*x^2-2*x+3,{2,3,5,7}>,
<-3*x^6-2*x^5+2*x^4+3*x^3-2*x^2-x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4-x^3-2*x-1,{2,5}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^5+2*x^4-x^3-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4-x^3-x+2,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-2*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2-2*x-1,{2,3}>,
<-3*x^6+2*x^5+2*x^4+x^3+x-1,{2,3}>,
<2*x^6+2*x^5-2*x^4+3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x^2+x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+x^2+2,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+3*x-1,{2}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^3-3*x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^3-x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^3+x^2+x+2,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x-2,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^3-x^2+x-1,{2}>,
<3*x^6+x^5-3*x^3+2*x^2+2*x-3,{2,3}>,
<-2*x^6+x^5+x^4+3*x^3-2*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-x-3,{2}>,
<3*x^6-x^5-x^4-3*x^3+2*x^2+2*x-3,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2-2*x+3,{2,3}>,
<-x^6+2*x^5+x^4+2*x^2-2*x-3,{}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6-2*x^5+x^4+2*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x-2,{2}>,
<-x^6-3*x^5-3*x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+x^4+2*x^2-2*x-3,{2,3}>,
<2*x^6-3*x^5-3*x^3+2*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2-2*x+3,{2}>,
<-2*x^6-3*x^5-x^4-2*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-x^2-2,{2}>,
<-3*x^6-x^4+3*x^3-2*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3-x^2-x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3+x^2-2*x-1,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^3-x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3+2*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x^2-2*x-1,{2,3}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-2*x+3,{2,11}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x^2-x-1,{}>,
<-3*x^6-x^5-2*x^4+3*x^3-2*x^2-2*x+3,{2,3}>,
<-x^6-2*x^4-3*x^3-2*x^2+2*x+3,{}>,
<-2*x^6+2*x^5-3*x^4+x^3-2*x^2-2*x+3,{2}>,
<-x^6-3*x^5+3*x^4-x^3+2*x^2+2*x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2+2*x-3,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3-2*x^2+2*x+3,{2,3}>,
<-3*x^6+2*x^5+2*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-2*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3*x^2-2*x-1,{}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3*x^2-x-1,{2,3}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-3*x^2+x-3,{2}>,
<-x^6-3*x^4-3*x^3-2*x^2+2*x+3,{}>,
<2*x^6+3*x^4-3*x^3+2*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-3*x^2-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2+x-1,{2,3}>,
<-x^6-x^5-3*x^4-3*x^3-2*x^2+2*x+3,{}>,
<-3*x^6-2*x^5+2*x^4+3*x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-2*x^2+2*x+3,{2,7}>,
<-x^6+3*x^5+3*x^4+3*x^3+2*x^2-2*x-3,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+x^5-2*x^2-2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5-x^4-2*x^2+2*x+3,{2,3,5,7}>,
<-2*x^6+2*x^5+x^4+2*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4-2*x^2+2*x+3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+x+2,{2}>,
<-x^6-x^5-x^4+3*x^3-2*x^2-2*x+3,{}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x-1,{2}>,
<2*x^6-x^5+x^4+3*x^3+2*x^2-2*x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-x^6+3*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+3*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-3*x^2+3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+x-1,{2,3}>,
<2*x^6+x^5-3*x^4-3*x^3+3*x^2-2*x-3,{}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2-x-2,{}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2,3,5,61}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6+3*x^5+x^4-3*x^3-2*x^2+2*x+3,{}>,
<3*x^6+2*x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+x^2-3*x-1,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+2*x+2,{2,3,5}>,
<-3*x^6+2*x^5+2*x^4-3*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+3*x^2+2*x-3,{}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-3*x^2+2*x+3,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2,3}>,
<3*x^6+2*x^5-2*x^4-3*x^3+x^2+2*x+2,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-x^6+x^5-2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+2*x^2+x-1,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-2*x^2+x+2,{2}>,
<3*x^6-x^5+x^4+3*x^3-2*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-1,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+2*x^2+x-2,{2,3}>,
<-x^6+2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<2*x^6-2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+2*x^2-2,{2}>,
<3*x^6-2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4-3*x^3+2*x^2-x-3,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3-3*x^2+2*x+3,{}>,
<2*x^6-3*x^5+2*x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x^2+2*x+3,{0,2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-1,{2,3}>,
<3*x^6-2*x^5-2*x^4+2*x^3-3*x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5+x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-2*x^2-2*x+3,{2}>,
<-x^6-2*x^5+3*x^4+2*x^3+2*x^2-2*x-3,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+2*x^2+2*x-3,{}>,
<-x^6+2*x^5-x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+x^5-x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+x^5-x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+x^2+x-1,{2,3}>,
<2*x^6+x^5-x^4+3*x^3+3*x^2+2*x-3,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x^2-x-2,{}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2-x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x^2-1,{2}>,
<-x^6+x^4+3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-2*x^2-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x^2+2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2+x-1,{2}>,
<2*x^6+x^5-x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x^2+x+2,{2,3}>,
<3*x^6-2*x^5-2*x^4+3*x^3-2*x^2+x-2,{}>,
<-2*x^6-x^5+x^4+3*x^3-3*x^2+2*x+3,{2,5}>,
<-x^6+3*x^5+x^4-3*x^3-3*x^2-2*x+3,{0}>,
<3*x^6+x^5-x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-x^2+3*x+2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+x^2-x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x^2+2*x-1,{2,3}>,
<-2*x^6-2*x^5+x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-x^6+x^5+3*x^3-3*x^2+2*x+3,{2}>,
<2*x^6-x^5-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-x^5-3*x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2,{2}>,
<3*x^6-2*x^3+2*x^2+2*x-3,{}>,
<-2*x^6+3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+x^5+2*x^3-2*x^2-2*x+3,{2,3,7}>,
<-3*x^6+2*x^5+2*x^4-2*x^3-x-1,{2,3}>,
<3*x^6-3*x^3+3*x^2-2*x-3,{}>,
<-3*x^6-2*x^5+2*x^4+2*x^3+2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x+3,{2}>,
<-2*x^6+x^5-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3+x+2,{2,3}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x-1,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-3,{}>,
<3*x^6+2*x^5-3*x^4+3*x^3-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3-3,{2}>,
<3*x^6+2*x^5-2*x^4-3*x^3-x+3,{2}>,
<3*x^6-2*x^5-2*x^4+3*x^3+2*x-1,{2,3}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+x^2-x-2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2+x+2,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+x^2+x-1,{2,3}>,
<-2*x^6-x^5-x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+3*x-1,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-3*x+2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-3*x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x-1,{2,3}>,
<-3*x^6+x^5+3*x^3+3*x^2+2*x-3,{2,3}>,
<-x^6-x^5-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2+2,{2}>,
<-x^6+x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-x^6-x^4-3*x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+x^5+x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2-x+3,{2}>,
<-2*x^6+x^5+x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2-x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3+3*x^2-2*x-3,{}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+x^2+2*x-1,{0,2}>,
<2*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x+3,{}>,
<-x^6-3*x^5+x^4+3*x^3+3*x^2+2*x-3,{0,2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-2*x^2+3*x-1,{2,3}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6+3*x^4+2*x^3+2*x^2-2*x-3,{2}>,
<3*x^6-2*x^4-3*x^3-3*x^2-2*x+3,{}>,
<-2*x^6+2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<2*x^6-2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2-1,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x^2-1,{2,3,7}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<3*x^6+x^5-2*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+3*x^2-2*x-3,{2,3,5}>,
<2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{0,2,5,19}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2+2*x-1,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-x-3,{2,3}>,
<2*x^6-x^5-3*x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+x-1,{0,2}>,
<3*x^6+2*x^5-3*x^4+3*x^3-2*x^2-3*x+2,{0,2,3,5,19}>,
<-2*x^6+x^5+3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3+3*x^2-2*x-3,{}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-x-2,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x^2+3*x-1,{}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x^2-2*x-3,{2,3}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-3*x^2+2*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2+3*x+2,{}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-2*x^5-3*x^4+3*x^3-3*x^2+2*x+3,{}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2+3*x-2,{0,2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6+x^5-3*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6-x^5+3*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<-x^6-x^5+3*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-2*x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6-2*x^5+3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-3*x^6-2*x^5+3*x^4-2*x^3-3*x^2+x+3,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-x^5+3*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x+2,{2,3}>,
<-2*x^6-x^5+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3-x+3,{2,3}>,
<2*x^6+2*x^5-3*x^3-3*x^2-2*x+3,{2}>,
<-x^6+2*x^5-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3+2*x^2-3*x-1,{}>,
<2*x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+x^2-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+3*x^3-x^2+3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3+x^2-3*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3-3*x^2+2*x+3,{2,5,19}>,
<-x^6-x^5-x^4-2*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3-x^2+x+2,{2}>,
<-3*x^6-x^5-x^4+2*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3+x^2-x-2,{2}>,
<3*x^6+x^5-x^4-2*x^3+3*x^2-2*x-3,{2}>,
<-x^6+3*x^5-x^4-2*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+3*x-2,{2}>,
<-x^6-3*x^5-2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3+3*x-2,{2}>,
<-x^6-2*x^5-2*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x+2,{2}>,
<-x^6-2*x^5-2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-3*x^3-2*x^2-x+2,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x-1,{}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x+2,{2}>,
<3*x^6+2*x^5-3*x^4+3*x^3+3*x^2+x-3,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-3*x^4+3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x+3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3+x-3,{2,3,29}>,
<2*x^6+x^5-2*x^3-3*x^2-2*x+3,{}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+x-1,{2}>,
<-x^6-x^5+x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2+2*x+3,{2,3}>,
<-x^6-3*x^5-x^4+2*x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2,5}>,
<3*x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2,5,7}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+2*x^2-3*x-1,{2,3}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3*x^2+2*x-3,{}>,
<-2*x^6-3*x^5-2*x^4-2*x^3-3*x^2-2*x+3,{}>,
<-2*x^6-x^5+2*x^4-2*x^3+3*x^2-2*x-3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<-x^6-x^5-2*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+2*x^2-x-3,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+x^5+2*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+x^5+2*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+x+2,{2}>,
<-2*x^6-x^5-2*x^3-3*x^2-2*x+3,{2,3}>,
<-x^6-x^5+2*x^4-2*x^3-3*x^2-2*x+3,{}>,
<2*x^6+x^5-2*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-2*x^3-x+3,{2,3,23,29}>,
<-2*x^6+x^5+2*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5-3*x^4+x+3,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4-2*x^3+2*x^2+x-3,{2,3,29}>,
<3*x^6-2*x^5-3*x^4-2*x^3+2*x^2+3*x+2,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3-x^2+3*x-1,{2,3,5}>,
<-3*x^6+x^5-3*x^4+2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+3*x^2-x-1,{0,2}>,
<-x^6+x^5-3*x^4-2*x^3-3*x^2-2*x+3,{}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3-3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^5-3*x^4-x^3+3*x^2-2*x-3,{2}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+3*x^2+2*x-3,{}>,
<-3*x^6+2*x^5+3*x^4+x^3-3*x^2+x+2,{2,3}>,
<3*x^6-2*x^5-3*x^4-x^3+3*x^2-x-2,{2,3}>,
<2*x^6+3*x^4+x^3-3*x^2+2*x+3,{2}>,
<-x^6+3*x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3-3*x^2+2,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3-3*x^2+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-3*x^2+2*x+3,{2}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2+2*x+3,{}>,
<2*x^6+3*x^5-3*x^4-x^3+3*x^2-2*x-3,{2}>,
<-x^6-3*x^5+2*x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+3*x^4-3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3-2*x^2-x+3,{2,3}>,
<2*x^6+x^5-2*x^3+3*x^2-2*x-3,{}>,
<-2*x^6+3*x^5-2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3+3*x^2+x-1,{2,3}>,
<-2*x^6+2*x^5-x^4+x^3+3*x^2+2*x-3,{2}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3-x^2-2*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<2*x^6+2*x^5-x^4+x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+x^2-x+2,{}>,
<-3*x^6+x^5+3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<2*x^6+x^5-x^4+x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2+x-2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+3*x^2+x-2,{2,3}>,
<3*x^6+x^5-x^4+x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+3*x^2+x-1,{2}>,
<-x^6+x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+x^2-x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2-2,{2}>,
<3*x^6-x^4+x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-2*x^5-x^3+3*x^2-2*x-3,{}>,
<3*x^6-2*x^5-3*x^4-x^3+x^2+x-1,{2}>,
<2*x^6-2*x^5-x^3-3*x^2-2*x+3,{}>,
<2*x^6+2*x^5+x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2-3*x+2,{2,3}>,
<-2*x^6-2*x^5-x^3-3*x^2-2*x+3,{2}>,
<-x^6-3*x^5-x^4+x^3+3*x^2+2*x-3,{2}>,
<3*x^6-x^5-x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3+x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3-x-2,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+x-1,{2}>,
<-x^6+x^5+x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+3*x+2,{2}>,
<2*x^6-x^5-x^3+3*x^2-2*x-3,{}>,
<-3*x^6-2*x^5+3*x^4-x^3-3*x-1,{}>,
<-2*x^6+x^5+x^3-3*x^2+2*x+3,{}>,
<2*x^6+3*x^5+x^4+3*x^3+3*x^2+2*x-3,{}>,
<3*x^6-2*x^5-3*x^4-3*x^3-x^2-3*x-2,{}>,
<3*x^6-x^5-x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+2,{2,3}>,
<-x^6+x^3+3*x^2+2*x-3,{}>,
<-x^6+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3-3*x+2,{2,3}>,
<2*x^6-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+2*x^5-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+3*x^5-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x^2-2*x+3,{2,3}>,
<2*x^6-2*x^5-x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+x^2+2*x-1,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-x^2-2*x-1,{2}>,
<2*x^6+3*x^5-x^3+3*x^2-2*x-3,{2}>,
<-x^6+2*x^5-x^4+3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2-x-3,{2,3}>,
<-3*x^6+2*x^4-x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5-2*x^4-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6-x^5+2*x^4+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+2*x^2-2*x+2,{}>,
<2*x^6-3*x^5-x^4-x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3+x^2-3*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+x^2-3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-x^2+3*x-1,{2}>,
<2*x^6-3*x^5+x^4+x^3+3*x^2+2*x-3,{}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2-3*x-2,{}>,
<3*x^6+2*x^5-3*x^4+x^3-2*x^2+3*x+2,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3+3*x^2+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2+2*x-3,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-3*x^2+2*x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-2*x^2+2*x-1,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+2*x^2-x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-2*x^2-x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+x^3+2*x^2+x-1,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-2*x^2+x-3,{2,3}>,
<-3*x^6+2*x^4-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+2*x^4+x^3+3*x^2+2*x-3,{2}>,
<2*x^6-2*x^4-x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-2*x^2-2,{2}>,
<3*x^6+2*x^4+x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-2*x^4+x^3-3*x^2+2*x+3,{2}>,
<-x^6-x^5-2*x^4+x^3-3*x^2+2*x+3,{2}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2-2*x-3,{2}>,
<-x^6+2*x^5-2*x^4-x^3-3*x^2-2*x+3,{}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-2*x^2-3*x-1,{2,3}>,
<-2*x^6+3*x^5-2*x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2-3*x-2,{}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2+3*x+2,{}>,
<-3*x^6+2*x^5+3*x^4+x^3+3*x^2+3*x-1,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+x^3+3*x^2+2*x-3,{}>,
<3*x^6-2*x^5-3*x^4-x^3-3*x^2-2*x+3,{}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2+2*x-3,{2}>,
<-x^6-2*x^5+3*x^4-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+x^3+3*x^2+2*x-3,{}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2+x+2,{}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2-x-1,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2+x-2,{2,3}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2-x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2+x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-3*x^2+2,{2}>,
<-x^6+3*x^4-x^3+3*x^2-2*x-3,{0,2}>,
<-x^6-3*x^4+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-3*x^2-3,{2,3}>,
<2*x^6-x^5-x^4-2*x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+x^2+x-1,{2}>,
<-3*x^6+x^5+3*x^4-x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+2*x^3-x^2+x-1,{2,3}>,
<3*x^6-2*x^5-3*x^4-2*x^3-x^2-3*x+2,{2}>,
<2*x^6+x^5+x^4+2*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-3*x^2+x+3,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-x^2+x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+x^2-3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2+x-2,{2}>,
<3*x^6-2*x^5-3*x^4-x^3-3*x^2+x-1,{2}>,
<2*x^6+x^5+3*x^4-x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-x^2-x+3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^2-2*x+3,{2}>,
<-2*x^6-x^5-3*x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4-3*x^2+2*x+3,{2}>,
<2*x^6+x^5-3*x^4+3*x^2+2*x-3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+x^2-x-2,{2}>,
<3*x^6+x^5-3*x^4+3*x^2+2*x-3,{2,3}>,
<-x^6-2*x^5-3*x^4+x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4+2*x^2+3*x-2,{2,3,5}>,
<-2*x^6-2*x^5-3*x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^2+x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^2-3,{2,31}>,
<2*x^6+x^5-2*x^4+3*x^2+2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2+3*x-1,{0,2}>,
<-2*x^6+x^5+2*x^4-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^2+x-3,{2}>,
<-x^6+3*x^5-3*x^4-x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5+2*x^4-3*x^2-2*x+3,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4-x^3+3*x^2+3*x+2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^2-2*x-3,{2}>,
<-x^6+3*x^5-x^4+3*x^2+2*x-3,{2}>,
<-x^6+3*x^5+x^4-3*x^2+2*x+3,{}>,
<-3*x^6-2*x^5+3*x^4-x^2-3*x+2,{2,3}>,
<-2*x^6+x^5+x^4-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^2+3*x-2,{2}>,
<-3*x^6-2*x^5+3*x^4-x^2-x+3,{2}>,
<3*x^6+2*x^5-2*x^4+3*x^3+3*x^2+3*x-2,{2,3,463}>,
<-3*x^6+x^5+x^4-3*x^2-2*x+3,{2,3}>,
<3*x^6-x^5+3*x^4-3*x^2+2*x+3,{2}>,
<-x^6+3*x^5-2*x^4+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+x^2-3*x+2,{2}>,
<-x^6+x^5+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^2-3*x-1,{2}>,
<3*x^6-2*x^5-3*x^4-x-1,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x-2,{2}>,
<3*x^6+x^5-x^4-3*x^2+2*x+3,{2}>,
<-2*x^6+x^5+x^4+3*x^2+2*x-3,{2,3}>,
<-3*x^6-2*x^5+3*x^4-2*x^2-3*x+2,{2,3,5}>,
<-x^6+x^5+x^4+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+3*x+2,{2}>,
<3*x^6+2*x^5-3*x^4-x^2+x-3,{2}>,
<3*x^6-2*x^5-3*x^4-x^2-3,{2}>,
<3*x^6+2*x^5-3*x^4+x+2,{2}>,
<3*x^6+2*x^5-3*x^4-x^2-x-1,{2}>,
<-2*x^6-x^5-x^4-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^2-x+2,{2,3}>,
<3*x^6+2*x^5-3*x^4-2*x^2-x-3,{2}>,
<3*x^6-x^5+x^4+3*x^2+2*x-3,{2,3}>,
<-3*x^6+x^5-x^4-3*x^2-2*x+3,{2,3}>,
<-x^6-3*x^5-2*x^4-3*x^2+2*x+3,{2,223}>,
<2*x^6-3*x^5+2*x^4+3*x^2+2*x-3,{2,3}>,
<-3*x^6+2*x^5+3*x^4+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4+3*x^2+3*x-1,{2,3,7}>,
<-3*x^6-x^5+3*x^4+3*x^2-2*x-3,{2}>,
<3*x^6-x^4-x^3-3*x^2-2*x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^2-3*x-2,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^2+x+2,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^2-x-1,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6+x^5+3*x^4+x^3-3*x^2-2*x+3,{}>,
<3*x^6-2*x^5-3*x^4+x^3+3*x^2+x-1,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+x^5-3*x^4+x^3+3*x^2-2*x-3,{2,5}>,
<-3*x^6+2*x^5+3*x^4-x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-x^5+3*x^4+x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3-3*x^2-x+3,{}>,
<-3*x^6+x^5+3*x^4-x^3-3*x^2+2*x+3,{}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3+3*x^2-2*x-3,{2,3}>,
<2*x^6+2*x^4-x^3-3*x^2+2*x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2+2*x+3,{2,3}>,
<-3*x^6+x^5+2*x^4+x^3-3*x^2-2*x+3,{2,3}>,
<2*x^6-3*x^5+2*x^4-x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3-2*x^2-3*x-1,{2,11}>,
<2*x^6-3*x^5-2*x^4-x^3+3*x^2+2*x-3,{2}>,
<2*x^6+3*x^5+x^4-x^3-3*x^2+2*x+3,{}>,
<-x^6-3*x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3+x^2+3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+x^2-2*x-1,{2,3}>,
<-3*x^6-2*x^5+3*x^4-2*x^3+2*x^2+x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+x^2-x+3,{2}>,
<-x^6+x^5+x^4-x^3-3*x^2+2*x+3,{2}>,
<2*x^6-x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4-2*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^4+x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<-3*x^6+x^4-x^3-3*x^2+2*x+3,{2,3}>,
<2*x^6-x^5+x^4-x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4+2*x^3+2*x^2-3*x+2,{2,3}>,
<-2*x^6+x^5+x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4-x^3-3*x^2+2*x+3,{2,3}>,
<-x^6+2*x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+3*x^5-x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3+x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3+3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-x^4-x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x-2,{2}>,
<2*x^6+3*x^5-x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-2*x+2,{2}>,
<-x^6-2*x^5+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3+2*x-1,{2}>,
<2*x^6-2*x^5+x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+x^5-x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-3,{2,3}>,
<3*x^6+2*x^5-3*x^4-x^3-x+3,{}>,
<3*x^6-2*x^5-3*x^4+x^3+x+2,{}>,
<-3*x^6-2*x^5+3*x^4+x^3+x-1,{}>,
<-x^6-x^5-x^3-3*x^2+2*x+3,{2}>,
<2*x^6+x^5+3*x^4+3*x^2+2*x-3,{}>,
<2*x^6-x^5-x^3+3*x^2+2*x-3,{}>,
<-3*x^6+x^5-3*x^4-3*x^2+2*x+3,{2,3,5}>,
<-3*x^6+3*x^4+3*x^2-2*x-3,{}>,
<-3*x^6-2*x^5+3*x^4+x^3+x+3,{2,3}>,
<-3*x^6-3*x^4-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3+x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4-3*x^2-x-1,{2,3}>,
<3*x^6-2*x^5-3*x^4+x^3+2*x-2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2+3*x+2,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-x^2-3*x-1,{2}>,
<2*x^6+3*x^5+x^4-x^3+3*x^2+2*x-3,{2,7}>,
<-3*x^6+2*x^5+3*x^4-x^3+x^2+2*x-2,{2}>,
<-x^6-2*x^5+x^4+x^3+3*x^2-2*x-3,{}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2+x+2,{2,3}>,
<-3*x^6-2*x^5+3*x^4+x^3+x^2-x-1,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+2*x^4+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2+x-3,{2,3}>,
<-x^6+3*x^5-2*x^4-2*x^3+3*x+2,{2}>,
<-x^6-x^4+x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+x^5+2*x^4+3*x^2+2*x-3,{2}>,
<-2*x^6-x^4+x^3-3*x^2-2*x+3,{2}>,
<-2*x^6-x^5+2*x^4+3*x^2-2*x-3,{2}>,
<-2*x^6-x^5-2*x^4-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3+x^2+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^2-2*x-3,{2}>,
<3*x^6+x^5-x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2-x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+x^2-x+2,{2,3,7}>,
<3*x^6+2*x^5-3*x^4-x^3-x^2-x-2,{2,3,7}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2-1,{2}>,
<-3*x^6-x^4+x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-x^2+x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2-x+2,{}>,
<-3*x^6-2*x^5+3*x^4-x^3+x^2+x-1,{2}>,
<-x^6-2*x^5-x^4-x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+2*x^5-x^4+x^3-3*x^2-2*x+3,{2}>,
<-2*x^6-x^5-x^4+x^3-3*x^2+2*x+3,{2}>,
<2*x^6-3*x^5-x^4-x^3-3*x^2+2*x+3,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2-2*x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4+x^3-x^2-x-3,{2}>,
<-x^6+2*x^5-x^4-x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+2*x^5-x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3+2*x^2-x-1,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-2*x^2+x-1,{}>,
<-3*x^6-2*x^5+3*x^4+x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-2*x^2+x-2,{2,3}>,
<3*x^6+x^5+2*x^4-x^3+3*x^2+2*x-3,{2,3}>,
<-3*x^6-x^5-2*x^4+x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+x^3-2*x^2-1,{2}>,
<-3*x^6-2*x^4-x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+x^5-2*x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4+x^3+2*x^2+2*x-1,{}>,
<3*x^6+2*x^5-3*x^4-x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+3*x^2-2*x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+x^3+3*x^2-2*x-3,{}>,
<3*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x+3,{}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2+2*x-1,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3-2*x^2+2*x+2,{2,3,5}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2+x-2,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2+x-1,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x^2+2*x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-2*x^2-2*x-2,{2,3}>,
<-3*x^6+2*x^5+3*x^4-x^3+2*x^2+x-2,{2}>,
<-x^6-3*x^4-x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+x^3-3*x^2-2,{2}>,
<3*x^6+3*x^4+x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2-3,{2,3}>,
<2*x^6+x^5-3*x^4+x^3-3*x^2-2*x+3,{0,2}>,
<-x^6+x^5+3*x^4+x^3+3*x^2-2*x-3,{0,2}>,
<3*x^6-2*x^5-3*x^4+x^3-3*x^2+x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2-x+3,{2,3}>,
<-3*x^6+x^5-3*x^4+x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4-x^3-3*x^2-2*x-2,{2,3,13}>,
<-2*x^6-3*x^5+3*x^4-x^3+3*x^2+2*x-3,{}>,
<2*x^6-3*x^5+3*x^4-x^3+3*x^2+2*x-3,{}>,
<-2*x^6+3*x^5-3*x^4+x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3+3*x^2+3*x+2,{}>,
<2*x^6-3*x^5-3*x^4+2*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3+3*x^2-x+3,{2,3}>,
<-3*x^6-2*x^5+3*x^4+2*x^3-3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3+3*x^2-3*x-1,{2,3,13}>,
<-3*x^6+2*x^5+3*x^4-2*x^3-3*x^2-3*x+2,{}>,
<2*x^6+3*x^5-2*x^4-2*x^3+3*x^2+2*x-3,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3+2*x^2-x+2,{}>,
<-2*x^6+3*x^5+x^4-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3+x^2-x-3,{2,3}>,
<3*x^6+2*x^5-3*x^4-2*x^3+x^2-x+3,{}>,
<3*x^6+2*x^5-3*x^4-x^3+2*x^2+2*x-2,{2,3,97}>,
<3*x^6+2*x^5-3*x^4-x^3+2*x^2+x+2,{2}>,
<-x^6-x^5+2*x^4+x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^4-3*x^2-2*x+3,{}>,
<-x^6+x^5-2*x^4-3*x^2-2*x+3,{2}>,
<-x^6-x^5-x^4-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3-x^2-x-2,{2}>,
<-3*x^6+x^5-x^4+2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+x^2+3*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4-2*x^3+x^2-3*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3-2*x^2-3*x-2,{2,7}>,
<-x^6+x^5-2*x^4-2*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3-2*x^2+x-2,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-3*x^2+2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+2*x^3-2*x^2-2,{}>,
<3*x^6+2*x^5-3*x^4-2*x^3-2*x^2-x-1,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+3*x^2+2*x-3,{}>,
<-2*x^6+x^5-2*x^4+2*x^3-3*x^2-2*x+3,{}>,
<2*x^6-3*x^5+x^3+3*x^2-2*x-3,{}>,
<-2*x^6-3*x^5+x^3-3*x^2-2*x+3,{}>,
<3*x^6-2*x^5-3*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-3*x+2,{}>,
<3*x^6+2*x^5-3*x^4-2*x^3-3*x^2+3*x-2,{}>,
<-2*x^6-x^5-3*x^4+2*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4+2*x^3-3*x^2-2*x+3,{}>,
<3*x^6+2*x^5-3*x^4-2*x^3-3*x^2-x-1,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+3*x^2+2*x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4+2*x^3-3*x^2+x-3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x^2+2*x+3,{2,3}>,
<2*x^6+x^5+3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+3*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+3*x^2+3,{2}>,
<-2*x^6+x^5+2*x^3-3*x^2-2*x+3,{2,5}>,
<-3*x^6+x^5+2*x^3-3*x^2-2*x+3,{2,3}>,
<-x^6-3*x^5-2*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-2*x^3+x^2+3*x-1,{2,3}>,
<3*x^6+2*x^5-3*x^4-2*x^3-x^2+x-1,{2,3}>,
<-2*x^6+x^5-x^4-2*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x^2-2*x+3,{2,5}>,
<3*x^6+2*x^5-3*x^4-3*x^3+2*x^2+3*x+2,{2,3}>,
<3*x^6+2*x^5-3*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+2*x^2-x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3+2*x^2-x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3+2*x^2+x+2,{2}>,
<-x^6+x^5+2*x^4+3*x^3-3*x^2-2*x+3,{}>,
<3*x^6-x^5-2*x^4-3*x^3+3*x^2+2*x-3,{2,3}>,
<2*x^6-2*x^5-2*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+x^2+x-2,{2}>,
<3*x^6+x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+x^4-3*x^3-3*x^2+2*x+3,{2,3}>,
<3*x^6-x^5+x^4-3*x^3-3*x^2+2*x+3,{2,3}>,
<-x^6+x^5+x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3-x^2-x+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-3*x^5-x^4-3*x^3+3*x^2+2*x-3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+x^2+3*x-2,{2,5}>,
<3*x^6+2*x^5-3*x^4-3*x^3+2*x-2,{2}>,
<3*x^6+x^5-3*x^3-3*x^2+2*x+3,{2,3}>,
<2*x^6-x^5+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3+x-1,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3-x+2,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+x+3,{2}>,
<-3*x^6+x^5-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3,{2}>,
<-3*x^6-x^5-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+2*x-1,{}>,
<-x^6+3*x^5-2*x^3-3*x^2+2*x+3,{2}>,
<3*x^6+2*x^5-3*x^4-2*x^3+x-2,{2,3,5}>,
<-3*x^6+2*x^5+3*x^4-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^2+2*x+3,{2}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6+2*x^5-3*x^4-x^2+3*x+2,{2}>,
<-3*x^6-x^4-2*x^3-3*x^2+2*x+3,{2,3}>,
<-x^6-3*x^5+x^4+3*x^2-2*x-3,{2}>,
<-x^6+3*x^5-x^4-3*x^2+2*x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-x^5-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+x^2+x+2,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3-x^2-x-2,{2}>,
<-x^6-2*x^5-2*x^4-x^3-3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2+2*x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-3*x^2+2*x+3,{2,5}>,
<-2*x^6-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3+3*x^2+2*x-3,{2}>,
<-x^6+3*x^5-2*x^4+x^3-3*x^2-2*x+3,{2}>,
<2*x^6+x^5-x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+x^2-x-1,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-x^3-2*x^2-3*x-2,{2,3}>,
<3*x^6-x^5+x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-2*x^5+3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-3*x-2,{2,3}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-2*x-2,{2,5}>,
<3*x^6-2*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2,5}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4+3*x^3+3*x^2-2*x-3,{}>,
<-2*x^6-2*x^4+3*x^3-3*x^2-2*x+3,{}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2+x-1,{2,3}>,
<3*x^6+2*x^5-3*x^4-2*x^3-2*x^2-3*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2-x-2,{}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2-2*x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+2*x^2-x+3,{2,3}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2+2*x-3,{2,5}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-3*x^2+2*x+3,{2,3,7,19}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+2*x^2-x-2,{2,53}>,
<3*x^6+2*x^5-3*x^4-3*x^3-3*x^2+3*x-1,{2,3}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-2*x^2-x-1,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3-3*x^2-2*x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-3*x-2,{2,3}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-x+2,{0,2}>,
<-x^6-2*x^5-3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+x-1,{0,2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-x-1,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+3*x^2+x+2,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-2*x^2+x-2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+3*x^2-2*x-3,{2,3}>,
<-2*x^6-3*x^5-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2+2*x+2,{}>,
<3*x^6-x^5+3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<3*x^6+2*x^5-3*x^4-3*x^3-3*x^2+x-3,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3-3*x^2-1,{2}>,
<-3*x^6+x^5-3*x^4+3*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-3*x^2-x-3,{}>,
<-2*x^6-3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2+x+3,{}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x^2-x-1,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x^2+2,{2}>,
<-3*x^6+x^5-3*x^4+3*x^3-2*x^2+x+2,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x^2-x-3,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2+x+3,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6-2*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<-3*x^6+x^5-3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3+3*x^2-x+3,{}>,
<-3*x^6+2*x^5+3*x^4-3*x^3-2*x+2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2-x-3,{}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2-x+3,{}>,
<-3*x^6+x^5-3*x^4+3*x^3+2*x-1,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2+x+3,{}>,
<2*x^6+2*x^5+3*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+3*x-1,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-x+2,{2,11}>,
<3*x^6+2*x^5-3*x^4-3*x^3-3*x-1,{2}>,
<-3*x^6+x^5-3*x^4+3*x^3+x+3,{2,3}>,
<-3*x^6+2*x^5+3*x^4-3*x^3-3*x+2,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3+3*x-2,{2}>,
<-3*x^6+x^5+3*x^3+3*x^2+x+3,{2,3}>,
<3*x^6-2*x^5-3*x^4+3*x^3-x^2-3*x+2,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+x^2-x+3,{}>,
<3*x^6-x^5+3*x^4-3*x^3+x^2+3,{2}>,
<2*x^6+x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+x^2-1,{2}>,
<2*x^6-x^4-3*x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+x+3,{2,3}>,
<3*x^6-x^5+3*x^4-3*x^3+x+2,{2}>,
<-x^6-x^5+3*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x+2,{2}>,
<-x^6+2*x^5-3*x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^5+3*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2-x+3,{2,3}>,
<3*x^6-x^5+3*x^4-3*x^3+2*x-2,{2}>,
<2*x^6-3*x^5+3*x^3-3*x^2+x-3,{2}>,
<2*x^6+x^5+x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3+3*x-2,{2}>,
<-3*x^6-x^5-3*x^4-3*x^3+x^2-2*x-2,{2,3}>,
<-3*x^6+x^5-3*x^4+3*x^3+x^2+2*x+2,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+3*x-1,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+x+2,{2,3}>,
<-x^6-x^5+x^4-3*x^3-3*x^2-x-3,{}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+3*x-2,{}>,
<-3*x^6+x^5-3*x^4+3*x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4+3*x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2-2,{2}>,
<3*x^6-x^5+x^4-3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2+x-3,{2}>,
<2*x^6-x^4-3*x^3+3*x^2-x+3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4-3*x^3-2*x^2+3,{2}>,
<-x^6+2*x^4-3*x^3-3*x^2-x-3,{2}>,
<-x^6-2*x^4+3*x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+3*x^3+2*x^2+2,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-2*x^2-2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+3*x^2+x+3,{}>,
<3*x^6+x^5+3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<-3*x^6-x^5-3*x^4-3*x^3+2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-3*x^2-x-3,{2,3,5}>,
<3*x^6-3*x^4-3*x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^4+3*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-3*x^2-2,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-3*x^2+x+2,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-3*x^2+x-1,{}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-3*x^2+x-3,{2,3}>,
<-3*x^6-x^5-3*x^4+3*x^3+3*x^2+x+3,{2,3}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x^2+x-3,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+3*x^2+x+3,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+3*x^2+x+3,{}>,
<-x^6-3*x^5+3*x^4-2*x^3+3*x^2-x+3,{}>,
<-3*x^6+x^5-3*x^4+2*x^3-3*x^2+3*x+2,{}>,
<3*x^6-x^5+3*x^4-2*x^3+3*x^2-x+2,{}>,
<2*x^6+x^5-3*x^4+2*x^3-3*x^2+x-3,{}>,
<3*x^6+x^5+3*x^4+2*x^3+3*x^2+x-2,{}>,
<-3*x^6+x^5-3*x^4+2*x^3-3*x^2+x+3,{}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2-x+3,{}>,
<-3*x^6+x^5-x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3-x^2-2*x-1,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+3*x^2-x-3,{}>,
<-3*x^6-x^5-3*x^4-3*x^3+x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+3*x^2+2,{2}>,
<-x^6+3*x^4+2*x^3+3*x^2+x+3,{}>,
<2*x^6-3*x^4-2*x^3-3*x^2-x-3,{2}>,
<3*x^6-3*x^4-2*x^3-3*x^2-x-3,{2,3,17}>,
<3*x^6+x^5+3*x^4-2*x^3+3*x^2-x+3,{}>,
<-x^6-x^5+3*x^4+2*x^3+3*x^2+x+3,{2,5}>,
<-3*x^6-x^5-3*x^4-3*x^3-x^2+x+3,{2,3}>,
<2*x^6-2*x^5-x^4+3*x^3-3*x^2+x-3,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-x+3,{}>,
<-x^6+3*x^5+x^4-3*x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4-3*x^3-x^2+3*x+2,{2,3}>,
<-2*x^6+3*x^5+3*x^3-3*x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^3+3*x^2+x+3,{}>,
<-3*x^6+x^5-3*x^4+3*x^3+3*x+2,{2}>,
<3*x^6-x^5+3*x^4-3*x^3-2*x+2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3+3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4-2*x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3-2*x^2-3*x-1,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3+x^2-2*x-1,{2,3}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2-2*x-3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x^2+2*x+3,{2}>,
<3*x^6-2*x^5-3*x^4+3*x^3-x^2+3*x-1,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+x^2+3*x+2,{2}>,
<-3*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x-2,{}>,
<2*x^6+3*x^5-2*x^4-3*x^3-3*x^2+2*x+3,{}>,
<-x^6-3*x^5+2*x^4+3*x^3+3*x^2-2*x-3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3-2*x^2+2,{2,3}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2+x+3,{}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x^2+x-3,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^3+2*x^2-2*x-1,{2,3}>,
<-3*x^6-x^5-3*x^4-2*x^3-2*x^2+2*x+2,{}>,
<3*x^6-x^5+3*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2+2*x+3,{2}>,
<-x^6+2*x^5-x^4-3*x^3-3*x^2+2*x+3,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-3*x^2-x-3,{2,17}>,
<-3*x^6-x^5-3*x^4-2*x^3-x^2-3*x-1,{}>,
<3*x^6+x^5+3*x^4+2*x^3+2*x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3+x^2+3*x-2,{2}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2-x+3,{2,3}>,
<-x^6-x^5+x^4-2*x^3+3*x^2-x+3,{}>,
<3*x^6-x^5+3*x^4-2*x^3+x^2-3*x+2,{2}>,
<2*x^6-x^5-x^4-2*x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+x^2+3,{}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2+x+3,{2,3}>,
<2*x^6+x^5+x^4-2*x^3+3*x^2-x+3,{}>,
<2*x^6+x^4+2*x^3+3*x^2+x+3,{2,3}>,
<-3*x^6+x^5-3*x^4+2*x^3-x^2-x+2,{2,3}>,
<2*x^6-x^4+2*x^3-3*x^2+x-3,{}>,
<-3*x^6+x^5-3*x^4+2*x^3-x^2-x+3,{2,3,5}>,
<3*x^6-x^5+3*x^4-2*x^3+x^2-2,{}>,
<-3*x^6-x^5+x^4+2*x^3+3*x^2+x+3,{2,3}>,
<-3*x^6+x^5-3*x^4+2*x^3-x^2+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3+x^2+2*x+2,{2,7}>,
<2*x^6+3*x^5+2*x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4+2*x^3+x^2-2*x-1,{2,13}>,
<3*x^6+x^5+3*x^4+2*x^3+x^2-3*x-1,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3-x^2+3*x+2,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4+2*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3-3*x^2+x-3,{}>,
<-2*x^6+2*x^5+3*x^4-2*x^3+3*x^2-x+3,{}>,
<3*x^6+x^5+3*x^4+2*x^3-x-1,{2,3}>,
<-3*x^6-x^5-3*x^4-2*x^3+x+2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+2*x+2,{2}>,
<2*x^6+x^5-x^4+2*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-x^2-x-2,{}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3*x^2-2*x+3,{2}>,
<-3*x^6+2*x^5+3*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2+2*x+3,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2*x-3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+3*x^2-2*x-3,{2,5}>,
<2*x^6-3*x^5+2*x^3+3*x^2+x+3,{}>,
<-x^6+3*x^5-2*x^3-3*x^2-x-3,{2,3}>,
<-x^6-3*x^5+2*x^3+3*x^2+x+3,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-3*x^2-x-3,{2,3}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2+x+3,{2}>,
<-x^6-2*x^5+x^4-2*x^3-3*x^2-x-3,{}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x^2+x+3,{}>,
<-3*x^6+x^5-3*x^4+2*x^3+2*x^2+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4-2*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+x^5-3*x^4+2*x^3+2*x^2-2*x+2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-2*x^2-3*x-1,{2}>,
<-3*x^6+x^5-3*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-3*x^2+3*x-2,{2,3}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-3*x^2-x+3,{}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x^2-x-3,{2,3,5}>,
<-x^6+x^5-3*x^4+2*x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4+2*x^3-3*x^2+x-3,{2}>,
<-2*x^6-x^5-3*x^4-2*x^3+3*x^2-x+3,{2,3}>,
<-3*x^6-x^5-3*x^4-2*x^3+3*x^2-1,{2,3,7}>,
<-x^6-3*x^4-2*x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^4+2*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-3*x^2+x-2,{2,3,7}>,
<2*x^6+2*x^5-2*x^4+2*x^3-3*x^2+x-3,{}>,
<-x^6+x^5+2*x^4+2*x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3-2*x^2-x+3,{2,3,5}>,
<-3*x^6-x^5-3*x^4-3*x^3+x^2+3*x-1,{2,3,7,173}>,
<2*x^6+3*x^5+x^4-3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+2*x^3+2*x^2+3,{2,3}>,
<2*x^6-2*x^5+3*x^4-x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2-2*x+2,{2,3}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+3*x^2-x-1,{}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2-x-3,{}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2-x+3,{2,3}>,
<3*x^6+3*x^4-x^3+3*x^2-x+3,{2}>,
<2*x^6-3*x^4-x^3-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2+3,{2}>,
<3*x^6+x^5+3*x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2-x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-x+3,{2,3,13}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4-x^3+2*x^2-2*x-2,{2}>,
<-3*x^6+x^5-3*x^4+2*x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-2*x^2+x+2,{}>,
<-x^6-x^5+2*x^4-2*x^3-3*x^2-x-3,{2}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4-x^3-2*x^2-x+2,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+2*x^2-x+2,{2,3}>,
<3*x^6-x^5+3*x^4-x^3+2*x^2+2,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^3-2*x^2+x-2,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+2*x^2-x+3,{}>,
<-3*x^6+2*x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3+2*x^2-x-1,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4+x^3-2*x^2-x+2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x^2+x+3,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2-x-3,{}>,
<3*x^6-x^4+x^3-3*x^2+x-3,{2,3}>,
<-3*x^6+x^4-x^3+3*x^2-x+3,{2,3}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2-x+3,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3+x^2-x-1,{2,5}>,
<2*x^6+x^5-x^4-x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+x^3+x^2-x-3,{2,3}>,
<-x^6-2*x^5+x^4+x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-x^2+2*x+2,{2,5}>,
<2*x^6-3*x^5+x^4+x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-x^2+3*x+2,{2}>,
<3*x^6+x^5+3*x^4+x^3+x+3,{2,3}>,
<3*x^6+x^5+3*x^4+x^3+x+2,{2}>,
<-x^6+x^5+x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+2,{2}>,
<-x^6+x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+x^3+2,{2}>,
<-2*x^6-x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+3,{2}>,
<3*x^6+x^5-x^3+3*x^2-x+3,{2,3}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4+x^3-x+2,{2}>,
<3*x^6+x^5+3*x^4+x^3-x-2,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-2,{2}>,
<3*x^6-x^4-2*x^3+3*x^2-x+3,{2,3}>,
<3*x^6-x^5+3*x^4-2*x^3-x^2-3,{2,3}>,
<3*x^6-x^5+3*x^4-2*x^3-x^2+x+3,{}>,
<-3*x^6+x^5-3*x^4+2*x^3+x^2-x+2,{2}>,
<-x^6-2*x^5-x^4+2*x^3+3*x^2+x+3,{2}>,
<2*x^6+2*x^5+x^4-2*x^3-3*x^2-x-3,{2}>,
<-3*x^6+x^5-3*x^4+x^3+x^2+3*x+2,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+3*x-2,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+2*x+2,{2,5}>,
<-x^6-2*x^5+x^4-x^3-3*x^2-x-3,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2+x+3,{}>,
<-2*x^6+2*x^5-x^4+x^3+3*x^2+x+3,{2,11}>,
<-3*x^6-x^5-3*x^4-2*x^3-3*x+2,{2}>,
<-x^6-2*x^5-2*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+x+3,{2}>,
<3*x^6+x^5+2*x^3+3*x^2+x+3,{2,3}>,
<3*x^6-x^5-3*x^4+x^3-3*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4-x^3-x^2-1,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^3+x-3,{2,3,7}>,
<2*x^6+x^4-x^3-3*x^2-x-3,{2}>,
<2*x^6+2*x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2-x+2,{2}>,
<3*x^6+x^5+3*x^4+2*x^3-1,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2-x-1,{2,3}>,
<-3*x^6-x^5-3*x^4-2*x^3+2,{2}>,
<2*x^6+2*x^5-x^4-x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4-x^3+x^2+2*x+2,{2,3}>,
<-2*x^6+2*x^5-x^4-x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6+x^5+3*x^4+x^3-2*x^2+2*x-1,{2}>,
<-3*x^6+x^5-3*x^4+x^3+2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2-x+3,{2,3}>,
<-x^6-x^5+2*x^4-x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+x^3-2*x^2+x-2,{2}>,
<-3*x^6-x^5-3*x^4-x^3+x^2+3*x-1,{2}>,
<3*x^6+x^5+2*x^4+x^3-3*x^2+x-3,{2,3}>,
<-x^6+3*x^5-x^4-x^3+3*x^2-x+3,{2}>,
<-3*x^6-2*x^4+x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3-2*x^2+2*x+2,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2-x-3,{2}>,
<-x^6+2*x^5-2*x^4-x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4-x^3+2*x^2+3*x+2,{2,3}>,
<-2*x^6-3*x^5-3*x^4-x^3+3*x^2-x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2+2*x-1,{2}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2+2*x-2,{2,3}>,
<-3*x^6+x^5-3*x^4+x^3+3*x^2+x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2+x+3,{}>,
<2*x^6+2*x^5-2*x^4-x^3-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-2*x^2+3*x+2,{2,5}>,
<-2*x^6-3*x^5+2*x^4+x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+x^3-x^2+3*x-1,{2,3}>,
<-x^6-2*x^5+x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^3+3*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+3*x^2-x+2,{2}>,
<3*x^6-x^5+3*x^4-x^3-3*x^2+2,{2,3,5}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2-2,{2}>,
<3*x^6+3*x^4+x^3-3*x^2+x-3,{2,3,5}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2-3,{2}>,
<3*x^6+x^5+3*x^4+x^3-3*x^2-x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4-x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4-x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-x^3+3*x^2-x+3,{2,7}>,
<2*x^6+2*x^5+3*x^4-x^3-3*x^2-x-3,{2}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2-x-3,{}>,
<-3*x^6+x^5-3*x^4-3*x^2+3*x+2,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^2-x+3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^2-x+3,{}>,
<-3*x^6+x^5-3*x^4-3*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4+3*x^2-x+3,{}>,
<3*x^6+x^5+3*x^4+x^3+3*x^2-2*x+2,{2}>,
<-3*x^6+x^5-3*x^4-3*x^2+x+2,{2,3}>,
<3*x^6+x^5+3*x^4+3*x^2+3,{}>,
<3*x^6+x^5+3*x^4+x^3+3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+3*x^2+2,{2}>,
<2*x^6-3*x^4-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2+3*x+2,{2,3}>,
<-2*x^6+3*x^4+3*x^2-x+3,{2}>,
<3*x^6-3*x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4+x^3+3*x^2-3*x-2,{2,3}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2-x+3,{}>,
<-x^6+3*x^5+2*x^4+x^3+3*x^2+x+3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^2-x+3,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^2+x+3,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^2-x-3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-3*x^2+x-3,{}>,
<3*x^6+x^5+3*x^4+x^3-2*x^2+3*x-2,{}>,
<3*x^6-x^5+3*x^4+2*x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4+2*x^2+2*x+2,{}>,
<2*x^6+2*x^5-2*x^4+x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^2+x-3,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^2+x+3,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^2+3,{2}>,
<-x^6+2*x^4+3*x^2-x+3,{2}>,
<2*x^6-2*x^4-3*x^2-x-3,{2}>,
<-3*x^6+x^5-3*x^4-2*x^2+2*x+2,{2,3,7}>,
<3*x^6+x^5+3*x^4+2*x^2-2,{2}>,
<-3*x^6+x^5-3*x^4-2*x^2+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4-3*x^2+x-3,{2,3,5}>,
<3*x^6-x^5+3*x^4+2*x^2+x-3,{2,3}>,
<3*x^6+x^5+3*x^4+2*x^2-2*x-1,{2}>,
<-3*x^6-x^5-3*x^4-2*x^2+2*x+2,{}>,
<-3*x^6+x^5-3*x^4-2*x^2-3*x+2,{2}>,
<3*x^6+x^5+3*x^4+x^2+3*x+2,{2,3}>,
<-x^6+3*x^5-x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4+x^2+3*x-1,{2}>,
<2*x^6-3*x^5-x^4-3*x^2-x-3,{}>,
<2*x^6-2*x^5-x^4-3*x^2-x-3,{}>,
<3*x^6+x^5+3*x^4+x^2+2*x-2,{2}>,
<3*x^6-x^5+3*x^4+x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+x^2+x+2,{2}>,
<-3*x^6+x^5-3*x^4-x^2+x+2,{2}>,
<3*x^6+x^5+3*x^4+x^2+x-2,{2,3}>,
<3*x^6+x^5-x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4+x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+x^2+2,{2,3}>,
<-x^6+x^4+3*x^2-x+3,{}>,
<2*x^6-x^4-3*x^2-x-3,{2}>,
<3*x^6-x^4-3*x^2-x-3,{2,3}>,
<2*x^6-2*x^5+x^3+3*x^2+x+3,{2}>,
<-x^6+2*x^5-x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^5+x^3-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4-x^3+3*x-1,{2,3}>,
<-x^6+x^5+2*x^4+3*x^2-x+3,{}>,
<-2*x^6+x^5+2*x^4+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^2-x+3,{2}>,
<-x^6-3*x^5-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4+2*x+2,{2,7}>,
<-x^6+2*x^5+3*x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^2+x+3,{2,3}>,
<3*x^6-x^5+3*x^4-x+2,{2,3}>,
<-x^6-2*x^5+3*x^4+2*x^3-3*x^2+x-3,{2,3}>,
<3*x^6+x^5+3*x^4+x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+3*x^2-x+3,{2,3}>,
<3*x^6+x^5+3*x^4+x-2,{2}>,
<-3*x^6-x^5-3*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6-x^5+3*x^4-2*x^3-3*x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5+3*x^4+2*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^2+x-3,{2}>,
<3*x^6+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-x^3+3*x^2-3*x-1,{2,3}>,
<-3*x^6+x^5-3*x^4+2,{2}>,
<3*x^6+x^5+3*x^4-2,{2}>,
<-3*x^6-x^5-3*x^4-x^3-3*x^2-3*x+2,{2}>,
<3*x^6-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4+3*x+2,{2,3}>,
<2*x^6+2*x^5-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4+3*x-2,{2}>,
<-x^6-3*x^5+x^4-3*x^2-x-3,{2}>,
<-x^6+2*x^5+x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-x^2+x-1,{2}>,
<2*x^6-x^4+3*x^2+x+3,{2}>,
<-x^6-x^4+3*x^2-x+3,{2}>,
<2*x^6+x^4-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4+x^2+3,{2}>,
<3*x^6-x^5-x^4+3*x^2+x+3,{2,3}>,
<3*x^6+x^5+3*x^4-2*x-2,{2}>,
<2*x^6-x^5+x^4-3*x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-x^2+x-2,{2,3}>,
<-2*x^6-2*x^5-2*x^4+3*x^2-x+3,{}>,
<2*x^6-2*x^5-x^4+3*x^2+x+3,{2}>,
<-x^6-2*x^5-x^4+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^2+2*x+2,{2}>,
<3*x^6-x^5+3*x^4-x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-2*x^2-x-3,{2,3}>,
<3*x^6-2*x^4+3*x^2-x+3,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^2-x+3,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^2-2*x-1,{2}>,
<-3*x^6-x^5-3*x^4+2*x^2+3*x-1,{2}>,
<3*x^6+x^5+3*x^4+3*x^2-x+2,{2}>,
<-x^6-x^5+3*x^4+3*x^2+x+3,{}>,
<3*x^6-x^5+3*x^4-3*x^2-x-3,{2,3,37}>,
<3*x^6-3*x^4+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4-3*x^2-x+3,{2,3}>,
<2*x^6+x^5-3*x^4+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4-3*x^2+x-1,{}>,
<-x^6-3*x^5+3*x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-3*x^2+x-3,{2}>,
<-x^6-2*x^5+3*x^4+x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2-2*x+2,{2,3}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-x+2,{2}>,
<-3*x^6+x^5-3*x^4-x^3-3*x^2+x+2,{2,3}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-x-2,{2}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-x-3,{2}>,
<3*x^6+3*x^4+x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4-x^3+3*x^2+2,{2}>,
<-x^6+3*x^4-x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+3*x^2+3*x+2,{2,5}>,
<-2*x^6+3*x^5-3*x^4+3*x^2+x+3,{}>,
<3*x^6-x^5+3*x^4-3*x^2-2*x+2,{2}>,
<-3*x^6+x^5-3*x^4+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+3*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4-3*x^2-x-3,{2}>,
<-3*x^6+x^5-3*x^4+x^3-x^2+x+2,{2}>,
<3*x^6-x^5+3*x^4-x^3+x^2-x-2,{2}>,
<-x^6+2*x^5+3*x^4+x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2+2*x+2,{2}>,
<3*x^6+x^5+3*x^4-x^3+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6+x^5+3*x^4-x^3+2*x^2+3*x+2,{2}>,
<-3*x^6-x^5-3*x^4+x^3-2*x^2-3*x+2,{2,3}>,
<3*x^6-x^5+x^4+3*x^2+x+3,{}>,
<-x^6+x^5+x^4+3*x^2-x+3,{}>,
<2*x^6+2*x^5-2*x^4-x^3-3*x^2+x-3,{2}>,
<-2*x^6-x^5+x^4+3*x^2+x+3,{2}>,
<2*x^6-x^5-2*x^4+x^3-3*x^2-x-3,{}>,
<-3*x^6+x^5-3*x^4+x^3+x^2+3*x-2,{2}>,
<3*x^6+x^5+3*x^4-x^3+2*x^2+x-2,{}>,
<-3*x^6+x^5-3*x^4-x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4+x^3-x^2+3*x+2,{2,3}>,
<2*x^6+2*x^5+x^4+3*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4-x^3+2*x^2+3,{2}>,
<-x^6+2*x^4-x^3+3*x^2+x+3,{}>,
<2*x^6+2*x^5-2*x^4+x^3-3*x^2-x-3,{2}>,
<-2*x^6+2*x^4-x^3+3*x^2+x+3,{2,3}>,
<3*x^6-x^5+3*x^4+x^3+x^2-3*x+2,{2}>,
<-3*x^6+x^5-3*x^4-x^3-2*x^2+3,{2}>,
<3*x^6+x^5+3*x^4-x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^4+3*x^2-x+3,{2}>,
<2*x^6+2*x^5-x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+x^3+2*x^2-3,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^5-x^4-3*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2-x+3,{2,3}>,
<3*x^6+x^5+3*x^4-x^3+x^2+x+2,{2}>,
<-x^6-x^5+x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^5+x^4+3*x^2-x+3,{2}>,
<2*x^6-x^5-2*x^4-x^3-3*x^2+x-3,{2,37}>,
<-3*x^6-x^5-3*x^4+x^3-x^2-x+3,{2,3}>,
<-3*x^6-x^5-3*x^4+x^3-x^2+2,{2}>,
<-2*x^6+x^4+x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-x^2+3,{2}>,
<3*x^6+x^5+3*x^4-x^3+x^2-x-1,{2,5}>,
<3*x^6-x^5+3*x^4+x^3+2*x^2+x-2,{2}>,
<2*x^6-x^5-x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+x^3+x^2+x-3,{2,3}>,
<2*x^6+2*x^5+x^4+x^3+3*x^2-x+3,{}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4+2*x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^4-x^3+3*x^2+x+3,{}>,
<2*x^6-3*x^5+x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4+x^3-3*x-1,{2,3}>,
<2*x^6-3*x^5+x^4-x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4-2*x^2-x-2,{2}>,
<-x^6+3*x^5-x^4+x^3-3*x^2-x-3,{2}>,
<-x^6+2*x^5+2*x^4-3*x^2-x-3,{2}>,
<-3*x^6+x^5-3*x^4-x^3-x^2-3*x+2,{}>,
<-3*x^6-x^5-3*x^4+2*x^2+2*x+2,{}>,
<3*x^6-x^5+x^3-3*x^2-x-3,{2}>,
<2*x^6-x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4+x^3-1,{2}>,
<-3*x^6-x^5-3*x^4+x^3+2,{2,5}>,
<-x^6-2*x^5-x^3+3*x^2+x+3,{2}>,
<2*x^6-2*x^5-x^3-3*x^2+x-3,{}>,
<-3*x^6+x^5-3*x^4-x^3+3,{2}>,
<3*x^6+x^5+3*x^4-x^3-2*x-2,{2}>,
<2*x^6+3*x^5+x^3+3*x^2-x+3,{2}>,
<-x^6-3*x^5-x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3+x+2,{2}>,
<2*x^6+3*x^5+x^3-3*x^2-x-3,{2,3,11}>,
<-x^6+3*x^5+x^4-x^3-3*x^2+x-3,{2,3}>,
<3*x^6+x^5+3*x^4-x^3-x-2,{2}>,
<-x^6-2*x^5-x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6+2*x^5+x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-x^2+x+2,{2}>,
<-x^6+x^5-x^4-x^3+3*x^2+x+3,{2,3,7}>,
<-x^6+x^4+x^3+3*x^2-x+3,{2,3}>,
<-x^6+2*x^5+3*x^4-3*x^2-x-3,{2}>,
<-3*x^6+x^5-3*x^4+3*x^2-3*x-2,{2,3,7}>,
<-2*x^6+3*x^4-x^3+3*x^2+x+3,{2}>,
<3*x^6-3*x^4-x^3-3*x^2+x-3,{2,3}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5-3*x^4+x^3-3*x^2-x-3,{2}>,
<-2*x^6-x^5+3*x^4-x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-3*x^2+x+3,{2,3}>,
<3*x^6+x^5+3*x^4-x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-2*x^2-2,{2}>,
<3*x^6+2*x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+x^3-2*x^2+x+3,{2,3,5}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2-x-3,{2}>,
<-x^6+3*x^5+2*x^4+x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2-x-3,{}>,
<-x^6+3*x^5-3*x^4-x^3+3*x^2+x+3,{}>,
<2*x^6-3*x^5+3*x^4+x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4+x^3+2*x+2,{2,3}>,
<-3*x^6-x^5-3*x^4+x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<-3*x^6+x^5-3*x^4-x^3+3*x^2-3*x-1,{2}>,
<3*x^6+x^5+3*x^4-x^3-3*x^2+x+3,{}>,
<-x^6-3*x^5-3*x^4-x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3-3*x+2,{2}>,
<-3*x^6-x^5-3*x^4+x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+x-3,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3-3*x^2+x-3,{2}>,
<2*x^6-2*x^5+x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-x^5-3*x^4+x^3+3*x^2-x-1,{2,3,5,37}>,
<2*x^6-x^5+3*x^4+2*x^3+3*x^2-x+3,{2}>,
<-x^6-x^5+3*x^4+2*x^3+3*x^2-x+3,{2}>,
<3*x^6+3*x^4-2*x^3+3*x^2+x+3,{}>,
<3*x^6-3*x^4-x^3+3*x^2+x+3,{2}>,
<2*x^6-3*x^4+2*x^3-3*x^2-x-3,{}>,
<2*x^6-3*x^4-x^3+3*x^2+x+3,{}>,
<3*x^6-x^5+3*x^4+2*x^3+3*x^2-2,{2}>,
<-x^6+x^5+3*x^4+2*x^3+3*x^2-x+3,{2,3}>,
<-x^6-3*x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6+3*x^4-x^3-3*x^2+x-3,{2}>,
<-3*x^6+x^5-3*x^4-2*x^3-3*x^2-x+2,{2,3,11,83}>,
<-3*x^6+x^5-3*x^4-x^3+3*x^2-2*x-1,{}>,
<-3*x^6-x^5-3*x^4+2*x^3-3*x^2+x+3,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3-2*x^2-2*x+2,{}>,
<3*x^6-x^5+3*x^4+2*x^3+2*x^2-2*x-2,{}>,
<2*x^6+2*x^5+3*x^4+2*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2-x+3,{}>,
<3*x^6-x^5+3*x^4+2*x^3+2*x^2-x+2,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3+2*x^2-x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4+2*x^3+3*x^2-x+3,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3-3*x^2-x-3,{2,5}>,
<2*x^6-2*x^4+2*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-3*x^2-x-3,{2}>,
<3*x^6-2*x^4+2*x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^3+2*x^2-x+2,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3-2*x^2+x+2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2-x-3,{2,3}>,
<-x^6-2*x^5+x^4+2*x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-2*x^3+3*x^2+x+3,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+3*x^2+x+3,{}>,
<3*x^6+x^5+3*x^4-2*x^3+x^2-x-3,{2,3}>,
<2*x^6+2*x^5-x^4+2*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^4+x^3-3*x^2-x-3,{2,3}>,
<3*x^6+x^5+3*x^4-x^3-x^2-3,{2}>,
<3*x^6+x^5+3*x^4-x^3-x^2-x+2,{2,3}>,
<-x^6-x^5-x^4-x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4-x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5-x^4+x^3+3*x^2-x+3,{2}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2-x-3,{}>,
<-2*x^6-2*x^5+2*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3-x-1,{2}>,
<2*x^6+x^5-2*x^3-3*x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^4+x^3+2*x^2-3*x-1,{2,5}>,
<3*x^6-x^5+3*x^4+x^3-2*x^2-3*x-2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4+x^3+3*x^2-x+3,{2,3}>,
<2*x^6-x^5-2*x^4+x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+x^3+2*x^2-x+2,{2}>,
<3*x^6-x^5+3*x^4+x^3-2*x^2+2,{2,3}>,
<3*x^6+x^5+3*x^4-x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4-x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3+x-2,{2}>,
<3*x^6+x^5+2*x^3-3*x^2-x-3,{2,3}>,
<-3*x^6+x^5-3*x^4-2*x^3-2*x-1,{2}>,
<-x^6-2*x^5-2*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+2*x+2,{2}>,
<-x^6-3*x^5-x^4+2*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3-x^2-2*x+2,{2}>,
<3*x^6-x^5+3*x^4+2*x^3-x^2-2*x-1,{2}>,
<-3*x^6+x^5-3*x^4-2*x^3+x^2+2*x+2,{2}>,
<3*x^6-x^5-x^4+2*x^3+3*x^2-x+3,{2}>,
<2*x^6+x^5+x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<2*x^6+x^4+2*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3+x^2-1,{}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2+x+3,{2,3,23}>,
<3*x^6+x^5+3*x^4-2*x^3+x^2-x+2,{2}>,
<2*x^6+x^5-x^4+2*x^3-3*x^2-x-3,{2}>,
<3*x^6-x^5-x^4-2*x^3-3*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3-3*x^2-x-3,{}>,
<-2*x^6-3*x^5-x^4-2*x^3+3*x^2+x+3,{}>,
<2*x^6-2*x^5-2*x^4+2*x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+2*x^2-2*x-1,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3-2*x^2-x+2,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3-2*x^2-x-1,{2,3}>,
<3*x^6+x^5+2*x^4-2*x^3-3*x^2+x-3,{2,3,11}>,
<3*x^6-2*x^4+2*x^3+3*x^2-x+3,{2}>,
<2*x^6-2*x^4+2*x^3+3*x^2-x+3,{2}>,
<2*x^6+2*x^4+2*x^3-3*x^2-x-3,{2}>,
<-x^6+x^5+2*x^4+2*x^3-3*x^2-x-3,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+3*x^2+x+3,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3-3*x^2-x-3,{}>,
<3*x^6-x^5+3*x^4+x^3+3*x^2-3*x+2,{2,3}>,
<3*x^6+x^5+3*x^4-2*x^3-2*x^2-2*x-2,{2,3}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2-x+3,{}>,
<2*x^6+3*x^5+2*x^4+2*x^3-3*x^2-x-3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+3*x^2-2*x-1,{2}>,
<3*x^6-x^5+3*x^4+2*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+2*x^3-3*x^2-x+2,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<-x^6+x^5-3*x^4-2*x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4-2*x^3+3*x^2+x+2,{}>,
<3*x^6-x^5+3*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6-x^5-3*x^4-2*x^3+3*x^2+x+3,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3-3*x^2-3*x-1,{2,3}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2-x+3,{}>,
<3*x^6+x^5+3*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+3*x^2+x+3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+3*x^2-x+3,{2,3}>,
<2*x^6-2*x^5+3*x^4-2*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x^2+x+2,{2,3}>,
<-3*x^6-x^5-3*x^4+2*x^3+3*x^2+3*x-2,{2,5}>,
<-3*x^6+x^5-3*x^4-3*x^3-3*x^2+2,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3-3*x^2+3,{2}>,
<-2*x^6+2*x^5-x^3+3*x^2+x+3,{2,7}>,
<3*x^6-x^5+3*x^4+3*x^3+3*x^2+x+2,{2}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2+x+3,{}>,
<-3*x^6-x^5-3*x^4+3*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6-x^5+3*x^4+x^3-x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-2*x^2-3*x+2,{2,3}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+2*x^2+3*x-2,{2,3}>,
<2*x^6+x^5-x^3-3*x^2+x-3,{2,3}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3-2*x^2+2*x+2,{2,3}>,
<2*x^6-x^5-2*x^4-3*x^3-3*x^2+x-3,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2+x+3,{}>,
<-3*x^6+x^5-3*x^4-3*x^3-2*x^2-x+3,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3+2*x^2-x-1,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+2*x^2+x-3,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+3*x^2+x+3,{}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-x-3,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2+x+3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3-2*x^2-2*x+2,{2,5}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2+x+3,{2,5}>,
<3*x^6+x^5-2*x^4-3*x^3-3*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3+2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2+x+3,{}>,
<2*x^6-2*x^4+3*x^3-3*x^2-x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+3*x^2-x+3,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+3*x^2-x+3,{}>,
<-x^6-3*x^5+2*x^4+3*x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2-x+3,{2,3,7}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+x^2+3*x+2,{2,3}>,
<-x^6+3*x^5+x^4-3*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-x^2+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-x^2-3*x+2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2-x+3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-3*x^2+x-3,{2,5}>,
<3*x^6-x^5+3*x^4+3*x^3-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+x^2+2*x-2,{2}>,
<3*x^6-x^5+3*x^3+3*x^2-x+3,{2}>,
<-2*x^6-x^5+3*x^3+3*x^2-x+3,{2}>,
<3*x^6+x^5-x^4-3*x^3-3*x^2+x-3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+x^2+3,{2}>,
<3*x^6-x^5+3*x^3-3*x^2-x-3,{2,3}>,
<2*x^6+x^4-3*x^3+3*x^2+x+3,{}>,
<3*x^6+3*x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3-x^2+2,{}>,
<3*x^6+x^5+3*x^4-3*x^3-1,{2}>,
<-2*x^6+x^4+3*x^3+3*x^2-x+3,{}>,
<-3*x^6-x^5-3*x^4+3*x^3+2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-2,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+3,{2,3}>,
<2*x^6-2*x^3-3*x^2+x-3,{2,5}>,
<-2*x^6-2*x^3+3*x^2+x+3,{2}>,
<3*x^6-2*x^3-3*x^2+x-3,{2,3}>,
<3*x^6-x^5+3*x^4+2*x^3+x+3,{2,3}>,
<-3*x^6-x^5-3*x^4+2*x^3+x+2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+3*x^2+x-2,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3+3*x^2-x-3,{2,3}>,
<3*x^6+3*x^4-3*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+2*x^2-x+2,{2,3}>,
<-3*x^6-2*x^4+3*x^3+3*x^2-x+3,{2}>,
<-2*x^6-x^5+3*x^4+3*x^2+x+3,{2,5,7,11}>,
<3*x^6-x^5-3*x^4-3*x^2+x-3,{2,3}>,
<-3*x^6+x^5+3*x^4+3*x^2-x+3,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3-2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3-3*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+3*x^2-1,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+3*x^2-x+3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-3*x^2-x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-3*x^2-x-3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3+x^2-x+2,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3-3*x^2+3*x-2,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2+3*x+2,{}>,
<-3*x^6-x^5-3*x^4+3*x^3-x^2+x+2,{2,3}>,
<-x^6-3*x^5-3*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3+x^2+x-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-3*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2+3*x-2,{}>,
<3*x^6-x^5-x^4-3*x^3-3*x^2+x-3,{2}>,
<2*x^6-x^5+3*x^4-3*x^3+2*x^2-x+3,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2+2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+3*x^2-1,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3-3*x^2+2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3-3*x^2+3,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+3*x^3+3*x^2-x-3,{2,3}>,
<-3*x^6+x^5-3*x^4-2*x^3+x^2+x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3-x^2+2,{2}>,
<3*x^6+x^5+3*x^4-2*x^3-x^2-1,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+x^2+2,{2,5}>,
<-x^6-3*x^5-2*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2+2,{}>,
<3*x^6+x^5+2*x^4+3*x^3+2*x^2-1,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3+x^2+3,{2,3}>,
<-x^6-x^5-x^4-2*x^3+3*x^2+x+3,{}>,
<2*x^6-2*x^4+3*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2+x+2,{2,3}>,
<2*x^6+x^5+x^4+2*x^3-3*x^2-x-3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2-x-3,{}>,
<-x^6+2*x^5+x^4+2*x^3-3*x^2-x-3,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3+2*x^2-x+3,{}>,
<3*x^6-x^5+2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-x^5-2*x^4-3*x^3-2*x^2+x+3,{2}>,
<-x^6+x^5+x^4-3*x^3+2*x^2-x+3,{}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2-x+3,{2,7,383}>,
<-3*x^6-x^5-2*x^4-3*x^3-x^2+x+2,{2}>,
<3*x^6+x^5+2*x^4+3*x^3+x^2-2*x+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x^2+x-3,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+2*x^2+x+3,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3+x^2+3*x-2,{2,3,109}>,
<-x^6+3*x^5+3*x^3+2*x^2+x+3,{}>,
<-2*x^6+3*x^5+3*x^3+2*x^2+x+3,{2}>,
<-x^6-2*x^5-3*x^3+2*x^2-x+3,{}>,
<2*x^6+2*x^5+3*x^3-2*x^2+x-3,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3+x-1,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-x-2,{2}>,
<3*x^6-x^5-3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3-x-3,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3+2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-2,{2}>,
<3*x^6-3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x+3,{2,3}>,
<2*x^6-x^5-3*x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x-1,{}>,
<-3*x^6+x^5-3*x^4-3*x^3-x+2,{2}>,
<-x^6-2*x^5-3*x^3-3*x^2+x-3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3-3*x-1,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+3*x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2-3*x-1,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x-1,{2,3,47}>,
<2*x^6-2*x^5+3*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+3*x+2,{2}>,
<-x^6+3*x^5-3*x^3+2*x^2-x+3,{2,3}>,
<2*x^6-3*x^5+3*x^3-2*x^2+x-3,{2}>,
<-x^6+3*x^5-x^4+3*x^3+2*x^2+x+3,{}>,
<-3*x^6+x^5-2*x^4+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-x^2-x+3,{}>,
<-x^6-x^5-x^4-3*x^3+2*x^2-x+3,{2}>,
<2*x^6+x^5+x^4+3*x^3-2*x^2+x-3,{}>,
<3*x^6+x^5+2*x^4+3*x^3-x^2+x-2,{}>,
<-3*x^6+x^5-x^4+3*x^3+2*x^2+x+3,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3-x^2+3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3-x^2+2,{2}>,
<-x^6-x^4-3*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3+x^2+2,{2}>,
<-2*x^6-x^4-3*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2+3*x+2,{2,3,5}>,
<3*x^6+x^4-3*x^3-2*x^2-x-3,{2,3}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-2*x^2+x-2,{2,3}>,
<3*x^6+x^5+3*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x^2-x-3,{}>,
<-3*x^6+x^5-3*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3+3*x^2-x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-x^2-x-2,{2}>,
<3*x^6+x^5+x^4-3*x^3-2*x^2-x-3,{2,3}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2+x-3,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-2*x^2+x-3,{2}>,
<-3*x^6+x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x^2+3*x+2,{2,3}>,
<3*x^6-x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-2*x^2-x-3,{2,3,7}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-2*x^2+x-3,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3-2*x^2-x-3,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-x^6+x^5-2*x^4+3*x^3+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x^2+x-2,{2}>,
<-3*x^6+x^5-2*x^4+3*x^3+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<3*x^6-2*x^4+3*x^3+2*x^2+x+3,{2}>,
<-x^6+x^5-2*x^4-3*x^3+2*x^2-x+3,{2}>,
<-x^6-2*x^4-3*x^3+2*x^2-x+3,{2,3}>,
<2*x^6+2*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x^2-2,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x^2+x+2,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3+3*x^2-2*x+2,{2,3}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2+2*x-2,{2,3}>,
<-x^6+x^5+3*x^4+3*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2-1,{2}>,
<3*x^6+3*x^4+3*x^3-2*x^2+x-3,{2}>,
<-3*x^6-3*x^4-3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-3*x^2+x+3,{2,3}>,
<-2*x^6+x^5-3*x^4-3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-3*x^2+2*x+2,{2,3}>,
<-x^6+2*x^5-3*x^4-3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-3*x^3-3*x^2+3*x+2,{2,3}>,
<-3*x^6-x^5-2*x^4-3*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3+2*x^2-x+3,{2,5}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3-3*x^2+2*x+2,{2,11}>,
<2*x^6+x^5+3*x^4+2*x^3+2*x^2+x+3,{}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-2*x^2+x-3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+2*x^2+x+3,{2,3}>,
<-x^6+2*x^5-x^4+3*x^3-2*x^2+x-3,{}>,
<3*x^6-x^5+2*x^4-3*x^3+x^2-2*x-1,{2}>,
<-3*x^6-x^5-2*x^4-3*x^3-x^2-2*x+2,{2}>,
<3*x^6-x^5+2*x^4-3*x^3+x^2+3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3+x^2+x+2,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2+3,{2}>,
<2*x^6-3*x^4-2*x^3-2*x^2-x-3,{2}>,
<3*x^6-3*x^4+2*x^3-2*x^2+x-3,{2}>,
<-3*x^6+3*x^4-2*x^3+2*x^2-x+3,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-2*x^2+x-3,{}>,
<3*x^6-x^5+2*x^4-3*x^3+x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2+2*x-2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x^2+x-3,{}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3+2*x^2-3*x+2,{2,3}>,
<-x^6-2*x^5+3*x^4+2*x^3+2*x^2+x+3,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<-x^6+x^5+2*x^4+2*x^3+2*x^2+x+3,{}>,
<2*x^6-2*x^5-3*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+2*x^2-x+3,{}>,
<2*x^6-x^5-2*x^4-2*x^3-2*x^2-x-3,{2,3,5}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x^2-x+3,{}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x^2+2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x^2-x-2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6-2*x^4+2*x^3-2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+2*x^2-x+3,{2,3}>,
<2*x^6-2*x^5+2*x^4+2*x^3+2*x^2+x+3,{}>,
<2*x^6+3*x^5+x^4+2*x^3+2*x^2+x+3,{}>,
<-3*x^6-x^5-2*x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^3+2*x^2-x+3,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2+x-3,{}>,
<-2*x^6-3*x^5+x^4-2*x^3+2*x^2-x+3,{}>,
<-3*x^6+x^5+x^4+2*x^3+2*x^2+x+3,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+x^2+3,{2,3}>,
<3*x^6+x^5+2*x^4+2*x^3+x^2+2,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-x^2-x+2,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+x^2-1,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2-x+2,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3-x^2+2,{2}>,
<-3*x^6-x^5-3*x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+x^2-x-1,{2}>,
<3*x^6-x^5+3*x^4+3*x^3-x^2-1,{2}>,
<2*x^6-x^5-x^4+2*x^3-2*x^2+x-3,{2}>,
<-2*x^6-x^5+x^4+2*x^3+2*x^2+x+3,{2}>,
<2*x^6+x^4-3*x^3-3*x^2+x-3,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+x^2-2*x-2,{2}>,
<3*x^6+x^5+3*x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+x^2-3*x-1,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-3*x^2+x-3,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2+x-3,{}>,
<-3*x^6-x^5-2*x^4-2*x^3-x^2+3*x+2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x+2,{2}>,
<-x^6-2*x^5-2*x^3-2*x^2-x-3,{2}>,
<2*x^6-2*x^5-2*x^3-2*x^2-x-3,{}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x-2,{}>,
<3*x^6+x^5+3*x^4-3*x^3-x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x-2,{2}>,
<2*x^6-x^5-2*x^3+2*x^2-x+3,{2}>,
<2*x^6-x^5+2*x^3-2*x^2+x-3,{}>,
<3*x^6+x^5+2*x^4+2*x^3-2*x+2,{2}>,
<-x^6+2*x^5-2*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-3*x+2,{2}>,
<-x^6+3*x^5-2*x^3-2*x^2-x-3,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+3*x+2,{2,3}>,
<2*x^6-3*x^5-2*x^3-2*x^2-x-3,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-x^2+x+3,{2}>,
<2*x^6+x^5-x^4+2*x^3+2*x^2+x+3,{2}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2-x-3,{2}>,
<-x^6-3*x^5+x^4-2*x^3+3*x^2+x+3,{2}>,
<-x^6-3*x^5+2*x^3-3*x^2-x-3,{}>,
<-x^6-3*x^5+2*x^3+3*x^2-x+3,{}>,
<2*x^6-3*x^5+2*x^3-3*x^2-x-3,{2}>,
<-2*x^6-3*x^5+2*x^3+3*x^2-x+3,{2}>,
<-3*x^6-x^5-3*x^4+2*x^3-2*x+2,{2,3}>,
<-3*x^6-x^5-2*x^4-2*x^3+x^2+3*x-1,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-2*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-x+3,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2-2*x-2,{2,3}>,
<-x^6+x^5-2*x^4+2*x^3+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+2*x^2-x+2,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2-x-2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-2*x^2+2,{}>,
<-x^6+2*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2-1,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+2*x^2+2,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+2*x^2+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-2*x^2-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-2*x^2-x-2,{2,3}>,
<2*x^6+3*x^5+x^4-2*x^3+3*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-2*x^2+x-3,{2,3}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2-x+3,{2}>,
<-x^6-2*x^5+2*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+3*x^4-2*x^3+x^2+2*x+2,{}>,
<3*x^6-x^5+2*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3-2*x^2+x-3,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3+2*x^2-x+3,{}>,
<2*x^6+2*x^5-x^4-2*x^2+3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-2*x^2+x-3,{}>,
<2*x^6+3*x^5+2*x^4-2*x^3-2*x^2-x-3,{}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+2*x^2-x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-3*x^6-3*x^4-2*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+2*x^2-x+3,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-2*x^2+x-3,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+2*x^2+x+3,{}>,
<3*x^6-x^5+2*x^4-2*x^3-3*x^2+x-1,{2,3}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x^2-x+2,{2}>,
<-3*x^6+x^5-2*x^4+2*x^3+3*x^2+3*x+2,{2,3}>,
<2*x^6+2*x^5-3*x^4-2*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+3*x^2+3*x-1,{2,3}>,
<3*x^6-x^5+2*x^4-x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+3*x-2,{2,3,5,131}>,
<-3*x^6-x^5-2*x^4-2*x^3+3*x^2+2*x-1,{2}>,
<3*x^6-x^5+2*x^4-2*x^3-x^2-3*x-2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-x^2+2*x-1,{2}>,
<-3*x^6+x^5-2*x^4+x^3-3*x^2+2,{2}>,
<-x^6-x^5+3*x^4+x^3+2*x^2+x+3,{}>,
<2*x^6-x^5-3*x^4+x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-x^5-2*x^4-2*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2-x+3,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-x^3-2*x^2-x-3,{2}>,
<2*x^6+2*x^4+x^3+2*x^2+x+3,{}>,
<2*x^6-2*x^4+x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2-2*x-2,{2,3}>,
<3*x^6+x^5+2*x^4+x^3+2*x^2-2,{2}>,
<-3*x^6+x^5-2*x^4+x^3-2*x^2+3,{2}>,
<-3*x^6-x^5-2*x^4-x^3-3*x^2+3*x+2,{2}>,
<3*x^6+x^5+2*x^4+x^3+2*x^2-3,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2-x-3,{2,3}>,
<3*x^6-x^5+2*x^4-x^3+2*x^2-2*x+2,{2}>,
<3*x^6+x^5-2*x^4-x^3-2*x^2-x-3,{2,3}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3+x^2+3,{2}>,
<-x^6+2*x^5+x^4-x^3+2*x^2-x+3,{2}>,
<2*x^6+x^4+x^3+2*x^2+x+3,{2,11}>,
<2*x^6-3*x^5-x^4+x^3-2*x^2+x-3,{}>,
<-2*x^6-3*x^5+x^4+x^3+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+x^3+x^2-1,{2,3}>,
<2*x^6-3*x^5-x^3-2*x^2-x-3,{2}>,
<2*x^6-x^4+x^3-2*x^2+x-3,{2}>,
<-2*x^6-3*x^5-x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-2*x+2,{2,3}>,
<-2*x^6+x^4-x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4+x^3+2*x-1,{2}>,
<3*x^6-x^4+x^3-2*x^2+x-3,{2,3}>,
<-2*x^6-2*x^5-x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+2*x^4-3*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-x^3+x^2+x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+x^3+2*x^2+x+3,{2,3}>,
<-3*x^6-x^5-2*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6-x^5-2*x^4-x^3-x^2+x+2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-x^3-x-3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2+3*x+2,{2}>,
<3*x^6-x^5+2*x^4-x^3+3,{2}>,
<3*x^6+x^5+2*x^4+3*x^3-3*x^2+3*x-1,{2,3}>,
<-x^6-x^3+2*x^2-x+3,{2}>,
<2*x^6+x^3-2*x^2+x-3,{}>,
<-x^6+x^5-x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5-x^4+x^3-2*x^2+x-3,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4+x^3-x+2,{2}>,
<-3*x^6+x^5-2*x^4+x^3-x+3,{2}>,
<2*x^6-3*x^5+x^3-2*x^2+x-3,{2}>,
<2*x^6-2*x^5+x^3-2*x^2+x-3,{2,3}>,
<-3*x^6-x^5-2*x^4-x^3+x^2-3*x-2,{2,3}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+x+3,{2}>,
<-2*x^6-2*x^5+x^3+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3+x^2-2*x+2,{2}>,
<-3*x^6-x^5-2*x^4-x^3+x^2-2*x-1,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4+x^3+x^2+2*x+2,{2}>,
<3*x^6+x^5-x^4-x^3+2*x^2-x+3,{2,3}>,
<3*x^6-x^5+2*x^4-x^3-x^2+x+2,{2}>,
<-3*x^6-x^5-2*x^4-x^3+x^2+x+2,{2}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-x+3,{2}>,
<2*x^6+2*x^5-x^4-x^3+2*x^2-x+3,{2}>,
<-x^6-2*x^5-x^4+x^3+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4-x^3+x^2+2*x+2,{2}>,
<3*x^6-x^5+2*x^4-x^3-x^2+2*x-2,{2}>,
<-3*x^6+x^5-2*x^4+x^3+x^2-3*x-1,{2}>,
<-3*x^6-x^5-2*x^4-2*x^3+x^2-x+2,{2}>,
<3*x^6+x^5+2*x^4+2*x^3-x^2+x-2,{}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-x^4+2*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-x^4-2*x^3+2*x^2-x+3,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3-x^2+3*x+2,{2,3}>,
<-x^6+2*x^5-2*x^4+x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-2*x^2-x+2,{2}>,
<-3*x^6-x^5-2*x^4-x^3+2*x^2-x-1,{2}>,
<-3*x^6-x^5-2*x^4-x^3+2*x^2-x+2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+2*x^2-x+3,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+2*x^2-3*x-2,{2}>,
<-3*x^6-x^5-2*x^4-x^3+2*x^2+2*x+2,{2}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+x^3+2*x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-2*x^2-x-3,{}>,
<3*x^6+x^5+2*x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4-x^3-2*x^2-x-3,{2,3}>,
<3*x^6+x^5+2*x^4+x^3-3*x-1,{2}>,
<-3*x^6+x^5+3*x^4+x^3+2*x^2+x+3,{2,3,5}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2-2,{2}>,
<3*x^6+3*x^4+x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^3+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2+x+2,{}>,
<-3*x^6-x^5-2*x^4-x^3+3*x^2+2*x-1,{2,3}>,
<-2*x^6+3*x^5+3*x^4-x^3-2*x^2-x-3,{}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2+3*x+2,{}>,
<2*x^6+3*x^5+3*x^4+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+2*x^3-3,{2,3}>,
<2*x^6+x^5+3*x^4+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^2-3*x-1,{2,3}>,
<2*x^6+x^5-3*x^4-2*x^2+x-3,{2,5}>,
<-3*x^6+x^5-2*x^4-3*x^2+x+3,{2,3}>,
<2*x^6+3*x^5-3*x^4-2*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4+2*x^2-x+3,{2,3}>,
<3*x^6-x^5+2*x^4-2*x^3+x+3,{2,3}>,
<-3*x^6+x^5-2*x^4-3*x^2+2*x+2,{2}>,
<-x^6+x^5-2*x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^2+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^2+x+3,{}>,
<3*x^6+x^5+2*x^4+2*x^2+x+2,{}>,
<3*x^6-x^5+2*x^4+2*x^2-1,{}>,
<3*x^6-x^5+2*x^4+2*x^2+x-2,{2}>,
<-x^6-2*x^5+2*x^4+2*x^2+x+3,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^2-x-3,{2}>,
<-x^6-3*x^5-x^4-2*x^2-x-3,{2,3}>,
<3*x^6-x^5+2*x^4+x^2-2*x+2,{2}>,
<-x^6-2*x^5+x^4+2*x^2-x+3,{}>,
<-3*x^6+x^5-2*x^4-x^2+2*x+2,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3+2*x^2-x+3,{2,3}>,
<3*x^6-x^5+2*x^4+x^2-x+3,{2,5}>,
<-3*x^6+x^5-2*x^4+x^3-2*x^2-2*x+2,{2,3}>,
<-x^6+x^5+x^4+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3+2*x^2-2*x-2,{2,5}>,
<3*x^6-x^5+2*x^4+x^2-x-2,{2}>,
<3*x^6+x^5-x^4-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4+x^2+3,{2,3}>,
<3*x^6+x^5+2*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6-x^4-2*x^2-x-3,{2}>,
<-x^6+3*x^5+2*x^4-x^3+2*x^2-x+3,{}>,
<-2*x^6+x^4+2*x^2+x+3,{2}>,
<-x^6-3*x^5-x^4-x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4-x^2+3,{2}>,
<2*x^6-x^5+x^4-x^3+2*x^2-x+3,{2}>,
<2*x^6+x^5+x^4+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-x^3+x^2-x-1,{}>,
<3*x^6+x^5+2*x^4+x^2-x-1,{2}>,
<-3*x^6+x^5-2*x^4-x^2-x+2,{2}>,
<3*x^6-x^5-x^4-2*x^2+x-3,{2,3,5}>,
<3*x^6+x^5+2*x^4+x^2-x-3,{2,3,5}>,
<-3*x^6-x^5-2*x^4-2*x^2+3,{2}>,
<3*x^6+x^5+2*x^4+2*x^2-3,{2}>,
<3*x^6+x^5+2*x^4+2*x^2-x+3,{2,3,5,7}>,
<3*x^6-x^5+2*x^4-x^3-2*x^2+2*x+2,{2}>,
<-3*x^6-x^5-2*x^4-2*x^2+x+2,{2}>,
<-3*x^6+x^5-2*x^4+x^3+2*x^2-2*x-1,{2}>,
<3*x^6+x^5+2*x^4+x-1,{2,3}>,
<2*x^6+x^5-2*x^2+x-3,{}>,
<-x^6-3*x^5+3*x^4-x^3-2*x^2-x-3,{2}>,
<2*x^6+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4+x^3-3*x^2+3*x-1,{2,7}>,
<3*x^6-x^5+2*x^4-x^3-2*x^2+2*x-1,{2}>,
<-x^6+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4-x^3+3*x^2-3*x+2,{2,3}>,
<-x^6+2*x^5-3*x^4+x^3+2*x^2+x+3,{2}>,
<2*x^6-2*x^2+x-3,{2}>,
<-3*x^6+x^5-2*x^4-3*x+2,{2}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2+3,{2}>,
<-x^6-3*x^5+x^4-2*x^2-x-3,{2}>,
<-x^6+3*x^4-x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-x^2+3*x-1,{2}>,
<2*x^6-3*x^5+x^4-2*x^2-x-3,{}>,
<-3*x^6+x^5-2*x^4+3,{2}>,
<3*x^6-x^5+2*x^4-x^3-3*x^2-1,{2}>,
<-x^6-2*x^5+x^4-2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^2+x-3,{}>,
<3*x^6+x^5+2*x^4-x^2+2*x-2,{2}>,
<3*x^6+x^5+2*x^4-x-3,{}>,
<2*x^6+3*x^4+x^3-2*x^2+x-3,{2,5}>,
<-x^6+3*x^5-2*x^2-x-3,{}>,
<3*x^6+x^5+x^4-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-x^2+2*x+2,{2}>,
<-3*x^6-x^5-2*x^4+x^2+2*x-1,{2,3}>,
<-x^6+3*x^5+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4+x^2+2*x+2,{}>,
<-x^6+2*x^5-2*x^4+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^2-2*x+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^2-x+3,{2}>,
<-x^6+x^5+2*x^4-2*x^2+x-3,{2}>,
<-2*x^6-x^5-2*x^4+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-2*x^2-x-3,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^2+x+3,{}>,
<3*x^6-x^5+2*x^4-2*x^2+x-1,{2}>,
<-2*x^6+x^5+3*x^4+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^2-x+3,{}>,
<-3*x^6-x^5+3*x^4+2*x^2+x+3,{}>,
<-x^6+2*x^5+3*x^4+2*x^2-x+3,{}>,
<-3*x^6+x^5-2*x^4-3*x^2-2*x+2,{2}>,
<3*x^6-x^5+2*x^4+3*x^2+2*x-2,{2}>,
<3*x^6+x^5+2*x^4+3*x^2-3*x+2,{2}>,
<-3*x^6+x^5-2*x^4-3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^2+x+3,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^2+3*x+2,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^2-x-3,{2,3}>,
<-2*x^6-2*x^5+2*x^4-x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4-2*x^2+3*x-2,{2}>,
<3*x^6+x^5+2*x^4-3*x^2+x-1,{2,3}>,
<-x^6+3*x^5-3*x^4+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4+3*x^2-x+2,{}>,
<-2*x^6-x^5-3*x^4+2*x^2-x+3,{}>,
<2*x^6-3*x^4+2*x^2+x+3,{}>,
<-3*x^6+x^5-2*x^4+3*x^2-x-1,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^2-x+3,{2}>,
<-x^6+2*x^5+3*x^4-2*x^2-x-3,{2}>,
<-2*x^6+2*x^5+x^4+2*x^2-x+3,{2}>,
<-x^6-3*x^5-x^4-2*x^2+x-3,{2,3}>,
<3*x^6+x^5+2*x^4+x^2-3*x-1,{2,3,5,11}>,
<2*x^6-3*x^5-x^4-2*x^2+x-3,{2,3,5}>,
<3*x^6+x^5+2*x^4+x^2-3*x-2,{2,3,5}>,
<3*x^6+x^5+2*x^4+3*x+2,{2}>,
<-3*x^6-x^5-2*x^4-3*x-1,{2,101}>,
<3*x^6-x^4-2*x^3-3*x^2-3*x-1,{}>,
<-3*x^6+x^5-2*x^4+3*x^2-3*x+2,{}>,
<3*x^6+x^5+2*x^4-3*x^2-3*x-2,{}>,
<-3*x^6-x^5-2*x^4+x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6+x^5+2*x^4-x^3+3*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^5-3*x^4+x^3-2*x^2-x-3,{2}>,
<2*x^6+x^5-3*x^4-x^3-2*x^2+x-3,{2}>,
<-2*x^6+x^5+3*x^4-x^3+2*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-x^3-2*x^2+x-3,{2,3}>,
<3*x^6+x^5+2*x^4-x^3+3*x^2+3,{2}>,
<3*x^6-x^5+2*x^4+x^3+3*x^2+2,{2}>,
<2*x^6-3*x^4-x^3-2*x^2+x-3,{2}>,
<-2*x^6+3*x^4+x^3+2*x^2-x+3,{2}>,
<3*x^6-3*x^4+x^3-2*x^2-x-3,{}>,
<-3*x^6+3*x^4-x^3+2*x^2+x+3,{}>,
<-x^6-x^5+3*x^4-x^3+2*x^2+x+3,{}>,
<2*x^6+x^5-3*x^4+x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4-x^3-3*x^2-x+3,{2,3}>,
<2*x^6+2*x^5-3*x^4+x^3-2*x^2-x-3,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-2*x^2+x-3,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4+x^3+2*x^2-x+3,{2}>,
<-x^6-x^5+2*x^4+x^3+2*x^2-x+3,{}>,
<2*x^6-x^5-2*x^4+x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+x^3-2*x^2-x-3,{2,3,31}>,
<-3*x^6-x^5+2*x^4+x^3+2*x^2-x+3,{2,3}>,
<-3*x^6-x^5-2*x^4+2*x^2+2*x-1,{2}>,
<-3*x^6+x^5-2*x^4-x^3-2*x^2+3,{2,3}>,
<-x^6+x^5+2*x^4+x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3+2*x^2+x-3,{2,3}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x^2-x+3,{}>,
<3*x^6-x^5+x^4-x^3-2*x^2-x-3,{2,3}>,
<2*x^6+2*x^5-2*x^4+x^3-2*x^2-x-3,{2,3}>,
<-2*x^6-2*x^5+2*x^4-x^3+2*x^2+x+3,{2}>,
<-3*x^6-x^4-x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+x^3+2*x^2+3*x+2,{2,3}>,
<3*x^6+x^5+2*x^4-x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^4-x^3+2*x^2+x+3,{}>,
<2*x^6+2*x^5-x^4-x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3+x^2-3*x-1,{2}>,
<3*x^6+x^5+2*x^4-x^3+x^2+2*x-2,{2}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2+x-3,{}>,
<3*x^6-x^5+x^4+x^3+2*x^2-x+3,{2,5}>,
<2*x^6-x^5-x^4+x^3-2*x^2-x-3,{2,5}>,
<3*x^6-x^4+x^3-2*x^2-x-3,{2,3}>,
<-2*x^6+x^5+x^4-x^3+2*x^2+x+3,{2,5}>,
<-3*x^6+x^4+x^3+2*x^2-x+3,{2,3}>,
<3*x^6-x^5+2*x^4+x^3+x^2+2,{2}>,
<3*x^6+x^5+2*x^4+3*x^2-1,{2,3,19}>,
<3*x^6+x^5+2*x^4-x^3+x^2-1,{2}>,
<2*x^6-x^4+x^3-2*x^2-x-3,{2}>,
<2*x^6-3*x^4-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+3*x^2-2,{}>,
<3*x^6-3*x^4-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+3*x^2+x+2,{2}>,
<3*x^6-x^5+2*x^4+x^3-2,{2}>,
<-3*x^6-x^5-2*x^4+x^3+3,{2}>,
<-3*x^6-x^3+2*x^2+x+3,{2}>,
<2*x^6-x^5-x^3+2*x^2+x+3,{2}>,
<-x^6-x^5-x^3+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4+x^3+x+2,{2}>,
<-3*x^6-x^5-2*x^4+x^3+x+3,{2}>,
<3*x^6+x^5+2*x^4-x^3-2*x-1,{2}>,
<2*x^6-2*x^5-x^3-2*x^2+x-3,{2,5}>,
<-x^6-3*x^5-x^3-2*x^2+x-3,{2,3}>,
<-3*x^6+x^5-2*x^4-x^3+x^2+2*x-1,{2,3}>,
<-3*x^6-x^5-2*x^4+x^3+x^2-x+2,{2}>,
<3*x^6+x^5+2*x^4-x^3-x^2+3,{2}>,
<2*x^6-x^4-x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+x^3-x^2-1,{2}>,
<2*x^6+x^4+x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-x^3-x^2-2,{2}>,
<3*x^6+x^4+x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-x^3-x^2-x+2,{2,3}>,
<-3*x^6-x^5-2*x^4+x^3+x^2+x+2,{}>,
<-x^6+2*x^4+x^3+2*x^2-x+3,{}>,
<-3*x^6+x^5-2*x^4-x^3-2*x^2+2,{}>,
<3*x^6+x^5+2*x^4-x^3+2*x^2-2,{}>,
<3*x^6-x^4+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4-x^2+x+2,{2,3}>,
<3*x^6+x^5+2*x^4-x^2-x-1,{2,3}>,
<2*x^6-2*x^5-3*x^4+x^3+2*x^2-x+3,{2}>,
<-x^6+2*x^5+3*x^4-x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3-3*x^2-2*x-1,{2,3}>,
<3*x^6-x^5+2*x^4+x^3-3*x^2-x+2,{2,3}>,
<2*x^6+2*x^5+3*x^4-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4-3*x^2-2*x-2,{2,3}>,
<2*x^6-x^5-3*x^4+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4+3*x^2+x-1,{2}>,
<-3*x^6-x^5-2*x^4+x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+2*x^2+x+3,{}>,
<2*x^6+2*x^5+3*x^4+x^3-2*x^2-x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3+2*x^2+x+3,{2,7}>,
<-3*x^6+x^5-2*x^4-x^3+3*x^2-3*x-2,{2,7}>,
<-x^6+3*x^5-x^3-2*x^2+x-3,{2}>,
<-x^6-2*x^5+x^3+2*x^2-x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2+x+3,{2}>,
<2*x^6+2*x^5-x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3-x-1,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2-2*x-1,{2}>,
<-x^6-3*x^5-2*x^4+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-3*x^2+2*x+2,{2}>,
<-3*x^6-x^5-2*x^4+2*x^2-3*x+2,{2,3,17}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^2-x+3,{2,3,7,17}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2-x-1,{2}>,
<3*x^6+x^5+2*x^4-2*x^2+2*x+2,{2,3}>,
<-3*x^6-x^5-2*x^4+2*x^2-2*x-1,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2+3*x+2,{2,3}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-x-3,{}>,
<-3*x^6+x^5-2*x^4-2*x^3-3*x^2+x+2,{2,3}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+2*x^2+x+3,{}>,
<-x^6-2*x^5+2*x^4+2*x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-2*x^2+2*x+2,{2,3}>,
<-3*x^6-x^5+3*x^4+2*x^3+2*x^2-x+3,{2,3}>,
<-x^6-x^5+2*x^4+2*x^3+2*x^2-x+3,{2,3}>,
<-3*x^6-x^5-2*x^4+2*x^3-3*x^2+2,{}>,
<-3*x^6+x^5-2*x^4-2*x^3-2*x^2+x+3,{2}>,
<2*x^6+2*x^4+2*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+3*x^2-2,{}>,
<3*x^6-x^5+2*x^4+2*x^3+2*x^2-1,{2,3}>,
<-3*x^6+x^5-2*x^4-2*x^3-3*x^2+3,{2,3,5}>,
<2*x^6-x^5+3*x^4-2*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-2*x^2+x-3,{2,3}>,
<-3*x^6+x^5-2*x^4-x^3+x^2-3*x-1,{}>,
<3*x^6+x^5+2*x^4-x^3-x^2-3*x-2,{2,13}>,
<3*x^6-x^5+2*x^4-3*x^2+3*x+2,{2,3}>,
<-3*x^6+x^5-2*x^4+3*x^2-3*x-1,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-2*x^2+3,{2,3}>,
<-3*x^6+2*x^4+2*x^3+2*x^2-x+3,{2}>,
<-x^6-x^5+2*x^4-x^3-2*x^2+x-3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3-2*x^2+x+2,{2,3}>,
<-3*x^6+x^5-2*x^4-x^3+2*x^2-2*x-1,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+2*x^2-x-2,{2}>,
<-3*x^6-x^5-2*x^4+x^3+2*x^2+3*x-2,{}>,
<2*x^6-3*x^5-2*x^4-x^3+2*x^2+x+3,{}>,
<-x^6+3*x^5+2*x^4+x^3-2*x^2-x-3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-x^6-3*x^5-2*x^4-x^3+2*x^2+x+3,{}>,
<-3*x^6+x^5-2*x^4-x^3+2*x^2-3*x+2,{2,7}>,
<3*x^6+x^5+2*x^4-2*x^3+2*x^2-x-3,{2,3}>,
<2*x^6-2*x^5+2*x^4-2*x^3+2*x^2+x+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^3-2*x^2+x-3,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+x^3-3*x^2-3*x-2,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-2*x^2-3*x-1,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^3+x^2-3*x+2,{2,3}>,
<-x^6-3*x^5+x^4+2*x^3+2*x^2-x+3,{}>,
<-3*x^6-x^5-2*x^4+2*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3+2*x^2+x+3,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-2*x^2-x-3,{}>,
<-2*x^6-2*x^5+x^4+2*x^3+2*x^2-x+3,{}>,
<-3*x^6+x^5-2*x^4-2*x^3-x^2+x+2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-2*x^2+x-3,{}>,
<3*x^6-x^5+2*x^4+2*x^3+x^2+3,{2}>,
<3*x^6-x^4+2*x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3-x^2+2,{}>,
<3*x^6+x^5+x^4+2*x^3+2*x^2-x+3,{2}>,
<2*x^6+x^5+x^4+2*x^3+2*x^2-x+3,{}>,
<-2*x^6+x^4-2*x^3+2*x^2+x+3,{}>,
<3*x^6+x^5-x^4+2*x^3-2*x^2-x-3,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+2*x^2+x+3,{}>,
<2*x^6+3*x^5-2*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+2*x+2,{2,3}>,
<3*x^6+x^5+2*x^4-2*x^3+x^2-2*x-1,{2,11,17}>,
<-x^6-2*x^5+2*x^3+2*x^2-x+3,{2}>,
<2*x^6-2*x^5+2*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3+x+3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3-x^2+2*x+2,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3+x+2,{2}>,
<-2*x^6-x^5+2*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3-x+3,{2,3}>,
<3*x^6+x^5+2*x^4-2*x^3+x-3,{2,3}>,
<2*x^6-2*x^3+2*x^2+x+3,{}>,
<-x^6+2*x^3+2*x^2-x+3,{2}>,
<3*x^6-2*x^3-2*x^2+x-3,{2,3}>,
<3*x^6+x^5+2*x^4-2*x^3-x+3,{2,3}>,
<-x^6-x^5-2*x^3+2*x^2+x+3,{2}>,
<2*x^6+x^5+2*x^3-2*x^2-x-3,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3+2*x-1,{2}>,
<-x^6+3*x^5+2*x^3-2*x^2-x-3,{2,5,23,41}>,
<-2*x^6-3*x^5-2*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2-2*x+2,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3+x^2+2*x+2,{2,3,5}>,
<-x^6+x^5-x^4-2*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4-2*x^3+2*x^2+x+3,{}>,
<3*x^6+x^5+x^4-2*x^3-2*x^2+x-3,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+2,{2}>,
<2*x^6+x^4+2*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+x-3,{2,3}>,
<-3*x^6+x^5-2*x^4-2*x^3+x^2-2*x-1,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+2*x-2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-x^2-3*x+2,{}>,
<-x^6+3*x^5+x^4+2*x^3-2*x^2-x-3,{}>,
<2*x^6+3*x^5+x^4+2*x^3-2*x^2-x-3,{}>,
<3*x^6-x^5+2*x^4+2*x^3-x^2+3*x-2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3+2*x^2-x+3,{2}>,
<-x^6-x^5-2*x^4+2*x^3+2*x^2-x+3,{}>,
<2*x^6+x^5+2*x^4-2*x^3-2*x^2+x-3,{}>,
<2*x^6+2*x^5-x^4+x^3-2*x^2-x-3,{}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2+3,{}>,
<2*x^6-x^5-2*x^4-2*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3+2*x^2-x-1,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2+x+3,{2,3}>,
<-2*x^6-x^5-2*x^4-2*x^3+2*x^2+x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3+x^2+2*x-2,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2-2*x+2,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2+x+2,{2,5}>,
<-3*x^6+x^5-2*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<3*x^6-x^5+2*x^4+x^3+x^2+3*x+2,{2}>,
<-3*x^6-x^5-2*x^4+2*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-2*x^2+x-3,{}>,
<3*x^6+x^5+2*x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6-x^5-2*x^4+x^3-x^2+3*x-1,{2}>,
<-3*x^6+x^5-2*x^4-2*x^3+3*x^2-1,{2,3}>,
<3*x^6-x^5+2*x^4+2*x^3-3*x^2+x+3,{2,3}>,
<-x^6+x^5+3*x^4+2*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-x^3+x^2-3*x-1,{}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^4-3*x^3+2*x^2+x+3,{2}>,
<2*x^6-3*x^4-3*x^3-2*x^2+x-3,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6-3*x^4-3*x^3-2*x^2+x-3,{2,5}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2-x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3-3*x^2-3*x+2,{}>,
<2*x^6+x^5-3*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3+2*x^2+3*x+2,{2,5}>,
<3*x^6-x^5+2*x^4+x^3-3*x^2+3,{2,3}>,
<3*x^6-x^5+2*x^4+3*x^3+2*x^2-3*x-1,{2}>,
<-3*x^6-3*x^4+x^3+2*x^2-x+3,{2,3}>,
<2*x^6-x^5-3*x^4-x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3+2*x^2-2*x-1,{2}>,
<-3*x^6+x^5-2*x^4-x^3+3*x^2-x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4-x^3-3*x^2-2*x+2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+2*x^2-x+3,{}>,
<-x^6-x^5+2*x^4+3*x^3+2*x^2-x+3,{}>,
<2*x^6-x^5-2*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-2*x^2-x-3,{}>,
<-3*x^6-x^5+2*x^4+3*x^3+2*x^2-x+3,{}>,
<2*x^6+2*x^4+3*x^3+2*x^2-x+3,{}>,
<3*x^6+x^5+2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2-x-3,{}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2-x-3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3-x^2+3*x+2,{}>,
<-3*x^6+x^5-2*x^4-3*x^3-2*x^2+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3+x^2-3*x-2,{}>,
<-x^6+2*x^5+x^4-3*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+x^4+3*x^3+2*x^2-x+3,{}>,
<3*x^6-x^5+2*x^4+3*x^3+2*x^2-3,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3+x^2+x-2,{2,3}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2+x-3,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+2*x^2-x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3-x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3+x^2+3,{}>,
<3*x^6-x^5+2*x^4+3*x^3+x^2+2,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3+x^2-1,{2,3}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2-x-3,{2,3}>,
<2*x^6-x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6+x^5+2*x^4-3*x^3+x^2-2,{2}>,
<2*x^6+3*x^5-3*x^3+2*x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3-x^2+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3+x^2+x+2,{2,3}>,
<-x^6-x^5+x^4-3*x^3+2*x^2+x+3,{}>,
<-3*x^6-x^5-2*x^4+3*x^3-3*x+2,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x+2,{2,5}>,
<2*x^6+2*x^5-3*x^3-2*x^2+x-3,{2}>,
<2*x^6-x^5-x^4-3*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x-2,{2,3}>,
<-3*x^6-x^5-2*x^4+3*x^3-x^2+2*x-1,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-x+2,{2,3}>,
<2*x^6+x^5-3*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-1,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3-x^2+3*x-1,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3+2,{2}>,
<3*x^6+x^5+3*x^3+2*x^2-x+3,{2,3}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x^2+x-3,{2,11}>,
<3*x^6+x^5+2*x^4-3*x^3-x^2+2*x-2,{2,11}>,
<3*x^6-x^5-x^4+3*x^3+2*x^2-x+3,{2}>,
<2*x^6-x^5+x^4+3*x^3-2*x^2-x-3,{2,3}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-2*x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3-3*x^2-3*x-1,{}>,
<3*x^6-x^5+2*x^4+2*x^3-3*x^2-2*x+2,{}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-2*x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3+2*x^2+x+3,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-2*x^2+x-3,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2*x^2+x-3,{2,5}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+2*x^2-x+3,{2}>,
<3*x^6+x^5+2*x^4-2*x^3-3*x^2+2,{2,3}>,
<3*x^6-x^5+2*x^4+x^3-2*x^2-2*x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3-2*x^2-x+3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6-x^5+2*x^4+x^3-2*x^2+3,{2,3}>,
<-2*x^6-2*x^4-3*x^3+2*x^2+x+3,{2}>,
<3*x^6-x^5+2*x^4+x^3-2*x^2+2,{2}>,
<3*x^6+2*x^4-3*x^3-2*x^2+x-3,{2,3}>,
<3*x^6+x^5+2*x^4-x^3-2*x^2-1,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-2*x^2-x+2,{2,3}>,
<-x^6-x^5+2*x^4-3*x^3-2*x^2+x-3,{2}>,
<2*x^6+2*x^4-x^3-2*x^2+x-3,{2}>,
<-x^6-x^5-2*x^4-3*x^3+2*x^2+x+3,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5-x^3-2*x^2+x-3,{2}>,
<3*x^6+x^3+2*x^2-x+3,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-x-3,{2}>,
<2*x^6+x^3+2*x^2-x+3,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x^2+3*x-2,{}>,
<-3*x^6+x^5-2*x^4-x^3+2,{2,3}>,
<2*x^6-3*x^5-3*x^4+3*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3+3*x^2-2*x-1,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3-3*x^2-x-2,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x^2-x+3,{}>,
<2*x^6-3*x^4+3*x^3+2*x^2-x+3,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3+3*x^2-1,{2}>,
<-x^6-3*x^5+2*x^3-2*x^2-x-3,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2+x+3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-3*x^2-1,{2}>,
<3*x^6+3*x^4+3*x^3+x^2+x+3,{2}>,
<2*x^6+3*x^4+3*x^3+x^2+x+3,{}>,
<3*x^6-x^5+x^4-3*x^3+3*x^2-1,{2}>,
<-3*x^6-x^5-x^4-3*x^3-3*x^2+2,{2}>,
<3*x^6+x^5+x^4+3*x^3+3*x^2-x+2,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-3*x^2+x+2,{}>,
<-2*x^6+x^5+3*x^4-3*x^3+x^2-x+3,{}>,
<3*x^6+3*x^4-3*x^3-2*x^2+x-3,{2}>,
<-3*x^6+x^5-x^4+3*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5+x^4+3*x^3+3*x^2-2*x+2,{}>,
<3*x^6+x^5-3*x^4+3*x^3+2*x^2-x+3,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-3*x^2+2*x+2,{2,3}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+2*x^3+3*x^2+2*x+2,{}>,
<2*x^6-2*x^5-3*x^4-2*x^3-2*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4-3*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4+3*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5+x^4+3*x^3+2*x^2+3,{2}>,
<3*x^6-x^5+x^4-3*x^3+2*x^2-3,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+x^2-x+3,{}>,
<-x^6+x^5+2*x^4-3*x^3+x^2-x+3,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6+x^5+x^4+3*x^3+2*x^2-2*x-1,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-x^5+x^4-3*x^3+2*x^2+2*x-2,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-2*x^2+3*x+2,{2,3}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+x^2+x+3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+x^2+x+3,{}>,
<-3*x^6-x^5-x^4-3*x^3-x^2-2*x+2,{2}>,
<3*x^6+x^5+x^4+3*x^3+x^2+x+2,{2}>,
<3*x^6-x^5-x^4-3*x^3-x^2-x-3,{2,3,7}>,
<2*x^6+x^4+3*x^3+x^2+x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3+x^2-2,{2}>,
<3*x^6-x^4-3*x^3-x^2-x-3,{2,3}>,
<-3*x^6+x^4-3*x^3+x^2-x+3,{2,3}>,
<3*x^6-x^5+x^4-3*x^3+x^2+x-3,{2,3}>,
<-x^6-2*x^5+x^4+3*x^3+x^2+x+3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-x^2-x-3,{}>,
<2*x^6-3*x^5-3*x^3+x^2-x+3,{2}>,
<-x^6-3*x^5-3*x^3-x^2-x-3,{2}>,
<-x^6-3*x^5-3*x^3+x^2-x+3,{2}>,
<2*x^6+3*x^5+3*x^3-x^2+x-3,{2,3}>,
<3*x^6-x^5+x^4-3*x^3-x+3,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-x+2,{2}>,
<-2*x^6+x^5+3*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3+2,{}>,
<3*x^6-x^5+x^4-3*x^3-1,{}>,
<-3*x^6+x^5-x^4+3*x^3+2,{2}>,
<-2*x^6+3*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+3,{2}>,
<3*x^6+x^5+x^4+3*x^3-x-2,{2}>,
<-3*x^6-x^5-x^4-3*x^3+x+3,{2,3}>,
<2*x^6-3*x^5+3*x^3+x^2+x+3,{}>,
<-3*x^6-x^5-x^4-3*x^3+3*x+2,{2}>,
<-3*x^6-x^5-x^4-3*x^3+x^2-3*x-2,{2}>,
<-3*x^6+x^5-x^4+3*x^3+x^2+3*x-1,{2}>,
<-3*x^6+x^5-x^4+3*x^3+x^2+3*x+2,{2,3}>,
<-2*x^6+3*x^5-x^4+3*x^3+x^2+x+3,{}>,
<3*x^6-x^5+x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+x^5-x^4+3*x^3+x^2+2*x-1,{2,3,5,37}>,
<-x^6+2*x^5-x^4+3*x^3+x^2+x+3,{}>,
<-3*x^6+x^5-x^4+3*x^3+x^2+2*x+2,{2,3}>,
<-2*x^6+2*x^5-x^4+3*x^3+x^2+x+3,{2,5}>,
<-x^6-x^5-x^4-3*x^3+x^2-x+3,{}>,
<-3*x^6+x^5-x^4+3*x^3+x^2+x+3,{2,3,5}>,
<3*x^6-x^5+x^4-3*x^3-x^2+3,{2}>,
<-x^6-x^4-3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+x^2+2,{2,3}>,
<-2*x^6-x^4-3*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3-x^2+x+2,{2,3}>,
<-x^6+x^5-x^4-3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+x^2+x+2,{2,3}>,
<3*x^6-x^5+x^4+3*x^3-x^2+x-3,{}>,
<3*x^6+x^5+x^4+3*x^3-x^2-x-3,{}>,
<3*x^6-x^5+x^4-3*x^3-x^2+2*x-2,{2,3}>,
<-x^6-3*x^5+x^4+3*x^3-x^2+x-3,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-x^2-3*x-2,{2,3}>,
<-3*x^6-x^5-2*x^4+3*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3+2*x^2-x+3,{2}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3+2*x^2+x+3,{}>,
<3*x^6-x^5+2*x^4+3*x^3-2*x^2+2,{2,3}>,
<-3*x^6-x^5-2*x^4+3*x^3+2*x^2-1,{2,3}>,
<3*x^6+x^5+x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3+x^2-x+3,{2,3,5}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2+x+3,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+2*x^2+x+3,{2}>,
<-3*x^6+x^5-2*x^4-3*x^3+x^2-2*x-1,{2,3}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2+2*x-1,{2}>,
<3*x^6+x^5+2*x^4-3*x^3-x^2-2*x-1,{}>,
<2*x^6+2*x^5+2*x^4-3*x^3-x^2-x-3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+x^2-x+3,{2,5}>,
<2*x^6+3*x^5-2*x^4-3*x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+3*x^3+2*x^2-3*x-1,{}>,
<2*x^6+2*x^5+x^4+3*x^3-2*x^2-x-3,{2}>,
<3*x^6+x^5+x^4+3*x^3-3*x^2+2*x-1,{2,3,13}>,
<3*x^6+x^5+x^4+3*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+x^5-x^4+3*x^3+3*x^2+2*x+2,{}>,
<3*x^6-x^5+2*x^4+3*x^3+2*x-2,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3+3*x-2,{2,3}>,
<3*x^6+x^5+2*x^4-3*x^3-3*x+2,{2,3}>,
<-3*x^6+x^5-2*x^4-3*x^3-3*x-1,{}>,
<2*x^6+3*x^5+3*x^3-2*x^2-x-3,{2}>,
<-x^6+3*x^5+x^4-3*x^3-2*x^2+x-3,{2}>,
<3*x^6+x^5+2*x^4-3*x^3+3*x^2-2*x+2,{2,3}>,
<3*x^6+3*x^4-3*x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3-3*x^2-3,{2}>,
<-x^6+x^5-3*x^4-3*x^3+x^2-x+3,{}>,
<-2*x^6-x^5-3*x^4+3*x^3+x^2+x+3,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+3*x^3+3*x^2-2*x+2,{2,3}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2+x-3,{2,7}>,
<2*x^6-3*x^5+3*x^4-2*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2+x-3,{}>,
<3*x^6+x^5+x^4+3*x^3+2*x^2+3*x-2,{}>,
<2*x^6+x^5+3*x^4+2*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6-x^5-x^4-2*x^3-3*x^2-x+2,{2,3}>,
<-3*x^6-x^5-x^4-3*x^3-2*x^2-2*x-1,{2}>,
<3*x^6+3*x^4-2*x^3+x^2-x+3,{2,3}>,
<2*x^6+3*x^4-2*x^3+x^2-x+3,{2}>,
<2*x^6-3*x^4+2*x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2-2,{2}>,
<3*x^6-3*x^4-2*x^3-x^2-x-3,{2,3}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2+x-3,{2}>,
<-3*x^6+x^5-x^4+2*x^3-3*x^2-x+2,{2,17}>,
<3*x^6+x^5+x^4+2*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6-x^5-x^4-2*x^3-3*x^2+2*x+2,{2}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2+x-2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3+x^2-x+3,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3+3*x^2-3*x-2,{2}>,
<3*x^6-x^5+x^4-2*x^3+3*x^2+x-3,{2,3}>,
<3*x^6-x^5+x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-x^2-x-3,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+x^2-x+3,{}>,
<-x^6-3*x^5+2*x^4-2*x^3+x^2-x+3,{}>,
<3*x^6+x^5+x^4+2*x^3+2*x^2+2,{2}>,
<-x^6+2*x^4+2*x^3+x^2+x+3,{}>,
<-3*x^6-x^5-x^4-2*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-2*x^4-2*x^3-x^2-x-3,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+2*x^3-2*x^2-x+2,{2,3}>,
<-3*x^6+x^5-x^4+2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+2*x^3-2*x^2-2*x+2,{2,3}>,
<-2*x^6-2*x^5+2*x^4+2*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-2*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+3*x^3+2*x^2-x+3,{}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+x^2+x+3,{}>,
<-x^6+x^5-2*x^4+3*x^3+x^2+x+3,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-x^2-x-3,{}>,
<-3*x^6+x^5-x^4+3*x^3-3*x^2+3*x+2,{2,3,13}>,
<3*x^6-x^5+x^4-3*x^3+3*x^2-2*x+2,{2,3}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4+2*x^3-x^2+3*x+2,{2}>,
<3*x^6-x^5+x^4-2*x^3+x^2-2*x+2,{2}>,
<-3*x^6-x^5-x^4-2*x^3-x^2-2*x-1,{2,3}>,
<3*x^6-x^5+x^4-2*x^3+x^2-x+2,{2}>,
<3*x^6-x^5+x^4-2*x^3+x^2-x-2,{}>,
<3*x^6+x^5-x^4+2*x^3-x^2+x-3,{2,3}>,
<-3*x^6-x^5+x^4-2*x^3+x^2-x+3,{2,3,5}>,
<3*x^6+x^4-2*x^3+x^2-x+3,{2}>,
<-3*x^6+x^4-2*x^3+x^2-x+3,{2}>,
<-x^6-x^5+x^4+2*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4-2*x^3-x^2+x+2,{2}>,
<3*x^6+x^5+x^4+2*x^3+x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4-2*x^3+x^2-x+3,{2,3}>,
<2*x^6-2*x^5-x^4+2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3+3*x-2,{2}>,
<2*x^6-2*x^5-2*x^3-x^2-x-3,{2}>,
<-2*x^6+2*x^5+2*x^3+x^2+x+3,{}>,
<3*x^6-x^5-2*x^3+x^2-x+3,{}>,
<2*x^6-x^5-2*x^3+x^2-x+3,{2}>,
<-x^6+x^5+2*x^3+x^2+x+3,{}>,
<-3*x^6+x^5-x^4+2*x^3+x+2,{2}>,
<3*x^6+x^5+2*x^3-x^2+x-3,{2,3}>,
<3*x^6-x^5+x^4-2*x^3-x-3,{2,3}>,
<3*x^6+x^5+x^4+2*x^3-2,{}>,
<-3*x^6+x^5-x^4+2*x^3+3,{2}>,
<3*x^6+x^5+x^4+2*x^3-2*x+2,{2}>,
<-3*x^6+x^5-x^4+2*x^3-2*x+2,{2,3,5}>,
<3*x^6+x^5+x^4+2*x^3-3*x+2,{2}>,
<-x^6-3*x^5+2*x^3-x^2+x-3,{2}>,
<-x^6+3*x^5-2*x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+2*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4+2*x^3-x^2+3*x+2,{2,17}>,
<-x^6-3*x^5+x^4-2*x^3-x^2-x-3,{2,13}>,
<-x^6-3*x^5-x^4-2*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4+3*x^3-2*x^2+3*x-1,{2,3}>,
<-3*x^6+x^5-x^4+3*x^3+2*x^2+3*x+2,{}>,
<3*x^6+x^5+x^4+3*x^3-2*x^2+3*x-2,{2}>,
<-x^6-2*x^5-x^4+3*x^3+2*x^2-x+3,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2-3,{2}>,
<2*x^6-x^4-2*x^3+x^2-x+3,{2}>,
<-x^6-x^4+2*x^3+x^2+x+3,{2}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2+x+3,{2}>,
<2*x^6+x^4+2*x^3-x^2+x-3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+2*x^2+x+2,{2,3}>,
<3*x^6-x^5+x^4-3*x^3-2*x^2+2*x+2,{2,3}>,
<3*x^6+x^5+x^4+2*x^3-x^2-3,{2,3}>,
<3*x^6+x^5+x^4+2*x^3-x^2-3*x-1,{2}>,
<2*x^6-x^5-x^4+2*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4+2*x^3-x^2-x-2,{2}>,
<-3*x^6-x^5-x^4-2*x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4-2*x^3+x^2-x+3,{2,3,5}>,
<3*x^6-x^5+x^4-2*x^3-x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4+2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3-x^2+2*x-2,{2}>,
<3*x^6+x^5+x^4+2*x^3-x^2+x+3,{2}>,
<3*x^6+x^5+x^4+2*x^3-x^2+x-1,{2,3}>,
<-3*x^6+x^5-x^4+2*x^3+x^2+x+2,{2}>,
<-3*x^6-x^5-x^4-2*x^3+2*x^2+2*x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2+x-3,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2-2*x-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-x^2-x-3,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+x^2+x+3,{2}>,
<-x^6-x^5+3*x^4-2*x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2-x+2,{2}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2-1,{2}>,
<3*x^6+x^5+x^4+2*x^3-3*x^2-2,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2+3,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3+x^2-x+3,{2}>,
<-x^6-x^5+3*x^4-3*x^3-x^2-x-3,{2}>,
<-x^6+x^5-3*x^4+3*x^3+x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-x^2+x-3,{2}>,
<2*x^6-3*x^4-3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^3+3*x^2-1,{2,3}>,
<-3*x^6+x^5-x^4+3*x^3+3*x^2+2,{2}>,
<3*x^6-x^5+x^4-3*x^3-3*x^2-2,{2,3,5}>,
<-2*x^6-3*x^5-3*x^4+2*x^3+x^2+x+3,{}>,
<3*x^6-x^5+x^4-x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-x^2+x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-x^2-x-3,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+2*x^2-3*x+2,{2,3}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2-x-3,{2,3,281}>,
<-x^6-2*x^5+2*x^4-2*x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2-2*x-1,{2,3}>,
<2*x^6-2*x^5+2*x^4-2*x^3-x^2-x-3,{}>,
<3*x^6+x^5+x^4+3*x^3-3*x^2+3*x-1,{2}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2-2*x-2,{2}>,
<3*x^6+x^5+x^4+2*x^3-2*x^2+x-1,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2-x-3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-x^2+x-3,{2}>,
<-x^6+2*x^5+3*x^4-x^3+x^2-x+3,{2}>,
<-x^6+2*x^4+x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-x^2+x-3,{2}>,
<-3*x^6-x^5-x^4-x^3-2*x^2+2,{2,3}>,
<-2*x^6+2*x^4-x^3+x^2-x+3,{}>,
<-2*x^6+2*x^5+3*x^4-x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-x^3-2*x^2+3,{2}>,
<3*x^6+x^5+x^4+x^3+2*x^2+3*x+2,{2,3}>,
<-3*x^6-x^5-x^4-x^3-2*x^2-3*x-1,{2,3}>,
<2*x^6-x^5-2*x^4+x^3-x^2+x-3,{2}>,
<2*x^6-x^5+2*x^4-x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4-x^3+2*x^2+x-2,{2,3}>,
<3*x^6-x^5+x^4-x^3+2*x^2-x-1,{}>,
<2*x^6-x^5-2*x^4-x^3-x^2-x-3,{}>,
<3*x^6-x^5-2*x^4+x^3-x^2+x-3,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-x^2-x-3,{}>,
<-2*x^6-3*x^5+2*x^4+x^3+x^2+x+3,{}>,
<3*x^6-x^5+x^4-x^3+2*x^2+2*x+2,{2}>,
<3*x^6+x^5+x^4+x^3+x^2+3*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3-x^2-x-3,{2,3}>,
<2*x^6+3*x^5-x^4+x^3-x^2+x-3,{2}>,
<-x^6+2*x^5+2*x^4-x^3+x^2-x+3,{2,5}>,
<3*x^6+x^5+x^4+x^3+x^2+2*x-2,{2}>,
<3*x^6+x^5+x^4+x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4-x^3-2*x^2+2*x+2,{2}>,
<3*x^6+x^5+x^4+x^3+x^2+x-3,{2,3}>,
<-x^6+x^4-x^3+x^2-x+3,{}>,
<-x^6+x^5+x^4-x^3+x^2-x+3,{2}>,
<2*x^6-x^5-x^4+x^3-x^2+x-3,{2}>,
<-3*x^6-x^5-x^4-x^3-x^2+2,{2,3}>,
<3*x^6+x^5-x^4-x^3-x^2-x-3,{2,3}>,
<3*x^6-x^5+x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4-x^3-x^2-x-3,{}>,
<3*x^6-x^5+x^4-x^3+x^2+2*x-2,{}>,
<3*x^6+x^5+x^4+x^3+x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4+x^3+x^2+x+3,{}>,
<-3*x^6+x^5-x^4+x^3-x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5-x^3-x^2-x-3,{2}>,
<-x^6-2*x^5+x^3+x^2+x+3,{2}>,
<2*x^6+2*x^5-x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4+x^3-2*x-2,{2}>,
<-3*x^6-x^5-x^4-x^3+3*x+2,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5+x^4-x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4-x^3-x^2-2*x-2,{2}>,
<3*x^6-x^5+x^4-x^3-x^2-x+2,{2}>,
<-3*x^6+x^5-x^4+x^3+x^2+x-1,{2}>,
<2*x^6-x^5+x^4-x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4-2*x^3+3*x^2+x+2,{2}>,
<-3*x^6+x^5-x^4+2*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+x^5-x^4+2*x^3+3*x^2-3*x-1,{}>,
<-3*x^6+x^5-x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6+2*x^5-2*x^4+x^3+x^2+x+3,{2}>,
<2*x^6-x^5+2*x^4-x^3-x^2-x-3,{}>,
<-2*x^6-x^5-2*x^4-x^3+x^2-x+3,{}>,
<2*x^6-2*x^4+x^3+x^2+x+3,{}>,
<-x^6-2*x^4-x^3+x^2-x+3,{2}>,
<3*x^6+2*x^4-x^3-x^2-x-3,{2}>,
<-3*x^6+x^5-x^4+x^3+x^2+x+3,{2,3,12479}>,
<2*x^6-x^4+x^3+x^2+x+3,{2}>,
<3*x^6-x^5+x^4-x^3-x^2-2,{2,3}>,
<-x^6-2*x^5+2*x^4+x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6+x^5-x^4+x^3+3*x^2+3*x-2,{2,3}>,
<-3*x^6+x^5-x^4+3*x^3+2*x^2+2*x-1,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2+x-3,{}>,
<3*x^6-x^5+x^4-x^3-3*x^2-3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4+x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+x^3-3*x^2+2*x+2,{}>,
<3*x^6-x^5+x^4-x^3-3*x^2+x+3,{2,3}>,
<3*x^6-x^5+x^4-x^3-3*x^2+2*x+2,{}>,
<-3*x^6-x^5-x^4-x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-x^2+x-3,{2}>,
<-3*x^6+x^5-x^4+x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3+x^2+x+3,{2}>,
<3*x^6-x^5+x^4-x^3-3*x^2+2*x-2,{2,23}>,
<-x^6-3*x^5+3*x^4+x^3-x^2+x-3,{2}>,
<2*x^6-3*x^5+3*x^4+x^2-x+3,{}>,
<-x^6+x^5-3*x^4+x^3+x^2+x+3,{2}>,
<-x^6+3*x^5+3*x^4+x^2+x+3,{2}>,
<2*x^6-3*x^5-3*x^4-x^2-x-3,{2,3}>,
<-2*x^6+x^5-3*x^4+x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5+3*x^4+x^2-x+3,{2}>,
<3*x^6+x^5+x^4+x^3-3*x^2+3,{2}>,
<2*x^6+2*x^5-3*x^4-x^2+x-3,{2}>,
<3*x^6-x^5+x^4+3*x^2-2*x-2,{2}>,
<2*x^6+x^5-3*x^4-x^2+x-3,{2}>,
<3*x^6-x^5+x^4-x^3-3*x^2-1,{2}>,
<3*x^6+x^5+x^4+3*x^2+x-2,{2,3}>,
<-3*x^6+x^5-x^4-3*x^2+x+3,{2}>,
<3*x^6-x^5+x^4+3*x^2-x-3,{2}>,
<-3*x^6+x^5-x^4+x^3+3*x^2+2,{2}>,
<3*x^6-x^5+x^4+3*x^2+2,{2}>,
<3*x^6+x^5+x^4+3*x^2-1,{2}>,
<-x^6+x^5+3*x^4+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-3*x^2+2,{2}>,
<3*x^6-3*x^4-x^2-x-3,{2}>,
<-3*x^6+3*x^4+x^2+x+3,{2}>,
<3*x^6+x^5+x^4+2*x^2+x+2,{2,3}>,
<-3*x^6-x^5-x^4-2*x^2-x+2,{2}>,
<-2*x^6-x^5+2*x^4+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4-2*x^2-x+3,{2,3}>,
<3*x^6+2*x^4+x^2-x+3,{2,3}>,
<2*x^6-2*x^4-x^2+x-3,{}>,
<3*x^6-x^5+x^4+2*x^2-2,{2,3}>,
<3*x^6-x^5+x^4+2*x^2+x-1,{2,3}>,
<-3*x^6-x^5-x^4-2*x^2+x+2,{2}>,
<-3*x^6+x^5-x^4-2*x^2-2*x+2,{2}>,
<2*x^6+x^4+x^2-x+3,{2}>,
<-x^6+x^4+x^2+x+3,{2}>,
<3*x^6-x^4-x^2+x-3,{2,3}>,
<3*x^6+x^5+x^4+x^2-x+3,{2}>,
<2*x^6+x^5-x^4-x^2-x-3,{2}>,
<3*x^6+x^5+x^4+x^2-x-2,{2,3}>,
<-3*x^6+x^5-x^4-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+x^2-x+3,{2}>,
<2*x^6-2*x^5+x^4+x^2+x+3,{2}>,
<3*x^6-x^5+x^4+x^2+2*x-1,{}>,
<-3*x^6+x^5-x^4-x^2-3*x-1,{2}>,
<3*x^6-x^5+x^4+x^2+3*x-1,{2}>,
<2*x^6-3*x^5-x^4-x^2+x-3,{2}>,
<-x^6+3*x^5-x^2+x-3,{2,3}>,
<-3*x^6+x^5-x^4+3*x+2,{2}>,
<-3*x^6+x^5-x^4+2*x-1,{2}>,
<3*x^6+x^5+x^4+2*x-2,{2}>,
<2*x^6+2*x^4+x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4+2,{}>,
<-2*x^6-x^5+3*x^4-x^3+x^2-x+3,{2}>,
<2*x^6+3*x^4-x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-x+2,{2,3,53}>,
<2*x^6+x^5-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-x-2,{2}>,
<3*x^6+x^5-x^2-x-3,{2}>,
<-3*x^6+x^5-x^4-2*x+2,{2}>,
<-x^6+3*x^5-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4+x^2-3*x+2,{}>,
<3*x^6+x^5+x^4-x^2+3*x-2,{}>,
<-x^6-2*x^5+x^4-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5+x^4-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-x^2+x-2,{2}>,
<3*x^6-x^4+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-x^2-x+3,{2}>,
<2*x^6-x^5-x^4+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-x^2-x-1,{2}>,
<-3*x^6+x^5-x^4+x^2-x+2,{}>,
<-x^6+2*x^5+x^4-x^2-x-3,{2}>,
<-2*x^6+x^5+3*x^4+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-3*x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-3*x^2-2*x+2,{2,3}>,
<-3*x^6-x^5-x^4+x^2+3*x-1,{2,3}>,
<-3*x^6-x^5-x^4-3*x^2+3*x+2,{2,3}>,
<3*x^6+x^5+x^4-x^2-3*x-2,{2,3}>,
<2*x^6-2*x^5+2*x^4-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+3*x^2+3*x-2,{2,3,19}>,
<2*x^6+2*x^5+2*x^4+x^2+x+3,{2,3}>,
<3*x^6-x^5+x^4+2*x^2-2*x-1,{2}>,
<2*x^6-2*x^5-2*x^4-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4+2*x^2+2*x-1,{}>,
<2*x^6+2*x^4+2*x^3-x^2+x-3,{2}>,
<-2*x^6-2*x^4+2*x^3+x^2+x+3,{2}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2-3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+x^2-x+3,{}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2+x+2,{2,3}>,
<3*x^6-x^5+x^4-2*x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5+2*x^4+2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4+2*x^3-2*x^2-x-2,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3+x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4+x^2+x+3,{2}>,
<-x^6-x^5-3*x^4+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4+3*x^2+x+2,{2,3}>,
<2*x^6-3*x^5+2*x^4+x^2+x+3,{2}>,
<-x^6-3*x^5+2*x^4+x^2+x+3,{2,3}>,
<-3*x^6+x^5-x^4-2*x^2-3*x+2,{2}>,
<3*x^6+x^5+x^4+2*x^2-3*x-2,{2}>,
<3*x^6-x^5+x^4-3*x^2+3,{}>,
<2*x^6-3*x^5+x^4+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+x^4+x^2-x+3,{2}>,
<3*x^6-x^5+x^4+x^2-x+3,{}>,
<-x^6+x^5+x^4+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4-x^3-x^2-3,{2}>,
<3*x^6-x^5+x^4-x^3-x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4+x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4-x^3-x^2+2*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3-x^2+x-3,{2}>,
<-x^6-3*x^5+x^4+x^3-x^2+x-3,{2}>,
<-3*x^6-x^5-x^4+x^3-3*x^2+2,{}>,
<-2*x^6+3*x^4+x^3+x^2-x+3,{}>,
<3*x^6-3*x^4+x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2-x+2,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4-x^3-x^2+x-3,{2}>,
<-3*x^6+3*x^4-x^3+x^2-x+3,{2,3}>,
<-3*x^6+x^5-x^4-x^3-3*x^2-x+3,{2,3,5}>,
<3*x^6+x^5+x^4+x^3+3*x^2-x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+x^2+x+3,{2}>,
<-x^6+x^5+3*x^4-x^3+x^2-x+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-x^2-x-3,{2,5}>,
<-x^6+3*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<3*x^6-2*x^4+x^3-x^2-x-3,{2,3}>,
<-3*x^6+2*x^4-x^3+x^2+x+3,{2,3}>,
<-3*x^6+x^5-x^4-x^3-2*x^2-x+2,{}>,
<3*x^6-x^5-2*x^4-x^3-x^2+x-3,{2,3}>,
<3*x^6-x^5+x^4+x^3+2*x^2+2*x+2,{2,3}>,
<-x^6-2*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-x^2+x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4+2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5-x^3+x^2-x+3,{2}>,
<-x^6-2*x^5-x^3-x^2-x-3,{2}>,
<-x^6-2*x^5-x^3+x^2-x+3,{2}>,
<2*x^6-2*x^5-x^3-x^2-x-3,{}>,
<-2*x^6-2*x^5-x^3+x^2-x+3,{}>,
<3*x^6-x^5-x^3-x^2-x-3,{2,3}>,
<-3*x^6-x^3+x^2-x+3,{2}>,
<2*x^6+x^5-2*x^4+x^2+x+3,{2}>,
<-x^6-x^5+2*x^4-x^2-x-3,{2}>,
<3*x^6+x^5+x^4+x^3-x+3,{2,3}>,
<3*x^6+x^5+x^4-2*x^2+x-1,{}>,
<2*x^6-x^5+2*x^4-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+x^3+x^2-3,{2}>,
<3*x^6-x^5+x^4+x^3+x^2+x+2,{2,3}>,
<-x^6+x^5+x^4+x^3+x^2-x+3,{2}>,
<-2*x^6+x^5-2*x^4+x^2+x+3,{2}>,
<2*x^6+x^5-x^4+x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4+x^3-x^2+x+3,{2,3}>,
<2*x^6-2*x^4+x^2-x+3,{2}>,
<-x^6-2*x^5+x^4-x^3+x^2+x+3,{2,3}>,
<2*x^6-2*x^5-x^4-x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4-2*x^2+2*x+2,{}>,
<3*x^6-x^5+x^4+x^3-x+2,{2}>,
<-3*x^6-x^5-x^4+x^3-x+2,{2}>,
<3*x^6+x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-x^3+2,{2}>,
<3*x^6-x^5+x^4+x^3-1,{2,3}>,
<2*x^6-x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4+x^3-2,{2}>,
<-3*x^6-x^5-x^4+x^3+3,{2}>,
<3*x^6-x^5-x^3+x^2+x+3,{2}>,
<2*x^6-x^5-x^3+x^2+x+3,{2}>,
<2*x^6-x^5-x^3-x^2+x-3,{2,3}>,
<-3*x^6+x^5-x^4-x^3-2*x-1,{2}>,
<-x^6-x^5+3*x^4-x^2+x-3,{2}>,
<3*x^6-x^5+x^4+x^3+2*x^2-2*x-1,{2}>,
<-x^6-3*x^5-x^4-x^3-x^2+x-3,{2,3,113}>,
<-x^6+3*x^5-x^3-x^2+x-3,{2}>,
<-2*x^6-3*x^5+x^3+x^2-x+3,{}>,
<3*x^6-x^5-x^4+x^3+x^2-x+3,{2}>,
<3*x^6-x^4-x^3+x^2+x+3,{2}>,
<2*x^6-x^4-x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-x^3-x^2-1,{2,43}>,
<-3*x^6-x^5-x^4+x^3+x^2+2,{2}>,
<3*x^6-x^5+x^4+x^3-x^2+x+3,{}>,
<-3*x^6+x^5-x^4-x^3+x^2-2*x-1,{2,3}>,
<3*x^6-x^5+x^4+x^3-x^2+2*x-2,{2}>,
<3*x^6-x^5+x^4-2*x^2+3*x-2,{2}>,
<-3*x^6+x^5-x^4+3*x^2+3*x-1,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^2+x-3,{2}>,
<3*x^6+x^2+x+3,{2}>,
<3*x^6-x^5+x^4+2,{}>,
<-x^6+3*x^5+x^4+x^3-x^2-x-3,{}>,
<3*x^6+x^5+x^4-x^3-x^2-3*x-1,{2}>,
<-3*x^6-x^5-x^4+3*x^2+2*x-2,{2}>,
<-3*x^6-x^5-x^4+3*x^2+2*x-1,{2}>,
<-3*x^6-x^5-x^4+3*x^2+3*x+2,{2}>,
<3*x^6-x^5+x^4+x^3-2*x^2-3,{2}>,
<2*x^6+x^5-2*x^4+x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-x^3+2*x^2-x-1,{2}>,
<3*x^6+x^5+x^4-x^3-2*x^2-2*x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-x^2-x-3,{2}>,
<-x^6-2*x^5-3*x^4+x^3+x^2-x+3,{2}>,
<-x^6-2*x^5-2*x^4-x^3+x^2+x+3,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-x^2-x-3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-x^2+x-3,{2,3}>,
<3*x^6+x^5+x^4-x^3-2*x^2-3*x-2,{2,3}>,
<-2*x^6-3*x^5-3*x^4+x^3+x^2-x+3,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3+x^2+x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+x^2+x+3,{}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2-3*x+2,{2}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3+x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-2*x^3+3*x^2-1,{2}>,
<2*x^6-3*x^4+2*x^3-x^2-x-3,{2}>,
<3*x^6-3*x^4+2*x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2-3,{2}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2+x+2,{2}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2+x+2,{}>,
<-2*x^6+x^5+3*x^4+2*x^3+x^2-x+3,{}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2+x+3,{2,3}>,
<-3*x^6+x^5+3*x^4+2*x^3+x^2-x+3,{2,3}>,
<-3*x^6-x^5-x^4+2*x^3-3*x^2+2*x+2,{2,5}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+x^2-x+3,{2,7,107}>,
<3*x^6-x^5+x^4+2*x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6+x^5+x^4-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2+x-3,{2,3}>,
<-x^6-3*x^5+2*x^4+2*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2+3*x-2,{2,3}>,
<-3*x^6-x^5-x^4+x^3+3*x^2-1,{2}>,
<-3*x^6+x^5-x^4-x^3+3*x^2+3,{2,3}>,
<3*x^6-x^5-3*x^4-x^3+x^2+x+3,{2,3}>,
<-3*x^6-x^5-x^4+x^3+3*x^2+x-1,{2,3}>,
<-2*x^6+2*x^5+3*x^4+x^3-x^2-x-3,{2}>,
<-x^6-2*x^5-3*x^4-x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4-x^3+3*x^2-2*x+2,{2,3}>,
<-x^6+3*x^5-3*x^4+x^3+x^2-x+3,{}>,
<3*x^6-x^5+x^4+2*x^3+2*x^2-2,{2,3}>,
<3*x^6-x^5+x^4+2*x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3+x^2-x+3,{}>,
<-x^6-3*x^5+x^4+x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+x^3-x^2-3*x-1,{2}>,
<-3*x^6+x^5-x^4-x^3+x^2+3*x+2,{2}>,
<2*x^6-2*x^5-x^4+x^3+x^2-x+3,{}>,
<2*x^6-2*x^5+2*x^4-2*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-3*x^6-x^5-x^4+2*x^3-2*x^2+2*x+2,{}>,
<-x^6+3*x^5-x^4-x^3-x^2+x-3,{2,29}>,
<3*x^6-x^5+x^4+x^3+x^2-2*x-1,{2}>,
<3*x^6+x^5+x^4-x^3+x^2+x+2,{2}>,
<2*x^6+x^5-x^4-x^3-x^2+x-3,{2}>,
<-3*x^6+x^5-x^4-x^3-x^2+x+3,{2,3}>,
<3*x^6-x^5+x^4+x^3+x^2+2,{2}>,
<2*x^6-x^4-x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4-x^3+x^2-2,{2}>,
<-3*x^6+x^5-x^4-x^3-x^2+3,{2}>,
<3*x^6-x^5+x^4+2*x^3+x^2-x-3,{}>,
<3*x^6+x^5+x^4-2*x^3+x^2+2,{2}>,
<-x^6+x^4-2*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4+2*x^3-x^2+2,{2,3}>,
<-3*x^6-x^5-x^4+2*x^3-x^2+3,{2}>,
<2*x^6-x^5-x^4-2*x^3-x^2+x-3,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-x-3,{2,3}>,
<2*x^6+x^5-2*x^4-x^3-x^2+x-3,{2,3}>,
<-2*x^6+3*x^5+x^4+2*x^3+x^2-x+3,{2,13}>,
<-2*x^6-x^5+2*x^4+x^3+x^2-x+3,{2,3,5}>,
<-3*x^6-x^5-x^4+2*x^3-3*x-1,{2}>,
<2*x^6+2*x^5-2*x^3+x^2+x+3,{2}>,
<-3*x^6+x^5-x^4-2*x^3+2*x+2,{2}>,
<3*x^6+x^5-2*x^3+x^2+x+3,{2,3}>,
<2*x^6+x^5-2*x^3+x^2+x+3,{2}>,
<2*x^6+x^5-2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4-2*x^3+x-2,{2}>,
<3*x^6+x^5-2*x^3-x^2+x-3,{2,3}>,
<3*x^6+x^5+x^4-2*x^3+3,{2,3}>,
<2*x^6-2*x^3-x^2+x-3,{}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2+2*x-2,{2}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2+x+2,{}>,
<-x^6+x^5+2*x^4-2*x^3+x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-x^2-x-3,{2,3}>,
<3*x^6+x^5+x^4-2*x^3+2*x^2+x-3,{2,3}>,
<3*x^6+2*x^4+2*x^3+x^2-x+3,{}>,
<-3*x^6+x^5-x^4-2*x^3-2*x^2+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-x^2+x-3,{2}>,
<3*x^6+x^5+x^4-2*x^3-2*x-2,{2}>,
<-x^6-3*x^5-2*x^3+x^2+x+3,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+x^2-x+3,{}>,
<-x^6+3*x^5+x^4-2*x^3-x^2+x-3,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4+2*x^3-x^2-x+2,{}>,
<3*x^6-x^5+x^4+2*x^3-x^2-x-1,{2}>,
<3*x^6+x^5+x^4-2*x^3+x^2+2*x+2,{2}>,
<2*x^6-x^5-x^4-2*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3-x^2-x-2,{2}>,
<-3*x^6-x^5-x^4+2*x^3-x^2-2*x+2,{2}>,
<3*x^6+x^5+x^4-2*x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4+2*x^3-x^2-x-3,{}>,
<-x^6+2*x^5-x^4+2*x^3+x^2-x+3,{2}>,
<2*x^6+2*x^5+x^4+2*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-2*x^3-x^2-3*x-1,{}>,
<3*x^6-x^5-x^4+2*x^3-x^2-x-3,{}>,
<2*x^6+3*x^5+x^4+2*x^3-x^2-x-3,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3-2*x^2+3*x+2,{2,3}>,
<3*x^6+x^5+x^4-2*x^3-2*x^2+2*x+2,{2}>,
<-3*x^6-x^5-x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-3*x^6-x^5-x^4+2*x^3+2*x^2-2*x-1,{}>,
<2*x^6+3*x^5+2*x^4-2*x^3-x^2+x-3,{2}>,
<2*x^6-2*x^4+2*x^3+x^2-x+3,{2,13}>,
<-x^6+x^5+2*x^4+2*x^3-x^2-x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-x^2+x-3,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4+2*x^3-2*x^2+x-2,{2}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2+3*x-1,{2,3}>,
<-2*x^6-3*x^5+2*x^4+x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+x^3-2*x^2-2*x+2,{2}>,
<-3*x^6-x^5-x^4+x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3+x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-x^3+2*x^2+2*x+2,{2,23}>,
<-2*x^6-2*x^5-2*x^4+x^3+x^2-x+3,{2}>,
<3*x^6-2*x^4-x^3+x^2+x+3,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3+x^2+x+3,{}>,
<3*x^6-x^5+x^4+2*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2-3*x+2,{2,5}>,
<-3*x^6+x^5-x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2-x-3,{}>,
<3*x^6-x^5+x^4+2*x^3-3*x^2+3*x-2,{}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-x^5+x^4+3*x^3+3*x^2-3*x-1,{}>,
<3*x^6+x^5+x^4-x^3-x^2+2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-x^2+x-3,{2,13}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2+x-3,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+x^2-x+3,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+x^2+x+3,{}>,
<3*x^6+x^5-3*x^4-3*x^3-x^2+x-3,{2,3}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2+2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+x^2-x+3,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-x^2+x-3,{}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2-x-2,{}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2+x-3,{2,3}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+x^5-x^4-3*x^3-3*x^2-2*x+2,{2,3}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2-x-3,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3+x^2-x+3,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-x^2+x-3,{2}>,
<3*x^6-x^5+x^4+x^3+3*x^2-x-1,{2,5}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4+x^3-3*x^2-x+2,{2,3}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2-x+3,{}>,
<3*x^6+x^5-3*x^4-x^3-x^2+x-3,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-3*x^2+2*x-1,{2,3}>,
<-3*x^6-x^5-x^4+3*x^3-2*x^2-2*x+2,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2+x-3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-x^2+x-3,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4+3*x^3-2*x^2-x+3,{2,11}>,
<3*x^6-x^5+x^4-3*x^2-2*x-2,{2,5}>,
<3*x^6+2*x^4-3*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-x^3+3*x^2+3,{2}>,
<2*x^6+2*x^4-3*x^3+x^2+x+3,{2}>,
<2*x^6-2*x^4+3*x^3-x^2-x-3,{2}>,
<-x^6+3*x^4+x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4+3*x^3+2*x^2+x+2,{}>,
<-x^6+x^5+2*x^4+3*x^3+x^2-x+3,{2}>,
<2*x^6+2*x^4-x^3+x^2+x+3,{2}>,
<-2*x^6+2*x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-3*x^3+x^2-1,{2}>,
<-3*x^6+x^5-x^4-3*x^3-2*x^2-x+2,{2}>,
<2*x^6-x^4+3*x^3-x^2-x-3,{2}>,
<-3*x^6-x^5+x^4-3*x^3+x^2+x+3,{2,3}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2+x-3,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2+x+3,{2}>,
<3*x^6+x^5+x^4-x^3+2*x^2-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3-x^2-x-3,{2}>,
<2*x^6-2*x^4+x^3-x^2-x-3,{}>,
<2*x^6-3*x^5-x^4+3*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2-x+3,{}>,
<3*x^6+x^5+x^4-3*x^3+x^2-3*x+2,{2}>,
<-3*x^6-x^5-x^4+3*x^3-2*x^2+3,{2}>,
<-x^6-2*x^5+3*x^3+x^2-x+3,{2}>,
<2*x^6+2*x^5+3*x^3-x^2-x-3,{}>,
<-3*x^6-x^5-x^4+3*x^3-3*x-1,{2,3}>,
<2*x^6-x^5+x^4+3*x^3+x^2-x+3,{2}>,
<-2*x^6+2*x^5+3*x^3+x^2-x+3,{2}>,
<2*x^6-2*x^5+3*x^3-x^2-x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3+3*x-2,{2}>,
<3*x^6+x^5+x^4-3*x^3-3*x-1,{2}>,
<3*x^6-x^5+x^4+3*x^3-2*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-x^2+x-3,{2}>,
<-3*x^6-x^5-x^4+3*x^3+3*x+2,{2}>,
<3*x^6-x^5+3*x^3+x^2-x+3,{2,3}>,
<-2*x^6-3*x^5-3*x^3+x^2+x+3,{}>,
<-x^6-x^5+x^4+3*x^3+x^2-x+3,{2,3}>,
<2*x^6-2*x^5+3*x^3+x^2-x+3,{2,3}>,
<3*x^6+x^5+x^4-3*x^3+x+2,{}>,
<-3*x^6-x^5-x^4+3*x^3-x+2,{2}>,
<-x^6-3*x^5+x^4+3*x^3-x^2-x-3,{2}>,
<-3*x^6+x^5-x^4-3*x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4+3*x^3-3,{2}>,
<3*x^6-x^5+x^4+3*x^3+x-2,{2,5}>,
<3*x^6-x^5+x^4+3*x^3-x^2-2*x-1,{2}>,
<3*x^6+x^4-3*x^3+x^2+x+3,{2,3}>,
<-3*x^6+x^5-x^4-3*x^3+x^2+2*x+2,{}>,
<-3*x^6+x^5-x^4-3*x^3-2*x-1,{2}>,
<-3*x^6+x^5-x^4-3*x^3+x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^3+x^2-x+3,{2}>,
<3*x^6-x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<3*x^6+x^5+x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-2*x^4+3*x^3+x^2-x+3,{2}>,
<3*x^6+2*x^4+3*x^3-x^2-x-3,{2}>,
<-3*x^6+x^5-x^4-3*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+x^5+x^4-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5-x^4-3*x^3+2*x^2+2*x-1,{2,3}>,
<-3*x^6+x^5-x^4-3*x^3+3*x^2+3*x-2,{2}>,
<-3*x^6-x^5-x^4+3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+x^2-x+3,{2}>,
<-3*x^6-x^5-x^4+3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6-x^5+x^4+3*x^3-3*x^2-2*x-2,{}>,
<3*x^6+x^5-3*x^4-3*x^3+x^2+x+3,{}>,
<-3*x^6-x^5-x^4+3*x^3+3*x^2-x-1,{2,3,11,31,47}>,
<3*x^6-3*x^4+3*x^3+x^2-x+3,{2}>,
<-x^6-3*x^4-3*x^3+x^2+x+3,{2}>,
<2*x^6+3*x^4+3*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3-3*x^2-x-1,{2,3}>,
<-3*x^6-x^5-x^4+3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-x^2+x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2+x-3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x^2-x+3,{}>,
<2*x^6+3*x^5+3*x^4+3*x^3-x^2-x-3,{2}>,
<3*x^6-x^5+x^4+3*x^3-2*x^2+3,{2,3}>,
<-3*x^6+x^5-x^4-3*x^3+2*x^2-1,{2}>,
<3*x^6+x^5+x^4-3*x^3-2*x^2-1,{2,3}>,
<2*x^6+2*x^4-3*x^3-x^2+x-3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x+3,{2}>,
<3*x^6-x^5-3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+x^5+3*x^3-3*x^2+x+3,{2,3}>,
<3*x^6-x^5-3*x^3+3*x^2+3,{2}>,
<3*x^6-x^5+x^4+x^3-x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+x+3,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+x+3,{}>,
<3*x^6-x^5-3*x^3+3*x^2-3,{2,5}>,
<-x^6+2*x^5+2*x^4+3*x^3+x+3,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x+3,{}>,
<-3*x^6-x^5-3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-x^4-3*x^3+x^2+x+3,{2}>,
<-3*x^6-x^5-3*x^3-2*x^2-x+2,{2}>,
<3*x^6+x^4-3*x^3-x^2+x-3,{2}>,
<-x^6-x^5+3*x^4+3*x^3+x+3,{2}>,
<3*x^6+x^5+x^4-3*x^3-x^2-3,{2,3}>,
<-3*x^6+x^5+3*x^3-2*x^2+x+3,{2,3}>,
<3*x^6-x^5+x^4+3*x^3-x^2+x+2,{2}>,
<-x^6+x^5+x^4+3*x^3-x^2-x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3-x^2-x-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+x+3,{2,3}>,
<2*x^6-2*x^5+3*x^4+3*x^3+x+3,{2}>,
<3*x^6+x^5+3*x^3+2*x^2+2,{2}>,
<2*x^6+x^5+x^4+3*x^3-x^2-x-3,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-x^2-x-3,{2}>,
<3*x^6-2*x^4-3*x^3-x-3,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+x-3,{2}>,
<3*x^6+x^5+x^4-3*x^3-x^2-2*x-1,{2}>,
<3*x^6+x^5+3*x^3+2*x^2-3,{2}>,
<3*x^6-x^5-3*x^3+3*x^2+2*x-2,{2}>,
<3*x^6+x^5+3*x^3+x^2-1,{2}>,
<-3*x^6+x^5+3*x^3-x^2+2,{2}>,
<-2*x^6+x^4+3*x^3+x+3,{2}>,
<-3*x^6-x^5-3*x^3-x^2+3,{}>,
<3*x^6-x^5-3*x^3+x^2-3,{}>,
<3*x^6-x^5-3*x^3+x^2+x-2,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-x-3,{2,3}>,
<3*x^6-x^5-3*x^3+x^2+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-x^2-x-3,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3+x^2-x+3,{2}>,
<3*x^6+x^5+x^4-2*x^3-2*x^2-3*x-1,{2}>,
<3*x^6-x^5+x^4+3*x^3+3*x^2-2,{2}>,
<-x^6+x^5-3*x^3-x+3,{}>,
<3*x^6+x^5+3*x^3-x-3,{2,3}>,
<3*x^6-x^5-3*x^3+2*x-2,{2,3}>,
<-3*x^6+x^5+3*x^3-3*x-1,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+x-3,{}>,
<2*x^6-3*x^5-x^4-3*x^3-x+3,{}>,
<-x^6+3*x^5-x^4+3*x^3+x+3,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+x-3,{2}>,
<3*x^6-3*x^4+3*x^3-x^2-x-3,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-x+3,{2}>,
<-x^6-2*x^5+x^4-3*x^3-x-3,{}>,
<2*x^6+x^5+3*x^4+3*x^3+x^2-x+3,{2,3}>,
<3*x^6-x^5-3*x^3-x^2-2*x-1,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3-x-3,{}>,
<3*x^6-x^5-3*x^3-x^2-2*x-2,{2}>,
<-x^6+x^5+x^4+3*x^3+x-3,{2}>,
<3*x^6+x^5+3*x^3-x^2+x-1,{2}>,
<3*x^6+x^5+3*x^3-x^2-1,{2}>,
<3*x^6-x^5-3*x^3-x^2+x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+x+3,{}>,
<-x^6-2*x^5-x^4+3*x^3+x+3,{}>,
<3*x^6+x^4+3*x^3+x-3,{2,3}>,
<2*x^6+2*x^5+x^4-3*x^3-x-3,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3+x+3,{2}>,
<-3*x^6-x^5-3*x^3+x^2+3*x-1,{2,3}>,
<3*x^6-x^5-3*x^3-x^2-3,{2}>,
<3*x^6+x^5-x^4-3*x^3-x+3,{}>,
<2*x^6-x^5+x^4+3*x^3+x-3,{}>,
<-2*x^6-x^5+2*x^4-3*x^3-x-3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+x+3,{2}>,
<-x^6+x^5+2*x^4+3*x^3+x-3,{2}>,
<3*x^6+x^5+3*x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-x-3,{2}>,
<3*x^6+x^5+3*x^3-2*x^2+2,{2,3}>,
<-x^6+2*x^4+3*x^3+x-3,{2}>,
<2*x^6+2*x^4-3*x^3-x-3,{2}>,
<3*x^6-x^5-3*x^3-2*x^2-2,{2}>,
<3*x^6+2*x^4-3*x^3-x-3,{2}>,
<3*x^6+x^5+3*x^3-2*x^2-3,{2}>,
<3*x^6-x^5-3*x^3-2*x^2+x-1,{2,3}>,
<3*x^6-x^5-3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x-3,{}>,
<-x^6+2*x^5+2*x^3-x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-x+3,{2}>,
<-3*x^6+x^5-x^4-2*x^3+3*x^2+x-1,{2}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2+x-2,{2,11}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2+3,{2}>,
<-x^6+3*x^4+2*x^3-x^2-x-3,{2,5,7}>,
<3*x^6+x^5+x^4-2*x^3-3*x^2-3,{2}>,
<-x^6+x^5-3*x^4+2*x^3+x^2-x+3,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-x+3,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3+x-3,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3-x+3,{2}>,
<-x^6+3*x^5+x^4+3*x^3+x+3,{}>,
<-2*x^6+2*x^5+x^4+3*x^3+x+3,{2}>,
<-x^6+x^5+x^4+3*x^3+x+3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x+3,{2}>,
<2*x^6-x^5-x^4-3*x^3-x-3,{2,3}>,
<-2*x^6+3*x^5-3*x^4+3*x^3+x+3,{2}>,
<-2*x^6+x^5+x^4+3*x^3+x+3,{2}>,
<3*x^6-x^5-3*x^3-3*x^2-2*x+2,{2}>,
<3*x^6+x^5+3*x^3+x^2+x-3,{2}>,
<-3*x^6-x^5-3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+x^4+3*x^3+x+3,{}>,
<-3*x^6-x^5+3*x^4-2*x^3-x+3,{2}>,
<2*x^6+3*x^4+2*x^3+x+3,{2}>,
<3*x^6-x^5-2*x^3+3*x^2-1,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+x-3,{2,3}>,
<-3*x^6-x^5-2*x^3-3*x^2+2,{2,3}>,
<3*x^6+x^5+2*x^3+3*x^2-x+2,{2,3}>,
<2*x^6+3*x^5+3*x^4-2*x^3-x+3,{2}>,
<3*x^6+x^5+2*x^3+3*x^2-3*x-1,{2,3}>,
<2*x^6+x^5-3*x^4-2*x^3-x-3,{2}>,
<-3*x^6-x^5-2*x^3-3*x^2+3*x+2,{2,3}>,
<-x^6+3*x^5+2*x^4+2*x^3+x+3,{2}>,
<3*x^6+x^5+2*x^3+3*x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+x-3,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3-x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-x-3,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+x+3,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+x+3,{2}>,
<3*x^6-x^5-2*x^3+2*x^2-x-2,{}>,
<2*x^6+2*x^5-3*x^4-2*x^3-x-3,{2,3,13}>,
<3*x^6+x^5+2*x^3+3*x^2-2*x-2,{2}>,
<-3*x^6-x^5-2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+x+3,{2}>,
<3*x^6-x^5-2*x^3+2*x^2+3,{2,3,5,7}>,
<-3*x^6+2*x^4+2*x^3+x+3,{2}>,
<-x^6+x^5+2*x^4-2*x^3-x+3,{2}>,
<-x^6-2*x^5+x^4-2*x^3-x+3,{2}>,
<3*x^6+x^5+2*x^3+2*x^2-2*x+2,{2,3}>,
<-3*x^6-x^5-2*x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3-x+3,{2}>,
<3*x^6-x^5-2*x^3+x^2-2*x-2,{2}>,
<-3*x^6-x^5-2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6+x^5+x^4+2*x^3+x+3,{2}>,
<3*x^6-x^5-2*x^3+x^2-x-1,{}>,
<3*x^6+x^5+2*x^3+2*x^2-3*x+2,{}>,
<2*x^6+x^5-x^4+2*x^3+x-3,{2}>,
<-3*x^6-x^5-2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x+3,{2}>,
<3*x^6+x^5+2*x^3+x^2-x-3,{2}>,
<2*x^6+2*x^5+x^4-2*x^3-x+3,{2}>,
<-3*x^6-x^5-2*x^3-x^2+2*x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+x-3,{2}>,
<2*x^6-3*x^5-3*x^3-x-3,{2,19}>,
<-2*x^6+3*x^5+x^4-2*x^3-x+3,{2}>,
<3*x^6-x^5-2*x^3-3*x+2,{2}>,
<-x^6+2*x^5+2*x^3+x+3,{2,7}>,
<-2*x^6-2*x^5-2*x^3-x+3,{2}>,
<-3*x^6+x^5+2*x^3+3*x-1,{2,3}>,
<3*x^6+x^5+2*x^3+x+3,{2}>,
<-x^6+x^5+2*x^3+x+3,{}>,
<-x^6-3*x^5-2*x^3-x+3,{2}>,
<2*x^6-x^5-2*x^3-x-3,{2}>,
<-3*x^6-x^5-2*x^3-3*x+2,{}>,
<-2*x^6+x^5+2*x^3+x+3,{2}>,
<-2*x^6-3*x^5-2*x^3-x+3,{}>,
<3*x^6+x^5+2*x^3+2,{2}>,
<-x^6+2*x^3+x+3,{}>,
<3*x^6-x^5-2*x^3-3,{2}>,
<3*x^6-x^5-2*x^3+x+2,{2}>,
<-x^6+x^5+3*x^4-3*x^3-x-3,{2,541}>,
<-3*x^6-x^5-2*x^3+x+3,{2}>,
<2*x^6-2*x^3-x-3,{}>,
<3*x^6-x^5-3*x^3-3*x^2+x-1,{}>,
<3*x^6-x^5-2*x^3+x-3,{2}>,
<3*x^6-x^5-2*x^3+3*x+2,{2}>,
<-3*x^6+x^5+3*x^3+3*x^2-x+2,{2}>,
<3*x^6+x^5+3*x^3-3*x^2-3*x-2,{2}>,
<3*x^6-2*x^3-x-3,{2}>,
<3*x^6+x^5+2*x^3+3*x^2+3*x+2,{2,3}>,
<-3*x^6-x^5-x^4+3*x^3+2*x^2+x+2,{2,3}>,
<-x^6-3*x^5-3*x^4-2*x^3-x-3,{2}>,
<3*x^6+x^5+2*x^3-3*x-1,{2,3}>,
<2*x^6+3*x^5+x^4+2*x^3+x-3,{2,3}>,
<2*x^6+3*x^5-2*x^3-x-3,{2}>,
<3*x^6-x^5-2*x^3+3*x^2-3*x-1,{2}>,
<3*x^6+x^5+2*x^3-x^2+3*x-2,{2,3}>,
<-3*x^6-x^5-2*x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5-x^4+2*x^3+x+3,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3+x-3,{2}>,
<3*x^6+x^5+2*x^3+3*x^2+2*x+2,{2,3}>,
<3*x^6+x^5+2*x^3-x^2-x+3,{2,3}>,
<3*x^6+x^5+2*x^3-x^2-x-1,{}>,
<-2*x^6-x^5-3*x^4-3*x^3-x+3,{2}>,
<-2*x^6+3*x^4+3*x^3+x-3,{2}>,
<3*x^6+x^5+3*x^3-3*x^2+2,{2}>,
<-x^6+3*x^4+3*x^3+x-3,{}>,
<-x^6-3*x^4-3*x^3-x+3,{2}>,
<2*x^6+3*x^4-3*x^3-x-3,{2}>,
<-2*x^6-3*x^4-3*x^3-x+3,{2}>,
<-3*x^6-x^5-3*x^3+3*x^2+3,{2}>,
<-3*x^6-x^5-2*x^3+2*x^2-2*x-2,{2}>,
<3*x^6+x^5+2*x^3-2*x^2+2*x+2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-x-3,{2}>,
<3*x^6+x^5+2*x^3-2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3+x-3,{2}>,
<-3*x^6-x^5-2*x^3+2*x^2-x-1,{2,3,7}>,
<3*x^6+x^5+2*x^3-2*x^2+x-2,{2,3}>,
<3*x^6+x^5+2*x^3-2*x^2-1,{2}>,
<-3*x^6+x^5+2*x^3+2*x^2+3,{2}>,
<3*x^6-x^5-2*x^3-2*x^2+x+3,{2,3}>,
<-x^6+x^5-2*x^4-2*x^3-x+3,{2}>,
<-3*x^6-x^5-2*x^3+2*x^2+x+2,{2}>,
<-3*x^6+x^5+2*x^3+2*x^2-2*x-1,{2,3}>,
<-x^6+3*x^5+2*x^4-2*x^3-x-3,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+x+3,{2}>,
<-3*x^6-x^5-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3-x+3,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+x-3,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-x-3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-x-3,{}>,
<3*x^6+x^5+2*x^3-3*x^2+2*x-2,{}>,
<3*x^6+x^5+2*x^3-3*x^2+x+3,{}>,
<-2*x^6+x^5+3*x^4+2*x^3+x-3,{}>,
<3*x^6+x^5+2*x^3-3*x^2+x+2,{2}>,
<3*x^6+x^5+2*x^3-3*x^2+x-1,{2}>,
<-x^6+x^5-x^4+2*x^3+x+3,{2}>,
<3*x^6-x^4+2*x^3+x+3,{2}>,
<-3*x^6-x^5-2*x^3+x^2+2,{2}>,
<3*x^6+x^5+2*x^3-x^2-2,{2}>,
<-3*x^6-x^4-2*x^3-x+3,{2}>,
<2*x^6+3*x^4+2*x^3+x-3,{2,3,5}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-x-3,{2}>,
<3*x^6+x^5+2*x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6+x^5+2*x^3+3*x^2-3*x-1,{}>,
<-x^6+3*x^5-3*x^4-2*x^3-x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-x-3,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-x+3,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x+3,{2}>,
<3*x^6-x^5-x^3+3*x^2-x+2,{2}>,
<3*x^6-x^5-x^3+3*x^2-x-1,{2}>,
<-3*x^6+x^5+x^3-3*x^2+x+2,{2}>,
<3*x^6-x^5-x^3+3*x^2+3,{2,3}>,
<-x^6+3*x^4+x^3+x+3,{2}>,
<2*x^6-3*x^4-x^3-x-3,{}>,
<-2*x^6+3*x^4+x^3+x+3,{}>,
<-3*x^6-x^5-x^3-3*x^2+x+2,{2}>,
<-2*x^6-x^5+3*x^4+x^3+x+3,{2,3}>,
<-x^6+2*x^5+3*x^3+x+3,{2}>,
<-2*x^6+2*x^5+3*x^3+x+3,{2,5}>,
<3*x^6-x^5-3*x^3-x-1,{2}>,
<3*x^6+x^5+3*x^3+x-3,{2}>,
<-x^6-3*x^3-x+3,{2}>,
<-x^6+3*x^5+x^4+2*x^3+x-3,{2,3}>,
<3*x^6+x^5+2*x^3-x^2+3*x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3+x+3,{2}>,
<2*x^6-2*x^5-3*x^4+x^3+x-3,{2}>,
<3*x^6+x^5+2*x^3-3*x^2+x-2,{2}>,
<3*x^6-x^5-2*x^3-3*x^2+2,{2,3}>,
<-x^6+3*x^4-2*x^3-x-3,{2}>,
<-x^6-3*x^4+2*x^3+x+3,{2}>,
<-x^6+2*x^4+x^3+x+3,{2}>,
<-3*x^6-x^5-x^3-2*x^2+2,{2}>,
<2*x^6-x^5+2*x^4+x^3+x+3,{2}>,
<3*x^6+x^5+x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-2*x^4+x^3+x-3,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+x+3,{2,7}>,
<2*x^6+2*x^5-2*x^4-x^3-x-3,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3-x+3,{2}>,
<3*x^6-x^5-x^3+2*x^2+3*x+2,{2}>,
<3*x^6+x^5+x^3+2*x^2-3*x-1,{}>,
<-x^6+3*x^5+x^4+x^3+x+3,{2}>,
<3*x^6+x^5+x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5-x^4-x^3-x-3,{2}>,
<-x^6+2*x^5+x^4+x^3+x+3,{}>,
<2*x^6+2*x^5-x^4+x^3+x-3,{}>,
<3*x^6+x^5+x^3+x^2+2*x-2,{2}>,
<3*x^6+x^5+x^3+x^2-3,{2}>,
<3*x^6+x^5+2*x^3-x^2-x-2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-x+3,{2}>,
<-x^6+3*x^5+x^4-2*x^3-x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-x-3,{2,3}>,
<3*x^6+x^5+2*x^3-2*x^2+3*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-x-3,{}>,
<3*x^6-x^5-2*x^3-2*x^2-3*x-2,{}>,
<-3*x^6-x^5-x^3-x^2+3*x-1,{2,3}>,
<-3*x^6-x^5-x^3-x^2+3*x+2,{2,3}>,
<3*x^6-x^5-x^3-3*x-1,{2,11}>,
<-x^6+2*x^5+x^3+x+3,{2}>,
<3*x^6+x^5+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-x^3-x+3,{2}>,
<3*x^6+x^3+x-3,{}>,
<3*x^6+x^5+x^3-3,{}>,
<3*x^6-x^5+x^3+x+3,{}>,
<3*x^6+x^5+x^3-2*x+2,{2}>,
<3*x^6+x^5+x^3-2*x-1,{}>,
<-3*x^6+x^5+x^3-2*x+2,{2}>,
<-3*x^6+x^5+3*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+x-3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-x+3,{2}>,
<3*x^6+x^5+x^3-x^2+2*x-1,{2}>,
<3*x^6-x^5-x^3-x^2-x+3,{2,3}>,
<2*x^6-x^5+x^4-x^3-x-3,{2}>,
<2*x^6-x^4-x^3-x+3,{2,3}>,
<3*x^6+x^5+x^3-x^2-1,{}>,
<2*x^6+x^4+x^3+x-3,{}>,
<3*x^6+x^5+x^3-x^2-2,{}>,
<-3*x^6-x^5-x^3+x^2+3,{2,3}>,
<2*x^6+x^5-x^4-x^3-x+3,{2}>,
<-3*x^6-x^5-x^3+x^2+2*x-1,{2,3}>,
<3*x^6-x^5-x^3-x^2+3*x+2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x+3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x+3,{2}>,
<3*x^6-2*x^4-x^3-x+3,{2,3}>,
<-3*x^6+x^5+x^3-2*x^2+3*x-1,{2}>,
<3*x^6-x^5-x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-x+3,{2}>,
<2*x^6+2*x^4-x^3-x-3,{2}>,
<3*x^6+x^5+x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-x+3,{2}>,
<3*x^6+x^5+x^3+2*x^2+2*x-2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-x-3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+x^2+x+3,{}>,
<3*x^6+x^5+x^3+2*x^2+3,{2,3}>,
<-x^6+3*x^5+2*x^4+3*x^3-x^2-x-3,{2,5}>,
<-x^6-3*x^5-2*x^4-3*x^3+x^2+x+3,{}>,
<-2*x^6+2*x^5+3*x^4+x^3+x-3,{2}>,
<-3*x^6+x^5+x^3+3*x^2+2*x-1,{2,5}>,
<-x^6+2*x^5-3*x^4+x^3+x+3,{2,3}>,
<-3*x^6+x^5-x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-x^5-x^3+3*x^2-2*x+2,{2,3}>,
<3*x^6-x^5-x^3-3*x^2-2*x-2,{2}>,
<3*x^6+x^5+x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+x^3+x+3,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-x-3,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-x+3,{2}>,
<-x^6+2*x^5+3*x^4-x^3-x-3,{2}>,
<3*x^6-x^5-x^3-3*x^2+2*x-1,{}>,
<2*x^6-2*x^5+3*x^4+x^3+x-3,{2}>,
<3*x^6+x^5+x^3-3*x^2-2*x-2,{2}>,
<-3*x^6+x^5+x^4+2*x^3+x+3,{2,3}>,
<3*x^6+x^5+2*x^3+x^2-2,{2}>,
<3*x^6-x^4+2*x^3+x-3,{2}>,
<2*x^6-2*x^5-3*x^4-x-3,{2}>,
<3*x^6-x^5+3*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4-x-3,{}>,
<3*x^6-x^5+3*x^2-x-2,{2}>,
<3*x^6-x^5+3*x^2+3,{2}>,
<-3*x^6-x^5-3*x^2+2,{2}>,
<3*x^6+x^5+3*x^2-2,{2}>,
<3*x^6-3*x^4+x-3,{2}>,
<2*x^6-x^5+3*x^4+x+3,{2}>,
<3*x^6+x^5+3*x^2-x-1,{2}>,
<-3*x^6-x^5-3*x^2+x+2,{2}>,
<-3*x^6-x^5+3*x^4+x+3,{2,3}>,
<3*x^6-x^5-x^3+x^2+2*x+2,{2,3}>,
<3*x^6+x^5+3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x+3,{2}>,
<3*x^6-x^5-x^3+x^2+3*x+2,{2}>,
<2*x^6+2*x^4+x+3,{2}>,
<-x^6+2*x^4-x+3,{2}>,
<-3*x^6-x^5-2*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+x-3,{2}>,
<-x^6-3*x^5-x^4-x-3,{}>,
<-x^6+3*x^5+x^4+x+3,{2}>,
<-3*x^6+x^5-x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+x+3,{}>,
<3*x^6+x^5+x^2+2*x-2,{2}>,
<2*x^6+3*x^5+x^4+x^3+x-3,{}>,
<-2*x^6-3*x^5-x^4-x^3-x+3,{}>,
<3*x^6-x^5+x^2+3,{2,3}>,
<2*x^6+x^4+x+3,{2}>,
<2*x^6-x^4+x-3,{2}>,
<3*x^6+x^5+3*x^3-2,{2}>,
<3*x^6+x^5+x^2-x+2,{2,3}>,
<-3*x^6+x^5-x^2-x+2,{}>,
<-2*x^6-x^5+x^4+x+3,{}>,
<3*x^6+x^5+3*x^3-x+2,{}>,
<3*x^6-x^5-x^3-2*x-2,{2}>,
<2*x^6-x^5-x^3-x+3,{2,5}>,
<3*x^6-x^5-x^3-x-1,{}>,
<2*x^6-3*x^5-x-3,{2}>,
<-3*x^6+x^5-x^2-x+3,{2,3}>,
<-2*x^6+3*x^5+x+3,{2}>,
<2*x^6+2*x^5+x+3,{2}>,
<2*x^6-x^5-x^3-x-3,{2}>,
<-x^6-2*x^5-x-3,{2}>,
<3*x^6-x^5-2*x-1,{}>,
<2*x^6-2*x^5-x^4+x-3,{2}>,
<2*x^6-2*x^5-x-3,{}>,
<-x^6-3*x^5-x^4+x-3,{2}>,
<3*x^6-x^5-3*x-1,{2}>,
<-3*x^6-x^5-x^3-x+3,{2,3}>,
<-3*x^6+x^5-x+2,{2}>,
<-2*x^6-3*x^5+x+3,{2}>,
<-2*x^6+2*x^5-x^4+x+3,{2}>,
<-x^6+x^5+x^4+x-3,{2}>,
<-x^6-x^5-x^4-x+3,{2}>,
<-3*x^6+x^5+x^2+x+2,{2}>,
<-3*x^6-x^5+x^2+2*x-1,{2}>,
<-2*x^6-x^5-x^4-x+3,{2}>,
<3*x^6-x^5-x^2+3*x+2,{2}>,
<3*x^6+x^5-x^2+2,{2,3}>,
<-x^6+3*x^5+x^4-x-3,{2}>,
<-x^6-3*x^5-x^4+x+3,{}>,
<-x^6-3*x^5+2*x^4-x-3,{2}>,
<3*x^6+x^5-x^2-x+3,{2}>,
<3*x^6-x^5-2*x^2-2*x-1,{2}>,
<3*x^6+x^5-x^2-2*x+2,{}>,
<3*x^6-x^5-2*x^2-2*x-2,{2}>,
<-3*x^6-x^5+2*x^2+x-1,{2}>,
<-3*x^6+x^5+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4-x+3,{}>,
<-x^6+2*x^5+2*x^4-x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+x-3,{2}>,
<-3*x^6-2*x^4+x+3,{2}>,
<-3*x^6-x^5+2*x^2+3*x+2,{2}>,
<3*x^6-x^5-2*x^2+x+2,{2,3}>,
<3*x^6+x^5-3*x^2-3,{2}>,
<-x^6-x^5-3*x^4+x+3,{}>,
<-2*x^6+2*x^5+3*x^4-x-3,{2}>,
<-2*x^6-2*x^5-3*x^4+x+3,{2}>,
<3*x^6+x^5-x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6-x^5+x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-x^5+x^3-3*x^2-3*x+2,{2,5}>,
<3*x^6+x^5-x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-x^5+x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5+3*x^4+x^3-x+3,{2}>,
<-2*x^6-x^5-x+3,{2,79}>,
<3*x^6+x^5+3,{2}>,
<2*x^6-x^5+x+3,{2}>,
<3*x^6-x^5+x-1,{2}>,
<3*x^6-x^5+3*x^2-2*x+2,{2}>,
<3*x^6+x^5+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^4+x^3-x-3,{}>,
<-2*x^6+2*x^4+x^3-x+3,{2}>,
<-3*x^6+x^5-x^3-2*x^2+3,{2,3}>,
<3*x^6+x^5-x^3+2*x^2-3,{2}>,
<3*x^6+x^5-x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4-x^3+x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3-x-3,{2,3}>,
<-x^6+2*x^5+2*x^4+x^3-x+3,{}>,
<2*x^6+2*x^5-2*x^4+x^3-x-3,{2}>,
<-x^6-3*x^5-x^4+x^3-x-3,{}>,
<3*x^6+x^5-x^3+3*x^2-2*x-2,{2,3,127}>,
<3*x^6-x^5+x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6+x^5-x^3+3*x^2-3*x-1,{2}>,
<-3*x^6+x^5-x^3-3*x^2-3*x+2,{}>,
<-x^6+2*x^5+2*x^4-x^3+x+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-x-3,{}>,
<3*x^6-x^5+x^3+2*x^2-x+2,{2,3}>,
<-3*x^6-x^5+x^3-2*x^2-x+2,{2}>,
<-3*x^6+x^5-x^3-2*x^2+x+3,{2}>,
<3*x^6+2*x^4+x^3-x+3,{2}>,
<2*x^6-3*x^5+x^3-x+3,{2}>,
<-x^6+3*x^5-x^3+x-3,{}>,
<-x^6-3*x^5+x^3-x+3,{2}>,
<-3*x^6+x^5-x^3+3*x+2,{2}>,
<3*x^6+x^5-x^3+2*x+2,{}>,
<-2*x^6-2*x^5+x^3-x+3,{2}>,
<-3*x^6-x^5+3*x^2-3*x-1,{2,3}>,
<3*x^6+x^5-x^3+3,{2}>,
<-3*x^6-x^5+3*x^2-3*x+2,{2,3}>,
<3*x^6+x^5-x^3+2,{2,7}>,
<-x^6-x^3+x+3,{}>,
<-3*x^6-x^5+x^3+2,{2,3}>,
<2*x^6-2*x^5-x^3+x+3,{2}>,
<-x^6+2*x^5+x^3-x-3,{2}>,
<-2*x^6-2*x^5-x^3+x+3,{2,3}>,
<3*x^6-x^5+x^3+3*x+2,{2,3}>,
<-x^6-3*x^5-x^3+x-3,{2}>,
<2*x^6-3*x^5-x^3+x-3,{2,3}>,
<-3*x^6+x^5-x^3+x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+x-3,{2}>,
<3*x^6-x^5-x^3-2*x^2-3*x+2,{2}>,
<-3*x^6-x^5-x^3+2*x^2-3*x-1,{2,3}>,
<-x^6+3*x^5-2*x^4+x^3+x+3,{2}>,
<-3*x^6+x^5+x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+x+3,{}>,
<-3*x^6-x^5-x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+x+3,{2,5}>,
<3*x^6-x^5+x^3-x^2-2*x-1,{2}>,
<2*x^6+3*x^4-x^3+x+3,{2}>,
<3*x^6-x^5+x^3+3*x^2-1,{2}>,
<2*x^6+2*x^5+x^4-x^3+x-3,{2}>,
<2*x^6-3*x^4-x^3+x-3,{2}>,
<3*x^6-x^5+x^3-x^2-2*x-2,{2}>,
<3*x^6-3*x^4+x^3-x-3,{2}>,
<2*x^6+x^5-x^4-x^3+x+3,{2}>,
<-2*x^6+x^5+3*x^4+x^3-x+3,{2}>,
<3*x^6-x^5+x^3-x^2-3,{2}>,
<-3*x^6-x^5+x^3-3*x^2+x+3,{2,3}>,
<2*x^6-2*x^5-x^4-x^3+x+3,{2}>,
<-3*x^6+x^5-x^3+x^2-2*x-1,{}>,
<3*x^6+x^5-x^3+3*x^2-2*x+2,{2}>,
<-x^6-2*x^5-x^4-x^3+x+3,{2}>,
<3*x^6+x^5-x^3+3*x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5+x^4+x^3-x-3,{}>,
<-2*x^6-2*x^5-x^4-x^3+x+3,{}>,
<-3*x^6+x^5-x^3-3*x^2-2*x+2,{2,3}>,
<-3*x^6+x^5-x^3+x^2-3*x-2,{}>,
<2*x^6+3*x^5+x^4+x^3-x-3,{}>,
<-2*x^6-3*x^5-x^4-x^3+x+3,{}>,
<3*x^6-x^5+x^3-2*x^2-2,{2}>,
<-x^6-3*x^5-2*x^4+x^3-x+3,{2}>,
<-3*x^6+x^5-x^3+2*x^2+3,{2,3}>,
<-3*x^6-2*x^4-x^3+x+3,{2,3}>,
<3*x^6+x^5-x^3-2*x^2-x+3,{2,3}>,
<3*x^6+x^5-x^3-2*x^2+3*x-2,{2}>,
<-3*x^6+x^5-x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3-x+3,{2}>,
<-3*x^6+x^5-x^3+2*x^2-2*x-2,{2,11}>,
<3*x^6+x^5-x^3-2*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+x^3-x-3,{2}>,
<-3*x^6-x^5+x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6-x^5+x^3+3*x^2-3*x-1,{}>,
<-x^6-3*x^5-3*x^4+x^3-x+3,{}>,
<-2*x^6+3*x^5-2*x^4+x^3-x+3,{2}>,
<3*x^6+x^5-x^3-2*x^2+x+3,{2}>,
<-2*x^6-x^5-3*x^4+x^3-x+3,{}>,
<-x^6-x^5+2*x^4+x^3-x-3,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+x+3,{2}>,
<2*x^6-2*x^4+x^3-x+3,{}>,
<-3*x^6-3*x^4-x^3+x+3,{2}>,
<-2*x^6+x^5-3*x^4+x^3-x+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-x+3,{2}>,
<-3*x^6-x^5+x^3+3*x^2+3*x-1,{2,3,5}>,
<-x^6+3*x^5-3*x^4+x^3+x+2,{2}>,
<-3*x^6+x^5-x^3+3*x^2-3*x+2,{2}>,
<-x^6-x^5+3*x^4+2*x^3-x+3,{2}>,
<3*x^6-x^5+2*x^3+3*x^2-3*x+2,{2,3}>,
<-3*x^6-x^5+2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-x+3,{}>,
<3*x^6+x^5-2*x^3+3*x^2+x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x+3,{2}>,
<2*x^6-3*x^5+2*x^4-x+3,{2}>,
<-3*x^6-x^5-2*x^2-3*x-1,{2,3}>,
<3*x^6+x^5+2*x^2+3*x-2,{}>,
<3*x^6+x^5+2*x^2+x-1,{2,3}>,
<3*x^6-x^5+2*x^3+2*x^2-x-3,{2,3}>,
<-x^6+2*x^4+2*x^3-x+3,{2,3}>,
<2*x^6-2*x^4-2*x^3+x-3,{2}>,
<3*x^6-2*x^4+2*x^3-x-3,{2}>,
<3*x^6+x^5-2*x^3+2*x^2-x-1,{2,3}>,
<-3*x^6+x^5-2*x^3-2*x^2-x+2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+x+3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x+3,{2,7}>,
<2*x^6+2*x^5+2*x^4+x^3+x-3,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-x+3,{}>,
<3*x^6-x^5-x^3-2*x^2-x-2,{2}>,
<3*x^6+x^5-2*x^3+x^2+x+2,{2,3}>,
<-x^6-x^5+x^4+2*x^3-x+3,{2}>,
<-3*x^6-x^5+2*x^3-x^2-x+2,{}>,
<-2*x^6-x^5+x^4+2*x^3-x+3,{}>,
<2*x^6+x^5+3*x^4+x^3+x-3,{2}>,
<-3*x^6-3*x^4-x^3-x+3,{2,3}>,
<2*x^6-3*x^5-x^4-2*x^3+x-3,{2,3}>,
<-3*x^6-x^5+2*x^3-3*x-1,{2}>,
<3*x^6-x^5+2*x^3-x+3,{}>,
<2*x^6-x^5+2*x^3-x+3,{2}>,
<-x^6-x^5+2*x^3-x+3,{2}>,
<2*x^6-x^5+2*x^3-x-3,{}>,
<3*x^6-2*x^3+x+3,{2}>,
<2*x^6-x^5-2*x^3+x+3,{2,3,13}>,
<-2*x^6+x^5+2*x^3-x+3,{2}>,
<2*x^6-2*x^5-2*x^3+x+3,{2}>,
<-3*x^6-x^5+2*x^3+2*x-1,{2}>,
<3*x^6+x^5-2*x^3-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^3-x-3,{2}>,
<2*x^6-3*x^5-2*x^3+x-3,{2}>,
<3*x^6+x^5-2*x^3-3*x-2,{2}>,
<-3*x^6-x^5+2*x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^3-x+3,{2}>,
<2*x^6-3*x^5+x^4+2*x^3-x-3,{2}>,
<3*x^6+x^5-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-x^5+2*x^3-x^2-2*x+2,{2}>,
<-x^6-2*x^5+x^4+2*x^3-x-3,{2}>,
<3*x^6+x^5-2*x^3-x^2+x+3,{}>,
<3*x^6+x^5-2*x^3-x^2+2,{}>,
<3*x^6+x^5-2*x^3-x^2-x+2,{2}>,
<-3*x^6-x^5+2*x^3-x^2-2*x+2,{}>,
<-x^6+x^5-x^4+2*x^3-x+3,{2}>,
<-3*x^6-x^5+2*x^3+x^2+x+2,{}>,
<-2*x^6+x^5-x^4+2*x^3-x+3,{}>,
<-x^6-3*x^5-x^4-2*x^3+x+3,{2}>,
<-x^6+3*x^5-2*x^4-2*x^3+x+3,{2}>,
<-3*x^6+x^5-2*x^3+x^2-2*x-2,{2,5}>,
<2*x^6-3*x^5+2*x^4+2*x^3-x-3,{2}>,
<-3*x^6-x^5+2*x^3+2*x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5+x^4+2*x^3-x-3,{2}>,
<3*x^6+x^5-2*x^3-2*x^2+x-2,{2,3}>,
<3*x^6-2*x^4-2*x^3+x+3,{2,3}>,
<-3*x^6+x^5-2*x^3+2*x^2-1,{2}>,
<3*x^6+x^5-2*x^3-x^2-2*x-2,{2,3}>,
<-3*x^6-2*x^4-2*x^3+x+3,{2,3}>,
<-x^6-2*x^5-2*x^4-2*x^3+x+3,{2}>,
<3*x^6-x^5+2*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+x^5-2*x^3+3*x^2+2*x-2,{2}>,
<3*x^6+x^5-2*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-x+3,{2,3}>,
<3*x^6+x^5-2*x^3-3*x^2+x+3,{2,3}>,
<2*x^6+x^5-3*x^4-2*x^3+x+3,{}>,
<-x^6-x^5+3*x^4+2*x^3-x-3,{0,2}>,
<3*x^6+x^5-2*x^3-3*x^2+x-1,{}>,
<-3*x^6-x^5+2*x^3+3*x^2-x+2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+x+3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+x-3,{2,3,7}>,
<3*x^6-x^5+3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6-x^5+3*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6-x^5+3*x^3-3*x^2-x+2,{2}>,
<2*x^6-2*x^5-x^4+x^3-x+3,{}>,
<-3*x^6-x^5+x^3+x^2-2*x-1,{}>,
<3*x^6+x^5-x^3-3*x^2+2,{2}>,
<-3*x^6-x^5+x^3+3*x^2-1,{2}>,
<3*x^6-x^5+x^3-3*x^2-1,{2}>,
<2*x^6+3*x^4-x^3+x-3,{2}>,
<3*x^6-x^5+x^3-3*x^2-2,{2,3}>,
<3*x^6+3*x^4-x^3+x-3,{2}>,
<3*x^6-x^5+2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-x-3,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3-x+3,{2}>,
<-x^6-2*x^5+2*x^4+2*x^3-x+3,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3-x-3,{2,5}>,
<2*x^6+x^5+2*x^4-2*x^3+x+3,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+x-3,{2}>,
<3*x^6+x^5-2*x^3+2*x^2+x-2,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+x-3,{2}>,
<-x^6-2*x^5+x^4+3*x^3-x+3,{2,3}>,
<-3*x^6-x^5+3*x^3-x^2-2*x+2,{2}>,
<3*x^6-x^5+3*x^3+x^2-2*x-2,{2}>,
<3*x^6-x^5+3*x^3+x^2-x+2,{2}>,
<-3*x^6+x^5-3*x^3-x^2+x+2,{2,3}>,
<-3*x^6+x^4+3*x^3-x+3,{2}>,
<3*x^6+x^5-3*x^3+x^2-x-2,{2}>,
<3*x^6-x^5-x^4-3*x^3+x-3,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3+x+3,{2}>,
<-3*x^6-x^5+3*x^3-x^2+2*x-1,{2,3}>,
<-x^6-2*x^5+x^4-3*x^3+x+3,{}>,
<-3*x^6+x^5-3*x^3-x^2-2*x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-x+3,{2,5}>,
<-3*x^6+x^5-3*x^3-x^2-3*x+2,{2,3}>,
<-x^6-3*x^5+3*x^3-x-3,{2}>,
<2*x^6-2*x^5+3*x^3-x+3,{2}>,
<-x^6-2*x^5+3*x^3-x+3,{2}>,
<2*x^6-2*x^5+3*x^3-x-3,{2}>,
<3*x^6-x^5+3*x^3+2,{2}>,
<3*x^6+x^5-3*x^3-2,{2}>,
<3*x^6+3*x^3-x-3,{2}>,
<3*x^6+x^5-3*x^3-3,{2,13}>,
<3*x^6-x^5+3*x^3+x+2,{2}>,
<-3*x^6+x^5-3*x^3-x-1,{2,5}>,
<-x^6-x^5-3*x^3+x+3,{}>,
<-3*x^6+x^5-3*x^3-2*x-2,{2,3,23}>,
<2*x^6-2*x^5-3*x^3+x-3,{2}>,
<-2*x^6-2*x^5-3*x^3+x+3,{2}>,
<-2*x^6+3*x^5+3*x^3-x+3,{2}>,
<3*x^6-x^5+3*x^3-x^2-x+2,{2,3}>,
<-x^6-2*x^5-3*x^4-2*x^3+x+3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3+x-3,{2}>,
<-3*x^6+x^5-2*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x+3,{2}>,
<3*x^6-x^4+3*x^3-x+3,{}>,
<2*x^6-x^4+3*x^3-x+3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x-3,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+x-3,{2}>,
<3*x^6-x^5+2*x^3-3*x^2+3*x-2,{2,3}>,
<-x^6+x^4-3*x^3+x-3,{2}>,
<3*x^6+x^5-3*x^3-x^2-1,{}>,
<2*x^6+x^4+3*x^3-x-3,{2}>,
<-3*x^6+x^5-3*x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6-x^5+3*x^3-x^2-2,{2}>,
<3*x^6+x^4+3*x^3-x-3,{2,3}>,
<3*x^6-x^5+3*x^3+3*x^2-3*x-2,{2,3}>,
<3*x^6-x^5+3*x^3-x^2+x+3,{}>,
<2*x^6-x^5+x^4-3*x^3+x-3,{2}>,
<-3*x^6+x^5-3*x^3+x^2-3*x-1,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3-x+3,{2}>,
<3*x^6-x^5+3*x^3-x^2+x-2,{2,3}>,
<3*x^6-x^5+3*x^3-2*x^2-2*x+2,{2,3}>,
<-x^6-2*x^5+2*x^4+3*x^3-x-3,{2}>,
<-3*x^6+x^5-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+x-3,{}>,
<3*x^6+x^5-3*x^3-2*x^2-2*x-2,{}>,
<3*x^6-x^5+3*x^3-2*x^2-2*x-2,{2}>,
<-3*x^6+x^5-3*x^3+2*x^2-3*x-2,{2}>,
<3*x^6-2*x^4+3*x^3-x+3,{2}>,
<3*x^6-x^5+3*x^3-2*x^2+3*x+2,{2,3}>,
<3*x^6-x^5+3*x^3-2*x^2-1,{2}>,
<-3*x^6+x^5-3*x^3+2*x^2-3*x-1,{2,5}>,
<-3*x^6-x^5+3*x^3+2*x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-x-3,{2}>,
<-x^6-x^5-2*x^4-3*x^3+x+3,{2}>,
<3*x^6+x^5-3*x^3-2*x^2-x-2,{2}>,
<-3*x^6-x^5+3*x^3+3*x^2-2*x-1,{}>,
<-x^6+2*x^5-3*x^4-3*x^3+x+3,{}>,
<2*x^6-2*x^5+3*x^4+3*x^3-x-3,{}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+x+3,{}>,
<-2*x^6-x^5-3*x^4+3*x^3-x+3,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+x+3,{2}>,
<3*x^6+x^5-3*x^3-3*x^2-x-1,{2}>,
<2*x^6-x^4-2*x^3+x-3,{2,3}>,
<2*x^6+x^4+x^3-x+3,{2}>,
<3*x^6-x^5+x^3+x^2-1,{2}>,
<-3*x^6-x^5+x^3-x^2+2,{2}>,
<-2*x^6+x^4-x^3+x+3,{2}>,
<-3*x^6+x^5-x^3-x^2+3,{2}>,
<2*x^6-x^5+x^4-x^3+x+3,{}>,
<-3*x^6+x^5-x^3-x^2-x+2,{2}>,
<-3*x^6-x^5+x^3-x^2+3*x-1,{2}>,
<-3*x^6+x^5-3*x^3+3*x^2-2*x+2,{2,37}>,
<3*x^6+x^5-3*x^3-3*x^2-2*x-2,{2,3}>,
<3*x^6+3*x^4-2*x^3+x+3,{2}>,
<-3*x^6-x^5+2*x^3-3*x^2+2,{2}>,
<-3*x^6-x^5+2*x^3-3*x^2+3,{2}>,
<-x^6-x^5+3*x^4-2*x^3+x+3,{}>,
<-3*x^6-x^5+2*x^3-3*x^2+x+2,{2,3}>,
<3*x^6+x^5-x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6+3*x^4+3*x^3-x^2+x+3,{2,5}>,
<3*x^6-3*x^4-3*x^3+x^2-x-3,{2}>,
<-3*x^6+3*x^4+3*x^3-x^2+x+3,{2,3}>,
<-3*x^6-x^5+3*x^3+3*x^2+3*x+2,{2,3,11}>,
<3*x^6+x^5-3*x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2-x+3,{}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6+3*x^4-3*x^3+x+3,{}>,
<-3*x^6-x^5+x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^4+3*x^3-x+3,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+x^2+x-3,{}>,
<2*x^6-3*x^4-3*x^3+x-3,{}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2-x+3,{}>,
<3*x^6+x^5-3*x^3+3*x^2-2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+x^2+x-3,{2,3}>,
<3*x^6-x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<3*x^6-x^5-x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6+2*x^4-3*x^3-x^2-x+3,{2}>,
<-x^6+2*x^4+3*x^3-x^2+x+3,{}>,
<2*x^6-2*x^4-3*x^3+x^2-x-3,{2}>,
<-2*x^6+2*x^4+3*x^3-x^2+x+3,{2}>,
<3*x^6-2*x^4-3*x^3+x^2-x-3,{2,3}>,
<-3*x^6+2*x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4+3*x^3+2*x^2-x-2,{2}>,
<-3*x^6-x^5+x^4-3*x^3-2*x^2+x+3,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+x^2+x-3,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+x^2+x-3,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2+x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3-x^2+3*x+2,{2,3}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2+x+3,{2}>,
<-x^6+2*x^5-x^4+3*x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4-3*x^3+x^2-2*x-1,{2,3}>,
<-3*x^6-x^5+x^4-3*x^3-x^2-x+3,{2,3,5}>,
<3*x^6+x^4-3*x^3-x^2-x+3,{2}>,
<-x^6+x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6-x^4+3*x^3+x^2+x-3,{2,3,5}>,
<-2*x^6+x^4+3*x^3-x^2+x+3,{2,3,5}>,
<3*x^6-x^5-x^4-3*x^3+x^2+x+2,{2,3}>,
<3*x^6+x^5-x^4+3*x^3+x^2-x-1,{2}>,
<3*x^6-x^5+3*x^3+3*x^2+3*x+2,{}>,
<-x^6+3*x^5-3*x^4+3*x^3-x-3,{2,5}>,
<3*x^6-x^5+3*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-x+3,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3-x-3,{2}>,
<-3*x^6-x^5+3*x^3-2*x^2-2*x+2,{2}>,
<3*x^6+2*x^4+3*x^3-x+3,{2,3}>,
<3*x^6-x^5+3*x^3+2*x^2-1,{2,3}>,
<-2*x^6-2*x^5+2*x^4+3*x^3-x+3,{2}>,
<2*x^6-2*x^4+3*x^3-x-3,{2}>,
<-x^6+x^5+2*x^4-3*x^3+x+3,{2}>,
<3*x^6+x^5-3*x^3+2*x^2-2*x+2,{2}>,
<3*x^6+x^5-3*x^3+2*x^2-2*x-2,{}>,
<2*x^6-3*x^5+2*x^4-3*x^3+x+3,{}>,
<-3*x^6+x^5-3*x^3-2*x^2-3*x+2,{2,3}>,
<2*x^6-3*x^5+x^4+3*x^3-x+3,{}>,
<3*x^6-x^5+3*x^3+x^2-2*x+2,{2,3}>,
<-2*x^6+2*x^5+x^4-3*x^3-x^2-x+3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4-3*x^3-3*x-2,{2,3}>,
<-3*x^6-x^5+x^4-3*x^3-3*x^2+2*x+2,{2}>,
<3*x^6-x^5-x^4-3*x^3-3*x+2,{2,3}>,
<-x^6-3*x^5-2*x^4-3*x^3+x^2-x-3,{2}>,
<2*x^6+3*x^5+3*x^3+x^2+x-3,{2}>,
<3*x^6+x^5-x^4+3*x^3+3*x-2,{2,7}>,
<2*x^6-3*x^5-2*x^4-3*x^3+x^2-x-3,{}>,
<-3*x^6-x^5+x^4-3*x^3-2*x-1,{2}>,
<2*x^6+2*x^5+3*x^3+x^2+x-3,{}>,
<3*x^6-x^5-x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^3-x^2-x+3,{2}>,
<2*x^6+x^5+3*x^3+x^2+x-3,{}>,
<3*x^6-x^5-x^4-3*x^3-x-2,{2}>,
<-x^6+3*x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4-3*x^3-x-1,{2}>,
<-3*x^6-x^5+x^4-3*x^3+3,{2}>,
<-x^6-x^5-3*x^3-x^2-x+3,{}>,
<3*x^6+x^5-x^4+3*x^3-3,{2}>,
<3*x^6-x^5-x^4-3*x^3+2*x-2,{}>,
<2*x^6+x^5-3*x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4+3*x^3-x-2,{2,3}>,
<3*x^6+x^5-x^4+3*x^3-2*x+2,{2,3}>,
<-x^6+2*x^5-3*x^3-x^2-x+3,{2}>,
<2*x^6-2*x^5+3*x^3+x^2+x-3,{}>,
<-3*x^6+x^5+x^4+3*x^3+x^2+x-1,{2,3,7,101}>,
<2*x^6+x^5+x^4+3*x^3+x^2+x-3,{2}>,
<2*x^6-x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3+x^2-1,{2}>,
<-3*x^6-x^5+x^4-3*x^3+x^2+2,{}>,
<-2*x^6-x^4+3*x^3-x^2+x+3,{}>,
<-3*x^6-x^5+x^4-3*x^3+x^2+3,{2,3}>,
<-2*x^6+x^5-x^4-3*x^3-x^2-x+3,{2}>,
<-x^6+2*x^5-x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3+x^2-2*x+2,{2}>,
<-3*x^6+x^5+x^4+3*x^3-x^2-x+3,{2}>,
<-x^6+x^5+3*x^4+3*x^3-x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3+2*x^2+2,{2,3}>,
<-2*x^6-2*x^4+3*x^3-x^2+x+3,{2,11}>,
<3*x^6+2*x^4+3*x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4-3*x^3-2*x^2+x+2,{2,3}>,
<-3*x^6-x^5+x^4-3*x^3+2*x^2+x-1,{2,3}>,
<2*x^6+x^5+2*x^4-3*x^3+x^2-x-3,{}>,
<-3*x^6+x^5+x^4+3*x^3+3*x^2+3*x-2,{2,3}>,
<2*x^6-3*x^5-3*x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+3*x^3+3*x^2+3*x-1,{}>,
<2*x^6+3*x^5+3*x^4+3*x^3+x^2+x-3,{2}>,
<-3*x^6+x^5+x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4+3*x^3-3*x^2+2*x-2,{2,3}>,
<-3*x^6+x^5+x^4+3*x^3+3*x^2+x-3,{2,3}>,
<-x^6+x^5+3*x^4+3*x^3+x^2+x-3,{2}>,
<-x^6-x^5-3*x^4-3*x^3-x^2-x+3,{2,3,31}>,
<-3*x^6-x^5+x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^3+3*x^2+2*x-1,{2}>,
<3*x^6+x^5-3*x^3-3*x^2-2*x-1,{2,3}>,
<3*x^6-x^5-x^4-3*x^3-3*x^2+2,{2,3}>,
<-x^6-3*x^4-3*x^3-x^2-x+3,{2}>,
<-3*x^6-x^5+x^4-3*x^3+3*x^2+2,{}>,
<-3*x^6+x^5+x^4+3*x^3+3*x^2-x-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3+x^2+x-3,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-3*x^5-3*x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+x^2-x-3,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-3*x^6-x^5+x^4-2*x^3-3*x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+x^2-x-3,{2}>,
<3*x^6-x^5-x^4-2*x^3+3*x^2+3,{2,3}>,
<3*x^6+x^5-x^4+2*x^3+3*x^2+3*x-1,{}>,
<-2*x^6-x^5-2*x^4-3*x^3-x^2-x+3,{}>,
<3*x^6+x^5-x^4+2*x^3+3*x^2-3,{2,3,19}>,
<3*x^6+x^5-x^4+2*x^3+3*x^2-x-1,{2}>,
<-3*x^6-x^5+x^4-2*x^3-3*x^2+x+2,{}>,
<3*x^6-2*x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-2*x^3+3*x^2+2*x+2,{2}>,
<-3*x^6+x^5+x^4+2*x^3-3*x^2+3*x+2,{2,3}>,
<-x^6+2*x^5+3*x^4-2*x^3-x^2-x+3,{2}>,
<-x^6+2*x^4-3*x^3+x^2-x-3,{2}>,
<-x^6-2*x^4+3*x^3-x^2+x+3,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3+x^2+x-3,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-x^2+x+3,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4+2*x^3+2*x^2+x-1,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3-x^2+x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4-2*x^3-x^2-x+3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+x^2-x-3,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3+x^2-x-3,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-x^2-x+3,{2,3}>,
<2*x^6+3*x^5-2*x^4-2*x^3+x^2-x-3,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+x^2+x-3,{2,3}>,
<3*x^6-x^5-x^4-2*x^3+x^2-3*x+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3+x^2-x-3,{2,5}>,
<-3*x^6-x^5+2*x^4-2*x^3-x^2-x+3,{2,3}>,
<3*x^6+x^5-x^4+2*x^3+x^2+3*x-1,{}>,
<3*x^6+x^5-x^4+2*x^3+2*x^2-2,{2}>,
<-3*x^6+x^5+x^4+2*x^3-2*x^2+3,{2,3}>,
<-2*x^6-2*x^5+x^4-2*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^3-x^2+x+2,{2}>,
<3*x^6+x^5-x^4+2*x^3+x^2+x-2,{2}>,
<2*x^6+x^4+2*x^3-x^2+x+3,{}>,
<-x^6+x^4-2*x^3-x^2-x+3,{2}>,
<2*x^6-x^4+2*x^3+x^2+x-3,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-x^2-x+3,{2}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+x-3,{}>,
<2*x^6+x^5+x^4-2*x^3-x^2-x+3,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2-x+3,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4-2*x^3+x^2-x-3,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+x^2-x-3,{2}>,
<-3*x^6-x^5+x^4-3*x^3+x^2-2*x+2,{2}>,
<-3*x^6+x^5+x^4-2*x^3-x^2-x+3,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-2*x^3+x^2+3*x-1,{2}>,
<-3*x^6+x^5+x^4+2*x^3-x^2-3*x+2,{}>,
<-3*x^6-x^5+x^4-2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3-x^2-x+3,{2}>,
<-2*x^6-x^5+x^4-3*x^3+x^2-x-3,{2}>,
<-3*x^6+x^5+x^4+2*x^3+3*x-1,{2,3,31}>,
<2*x^6+3*x^5+2*x^3+x^2+x-3,{2}>,
<-3*x^6-2*x^3-x^2-x+3,{2}>,
<2*x^6+x^5-2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4+2*x^3-x-1,{2}>,
<-3*x^6+x^5+x^4+2*x^3-x+2,{}>,
<-2*x^6-x^5+2*x^3-x^2+x+3,{}>,
<-x^6+3*x^5-2*x^3+x^2-x-3,{2,3}>,
<-3*x^6+x^5+x^4+2*x^3+x^2+3*x-2,{2,3}>,
<-3*x^6+x^5+x^4+2*x^3+x^2+3*x+2,{2}>,
<-3*x^6-x^5+x^4-2*x^3+x^2-2*x-2,{2}>,
<3*x^6-x^5+3*x^3-3*x^2-3*x-2,{2,3}>,
<3*x^6-x^5+3*x^3-3*x^2-2*x+2,{2}>,
<3*x^6+x^5-x^4+2*x^3-x^2+2*x+2,{2,5}>,
<-3*x^6+x^5+x^4+2*x^3+x^2+2*x-1,{2,3}>,
<3*x^6+x^5-x^4+2*x^3-2*x^2+3*x+2,{}>,
<-3*x^6-x^5+x^4-2*x^3+x^2-2*x+2,{2,3}>,
<3*x^6+x^5-x^4+2*x^3-2*x^2+3*x-1,{2}>,
<3*x^6+x^5-x^4+2*x^3-x^2+x+2,{2}>,
<-x^6+x^5+x^4+2*x^3+x^2+x-3,{2}>,
<-3*x^6-x^5+x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-x^5+x^4-2*x^3+2*x^2-2*x+2,{2}>,
<3*x^6-x^5-x^4-2*x^3-x^2-2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-x^2+x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^3+x^2+3,{2}>,
<3*x^6-x^5-x^4-2*x^3-2*x^2-x+2,{2}>,
<-3*x^6+x^5+x^4+2*x^3+2*x^2+x-1,{2}>,
<3*x^6+x^5-x^4+2*x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+x^2-x-3,{}>,
<3*x^6-x^5-x^4-2*x^3-2*x^2-x-2,{2}>,
<2*x^6-2*x^4+2*x^3-x^2+x+3,{}>,
<-3*x^6-x^5+x^4-2*x^3+2*x^2-1,{2}>,
<3*x^6-x^5-x^4-2*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4-2*x^3+x^2-x-3,{}>,
<3*x^6-x^5-x^4-2*x^3-2*x^2+2*x-2,{2,3,41}>,
<2*x^6-2*x^5+x^4+3*x^3-x^2+x+3,{2}>,
<3*x^6+x^5-x^4+2*x^3-3*x^2+3*x+2,{}>,
<-3*x^6-x^5+x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6+x^5-x^4+2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^3+x^2-2*x-1,{2}>,
<3*x^6-x^5-x^4-2*x^3-x^2+3*x+2,{2,3}>,
<-3*x^6+x^5+x^4+2*x^3+x^2-3*x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-x^2-x+3,{2}>,
<-x^6+x^5-3*x^4+2*x^3-x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4+2*x^3+x^2+x-3,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+x^2-x-3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-x^2-x+3,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^3+3*x^2-3*x-2,{}>,
<2*x^6-3*x^5+3*x^4+2*x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4-2*x^3-3*x^2+3*x-2,{2,3}>,
<-x^6-3*x^5-3*x^4-x^3+x^2-x-3,{2,37}>,
<-3*x^6+x^5+x^4+x^3-3*x^2+3*x+2,{2,11}>,
<2*x^6+2*x^5+3*x^4+x^3-x^2+x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2-x+3,{}>,
<3*x^6+x^5-x^4+x^3+3*x^2+x-3,{2}>,
<3*x^6+3*x^4+x^3-x^2+x+3,{2}>,
<3*x^6+x^5-x^4+x^3+3*x^2-1,{2,3}>,
<2*x^6-3*x^4+x^3+x^2+x-3,{}>,
<-3*x^6+x^5+x^4+x^3-3*x^2-x+2,{2,3}>,
<-3*x^6-x^5+x^4-x^3-3*x^2+x+3,{2}>,
<-3*x^6+x^5+x^4+x^3-3*x^2-2*x+2,{2,3}>,
<-2*x^6-2*x^5+3*x^4+x^3-x^2+x+3,{2,37}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2+x+3,{2}>,
<-x^6-3*x^5+3*x^4+x^3-x^2+x+3,{}>,
<-3*x^6-x^5+x^4-x^3-3*x^2+3*x+2,{2,11}>,
<-x^6-3*x^5+2*x^4-x^3-x^2-x+3,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4+x^3+2*x^2+2*x+2,{2}>,
<-3*x^6-x^5+x^4-x^3-2*x^2-2*x+2,{2,3}>,
<3*x^6-x^5-x^4-x^3+2*x^2-2*x-2,{2}>,
<3*x^6+x^5-x^4+x^3+2*x^2-3,{2}>,
<3*x^6-x^5-x^4-x^3+2*x^2+x+2,{2}>,
<-3*x^6+x^5+x^4+x^3-2*x^2-3*x+2,{2}>,
<3*x^6-x^5-x^4-x^3+x^2-3*x-2,{2}>,
<-3*x^6+x^5+x^4+x^3-x^2+2*x+2,{}>,
<2*x^6-2*x^5+2*x^4+x^3-x^2+x+3,{2,3}>,
<3*x^6-x^5-x^4-x^3+x^2-2*x-2,{}>,
<3*x^6+x^5-x^4+x^3+x^2+x+2,{}>,
<-3*x^6+x^5+x^4+x^3-2*x^2-2*x+2,{2}>,
<-3*x^6+x^5+x^4+x^3-x^2+x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3-x^2-x+3,{}>,
<2*x^6-3*x^5+2*x^4+x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5-x^4+x^3+x^2+x-3,{}>,
<-x^6-3*x^5-x^4+x^3+x^2+x-3,{2}>,
<2*x^6+3*x^5+x^3+x^2+x-3,{2,5}>,
<-2*x^6-3*x^5-x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+x^3+x+2,{2,3}>,
<-2*x^6-x^5-x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-x^3+3,{2}>,
<2*x^6+x^3-x^2+x+3,{2}>,
<3*x^6+x^5-x^4+x^3-1,{2}>,
<2*x^6-x^3+x^2-x-3,{}>,
<3*x^6+x^5-x^4+x^3-2,{}>,
<3*x^6-x^3+x^2-x-3,{2,3}>,
<3*x^6+x^5-x^4+x^3-x+2,{2}>,
<-x^6-3*x^5-2*x^4+2*x^3-x^2+x+3,{2,5}>,
<2*x^6+3*x^5+2*x^4-2*x^3+x^2-x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-x^2+x+3,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3+x^2+x-3,{}>,
<-2*x^6+x^5-x^4+x^3-x^2+x+3,{2}>,
<3*x^6-x^4-x^3-x^2-x+3,{2,3}>,
<3*x^6+x^5-x^4+x^3-x^2-1,{2}>,
<2*x^6+x^4+x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4+x^3-x^2+x+3,{2,3}>,
<-x^6+2*x^5+x^4-x^3+x^2-x-3,{}>,
<-2*x^6-2*x^5-x^4+x^3-x^2+x+3,{}>,
<-x^6+3*x^5+x^4-x^3+x^2-x-3,{}>,
<-3*x^6-x^5+x^4-x^3+2*x^2-3*x-2,{2,3}>,
<2*x^6-3*x^5-2*x^4-x^3-x^2-x+3,{2}>,
<-2*x^6+x^4+x^3-x^2+x+3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+x-3,{}>,
<-2*x^6-3*x^5-2*x^4-x^3-x^2-x+3,{}>,
<2*x^6-2*x^5+x^4+x^3-x^2+x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2-x-3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+x^2-x-3,{2}>,
<3*x^6-x^5-x^4-x^3-2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4-x^3-x^2-x+3,{2}>,
<2*x^6-x^5+2*x^4-x^3+x^2-x-3,{2}>,
<-3*x^6-2*x^4-x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-x^3-2*x^2+2*x+2,{}>,
<-3*x^6-x^5+x^4-x^3+2*x^2+2*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3-x^2+x+3,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+x^2-x-3,{2,13,19}>,
<3*x^6+x^5-x^4+x^3-2*x^2-2*x-2,{2}>,
<-3*x^6+x^5-2*x^3-3*x^2-x+3,{2,3}>,
<-x^6-2*x^5+3*x^4-2*x^3+x+3,{2}>,
<3*x^6-x^5-x^4-x^3-3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+x^2+x-3,{}>,
<-2*x^6+3*x^5-3*x^4+x^3-x^2+x+3,{}>,
<3*x^6+x^5-x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+x^2+x-3,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4-2*x^3+3*x^2-2,{2}>,
<-3*x^6-x^5+x^4-2*x^3+3*x^2-1,{2,3}>,
<-3*x^6-3*x^4+2*x^3-x^2+x+3,{2,3}>,
<-3*x^6-x^5+x^4-2*x^3+3*x^2+x-1,{0}>,
<-2*x^6-x^5-3*x^4+2*x^3-x^2+x+3,{}>,
<-x^6+2*x^5-3*x^4-2*x^3-x^2-x+3,{}>,
<-x^6+3*x^4-x^3+x^2-x-3,{2,5,13}>,
<-3*x^6-x^5+x^4-2*x^3-2*x+2,{2}>,
<3*x^6-x^5-x^4-2*x^3+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^2+x+3,{2}>,
<3*x^6+x^5-x^4+3*x^2+3*x-2,{2}>,
<3*x^6-x^5-x^4+3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4+x^2+x-3,{2}>,
<3*x^6+x^5-x^4+3*x^2+2,{2,3}>,
<2*x^6-3*x^4+x^2-x-3,{2}>,
<3*x^6-3*x^4+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+x^2+x-3,{2}>,
<3*x^6-x^5-x^4+3*x^2+x-2,{2,3}>,
<-3*x^6-x^5+x^4-3*x^2+x+3,{2,3}>,
<-3*x^6-x^5+3*x^4-x^2+x+3,{2}>,
<3*x^6-x^5-x^4+3*x^2+2*x+2,{2}>,
<-x^6+3*x^5+x^4+x^3+x^2+x-3,{2,7}>,
<2*x^6-2*x^5-x^4-x^3-x^2-x+3,{2}>,
<-x^6-2*x^5+x^4-x^3+x^2-x-3,{2}>,
<2*x^6+2*x^5+x^4+x^3+x^2+x-3,{2}>,
<3*x^6+x^5-x^4+x^3-x^2+2*x-2,{2}>,
<3*x^6+x^5-x^4+x^3-x^2+x-1,{2,3}>,
<3*x^6-x^5-x^4+2*x^2-x-3,{2}>,
<2*x^6+2*x^4-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4-2*x^2+2,{2}>,
<3*x^6-x^5-x^4+2*x^2+x-1,{2,3}>,
<3*x^6+x^5-2*x^4+x^2-x-3,{2,3}>,
<3*x^6+x^5-x^4+2*x^2-2*x+2,{}>,
<-2*x^6-2*x^5-2*x^4-x^3-x^2-x+3,{2}>,
<2*x^6+x^5-2*x^4+x^3-x^2+x+3,{2}>,
<3*x^6+3*x^4+x^3+x^2+x-3,{2}>,
<3*x^6+x^5-x^4+x^2+2*x-1,{2}>,
<2*x^6-2*x^5-x^4+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+x^2-x+2,{2}>,
<3*x^6-x^5+2*x^3+x^2+3*x+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3+x-3,{2,3}>,
<3*x^6+x^5-2*x^3+x^2-3*x-1,{}>,
<3*x^6-x^5-x^4+x^2-x-3,{2,3,13,1549}>,
<3*x^6+x^4-x^2-x+3,{}>,
<2*x^6+x^5+x^4-x^2-x+3,{2}>,
<2*x^6-2*x^5+x^2-x-3,{2,3,103}>,
<3*x^6-x^5-x^4+x^2+x-1,{2}>,
<2*x^6+x^5-x^4+x^2-x-3,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2-x+3,{2}>,
<-3*x^6-x^5+x^4-2*x^2+2*x+2,{2,3,127}>,
<-x^6+3*x^5-2*x^4+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+x^2-3*x-2,{2}>,
<3*x^6-x^5-x^4+x^2-2*x+2,{2}>,
<3*x^6+x^5-x^4+x-1,{2}>,
<-3*x^6-x^5+x^4+3*x+2,{2}>,
<-3*x^6+x^5+x^4+x+2,{2}>,
<-2*x^6+x^5-x^2+x+3,{2}>,
<-2*x^6+3*x^5-x^2-x+3,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3-x^2+x+3,{2}>,
<2*x^6-3*x^5-x^4-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4+x^2+3*x-1,{2}>,
<-3*x^6+x^5+x^4+x^3+3*x^2+3*x-1,{2,3}>,
<-3*x^6+x^5+x^4+x^2+3*x+2,{2}>,
<2*x^6-x^5+x^4+x^2-x-3,{}>,
<3*x^6-x^4-x^2+x+3,{2,3}>,
<-2*x^6-3*x^5-x^4-x^2-x+3,{2}>,
<-3*x^6-x^4-x^2+x+3,{2}>,
<-x^6+2*x^5-x^4-x^2+x+3,{2}>,
<3*x^6+x^5-x^4-x^2-x-2,{2,7}>,
<-x^6-2*x^5+x^4+x^2+x-3,{2,3}>,
<-3*x^6+x^5+x^4+x^2-3*x-2,{2}>,
<3*x^6+x^5-x^4-x^2+2*x-2,{2}>,
<-x^6+3*x^5-x^4-x^2-x+3,{2}>,
<2*x^6+3*x^5+x^4+x^2-x-3,{}>,
<-3*x^6+x^5+x^4+2*x^2+3*x-2,{2}>,
<3*x^6-x^5-x^4-x^2-x+3,{2}>,
<2*x^6+3*x^5-2*x^4-x^2+x+3,{2}>,
<-3*x^6+x^5+x^4+2*x^2+3*x-1,{2,3}>,
<-2*x^6-x^5-3*x^4+x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4+2*x^2-3*x+2,{2,3}>,
<-3*x^6+x^5+x^4+x^3+3*x^2-2*x-2,{2}>,
<3*x^6+x^5-x^4-2*x^2+3*x-2,{2}>,
<3*x^6+x^5-x^4+x^3-3*x^2-2*x-1,{2}>,
<3*x^6-x^5-x^4-2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+x^2-x-3,{2}>,
<-3*x^6+x^5+x^4+2*x^2+2*x-1,{2,3}>,
<3*x^6+x^5-x^4-2*x^2+2*x-1,{2,3}>,
<3*x^6-x^5-x^4-x^3-3*x^2+2*x-2,{2,3}>,
<-3*x^6-x^5+x^4+2*x^2-2*x+2,{2}>,
<-x^6-3*x^5-3*x^4+x^3-x^2+x+3,{2}>,
<-x^6+x^5+2*x^4+x^2-x-3,{}>,
<-x^6+x^5-2*x^4-x^2-x+3,{2}>,
<-3*x^6-2*x^4-x^2+x+3,{2}>,
<2*x^6+x^5+2*x^4+x^2-x-3,{2}>,
<-2*x^6-2*x^5+2*x^4+x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4-x^2+x+3,{}>,
<-2*x^6+3*x^5+3*x^4+x^2+x-3,{2}>,
<3*x^6+x^5-x^4-3*x^2+3*x+2,{2,3}>,
<3*x^6+x^5-x^4-3*x^2+3*x-1,{2}>,
<3*x^6-x^5-x^4-2*x^2+x+2,{2}>,
<-3*x^6-x^5+x^4+3*x^2-3*x+2,{2,5}>,
<-3*x^6-x^5+x^4+3*x^2-2*x-2,{2}>,
<-x^6-x^5+3*x^4+x^2-x-3,{2}>,
<-x^6-3*x^4-x^2+x+3,{2}>,
<3*x^6+x^5-x^4-3*x^2+x+2,{2,3}>,
<3*x^6+x^5-x^4+x^3-2*x^2+x-1,{2}>,
<3*x^6-3*x^4-x^3+x^2+x-3,{2}>,
<-3*x^6+3*x^4-x^3-x^2+x+3,{2,3}>,
<2*x^6+x^5+3*x^4+x^3-x^2-x+3,{}>,
<3*x^6-x^5-x^4+x^3+3*x^2+x-1,{2,3}>,
<-x^6-2*x^5-3*x^4-x^3-x^2-x+3,{2,83,131}>,
<2*x^6-2*x^5+3*x^4-x^3+x^2-x-3,{2}>,
<-2*x^6+x^5+3*x^4+x^3+x^2+x-3,{2}>,
<-x^6+x^5+3*x^4+x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4-x^3-3*x^2+2,{}>,
<3*x^6-x^5-x^4-3*x-1,{2}>,
<-x^6+2*x^4+x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4-x^3-2*x^2+2,{2}>,
<2*x^6-2*x^5+x^4+x^3-x^2-x+3,{}>,
<-2*x^6+2*x^4+x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4+x^3+x^2-2*x-2,{2}>,
<-3*x^6+x^5+x^4-x^3-2*x^2+3,{2}>,
<3*x^6+x^4-x^3-x^2+x+3,{2}>,
<2*x^6-x^5-2*x^4-x^3+x^2+x-3,{2,3}>,
<3*x^6+x^5-x^4-x^3+x^2+2,{2}>,
<-3*x^6+x^5+x^4-x^3-2*x^2-3*x-1,{2}>,
<-x^6+x^4+x^3-x^2-x+3,{2}>,
<2*x^6-x^4+x^3+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-x^5+x^4+x^3-x^2-3*x-1,{}>,
<3*x^6-x^5-x^4+x^3+x^2-3*x-1,{}>,
<3*x^6+x^5-x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3+x^2-x-3,{}>,
<2*x^6+3*x^5+x^4+x^3-x^2-x+3,{2}>,
<-x^6-3*x^5-x^4-x^3+x^2+x-3,{2}>,
<-3*x^6+x^5+x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^3+x^2+x-3,{2}>,
<3*x^6+x^5-x^4-x^3+x^2-3*x-1,{2}>,
<3*x^6+x^5-x^4-x^3+2*x+2,{2,3}>,
<-x^6-2*x^5+x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4-x^3+2*x-1,{2}>,
<3*x^6-x^5-x^4+x^3+2*x+2,{2}>,
<-3*x^6-x^5+x^4+x^3+2*x-1,{2}>,
<-3*x^6-x^5+x^4+x^3-2*x+2,{2}>,
<3*x^6-x^5-x^4+x^3+2*x-1,{2}>,
<-3*x^6-x^5+x^4+x^3+2*x+2,{2}>,
<3*x^6+x^5-x^4-x^3+2*x-2,{2}>,
<3*x^6-x^5-x^4+x^3+2*x-2,{2,3}>,
<3*x^6-x^5-x^4+x^3-x+2,{2,3}>,
<-3*x^6-x^5+x^4+x^3+3*x-2,{2,7}>,
<2*x^6+3*x^5+x^3+x^2-x-3,{}>,
<3*x^6-x^5-x^4+x^3+3*x-2,{}>,
<3*x^6-x^5-x^4-2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6-x^5-x^4+x^3-x^2-3*x-2,{2}>,
<3*x^6+x^3-x^2-x+3,{2}>,
<2*x^6-2*x^5+x^4+x^3+x^2-x-3,{2}>,
<-x^6+2*x^5-x^4-x^3-x^2+x+3,{2}>,
<3*x^6+x^5-x^4-x^3-x^2+x+3,{}>,
<3*x^6+x^5-x^4-x^3-x^2+2,{2,3}>,
<3*x^6-x^5-x^4+x^3-x^2-2,{}>,
<3*x^6+x^5-x^4-x^3-3,{2}>,
<3*x^6+x^4-x^3+x^2+x-3,{2,3}>,
<3*x^6+x^5-x^4-x^3-2*x^2+3*x+2,{2}>,
<3*x^6+x^5-x^4-x^3-2*x^2-3,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x^2-x-3,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-x^2+x+3,{2}>,
<3*x^6-x^5-x^4+x^3-2*x^2-x-2,{2,3}>,
<3*x^6+x^5-x^4-x^3-2*x^2+3,{}>,
<3*x^6+x^5-x^4-x^3-2*x^2+2,{}>,
<3*x^6-x^5-x^4+x^3-x^2-3,{2,3,5}>,
<-x^6+2*x^4+x^3+x^2-x-3,{2}>,
<-3*x^6+x^5+x^4-x^3+x^2-x-1,{2,3}>,
<3*x^6-x^5-x^4+x^3-2*x^2-1,{2}>,
<-3*x^6+x^5+x^4-x^3+2*x^2+2,{}>,
<2*x^6+2*x^5+x^4+x^3+x^2-x-3,{2}>,
<-2*x^6-2*x^4-x^3-x^2+x+3,{}>,
<-x^6-3*x^5-x^4-x^3-x^2+x+3,{}>,
<3*x^6+x^5-x^4-x^3-x^2-3*x-2,{2}>,
<3*x^6+2*x^4-x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4+x^3-3*x^2-1,{2}>,
<2*x^6+3*x^4+x^3+x^2-x-3,{2,3}>,
<3*x^6-x^5-x^4+3*x^2+3*x-1,{2,3}>,
<-2*x^6-3*x^4-x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4-3*x^2+3*x+2,{}>,
<-3*x^6-x^5+x^4+2*x^3-3*x^2-2*x+2,{2}>,
<3*x^6+x^5-x^4-x^3-3*x^2-3,{2}>,
<-3*x^6-x^5+x^4+2*x^3-3*x^2-x+2,{2,3}>,
<3*x^6-x^5-x^4+x^3-3*x^2+x-1,{2}>,
<3*x^6-x^5-x^4+2*x^2-3*x+2,{2}>,
<3*x^6+x^5-x^4-2*x^3+3*x^2+x-2,{2,3}>,
<3*x^6-x^5-x^4+2*x^3+3*x^2+2,{2}>,
<-x^6-3*x^5-2*x^4+x^2-x-3,{2,7}>,
<2*x^6+3*x^5-2*x^4+x^2+x-3,{2}>,
<-2*x^6+x^5-3*x^4+x^3-x^2-x+3,{2}>,
<-2*x^6+2*x^5+2*x^4-x^2+x+3,{}>,
<-2*x^6-3*x^5+3*x^4-x^3+x^2+x-3,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+x^2+x-3,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3-x^2+x+3,{}>,
<-3*x^6+x^5+x^4-x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6+x^5-x^4-2*x^3+3*x^2+3*x-1,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-x^2+x+3,{2}>,
<3*x^6-x^5-x^4+2*x^3+2*x^2+2*x-2,{2}>,
<3*x^6-x^5-3*x^4-x^3+x^2+x-3,{2}>,
<-x^6-2*x^5+3*x^4-x^3-x^2+x+3,{}>,
<2*x^6+x^5+2*x^4-x^3-x^2+x+3,{}>,
<3*x^6+2*x^4-x^3-x^2+x+3,{2,3}>,
<3*x^6+x^5-x^4-x^3+2*x^2+2,{2,3}>,
<-2*x^6-x^5+x^4-2*x^3-x^2+x+3,{}>,
<3*x^6+x^5-x^4-2*x^3+x^2-2*x+2,{2}>,
<-3*x^6+x^5+x^4-2*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+2*x^3-x^2-x+3,{}>,
<2*x^6+2*x^5-x^4+2*x^3+x^2-x-3,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+2*x^3-3*x+2,{2}>,
<3*x^6+x^5-x^4-2*x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+x^2-x-3,{}>,
<3*x^6+x^5-x^4-2*x^3+2*x^2+x-2,{}>,
<3*x^6-x^5-2*x^4+2*x^3+x^2-x-3,{2,3}>,
<3*x^6+2*x^4+2*x^3-x^2-x+3,{2,3}>,
<2*x^6+2*x^5-x^2-x+3,{2}>,
<2*x^6+2*x^4+2*x^3-x^2-x+3,{}>,
<-x^6+2*x^5+x^2-x-3,{2}>,
<3*x^6+3*x^4+x^2-x-3,{2}>,
<-3*x^6-3*x^4-x^2+x+3,{2}>,
<-x^6+3*x^5+x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-x^2+x+3,{2,3,5}>,
<-x^6+3*x^5-x^2-x+3,{}>,
<-3*x^6+x^5+x^4-2*x^3-x-1,{2}>,
<3*x^6-x^5-x^4+2*x^3+x-1,{}>,
<-3*x^6-x^5+x^4+2*x^3+x+2,{2}>,
<3*x^6-x^5-x^4+2*x^3+x-2,{2}>,
<2*x^6-2*x^5-2*x^3+x^2+x-3,{2,3}>,
<-2*x^6-2*x^5-2*x^3-x^2+x+3,{2}>,
<3*x^6-x^4+2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4-2*x^3-3*x-1,{2}>,
<-3*x^6+x^5+x^4-2*x^3+x^2+3*x+2,{2}>,
<-3*x^6+x^5+x^4-2*x^3+x^2+2*x-1,{2}>,
<3*x^6+x^5-x^4-2*x^3-x^2+x+2,{}>,
<3*x^6+x^5-2*x^4-2*x^3-x^2+x+3,{2,3}>,
<-3*x^6+x^5+x^4-2*x^3+2*x^2+x-1,{2}>,
<-x^6+x^5-2*x^4-2*x^3-x^2+x+3,{}>,
<2*x^6-x^5+2*x^4+2*x^3+x^2-x-3,{2}>,
<-x^6-x^5-3*x^4-x^2+x+3,{}>,
<-x^6+2*x^5-3*x^4-x^2-x+3,{2}>,
<3*x^6-x^5-x^4-3*x^2+2*x-2,{2}>,
<3*x^6+x^5-x^4-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5-2*x^4-x^3-x^2+x+3,{}>,
<2*x^6-3*x^5+2*x^4-x^3+x^2+x-3,{2}>,
<3*x^6-x^5-x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+x^2-x-3,{2}>,
<-3*x^6-x^5+x^4+2*x^3+2*x^2+3*x-1,{2,7}>,
<3*x^6-x^5-x^4+2*x^3-2*x^2+3*x-1,{2,3}>,
<-3*x^6-x^5+x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3+x^2-x-3,{2,5}>,
<-x^6+2*x^5-3*x^4-2*x^3-x^2+x+3,{}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x^2+x+3,{2}>,
<3*x^6+x^5-x^4-2*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-x^4-2*x^3-3*x^2+x-1,{2,7}>,
<-3*x^6+x^5+x^4-2*x^3+3*x^2+x+2,{2,3}>,
<3*x^6+x^5-x^4-2*x^3-3*x^2-1,{2,3}>,
<3*x^6-x^5-x^4-3*x^2+3*x-2,{}>,
<-x^6-2*x^5+3*x^4+x^3-x^2-x+3,{}>,
<-3*x^6+x^5+x^4-x^3-3*x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3-x^2+x+3,{}>,
<-3*x^6-x^5+x^4+x^3-3*x^2-x+2,{2}>,
<-3*x^6+x^5+x^4-x^3-3*x^2+x+3,{2}>,
<3*x^6+3*x^4+x^3-x^2-x+3,{2}>,
<2*x^6-3*x^4-x^3+x^2+x-3,{2,3}>,
<3*x^6+x^5-x^4-x^3+3*x^2-2,{2,3}>,
<2*x^6+3*x^5+3*x^4+2*x^3+x^2-x-3,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+x^2+x-3,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3-x^2+x+3,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x^2+x+3,{}>,
<-3*x^6+x^5+x^4-3*x^3-3*x^2+x+2,{2}>,
<3*x^6+3*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3+3*x^2-1,{2}>,
<3*x^6-x^5-x^4+2*x^3+2*x^2+3*x-1,{2,3}>,
<-3*x^6+x^5+x^4-2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6-x^5-x^4+2*x^3+2*x^2+3*x-2,{2,3}>,
<-3*x^6+x^5+x^4-2*x^3-x^2+3*x-1,{2,3,19,43}>,
<2*x^6+x^5+x^4-2*x^3-x^2+x+3,{2,5}>,
<3*x^6+x^5-x^4-2*x^3+x^2+x-1,{2}>,
<-3*x^6-x^5+x^4+2*x^3-x^2-x+2,{2}>,
<3*x^6+x^4+2*x^3-x^2-x+3,{2,3}>,
<3*x^6-x^5-x^4+2*x^3-2*x^2-2,{2}>,
<3*x^6-x^5-x^4+2*x^3-2*x^2-3,{2}>,
<3*x^6-x^5-x^4+2*x^3-2*x^2+2*x+2,{2}>,
<3*x^6-x^5-x^4+3*x^3+2*x^2-2*x-2,{}>,
<-3*x^6-x^5+x^4+3*x^3-2*x^2-x+2,{2,3,61}>,
<3*x^6+x^5-x^4-3*x^3+2*x^2-3,{2,3}>,
<-2*x^6+x^5+2*x^4+3*x^3-x^2-x+3,{2}>,
<-x^6-x^5-x^4-2*x^3-x^2+x+3,{2}>,
<2*x^6-x^5+x^4-2*x^3+x^2+x-3,{2,3}>,
<3*x^6+x^5-x^4-2*x^3-x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4+2*x^3+x^2+3*x-1,{2,5}>,
<2*x^6-3*x^4+2*x^3+x^2-x-3,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6-3*x^4+2*x^3+x^2-x-3,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+x^2+x-3,{2}>,
<-x^6+x^5+3*x^4+2*x^3-x^2-x+3,{}>,
<3*x^6+x^5-x^4-2*x^3-x^2-3*x-2,{}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2-x-3,{2,7}>,
<-3*x^6+x^5+x^4-2*x^3-3*x^2-x+2,{2,3}>,
<3*x^6+x^5-x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-x^2-x+3,{2}>,
<-x^6+2*x^5+x^4-3*x^3-x^2+x+3,{}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2-x+3,{2}>,
<-3*x^6-x^5+x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6+x^4+3*x^3-x^2-x+3,{}>,
<2*x^6-3*x^5+2*x^3+x^2-x-3,{2}>,
<3*x^6+x^5-x^4-3*x^3+x^2-x-1,{2,3,5}>,
<2*x^6-x^5-x^4-3*x^3+x^2+x-3,{2}>,
<3*x^6-x^4-3*x^3+x^2+x-3,{2}>,
<2*x^6+2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<3*x^6-x^5-x^4+3*x^3+x^2+x+2,{2,3}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2+x-3,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-x^2-x+3,{}>,
<3*x^6+x^5-x^4-3*x^3+2,{2,3}>,
<3*x^6-x^5-x^4+3*x^3-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3-x^2+x+3,{2,3}>,
<2*x^6+3*x^3+x^2-x-3,{2}>,
<-2*x^6+3*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4-3*x^3+3,{2}>,
<3*x^6+x^5-x^4-3*x^3+x^2-3*x-2,{2,3}>,
<-3*x^6-x^5+x^4+3*x^3+x+2,{2}>,
<3*x^6+x^5-x^4-3*x^3+3*x+2,{2}>,
<3*x^6-x^5-x^4+3*x^3+x-2,{2}>,
<-3*x^6+x^5+x^4-3*x^3+3*x-1,{}>,
<-x^6+2*x^5+3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3-x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-x^2+x+3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-x^2-x+3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x^2-x-3,{}>,
<-3*x^6+x^5+x^4-3*x^3-3*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-x^2-x+3,{}>,
<2*x^6-3*x^5+2*x^4+3*x^3-x^2-x+3,{}>,
<-3*x^6+x^5+x^4-3*x^3-2*x^2+3*x+2,{}>,
<3*x^6+x^5-x^4-3*x^3+2*x^2+2*x+2,{2,3}>,
<-3*x^6+x^5+x^4-3*x^3-2*x^2+2*x+2,{}>,
<-3*x^6+x^5+x^4-3*x^3+x^2-3*x-1,{2}>,
<3*x^6+x^5-x^4-3*x^3-2*x^2+3*x-2,{2,3}>,
<-x^6-2*x^5+2*x^4+3*x^3+x^2-x-3,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2-x-3,{2}>,
<3*x^6-x^5-x^4+3*x^3-2*x^2-2*x-2,{2,3}>,
<-2*x^6-x^5-2*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-x^4-3*x^3-2*x^2-3,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-x^2-x+3,{2}>,
<-3*x^6+x^5+x^4-3*x^3+2*x^2-x-1,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-2*x^2-x-1,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+x^2-x-3,{}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-x^2+x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-x^2-x+3,{2}>,
<3*x^6-x^5-x^4+3*x^3-3*x^2-x-1,{2}>,
<2*x^6-3*x^4-3*x^3-x^2+x+3,{2}>,
<-3*x^6-x^5+x^4+3*x^3+3*x^2-1,{2}>,
<-2*x^6-3*x^4+3*x^3-x^2-x+3,{}>,
<3*x^6-x^5-x^4+3*x^3+3*x-2,{2,19}>,
<3*x^6-x^5-x^4+3*x^3-x^2-2*x+2,{2,3}>,
<3*x^6-x^5-x^4+3*x^3-x^2-2*x-2,{}>,
<3*x^6-x^4-3*x^3-x^2+x+3,{2,3}>,
<3*x^6-x^5-x^4+3*x^3-x^2+x-1,{2}>,
<-3*x^6+x^5+x^4-3*x^3+x^2-2*x-1,{2,3}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2-x-3,{2}>,
<-3*x^6+x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<-3*x^6+x^5+x^4-x^3+3*x^2+2*x-1,{2,73}>,
<3*x^6+x^5-x^4-3*x^3-x^2-3*x+2,{2}>,
<3*x^6-x^5-x^4+x^3-3*x^2-x-1,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-3*x^2-2*x+2,{2,3}>,
<-x^6-2*x^5-3*x^4-3*x^3-x^2+x+3,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2+x-3,{}>,
<3*x^6+x^5-x^4-x^3-3*x^2+3,{2,3}>,
<3*x^6+x^5-x^4-3*x^3-3*x^2-3*x+2,{2,3}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-2*x^2+x+3,{2}>,
<-x^6-x^5+3*x^4-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+x^4-3*x^3+3*x^2-3*x-1,{2,5}>,
<3*x^6-x^5-2*x^4-3*x^3+3*x^2-x-3,{2,3}>,
<3*x^6+3*x^4+3*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+3*x^2-1,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3-3*x^2+2,{2,3}>,
<-2*x^6+3*x^4-3*x^3-2*x^2-x+3,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3-x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x^2-3*x-1,{2,3}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2-x-3,{2,3,17}>,
<2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-x+3,{2,3,5}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3-2*x^2-x+3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2-x+3,{2,3,61}>,
<2*x^6+2*x^5-2*x^4+3*x^3+2*x^2+x-3,{2,3}>,
<3*x^6+x^5-2*x^4+3*x^3+2*x^2+x-3,{2,3,47}>,
<3*x^6+2*x^4+3*x^3-2*x^2+x+3,{2,3}>,
<-x^6+2*x^4-3*x^3-2*x^2-x+3,{2}>,
<2*x^6-2*x^4+3*x^3+2*x^2+x-3,{2}>,
<-2*x^6+2*x^4-3*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x^2+x+2,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^3-2*x^2-x+3,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+2*x^2-2*x-2,{}>,
<-3*x^6+x^5+2*x^4+3*x^3-x^2+3*x-2,{2}>,
<-3*x^6-3*x^4+2*x^3-x^2-x+3,{2,3}>,
<3*x^6+x^5-x^4-2*x^3-3*x^2-x+2,{2}>,
<3*x^6-x^5-x^4+2*x^3-3*x^2+x-2,{2,3}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+x^2+x-3,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3+x^2-x-3,{}>,
<-3*x^6-x^5+x^4+2*x^3+3*x^2+3*x-2,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2-x+3,{}>,
<2*x^6+2*x^4-3*x^2+3*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-3*x^3-x^2-2*x+2,{2,3}>,
<-2*x^6-2*x^5+x^4-3*x^3-2*x^2-x+3,{2}>,
<-x^6-x^5-x^4-3*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+x^2-1,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+x^4+3*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6-x^5+2*x^4-3*x^3-x^2+x+2,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+x^2-x-2,{2}>,
<3*x^6-x^5-2*x^4-3*x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4+3*x^3-2*x^2+x+3,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+x^2-2*x-2,{2}>,
<3*x^6-x^5-2*x^4-3*x^3+x^2+3*x+2,{2}>,
<-x^6-3*x^5-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+3*x+2,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^3-3*x-2,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x-2,{2}>,
<-x^6-2*x^5-3*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-3*x^3-2*x+2,{}>,
<3*x^6-x^5-2*x^4-3*x^3-2*x-2,{}>,
<-3*x^6-x^5+2*x^4-3*x^3-x-2,{2,11}>,
<3*x^6-x^5-2*x^4-3*x^3-x+2,{2,11}>,
<-3*x^6+x^5+2*x^4+3*x^3+x-1,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^3-x-1,{2}>,
<2*x^6-3*x^3-2*x^2-x+3,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3-1,{2,3}>,
<-3*x^6-3*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-3*x^3+x-1,{2}>,
<3*x^6-x^5-2*x^4-3*x^3+x-2,{2}>,
<-3*x^6+x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<3*x^6+x^5-x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3-2*x+2,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3+x^2-x-3,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+2*x^2-x-3,{2}>,
<-x^6+3*x^5+x^4+3*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-x^2+3*x-1,{2,3}>,
<2*x^6-2*x^5-x^4-3*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-3*x^3+x^2-2*x-1,{2,3}>,
<-2*x^6+3*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-x^2+2*x-1,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+2*x^2+x-3,{2}>,
<3*x^6-3*x^3+2*x^2-x-3,{2,3}>,
<3*x^6+x^5-2*x^4+3*x^3-x^2-x-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+x^2-x+2,{}>,
<3*x^6+x^5-2*x^4+3*x^3-x^2-3*x-2,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3+2*x^2-3*x-2,{2,3}>,
<-3*x^6-x^5+2*x^4-3*x^3+2*x^2-3*x-1,{}>,
<-2*x^6+x^5+3*x^4-3*x^3-2*x^2-x+3,{2,7,13}>,
<3*x^6-x^5-x^4+3*x^3+3*x-1,{2,3}>,
<-x^6+x^5-2*x^4+3*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6+2*x^4-3*x^3+2*x^2-x-3,{2}>,
<3*x^6-2*x^4-3*x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+2*x^2+2,{}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2-x+3,{}>,
<-3*x^6+x^5+2*x^4+3*x^3+2*x^2-x-2,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3+2*x^2+x-1,{2}>,
<3*x^6-x^5-x^4+3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6-x^5-2*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+x^2+x-3,{2,3}>,
<-3*x^6-x^5+2*x^4-3*x^3+2*x^2+2*x-1,{0,2}>,
<-x^6-2*x^5+2*x^4-3*x^3-x^2+x+3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+x^5-2*x^4+3*x^3+3*x^2+3*x-1,{}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x-3,{2,5}>,
<-3*x^6+x^5+2*x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2+2*x+2,{2,3}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2+2*x-1,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^3-x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2-x-3,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2+x-3,{}>,
<3*x^6+x^5-x^4-3*x^3+2*x^2-2*x-2,{2,3}>,
<-x^6+x^5-3*x^4+3*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+3*x^4-3*x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-3*x^3-3*x^2+3,{2}>,
<-3*x^6-x^5+2*x^4-3*x^3+3*x^2-1,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2*x^2-x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+2*x^2+x-3,{2,5}>,
<-3*x^6-3*x^4+3*x^3-2*x^2+x+3,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^3-3*x^2+2*x-2,{2,3}>,
<-3*x^6+x^5+3*x^4-3*x^3+2*x^2-x-3,{2}>,
<-3*x^6-x^5+x^4+3*x^3+3*x^2+x-1,{2,3}>,
<-2*x^6+3*x^4+2*x^3-2*x^2+x+3,{2,5}>,
<3*x^6-x^5-2*x^4-3*x^3-3*x^2+x-2,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-3*x^2+x+2,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3-3*x^2+3,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^3+3*x^2-2*x-1,{0,2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+x^2+x-3,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3-2*x^2-x+3,{}>,
<3*x^6+x^5-2*x^4+2*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+3*x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-2*x^2-x+3,{2,5,7}>,
<-x^6+3*x^5+3*x^4-2*x^3-2*x^2-x+3,{2}>,
<-x^6-x^5+x^4-2*x^3-2*x^2-x+3,{2,3,7}>,
<3*x^6+x^4-2*x^3-2*x^2-x+3,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3-x^2+2,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3-2*x^2+3*x-1,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4-2*x^3+x^2-2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+x^2-3,{2,3,7}>,
<-x^6+x^5+2*x^4+2*x^3-2*x^2+x+3,{}>,
<2*x^6-x^5+x^4+2*x^3-2*x^2+x+3,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+2*x^2+x-2,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3-x^2-x+2,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3+2*x^2-1,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-2*x^2+2,{2}>,
<-2*x^6-x^5+2*x^4+2*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+2*x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-3*x-2,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3-3*x-1,{2,3}>,
<2*x^6+3*x^5+2*x^3+2*x^2+x-3,{}>,
<-2*x^6-3*x^5-2*x^3-2*x^2-x+3,{}>,
<-3*x^6+x^5+2*x^4+2*x^3+2*x-2,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-2*x-1,{2,3}>,
<-x^6+2*x^5+2*x^3-2*x^2+x+3,{}>,
<2*x^6-2*x^5-2*x^3+2*x^2-x-3,{2}>,
<2*x^6-x^5-2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-x-3,{2,3}>,
<2*x^6-x^5-2*x^3+2*x^2-x-3,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-2*x^2+x+3,{2}>,
<-2*x^6-x^5-2*x^3-2*x^2-x+3,{2}>,
<-3*x^6-x^5+x^4+3*x^3+2*x^2+3*x+2,{2,3}>,
<3*x^6+x^5-2*x^4+2*x^3-1,{2,3}>,
<-2*x^6-2*x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^3-2*x^2+x+2,{2}>,
<3*x^6-2*x^3+2*x^2-x-3,{2,3}>,
<-x^6+x^5-2*x^3-2*x^2-x+3,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-x^2+x+3,{2,3}>,
<-x^6+3*x^5-3*x^4-3*x^3-x^2+x+3,{}>,
<-3*x^6-x^5+2*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5+2*x^3+2*x^2+x-3,{2}>,
<2*x^6+3*x^5-2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+x^2+3*x-1,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3-3*x-1,{}>,
<3*x^6-x^5-2*x^4-2*x^3-x^2-3*x-1,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+x^2-3*x+2,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x-2,{2}>,
<2*x^6-x^5+x^4-2*x^3+2*x^2-x-3,{2,3}>,
<3*x^6+x^5-2*x^4+2*x^3-x^2+x-2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3-x^2+2,{2}>,
<-x^6+x^4+2*x^3+2*x^2+x-3,{2}>,
<2*x^6+3*x^5+x^4-2*x^3+2*x^2-x-3,{2,5,7}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+2*x^2+3*x-1,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3-x^2-1,{2,11}>,
<-2*x^6-3*x^5-2*x^4-2*x^3-2*x^2-x+3,{2}>,
<2*x^6+x^4-2*x^3+2*x^2-x-3,{}>,
<-3*x^6+x^5+2*x^4+2*x^3+2*x^2+2*x-1,{2,3}>,
<-x^6-2*x^5-2*x^4-2*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-2*x^3-2*x^2-x+3,{}>,
<-3*x^6+x^5+2*x^4+2*x^3+2*x^2+x-2,{}>,
<-2*x^6-2*x^5-x^4+2*x^3-2*x^2+x+3,{2,3,5}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2+x+2,{}>,
<3*x^6+x^5-2*x^4+2*x^3-x^2-3*x+2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3-2*x^2-x-1,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+x^2+3*x-1,{}>,
<-x^6+3*x^5-x^4-2*x^3-2*x^2-x+3,{}>,
<2*x^6-x^5+2*x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2+3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+2*x^2-2,{2}>,
<-x^6+2*x^4+2*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2-3,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-2*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4-2*x^3+2*x^2+x-1,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-2*x^2-2*x-1,{2,3}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2+3*x+2,{2,3}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x^2+x-3,{}>,
<3*x^6+x^4-3*x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5+3*x^4-2*x^3+2*x^2-x-3,{}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2+3*x-2,{}>,
<-3*x^6+x^5+2*x^4+2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+2*x^2+x-3,{}>,
<-x^6-3*x^5-2*x^4+2*x^3-2*x^2+x+3,{}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<-3*x^6+3*x^4-2*x^3+2*x^2-x-3,{2,3}>,
<-2*x^6-3*x^4-2*x^3-2*x^2-x+3,{2,5,7}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2-x+3,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-x-3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2-x-2,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3+3*x^2+x-1,{0,2}>,
<3*x^6-x^5-2*x^4-2*x^3-3*x^2+x-1,{2}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2-x+2,{}>,
<-x^6-2*x^5-3*x^4+2*x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4-2*x^3-3*x^2-x+3,{2,3}>,
<-3*x^6+x^5+2*x^4+2*x^3+3*x^2-2*x+2,{2,3}>,
<-3*x^6-x^5+2*x^4-2*x^3+3*x^2-x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+2*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+x+3,{2}>,
<2*x^6-x^5+3*x^4+x^3-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4-x^3-3*x^2+x+2,{2}>,
<3*x^6+x^5-2*x^4+x^3+3*x^2-2*x-1,{2,3}>,
<-3*x^6-x^5+2*x^4-x^3-3*x^2-3*x+2,{2,3}>,
<-3*x^6-x^5+2*x^4-x^3-3*x^2+2*x+2,{}>,
<3*x^6+x^5-2*x^4+x^3+3*x^2-2*x-2,{}>,
<2*x^6+3*x^5+3*x^4-x^3-2*x^2-x+3,{}>,
<3*x^6-x^5-2*x^4-x^3+3*x^2-3*x-2,{2,3,7}>,
<2*x^6-3*x^5-3*x^4+x^3+2*x^2+x-3,{2,3}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2-x+3,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4+x^3+3*x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4-x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4+x^3+2*x^2+x-3,{}>,
<2*x^6+2*x^5-3*x^4+x^3+2*x^2+x-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-2*x^2-x+3,{2}>,
<2*x^6-x^5-2*x^4-x^3+2*x^2-x-3,{2}>,
<2*x^6+2*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4-x^3+3*x^2-2*x-2,{2,3}>,
<-3*x^6-x^5+2*x^4-x^3-2*x^2+3,{2,3}>,
<-2*x^6-x^5+3*x^4-x^3-2*x^2-x+3,{2,5}>,
<-3*x^6+3*x^4-x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+x^3-x^2+3*x+2,{2,3}>,
<-2*x^6-3*x^5+x^4-x^3-2*x^2-x+3,{}>,
<3*x^6-x^5-2*x^4-x^3+x^2-2*x-1,{2}>,
<2*x^6+x^5-x^4+x^3+2*x^2+x-3,{}>,
<-2*x^6-x^5+x^4-x^3-2*x^2-x+3,{}>,
<3*x^6+x^5-2*x^4+x^3+x^2+2,{2}>,
<-x^6+x^4+x^3-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4+x^3-x^2+3,{2}>,
<3*x^6-x^5-2*x^4-x^3+x^2+x+2,{2,3}>,
<-x^6-3*x^5-x^4+x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+3*x-2,{2,3}>,
<3*x^6+x^5-2*x^4+x^3+3*x+2,{2}>,
<-x^6+3*x^5+x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3+3*x-1,{}>,
<2*x^6-3*x^5-x^3+2*x^2-x-3,{2}>,
<-x^6-2*x^5-x^3+2*x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4-x^3-2*x+2,{2}>,
<3*x^6-x^5-2*x^4-x^3-2*x-2,{2}>,
<3*x^6+x^5-2*x^4+x^3+x-1,{2}>,
<3*x^6-x^5-2*x^4-x^3+3,{2}>,
<-x^6+x^3-2*x^2+x+3,{2}>,
<2*x^6-x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3-2*x+2,{2,3}>,
<-3*x^6-x^5+2*x^4-x^3+2*x-1,{2}>,
<3*x^6-x^5-2*x^4-x^3+2*x-2,{}>,
<-x^6+3*x^5-x^3+2*x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4-x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^3+2*x^2-x-3,{2}>,
<-x^6-3*x^5-x^4-2*x^3+2*x^2-x-3,{}>,
<3*x^6+x^5-2*x^4+2*x^3+x^2+3*x-1,{2}>,
<3*x^6+x^5-2*x^4+2*x^3+x^2+3*x-2,{2,3}>,
<-x^6+2*x^5+x^4+2*x^3-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4-2*x^3-x^2-2*x+2,{2,3,5}>,
<3*x^6+x^5-2*x^4+2*x^3+x^2+2*x-2,{2,5}>,
<3*x^6+x^5-2*x^4+x^3-x^2+2*x+2,{2}>,
<-3*x^6-x^5+2*x^4-x^3+x^2-2*x-1,{2,3}>,
<3*x^6+x^5-2*x^4+x^3-x^2+2*x-1,{}>,
<2*x^6-2*x^5+x^4-x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-x^6+3*x^5-x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-x^3-x^2+2*x+2,{2}>,
<-3*x^6+x^5+2*x^4+x^3+x^2-2*x-1,{2,11}>,
<3*x^6+x^5-2*x^4+x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4-x^3+2*x^2-x-3,{}>,
<-2*x^6-2*x^5-x^4+x^3-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-2*x^2-x+3,{2}>,
<-x^6-3*x^5-2*x^4-x^3-2*x^2-x+3,{2,5}>,
<3*x^6+x^5-2*x^4+3*x^3-x^2+x-2,{2}>,
<3*x^6-x^4+3*x^3-2*x^2+x+3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+2*x^2+x-3,{2}>,
<-3*x^6-x^5+2*x^4-x^3+2*x^2-2*x-2,{2,3}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2+2*x+2,{2,3}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5+2*x^4-x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-x^3-2*x^2-x+3,{}>,
<-2*x^6+x^5+2*x^4+x^3+2*x^2+x-3,{2}>,
<-3*x^6-x^5+2*x^4-x^3+2*x^2-x-1,{2,3}>,
<-x^6+2*x^4-x^3+2*x^2-x-3,{2,3}>,
<3*x^6+x^5-2*x^4+x^3-2*x^2-2,{2}>,
<-3*x^6-x^5+2*x^4-x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4-x^3-2*x^2+x-1,{2}>,
<-2*x^6-x^5-2*x^4+x^3-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4+x^3+2*x^2-2*x-2,{2,3}>,
<3*x^6-x^5-2*x^4-x^3-2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+2*x^2-x-3,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<3*x^6-x^5-2*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+2*x^2+x-3,{}>,
<3*x^6-x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<3*x^6+x^5-3*x^4+2*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6+x^5+3*x^4+2*x^3-2*x^2+x+3,{2,3}>,
<-3*x^6+x^5+2*x^4+x^3+3*x^2+2*x-1,{2}>,
<-3*x^6+x^5+3*x^4+x^3+2*x^2+x-3,{2}>,
<-2*x^6+x^5-3*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4-x^3-3*x^2+3,{2,3}>,
<-3*x^6+x^5+2*x^4+x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4-x^3-2*x^2-x+3,{2}>,
<-3*x^6-x^5+2*x^4-x^3+3*x^2-1,{0,2}>,
<3*x^6+x^5-2*x^4+x^3-3*x^2-1,{2,3}>,
<2*x^6+3*x^4-x^3+2*x^2-x-3,{}>,
<3*x^6+3*x^4-x^3+2*x^2-x-3,{2}>,
<-3*x^6-3*x^4+x^3-2*x^2+x+3,{2,3}>,
<-x^6-x^5-3*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^2-3*x-1,{2}>,
<2*x^6-x^5+3*x^4+x^3+2*x^2+x-3,{}>,
<3*x^6-x^5-2*x^4-x^3-3*x^2+x-2,{}>,
<-2*x^6-2*x^5-3*x^4+x^3-2*x^2+x+3,{2}>,
<-x^6+3*x^5-3*x^4-x^3-2*x^2-x+3,{}>,
<2*x^6-3*x^5-2*x^4+2*x^2-x-3,{}>,
<-2*x^6-3*x^5+2*x^4-2*x^2-x+3,{}>,
<2*x^6-2*x^5+2*x^4-2*x^2-x+3,{}>,
<2*x^6+3*x^5+3*x^4-x^3+2*x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3-2*x^2-x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+2*x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4+3*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+3*x^2+3*x+2,{2}>,
<-3*x^6+x^5+2*x^4-2*x^2+2*x+2,{2,3}>,
<3*x^6+x^5-2*x^4+2*x^2+x-2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4+3*x^2+3,{2,3}>,
<-3*x^6+x^5+2*x^4-2*x^2+x+3,{}>,
<3*x^6-x^5-2*x^4+2*x^2+x-1,{}>,
<-3*x^6+x^5+2*x^4-3*x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^2-x+3,{2}>,
<2*x^6-x^5-3*x^4+2*x^2+x-3,{}>,
<3*x^6+x^5-2*x^4+x^2+3*x-1,{2}>,
<3*x^6+2*x^4-2*x^2+x+3,{}>,
<3*x^6+x^5-2*x^4+3*x^2-x-2,{}>,
<-3*x^6-x^5+2*x^4-x^2-2*x+2,{2,3}>,
<3*x^6+x^5-2*x^4+x^2+2*x-2,{2,3}>,
<2*x^6-x^5+2*x^4-2*x^2+x+3,{2}>,
<2*x^6-x^5+x^4-2*x^2-x+3,{}>,
<-3*x^6+x^5+2*x^4-x^2-3*x+2,{}>,
<3*x^6-x^5-2*x^4+x^2+3*x-2,{}>,
<-x^6-3*x^5+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-2*x-1,{2}>,
<-2*x^6+2*x^5+x^4+x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-2*x-1,{2,3}>,
<-2*x^6-3*x^5+x^4+2*x^2-x-3,{2,3}>,
<-3*x^6+x^5+2*x^4+x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4-2*x^2+x+3,{2,3}>,
<-2*x^6+3*x^5-x^4-2*x^2+x+3,{2}>,
<2*x^6+2*x^5-x^4-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4+x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4+2*x^2+x-3,{2}>,
<-2*x^6-x^4-2*x^2+x+3,{}>,
<3*x^6-x^5-2*x^4-x^2+x-1,{2,3}>,
<-3*x^6+x^5+2*x^4+x^2-x+2,{2,3}>,
<-2*x^6+x^5-x^4-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-x^3+2*x^2+2*x+2,{2}>,
<-x^6-2*x^5+2*x^4+x^3-2*x^2+x+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4+x^3-x^2+3*x-1,{2,3}>,
<3*x^6-x^5-2*x^4-x-1,{2}>,
<-3*x^6+x^5+2*x^4+x+2,{2}>,
<3*x^6-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4+3*x^3+x^2-1,{2}>,
<-x^6-x^4-3*x^3-2*x^2-x+3,{2,3}>,
<-3*x^6+x^5+2*x^4+3*x^3+x^2-x-1,{2,3}>,
<-2*x^6-x^5-2*x^4-2*x^2-x+3,{2}>,
<-x^6-2*x^4-2*x^2-x+3,{2}>,
<-2*x^6-2*x^4-2*x^2-x+3,{2}>,
<3*x^6+2*x^4+2*x^2-x-3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^2-3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^2-x+3,{2,3}>,
<-3*x^6-x^5+2*x^4+2*x^2+x+2,{2,3,5}>,
<3*x^6-x^5-2*x^4-2*x^2+x-2,{2,3,5}>,
<3*x^6+x^5-2*x^4-2*x^2-2*x-1,{2,3}>,
<3*x^6-x^5-2*x^4-2*x^2+2*x-2,{}>,
<2*x^6+3*x^5-2*x^4-2*x^2-x+3,{2}>,
<-x^6-3*x^5+2*x^4+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4-2*x^2-3*x-2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^2+x-3,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-x^3-2*x^2+3*x-1,{2,3}>,
<-2*x^6-3*x^5-2*x^4+x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4-2*x^2-x+3,{2,3}>,
<-2*x^6+3*x^5+3*x^4+x^3+2*x^2+x-3,{2}>,
<-2*x^6-x^5+3*x^4+2*x^2-x-3,{}>,
<2*x^6+x^5-3*x^4-2*x^2+x+3,{}>,
<-x^6-x^5+3*x^4+2*x^2-x-3,{}>,
<-3*x^6-x^5+2*x^4-x^3+3*x^2-3*x-1,{2,3}>,
<3*x^6-x^5-2*x^4-3*x^2-x-1,{2}>,
<-x^6-3*x^5-3*x^4-x^3-2*x^2-x+3,{2}>,
<2*x^6-x^5+3*x^4+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4-3*x^2-x-2,{2,3}>,
<-x^6-3*x^4-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4+3*x^2+2,{2,3}>,
<-2*x^6-3*x^4-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4-3*x^2-3,{2,3}>,
<-x^6+x^5-3*x^4-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^2-2*x-1,{2}>,
<-3*x^6+x^5+2*x^4+3*x^2-2*x+2,{2}>,
<3*x^6-x^5-2*x^4-3*x^2+2*x-2,{2}>,
<3*x^6-x^5-2*x^4+x^3+3*x^2-2,{2}>,
<3*x^6-3*x^4+x^3+2*x^2-x-3,{2,3}>,
<2*x^6-x^5-3*x^4-x^3+2*x^2+x-3,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-2*x^2+x+3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4-3*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^4-x^3+2*x^2+x-3,{}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x^2-x+3,{2,3}>,
<-3*x^6+x^5+2*x^4-x^3-2*x^2-3*x-1,{2,11}>,
<3*x^6+x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-3*x^6-x^5+2*x^4+x^3-2*x^2+3*x+2,{}>,
<3*x^6-x^5-2*x^4+x^3+x^2-2*x-1,{2,3}>,
<-3*x^6-x^5+2*x^4+x^3-x^2-2*x+2,{2}>,
<3*x^6+x^5-2*x^4-x^3+x^2+2*x-2,{2}>,
<3*x^6+x^5-2*x^4-x^3+x^2+x+2,{}>,
<3*x^6+x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-x^3+x^2-3,{2,3}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2+x+3,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4-x^3+x^2-2*x-1,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x^2+x-3,{}>,
<-x^6-3*x^5+x^3-2*x^2-x+3,{2}>,
<-3*x^6-x^5+2*x^4+3*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^2-x-3,{}>,
<3*x^6-x^5-2*x^4-3*x^2+3*x-2,{2,3}>,
<3*x^6+x^5-2*x^4-x^3+3*x^2+x+2,{}>,
<-3*x^6+x^5+2*x^4-x^3-3*x^2+x+2,{2,3}>,
<3*x^6+x^5-2*x^4-x^3+3*x^2+3,{2,3}>,
<2*x^6+3*x^4-x^3-2*x^2+x+3,{}>,
<3*x^6-x^5-2*x^4+x^3+3*x^2-1,{2}>,
<-3*x^6+x^5+2*x^4-x^3-3*x^2+2,{2}>,
<3*x^6-x^5-2*x^4+x^2+2*x+2,{2,3}>,
<-3*x^6+x^5+2*x^4-x^3+3,{2}>,
<-x^6+3*x^5-x^4+2*x^2-x-3,{2}>,
<-3*x^6-x^3-2*x^2+x+3,{2,3,7}>,
<-x^6-x^5-x^3+2*x^2+x-3,{2,3}>,
<2*x^6-2*x^5-x^3+2*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4+x^3+3*x-2,{2}>,
<3*x^6-x^5-2*x^4+x^2+3*x-1,{2}>,
<3*x^6+x^5-2*x^4-x^3-x^2+3*x+2,{2}>,
<3*x^6+x^5-2*x^4-x^3-x^2+2,{2}>,
<-x^6-x^4-x^3-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4+x^3+x^2-3*x-1,{2}>,
<3*x^6+x^4-x^3+2*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4+x^3-x^2-3,{2,3}>,
<-x^6+3*x^5-x^4-x^3-2*x^2+x+3,{}>,
<3*x^6+x^5-2*x^4-x^3-x^2-x-2,{2,3}>,
<-3*x^6+x^5+2*x^4-x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3-x^2-x-2,{2}>,
<-3*x^6-x^5+2*x^4+x^3+2*x^2-3*x-1,{2}>,
<3*x^6-x^5-2*x^4+x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4+x^3+2*x^2-x-3,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-2*x^2+x+3,{2}>,
<-3*x^6-2*x^4-x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+x^3-2*x^2+x-1,{2,3}>,
<-2*x^6-x^5-2*x^4-x^3-2*x^2+x+3,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-x^3+2*x^2+3*x-1,{}>,
<2*x^6-3*x^5-2*x^4+x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4-x^3+2*x^2+2*x-2,{2}>,
<3*x^6-x^5-2*x^4+x^3+2*x^2+2,{2}>,
<3*x^6-x^5-2*x^4+x^3+2*x^2-1,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3-2*x^2+x+3,{}>,
<-3*x^6+x^5+2*x^4-x^3+3*x^2+2*x-1,{2}>,
<3*x^6+x^5-2*x^4-x^3-3*x^2+2*x-1,{2}>,
<-3*x^6-x^5+2*x^4+x^3+3*x^2-2*x+2,{2}>,
<3*x^6+x^5-2*x^4-x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2+x-3,{2,3}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-x-2,{2,3}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-1,{2,3}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-2,{2}>,
<3*x^6+3*x^4-x^3+2*x^2+x-3,{2}>,
<2*x^6+x^5+3*x^4+x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4-x^3+2*x-1,{2}>,
<-3*x^6+x^5+2*x^4-x^3+3*x^2-2*x-2,{2,3,109}>,
<2*x^6+2*x^5-x^3+2*x^2+x-3,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-2*x^2-x+3,{2,13}>,
<-3*x^6+x^5+2*x^4-x^3+3*x^2-2*x-1,{2}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2+2*x-1,{}>,
<-2*x^6+3*x^5+2*x^4+2*x^2+x-3,{2,163}>,
<3*x^6-x^5-2*x^4+x^3+2,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^2+3*x+2,{2}>,
<-3*x^6-x^5+2*x^4+x^3+3*x^2+2*x+2,{2}>,
<-3*x^6-x^5+2*x^4+2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4-x^3-2*x^2+x-2,{}>,
<-3*x^6+x^5+2*x^4-2*x^3-3*x^2+x+3,{2,3}>,
<3*x^6-2*x^4+x^3-2*x^2-x+3,{}>,
<-2*x^6+2*x^5+2*x^4+2*x^2+x-3,{2}>,
<-3*x^6-x^5+2*x^4+2*x^3-3*x^2-2*x+2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+3*x^2+3,{2}>,
<-x^6-2*x^4-x^3-2*x^2+x+3,{2}>,
<2*x^6-3*x^4+2*x^3+2*x^2-x-3,{2}>,
<-x^6-x^5-x^4-x^3-2*x^2-x+3,{}>,
<2*x^6+2*x^4-x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4+2*x^2+2*x-1,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3+3*x^2-x+2,{2,3}>,
<-3*x^6+x^5+2*x^4+2*x^2+x-1,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-2*x^2-x+3,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3+3*x^2-2*x-2,{}>,
<3*x^6+x^5-2*x^4-2*x^3+3*x^2+x-1,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3+2*x^2+x-1,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-2*x^2-x+3,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2+x-3,{}>,
<-3*x^6-x^5+2*x^4+2*x^3-2*x^2-x+2,{2}>,
<3*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^3+2*x^2-x-3,{2}>,
<3*x^6+2*x^4+2*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+x^2-3*x-1,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^3+2*x^2-x-3,{}>,
<-2*x^6+3*x^5+x^4-2*x^3-2*x^2+x+3,{}>,
<2*x^6+x^4-2*x^3-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3+x^2+x+2,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3+x^2-x-1,{2,3}>,
<2*x^6+x^5+2*x^4-2*x^3-2*x^2+x+3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3-x^2-x+2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+x^2+3*x-1,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x-1,{2}>,
<2*x^6-3*x^5+2*x^3+2*x^2-x-3,{2}>,
<-x^6-2*x^5+2*x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+x^2+x-2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-x-2,{2}>,
<3*x^6-2*x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-3,{2,3}>,
<-3*x^6-x^5+2*x^4+2*x^3-x^2+2*x+2,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3+x-1,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3-3*x+2,{2}>,
<-x^6-3*x^5-2*x^3+2*x^2+x-3,{}>,
<2*x^6-3*x^5-2*x^3+2*x^2+x-3,{2}>,
<2*x^6+x^5+2*x^3+2*x^2-x-3,{2}>,
<-2*x^6-3*x^5-2*x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-x^2-x+2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+2*x-2,{2}>,
<3*x^6+x^5-2*x^4-2*x^3-x^2+x-1,{}>,
<-3*x^6+x^5+2*x^4-2*x^3+x^2+x+2,{}>,
<3*x^6-x^5-2*x^4+2*x^3-x^2-x-2,{}>,
<3*x^6+x^5-2*x^4-2*x^3-x^2-2,{2,3}>,
<-x^6+3*x^5-x^4+x^3-2*x^2-x+3,{2}>,
<-3*x^6-x^5+2*x^4+x^3+x^2+3*x+2,{2}>,
<-3*x^6-x^5+2*x^4+x^3+2*x^2-3*x-2,{2}>,
<-x^6-2*x^4+2*x^3-2*x^2-x+3,{}>,
<3*x^6-x^5-2*x^4+2*x^3-2*x^2-2,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-2*x^2+x+2,{2,3}>,
<-2*x^6+x^5-2*x^2-x+3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2+x-3,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-2*x^2+x+3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+2*x^2+x-3,{2}>,
<-x^6-x^5-3*x^4+2*x^3-2*x^2-x+3,{2,11}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^4+2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+3*x^2+2,{}>,
<-2*x^6-3*x^4+2*x^3-2*x^2-x+3,{}>,
<3*x^6+x^5-2*x^4-2*x^3-3*x^2-x+3,{}>,
<-3*x^6-x^5+2*x^4+2*x^3+3*x^2+x-2,{2}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+3*x^2-x+2,{2,3}>,
<3*x^6+x^5-2*x^4-2*x^3-3*x^2-x-2,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3-3*x^2-3,{2,3,7}>,
<-3*x^6-x^5+2*x^4+2*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2*x^2+x+3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-2*x^2+x+3,{2}>,
<-3*x^6-x^5+2*x^4+3*x^3-3*x^2-x+2,{2,3}>,
<3*x^6-x^5-2*x^4+3*x^3+3*x^2-3,{2,3}>,
<2*x^6+3*x^5-3*x^4-3*x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5-2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+3*x^2-2*x+2,{2,3}>,
<3*x^6+x^5-2*x^4-3*x^3+2*x^2-2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-2*x^2+x+3,{2}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+3*x^2+2*x-1,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<3*x^6+x^5-2*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+2*x^2+x-3,{}>,
<3*x^6-x^5-2*x^4+3*x^3+x^2-1,{2,3}>,
<2*x^6-x^4-3*x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3-x^2+3,{2,3,11}>,
<-2*x^6-2*x^5-2*x^4-x^3-2*x^2+x+3,{2}>,
<2*x^6-x^5-x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-x^3+2*x^2+x-3,{2}>,
<-2*x^6+x^5+x^4+3*x^3-2*x^2-x+3,{2}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2-x+3,{}>,
<-x^6+3*x^5+2*x^4+x^3+2*x^2-x-3,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6+3*x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-1,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3+2,{2,3}>,
<-x^6-x^5-3*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x-2,{2}>,
<-3*x^6-x^5+2*x^4+3*x^3+2*x-1,{2,3}>,
<2*x^6-2*x^5-3*x^3+2*x^2+x-3,{2}>,
<-2*x^6+2*x^5+3*x^3-2*x^2-x+3,{2}>,
<-x^6+2*x^5-x^4+2*x^3-2*x^2-x+3,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+2*x^2+x-3,{2}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-x^2+x+2,{2,3}>,
<-x^6-x^5+x^4-2*x^3+2*x^2-x-3,{2}>,
<3*x^6+x^5-2*x^4+2*x^3-x^2+x-1,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2-2*x+2,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3+x^2-2*x-1,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2-2*x-2,{2,3}>,
<2*x^6+3*x^5+3*x^3-2*x^2-x+3,{2}>,
<2*x^6-2*x^4+3*x^3-2*x^2-x+3,{2}>,
<-x^6+2*x^4+3*x^3+2*x^2-x-3,{2}>,
<3*x^6+2*x^4-3*x^3+2*x^2+x-3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-2*x^2-3,{2}>,
<-x^6-x^5+2*x^4-3*x^3+2*x^2+x-3,{2,3}>,
<-3*x^6-x^5+2*x^4+3*x^3-2*x^2+2*x+2,{}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-x+3,{}>,
<3*x^6-x^5-2*x^4+3*x^3+2*x^2+3*x-2,{}>,
<2*x^6+3*x^5+x^4-3*x^3-2*x^2+x+3,{}>,
<3*x^6+x^5-2*x^4-3*x^3+x^2+x+2,{2}>,
<3*x^6-x^5-2*x^4+3*x^3+x^2+2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2-x+3,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3-2*x^2-2*x+2,{2,11}>,
<3*x^6-x^5-2*x^4+2*x^3+2*x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-2*x^4-2*x^3+2*x^2+x-3,{2}>,
<-x^6-3*x^4-3*x^3-2*x^2+x+3,{}>,
<2*x^6+3*x^4-3*x^3+2*x^2+x-3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-3*x^2-2,{2,3}>,
<3*x^6+x^5-2*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-2*x^2+x+3,{2,3}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-x-3,{2,7}>,
<3*x^6+x^5-2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3-3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+x^5-x^4-x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3-3*x^2+2,{}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2-2,{}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+x+3,{2}>,
<-x^6+x^5+3*x^4-3*x^3-3*x^2-x+3,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-x-3,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2+x-3,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+x^5-2*x^4+2*x^3-2*x^2-x+3,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+2*x^2-2*x-1,{2,3}>,
<-3*x^6-x^5+2*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-2*x^2+x+3,{}>,
<3*x^6+x^5-2*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-3*x^2-2*x-2,{}>,
<-x^6+x^5-3*x^4-3*x^3-2*x^2+x+3,{}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2-x-3,{}>,
<3*x^6-3*x^4+3*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3+3*x^2-1,{2,3}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-x+3,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x^2-x-3,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+3*x^2-x-3,{2}>,
<-3*x^6-x^5+2*x^4+3*x^3+3*x^2+x-2,{2,3}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x^2+x+3,{}>,
<-3*x^6+x^5+2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-3*x^6+x^5+2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2+x-3,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-3*x^2-x+3,{2}>,
<-x^6-3*x^5+x^4-3*x^3-3*x^2-x+3,{2,7}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2-x+3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+x^2-3*x-1,{2,3}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2+x-3,{2}>,
<-3*x^6+x^5+2*x^4-2*x^3+2*x^2+3*x-1,{2,3}>,
<3*x^6-x^5-2*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-x^6+2*x^5-2*x^4-2*x^3-2*x^2+x+3,{}>,
<-x^6+x^5-x^4+3*x^3+3*x^2+x-3,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3+x^2+2,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3-x^2-1,{2}>,
<2*x^6-x^4-3*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+x^2-2,{2}>,
<-3*x^6+x^4-3*x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+x^2+x-1,{2,3}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x^2+x+3,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x^2+x-3,{2}>,
<-x^6-x^5+3*x^4-3*x^3-3*x^2-x+3,{}>,
<3*x^6-x^5-3*x^4-3*x^3+3*x^2+3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+2*x^2-x-3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-x^2+3*x-2,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<-x^6-2*x^5-2*x^4+3*x^3-2*x^2-x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-2*x^2+x-1,{2,3}>,
<3*x^6-x^5-2*x^4+3*x^3-2*x^2-x-2,{}>,
<3*x^6-x^5-3*x^4-3*x^3-x-2,{2}>,
<3*x^6-3*x^3-3*x^2-x+3,{2}>,
<-2*x^6+3*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+2,{2}>,
<-x^6+3*x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-1,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+2,{2}>,
<-2*x^6+3*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3+x-1,{2,13}>,
<-3*x^6-x^5+2*x^4+3*x^3+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-2*x^2+x+3,{2}>,
<3*x^6+x^5-2*x^4-3*x^3-x^2+2*x+2,{2}>,
<-3*x^6-x^5+2*x^4+3*x^3+x^2-2*x-1,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+2*x^2-x-3,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3-2*x^2-x+3,{2}>,
<3*x^6-x^5-2*x^4+3*x^3-x^2-3,{2,3}>,
<3*x^6-x^5-2*x^4+3*x^3-x^2+x-1,{2,3}>,
<-3*x^6+x^5+2*x^4-3*x^3+x^2-2*x-2,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2+x+2,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2-x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^4+3*x^3+3*x^2+x-3,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2+3,{2}>,
<-2*x^6+x^4+3*x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2+2,{2,3}>,
<-x^6-x^4-3*x^3-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2+2,{2,3}>,
<-2*x^6+x^5+x^4-3*x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+x^2-x-1,{2,3,5}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2+2*x+2,{}>,
<-x^6+2*x^5+x^4-3*x^3+3*x^2-x-3,{0,2}>,
<-2*x^6-3*x^5-3*x^3-3*x^2-x+3,{}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2-3*x-1,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x+2,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-x^2+3*x-2,{2,3}>,
<-3*x^6-x^5+3*x^4-3*x^3+2*x^2-3*x-2,{}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x-1,{2,5,7}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x-1,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+3*x^2+x-3,{2}>,
<2*x^6+2*x^5+3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+x-2,{2}>,
<-3*x^6-x^5+2*x^4+3*x^3-3*x-1,{2,3,13}>,
<3*x^6+x^5-2*x^4-3*x^3+2*x-2,{}>,
<3*x^6-x^5-3*x^4-3*x^3-x+2,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3+2*x^2+x-1,{2,3}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6-x^5-3*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3+2*x^2-1,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x^2-x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-3*x^2+x+3,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3-3*x^2+x+3,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+2*x^2-2*x-1,{0,2}>,
<-3*x^6-x^5+3*x^4-3*x^3-2*x^2+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+2*x^2-x-2,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3-3*x^2-x+3,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+3*x^2-x-3,{}>,
<-3*x^6-x^5+3*x^4-3*x^3+2*x^2-x-1,{2,3}>,
<2*x^6+x^5-2*x^4-3*x^3+3*x^2-x-3,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-x+3,{2}>,
<-x^6+x^5-2*x^4+3*x^3-3*x^2+x+3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x^2+3*x-1,{2,3}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-x-3,{}>,
<-3*x^6+2*x^4+3*x^3+3*x^2+x-3,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-3*x^2-x+3,{}>,
<2*x^6-3*x^5+2*x^4+3*x^3+3*x^2+x-3,{}>,
<3*x^6-2*x^4-3*x^3-3*x^2-x+3,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3-2*x^2+3*x-2,{}>,
<-x^6+2*x^4-3*x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+3*x^2-1,{2,3,11}>,
<3*x^6-x^5-3*x^4-3*x^3-3*x^2-2,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2+x-3,{2,5}>,
<3*x^6-x^5-3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6-3*x^4+3*x^3-3*x^2+x+3,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-3*x^2+3*x-1,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3-3*x^2-x+2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2-3*x-1,{}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2-2*x-1,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^3-3*x^2+x-1,{2,7}>,
<2*x^6-x^5+3*x^4+3*x^3+3*x^2+x-3,{}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-3*x^2-x-2,{}>,
<-3*x^6-x^5+3*x^4-2*x^3-3*x^2-x+2,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3+3*x^2+2,{2,3}>,
<-x^6+3*x^4+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6+3*x^4+2*x^3-3*x^2+x+3,{2,3}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2+x-3,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3+x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5-x^4-3*x^3+3*x^2-x-3,{}>,
<-2*x^6-2*x^5+x^4-3*x^3-3*x^2-x+3,{}>,
<3*x^6+x^5-3*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+3*x^2+x-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^3+3*x^2+x-1,{}>,
<-3*x^6-x^5+3*x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4-3*x^3-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2+x-3,{2}>,
<-x^6-x^5-x^4-2*x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-x^2+x+2,{2,3}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2+x-2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x+2,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3+3*x-1,{2,3}>,
<2*x^6-3*x^5-2*x^3+3*x^2-x-3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^3-3*x^2-x+3,{2}>,
<-2*x^6+2*x^5+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-x-2,{2,3}>,
<-3*x^6-x^5+3*x^4-2*x^3-x-1,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3+x-1,{2,3}>,
<2*x^6+x^5+2*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3+x-2,{2}>,
<2*x^6+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-1,{2}>,
<-x^6-2*x^3-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4+3*x^3-3*x-2,{2,3}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2-3*x-2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3+3*x^2+x-3,{2,7}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x+2,{2,3}>,
<2*x^6+3*x^5+x^4+3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-3*x+2,{2}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2-2*x-2,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2+2*x+2,{2,3}>,
<-3*x^6-x^5+3*x^4-3*x^3+x^2-2*x-1,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^3-x^2+2*x-2,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3-x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-2*x^3+3*x^2-x-3,{}>,
<-x^6-2*x^5-x^4-2*x^3-3*x^2-x+3,{2}>,
<-x^6-2*x^5+x^4+3*x^3-3*x^2+x+3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+3*x^2-x-3,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+2*x^2+x-3,{2,3}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x^2-x+3,{}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-2*x^2-2*x+2,{}>,
<3*x^6-x^5-3*x^4-2*x^3+2*x^2-2*x-2,{}>,
<3*x^6+x^5-3*x^4+2*x^3+2*x^2-3,{2,3}>,
<2*x^6-x^5+2*x^4+2*x^3-3*x^2+x+3,{2}>,
<-x^6-x^5+2*x^4+2*x^3-3*x^2+x+3,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-x^2+3*x-2,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-2*x^2-2,{2}>,
<3*x^6+2*x^4+2*x^3+3*x^2+x-3,{2,3,5}>,
<-3*x^6-2*x^4-2*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6-x^5+2*x^4+2*x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-2*x^2+x+2,{2}>,
<-x^6+x^5+2*x^4-2*x^3+3*x^2-x-3,{0,2}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2-x-1,{}>,
<-2*x^6-x^5-2*x^4+2*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2-2*x-2,{2,3}>,
<-x^6-3*x^5-2*x^4+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2-3*x+2,{2,3}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+3*x^2-3*x+2,{2,3}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+3*x^2-x-3,{}>,
<-x^6-x^5+3*x^4-2*x^3+3*x^2-x-3,{}>,
<3*x^6-x^5-3*x^4-2*x^3-3*x^2+2,{2}>,
<-x^6+3*x^4+2*x^3+3*x^2+x-3,{0,2}>,
<-x^6+x^5+x^4-2*x^3-3*x^2-x+3,{2}>,
<-x^6-3*x^4-2*x^3-3*x^2-x+3,{2}>,
<2*x^6-x^5-x^4+2*x^3+3*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3-x^2+3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+3*x^2+x-3,{2,3}>,
<-2*x^6-3*x^5+x^4+2*x^3-3*x^2+x+3,{}>,
<3*x^6-x^5-3*x^4-x^3+3*x^2-x+2,{2}>,
<3*x^6+x^5-3*x^4+x^3+3*x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4-x^3+3*x^2-x-3,{2}>,
<-x^6-3*x^5+2*x^4-x^3-3*x^2-x+3,{2,3}>,
<-x^6-2*x^5+2*x^4-x^3-3*x^2-x+3,{2}>,
<2*x^6+2*x^4-x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5-3*x^4+x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4+x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-x^3+2*x^2-2,{2}>,
<-3*x^6-x^5+3*x^4-x^3-2*x^2+3,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5-3*x^4+x^3+2*x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5-x^4-x^3+3*x^2-x-3,{2}>,
<-x^6-3*x^5-x^4-x^3+3*x^2-x-3,{2}>,
<2*x^6-3*x^5-x^4-x^3+3*x^2-x-3,{}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2+x+3,{2}>,
<-x^6+2*x^5-x^4+x^3+3*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4-x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-3*x^2-x+3,{}>,
<3*x^6+x^5-3*x^4+x^3+x^2+x-1,{2,3,7,59}>,
<-2*x^6-x^5+x^4-x^3-3*x^2-x+3,{2}>,
<-2*x^6+3*x^4-x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4-x^3+x^2+3,{2,3}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4+x^3+x^2-1,{2}>,
<3*x^6+x^5-3*x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6-x^4-x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4+x^3-x^2-3*x-1,{2,3}>,
<-3*x^6-x^5+3*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+x^3+3*x^2+x-3,{2,5}>,
<-x^6-3*x^5-2*x^4-x^3+3*x^2-x-3,{2}>,
<-3*x^6-x^5+3*x^4-x^3-3*x+2,{2,3}>,
<2*x^6+x^5+x^3-3*x^2+x+3,{}>,
<3*x^6-x^5-3*x^4-x^3-3*x-2,{2}>,
<-x^6-x^5-x^3+3*x^2-x-3,{2}>,
<-x^6+x^5+x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4+x^3-3,{2}>,
<-x^6+2*x^5-x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4-x^3+2*x-1,{2}>,
<-3*x^6+x^5+3*x^4+x^3-2*x+2,{}>,
<3*x^6-x^5-3*x^4-x^3+2*x-2,{}>,
<2*x^6+3*x^5-x^4+x^3-3*x^2+x+3,{2}>,
<-x^6+3*x^5+x^4+x^3+3*x^2+x-3,{}>,
<3*x^6-x^5-3*x^4-x^3-x^2-3*x-1,{2}>,
<2*x^6+3*x^5+x^4+x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+x^3-x^2+3*x-2,{2}>,
<-3*x^6+x^5+3*x^4+x^3+x^2+2*x-2,{}>,
<3*x^6+x^5-3*x^4+x^3-x^2+2*x+2,{}>,
<-x^6+2*x^5-x^4+x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4+x^3-x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+2*x^2-2*x-2,{}>,
<-x^6-2*x^5-2*x^4-2*x^3-3*x^2-x+3,{2}>,
<-x^6+x^5+2*x^4+2*x^3+3*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+2*x^2-3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+2*x^2-2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-2*x^2+2,{2}>,
<-x^6+x^5-x^4-x^3-3*x^2-x+3,{2}>,
<-x^6+2*x^5-x^4-x^3-3*x^2-x+3,{}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-x^3-x^2+2*x-2,{2,3}>,
<3*x^6-x^5-3*x^4-x^3-x^2+3*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4-x^3-2*x^2-3*x+2,{2}>,
<3*x^6-x^5-3*x^4-x^3-2*x^2-x+2,{2}>,
<3*x^6-2*x^4-x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4+x^3+2*x^2-1,{2}>,
<3*x^6+x^5-3*x^4+x^3-2*x^2-1,{2,5}>,
<-3*x^6-x^5+3*x^4-x^3+2*x^2+2,{2,3}>,
<3*x^6+x^5-3*x^4+x^3-2*x^2-2,{2}>,
<-x^6-x^5-2*x^4+x^3-3*x^2+x+3,{2,7}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2-x-3,{2}>,
<-2*x^6-x^5-2*x^4+x^3-3*x^2+x+3,{2}>,
<-x^6+2*x^5-2*x^4-x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4+x^3+2*x^2-3*x+2,{2,3}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2-3*x-2,{2}>,
<3*x^6+x^5-3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6-x^5-3*x^4-2*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-3*x^4+2*x^3+3*x^2+x-3,{}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2+x-3,{2,5}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2+x-3,{2,3}>,
<-3*x^6+x^5+3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3-2*x^2+2*x-1,{2,13}>,
<-3*x^6+3*x^4-x^3+3*x^2-x-3,{2,3,5,17,29}>,
<3*x^6-3*x^4-x^3-3*x^2-x+3,{2,3,5}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2-2,{2}>,
<3*x^6-x^5-3*x^4-x^3-3*x^2-1,{2}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2+2,{}>,
<-2*x^6-3*x^4+x^3-3*x^2+x+3,{}>,
<3*x^6+x^5-3*x^4+x^3-3*x^2-2*x+2,{0,2,7}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-2*x^5-3*x^4+x^3-3*x^2+x+3,{2}>,
<-3*x^6+x^5+3*x^4+x^3+x^2+3,{2}>,
<-3*x^6-x^4-x^3-3*x^2-x+3,{2,3}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2+2*x+2,{2,5}>,
<-2*x^6+2*x^5-3*x^4-x^3-3*x^2-x+3,{2,5}>,
<-x^6+3*x^5-3*x^4-x^3-3*x^2-x+3,{}>,
<-2*x^6+3*x^5-3*x^4-x^3-3*x^2-x+3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4-3*x^2-3*x+2,{2}>,
<3*x^6-x^5-3*x^4+3*x^2-2*x+2,{2}>,
<3*x^6+x^5-3*x^4+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^2+x+3,{2,3,5}>,
<2*x^6+x^5+3*x^4-3*x^2+x+3,{}>,
<3*x^6-x^5-3*x^4+3*x^2+3,{2}>,
<2*x^6-x^5+3*x^4-3*x^2+x+3,{}>,
<3*x^6-x^5-3*x^4+3*x^2-x-2,{2}>,
<-x^6-x^5+3*x^4-3*x^2+x+3,{2}>,
<2*x^6+x^5-3*x^4+3*x^2-x-3,{}>,
<3*x^6-x^5-3*x^4+2*x^2-x-1,{2,3}>,
<3*x^6+x^5-3*x^4+3*x^2-3*x+2,{}>,
<2*x^6+x^5-2*x^4+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^2+x-2,{2}>,
<2*x^6+2*x^4-3*x^2-x+3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+2*x^2+2*x+2,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^2+3*x+2,{2}>,
<3*x^6-x^5-3*x^4+2*x^2-3*x-1,{2}>,
<3*x^6-x^5-3*x^4+2*x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-2*x^4+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4-2*x^2+2*x+2,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4+2*x^2+x+2,{2,3}>,
<-x^6+3*x^5-x^4+3*x^2+x-3,{2}>,
<2*x^6+3*x^5-x^4+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+x^2+3*x-2,{2}>,
<-3*x^6-x^5+3*x^4-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^2+x+3,{2}>,
<2*x^6-2*x^5-3*x^2-x+3,{2}>,
<-x^6+2*x^5+3*x^2+x-3,{2,11}>,
<3*x^6+x^5-3*x^4+2*x-1,{}>,
<-3*x^6-x^5+3*x^4-2*x+2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3-3*x^2-x+3,{2}>,
<2*x^6+x^5-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4-x-1,{}>,
<3*x^6+x^5-3*x^4-2*x-2,{2}>,
<-3*x^6-x^5+3*x^4+x^2-3*x-2,{}>,
<2*x^6-3*x^5-x^4-3*x^2-x+3,{}>,
<2*x^6+3*x^5+x^4+3*x^2+x-3,{}>,
<-2*x^6+2*x^5+x^4-3*x^2+x+3,{2,3,103}>,
<-x^6+x^5+x^4-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+x^2-2*x-2,{2,3}>,
<-3*x^6+x^5+3*x^4-x^2+x+2,{2,3}>,
<-x^6+2*x^5+x^4+3*x^2+x-3,{2}>,
<3*x^6+x^4-3*x^2+x+3,{2,3}>,
<2*x^6+x^5-x^4-3*x^2+x+3,{2}>,
<-x^6-x^5+x^4+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4+x^2-3,{2,3}>,
<3*x^6+x^5-3*x^4-x^2-1,{2}>,
<-2*x^6-x^4-3*x^2+x+3,{}>,
<2*x^6+x^5+x^4-3*x^2-x+3,{2}>,
<-x^6-2*x^5-x^4+3*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4+2*x^2-x-2,{2}>,
<-x^6+x^5+2*x^4+3*x^2+x-3,{}>,
<-3*x^6-x^5+3*x^4+2*x^2+2,{2,3}>,
<-3*x^6-2*x^4-3*x^2-x+3,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^2-x-1,{2}>,
<3*x^6+x^5-3*x^4-2*x^2-x-2,{2}>,
<3*x^6+x^5-3*x^4-2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^2-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4+2*x^3-3*x^2-x-1,{2,3}>,
<-3*x^6+x^5+3*x^4+2*x^3+3*x^2-x+2,{2,3}>,
<3*x^6+x^5-3*x^4+2*x^3-3*x^2-2*x-1,{2,3}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-3*x^2-x+3,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-3*x^2+x+3,{0,2}>,
<-3*x^6-x^5+3*x^4-2*x^3+3*x^2+3*x-1,{0,2,3}>,
<3*x^6+x^5-3*x^4+2*x^3-3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^2-x+3,{2}>,
<-x^6-3*x^5-2*x^4-3*x^2+x+3,{}>,
<-3*x^6+x^5+3*x^4+2*x^2-3*x+2,{2}>,
<3*x^6+x^5-3*x^4-2*x^2-3*x-2,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+x^2+x-2,{2,3}>,
<-3*x^6-x^5+3*x^4+3*x^2-3*x-1,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^2-3*x-2,{}>,
<2*x^6+x^5-x^4+2*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^2+2*x+2,{}>,
<3*x^6+x^5-3*x^4+2*x^3-x^2+x-1,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+x^2-x+2,{2}>,
<-2*x^6+x^4-2*x^3+3*x^2-x-3,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^2+x+3,{2}>,
<-3*x^6+x^5+3*x^4+3*x^2+x-3,{2,3}>,
<-3*x^6+x^5+3*x^4+3*x^2+x-2,{2}>,
<-3*x^6+x^5+3*x^4+3*x^2+x+2,{2,5}>,
<3*x^6-x^5-3*x^4-3*x^2-x-2,{2,3}>,
<3*x^6-x^5-3*x^4-3*x^2-1,{2}>,
<-3*x^6+x^5+3*x^4+3*x^2+3,{2}>,
<3*x^6-x^5-3*x^4-2*x^3-x^2-3,{2}>,
<2*x^6-x^5-x^4+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+x^2+x-1,{2}>,
<-x^6-2*x^5-x^4+2*x^3-3*x^2+x+3,{}>,
<3*x^6-x^5-3*x^4-2*x^3-x^2+2*x-2,{2}>,
<-x^6+3*x^5-x^4-2*x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4+2*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+x^5+3*x^4+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^2-2*x-1,{2,3}>,
<-3*x^6+x^5+3*x^4+3*x^2-3*x-2,{2}>,
<3*x^6+x^5-3*x^4-3*x^2-3*x-1,{2,3}>,
<2*x^6-3*x^5+3*x^4+3*x^2+x-3,{2}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2+x+3,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+3*x^2-x-3,{}>,
<3*x^6-x^5-3*x^4+x^3+3*x^2-2*x-2,{2}>,
<3*x^6+x^5-3*x^4-x^3+3*x^2+2,{2}>,
<-x^6+3*x^4+x^3-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4+x^3-3*x^2+2,{2,3}>,
<3*x^6-x^5-3*x^4+x^3+3*x^2+2*x-2,{}>,
<3*x^6-x^5-3*x^4+x^3+3*x^2+3*x+2,{2}>,
<-x^6-3*x^5-3*x^4-x^3+3*x^2+x-3,{2}>,
<-x^6-3*x^5+3*x^4-x^3-3*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3+2*x^2-3*x-2,{2,3}>,
<3*x^6-x^5-3*x^4+x^3+2*x^2-2*x+2,{2,3}>,
<3*x^6+x^5-3*x^4-x^3+2*x^2+2*x-1,{2,3}>,
<3*x^6-x^5-3*x^4+x^3+2*x^2-x+2,{2,3}>,
<3*x^6+2*x^4-x^3-3*x^2+x+3,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3+3*x^2-x-3,{}>,
<3*x^6+x^5-3*x^4-x^3+2*x^2-3,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-3*x^2-x+3,{}>,
<2*x^6-x^5+2*x^4-x^3-3*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3+2*x^2+2*x-1,{2,3}>,
<-3*x^6-x^5+3*x^4+x^3-2*x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4-x^3+3*x^2-x-3,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4-x^3+x^2+3*x-1,{2}>,
<3*x^6+x^5-3*x^4+x^3-3*x^2+2*x-2,{2}>,
<3*x^6+x^5-3*x^4-x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4+x^3+3*x^2-x-3,{2}>,
<-x^6+2*x^5+x^4+x^3-3*x^2-x+3,{2}>,
<2*x^6-2*x^5-x^4-x^3+3*x^2+x-3,{2}>,
<2*x^6+x^4+x^3-3*x^2-x+3,{2,3}>,
<3*x^6-x^5-3*x^4-x^3-3*x^2-x+2,{2}>,
<-3*x^6-x^5+3*x^4-x^3+3*x^2-x-1,{}>,
<3*x^6+x^5-3*x^4+x^3-3*x^2+x-1,{2}>,
<3*x^6-x^4+x^3+3*x^2-x-3,{2}>,
<-2*x^6-x^3-3*x^2+x+3,{2}>,
<3*x^6-x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4+x^3+2*x+2,{2,3}>,
<-3*x^6+x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3-x^2+3,{2}>,
<-x^6-x^4+x^3-3*x^2-x+3,{2}>,
<2*x^6+x^4+x^3+3*x^2-x-3,{}>,
<3*x^6+x^5-3*x^4-x^3-x^2-2,{}>,
<-3*x^6+x^5+3*x^4+x^3+2*x-1,{2}>,
<3*x^6+x^5-3*x^4-x^3-x^2-3,{2,3}>,
<2*x^6+2*x^5+x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4-x^3-x^2-x-1,{2}>,
<3*x^6+x^5-3*x^4-x^3-x^2-x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4-x^3-2*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3+3*x^2+x-3,{2}>,
<-x^6-3*x^5+x^4-x^3+3*x^2+x-3,{2,3,5,89}>,
<-2*x^6-3*x^5-2*x^4+x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4-x^3+2*x^2+2*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3-3*x^2-x+3,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2+x-3,{}>,
<3*x^6-x^5-3*x^4-3*x^2-2*x-1,{2,11}>,
<-2*x^6+2*x^5-2*x^4-x^3-3*x^2+x+3,{}>,
<3*x^6+x^5-3*x^4-x^3-2*x^2+x-1,{}>,
<-3*x^6+x^5+3*x^4+3*x^2+2*x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2+x-3,{2}>,
<-2*x^6+x^5-2*x^4-x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-x^3-2*x^2-1,{2,3}>,
<3*x^6+2*x^4+x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4+x^3-2*x^2+2*x-2,{2}>,
<3*x^6-x^5-3*x^4+x^3-2*x^2-3,{2}>,
<-x^6-x^5-2*x^4-x^3-3*x^2+x+3,{}>,
<2*x^6-x^5+2*x^4-x^3+3*x^2+x-3,{2,13}>,
<-2*x^6-3*x^5+2*x^4-x^3+3*x^2+x-3,{2,3,5}>,
<-x^6+2*x^5+2*x^4+x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4+x^3-2*x^2+2*x-1,{2}>,
<-3*x^6+x^5+3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-x^6+3*x^4-x^3+3*x^2+x-3,{0,2}>,
<-x^6-3*x^4-x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+x^3+3*x^2+2,{2}>,
<3*x^6+x^5-3*x^4-x^3-3*x^2-2,{2,3}>,
<3*x^6+3*x^4+x^3+3*x^2-x-3,{2,3}>,
<-3*x^6-3*x^2+x+3,{2}>,
<-3*x^6+x^5+3*x^4-x^3+3*x^2-2*x+2,{2,3}>,
<-2*x^6+2*x^5-3*x^4+x^3-3*x^2-x+3,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-x-3,{2}>,
<-3*x^6-x^5+3*x^4-x^3+2*x^2-x-2,{2,3}>,
<-2*x^6+x^5+3*x^4+2*x^3-3*x^2-x+3,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3+3*x^2-2*x-1,{}>,
<-3*x^6+x^5+3*x^4-2*x^3-3*x^2-2*x+2,{}>,
<3*x^6+x^5-3*x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<-3*x^6+x^5+3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3+2*x^2+2*x+2,{2}>,
<3*x^6-x^5-3*x^4+x^3-3*x-1,{2,3}>,
<2*x^6-3*x^5+x^3+3*x^2-x-3,{2,3}>,
<-2*x^6+x^5-x^3-3*x^2+x+3,{2}>,
<3*x^6+x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3+2,{2}>,
<-x^6-x^3-3*x^2+x+3,{2}>,
<2*x^6-x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3+2*x^2-x-1,{2,3}>,
<2*x^6-x^5-2*x^4-2*x^3+3*x^2+x-3,{}>,
<-2*x^6-x^5+2*x^4-2*x^3-3*x^2+x+3,{}>,
<2*x^6-3*x^5-3*x^4+x^3-3*x^2-x+3,{2}>,
<2*x^6+3*x^5+x^3-3*x^2-x+3,{}>,
<-2*x^6-3*x^5+x^4+x^3+3*x^2-x-3,{2}>,
<2*x^6-2*x^5-x^4+x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+x^3-x^2-2*x-2,{}>,
<3*x^6+x^5-3*x^4-x^3-x^2+x-1,{2,3}>,
<3*x^6-x^5-3*x^4+x^3-x^2-x-2,{2}>,
<-x^6-2*x^5+x^4-2*x^3-3*x^2+x+3,{}>,
<-2*x^6-2*x^5-x^4-x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+2*x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+3*x^2-x-3,{}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x+2,{}>,
<-x^6+2*x^5+2*x^3+3*x^2-x-3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3+x^2+3*x-2,{}>,
<3*x^6-x^5-3*x^4+2*x^3+2*x-1,{2}>,
<3*x^6+x^5-3*x^4-2*x^3+x+2,{2}>,
<-x^6-x^5+2*x^3-3*x^2-x+3,{}>,
<2*x^6-x^5+2*x^3+3*x^2-x-3,{2}>,
<2*x^6-2*x^5-2*x^3+3*x^2+x-3,{2}>,
<-x^6-3*x^5-2*x^3+3*x^2+x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3+x-2,{2}>,
<-x^6-3*x^5-2*x^3-3*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-2,{2}>,
<3*x^6-x^5-3*x^4-x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-x^4-3*x^2-x+3,{2}>,
<-2*x^6-3*x^5-2*x^3-3*x^2+x+3,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-x^2-2*x-1,{2,3}>,
<-2*x^6-2*x^5-x^4+2*x^3-3*x^2-x+3,{2}>,
<2*x^6-x^5+x^4+2*x^3+3*x^2-x-3,{2}>,
<-2*x^6+x^5-x^4-2*x^3-3*x^2+x+3,{2,13}>,
<3*x^6+x^5-3*x^4-2*x^3-x^2-1,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-x^2-2,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3+x^2+3,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3-x^2-x+2,{}>,
<-3*x^6+x^5+3*x^4-2*x^3+x^2-x-1,{2}>,
<-2*x^6-x^5-x^4-2*x^3-3*x^2+x+3,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3+x^2-2*x-1,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3-x^2-3*x+2,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-x^2-3*x-1,{}>,
<2*x^6+3*x^5+x^4+2*x^3+3*x^2-x-3,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2+x-3,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^3-2*x^2-3*x-2,{2,3}>,
<-3*x^6-x^5+3*x^4+2*x^3+2*x^2-2*x+2,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-x^6+x^5-2*x^4-2*x^3-3*x^2+x+3,{}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x^2-1,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3+2*x^2+2,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-2*x^2-2,{2}>,
<-3*x^6-2*x^4+2*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6-x^5+2*x^4-2*x^3+3*x^2+x-3,{2}>,
<-x^6-3*x^5+3*x^4-x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4+x^3-3*x^2+3*x-1,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-2*x^2+x+2,{2}>,
<3*x^6-x^5-3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-3*x^2-x+3,{2}>,
<2*x^6+x^5+3*x^4-2*x^3-3*x^2+x+3,{}>,
<-3*x^6+x^5+3*x^4-2*x^3+2*x^2-x-1,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+3*x^2-x-3,{2}>,
<3*x^6+3*x^4+2*x^3-3*x^2-x+3,{2,3,7}>,
<-x^6-x^5-3*x^4+2*x^3-3*x^2-x+3,{}>,
<-x^6-3*x^4+2*x^3-3*x^2-x+3,{2}>,
<-2*x^6-3*x^4+2*x^3-3*x^2-x+3,{2}>,
<-3*x^6-3*x^4+2*x^3-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4-2*x^3-3*x^2-x-1,{2,3}>,
<2*x^6+x^5+3*x^4+2*x^3+3*x^2-x-3,{2,3}>,
<2*x^6+2*x^5-3*x^4+2*x^3-3*x^2-x+3,{2}>,
<-x^6-x^5-3*x^4-x^3-3*x^2+x+3,{}>,
<3*x^6+x^5-3*x^4-x^3-3*x^2-x-2,{2,3}>,
<-3*x^6+x^5+3*x^4-x^3+3*x^2-2*x-2,{2,3}>,
<-x^6+2*x^5-3*x^4+x^3-3*x^2-x+3,{2,3}>,
<-2*x^6-3*x^5-x^4-3*x^2+x+3,{2}>,
<-x^6-3*x^5+2*x^4+3*x^2-x-3,{2}>,
<-x^6-3*x^5-3*x^4+x^3-3*x^2-x+3,{2,3}>,
<2*x^6-3*x^5+3*x^4+x^3+3*x^2-x-3,{}>,
<-3*x^6+x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-x^5+3*x^4+2*x^2-2*x-2,{2,3}>,
<3*x^6+x^5-3*x^4-x^3-3*x^2+x-1,{2}>,
<3*x^6+x^5-3*x^4-2*x^2+2*x+2,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+3*x^2+x-3,{2,5}>,
<2*x^6-3*x^4+x^3-3*x^2-x+3,{0,2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-3*x^2+x+3,{2,5}>,
<3*x^6-x^5-3*x^4+3*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6+2*x^4-3*x^3-3*x^2+x+3,{}>,
<3*x^6+x^5-3*x^4-3*x^3+2*x^2-1,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+2*x^2+3*x-1,{}>,
<3*x^6-2*x^4-3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3-2*x^2-x+2,{2,3}>,
<3*x^6-x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2+x-3,{2}>,
<-x^6+2*x^5-x^4+3*x^3+3*x^2-x-3,{2,19}>,
<2*x^6-2*x^5-x^4-3*x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+x^2+2*x-2,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3-x^2-3*x-1,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+x^2+3*x-1,{2,3}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2+x-3,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-x^2-3*x-2,{2}>,
<2*x^6+2*x^5-3*x^3-3*x^2+x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3+x-2,{2}>,
<-3*x^6+3*x^3-3*x^2-x+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-2*x-1,{2}>,
<2*x^6-x^5-3*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x-1,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2-x-3,{2}>,
<-2*x^6+2*x^5-3*x^3-3*x^2+x+3,{}>,
<2*x^6+2*x^5+3*x^3+3*x^2-x-3,{2}>,
<-2*x^6+2*x^5+3*x^3-3*x^2-x+3,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+3*x^2-x-3,{2}>,
<3*x^6+x^5-3*x^4-3*x^2-x-1,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+x^2-1,{2}>,
<-2*x^6-x^4+3*x^3-3*x^2-x+3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x^2+3,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3-x^2-3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+x^2-x-1,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-x^2-2*x-1,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x^2+2*x+2,{2,19}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2+x-3,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2+x+3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+x^2+3*x+2,{2,3}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-3*x^2-x+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-x^2-3*x-2,{2,3}>,
<2*x^6-3*x^5+2*x^4+3*x^3+3*x^2-x-3,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3-3*x^2-x+3,{}>,
<-3*x^6+x^5+3*x^4-2*x^3+2*x^2-3*x-1,{2,3,7}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x^2+2*x-1,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^3+x^2+3,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x^2+x-1,{}>,
<-3*x^6-x^5+3*x^4+2*x^3+3*x^2-3*x-2,{2,3}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2+x-3,{2}>,
<-3*x^6+x^4+2*x^3-3*x^2-x+3,{2,3}>,
<3*x^6-x^5-3*x^4+2*x^3-3*x^2-3*x-1,{2}>,
<3*x^6-2*x^4+3*x^3-3*x^2-x+3,{2}>,
<-x^6+2*x^5-3*x^4-2*x^3-3*x^2+x+3,{2,3}>,
<3*x^6+x^5-3*x^4-2*x^3+x^2-x-1,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+2*x^2-2,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+2*x^2-1,{2}>,
<-3*x^6+x^5+3*x^4-2*x^3-x^2-x+2,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x^2-1,{2}>,
<3*x^6-x^5-3*x^4+2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^4+3*x^3+3*x^2-x-3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+3*x^2+x-3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+2*x^2+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x^2+x+3,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x^2+x+3,{0,2}>,
<-x^6-3*x^5-x^4+3*x^3+3*x^2-x-3,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+2*x^2+3*x-1,{2,3}>,
<-3*x^6-2*x^4-3*x^3-3*x^2+x+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-2*x^2+3*x-1,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3+x^2+2*x-2,{2,3}>,
<-3*x^6-x^5+3*x^4+2*x^3+3*x^2-x-1,{0}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2+3*x-1,{2,3}>,
<-3*x^6-x^5+3*x^4+3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6+x^4-3*x^3-3*x^2+x+3,{2,3}>,
<2*x^6+x^5+2*x^4+2*x^3-3*x^2-x+3,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3-3*x^2-x+3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+x^2-1,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2+x+2,{2}>,
<-x^6-3*x^4-3*x^3-3*x^2+x+3,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3+3*x^2+3,{}>,
<-x^6+2*x^5+2*x^4+3*x^3+3*x^2-x-3,{2}>,
<3*x^6+3*x^4-3*x^3+3*x^2+x-1,{2}>,
<-x^6-x^5-3*x^4-3*x^3-3*x^2+x+3,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-3*x^2-3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2-2*x+2,{}>,
<-3*x^6-x^5+3*x^4+3*x^3-x^2+2,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+3,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<3*x^6+3*x^4+3*x^3+2*x^2-3*x-1,{2,7}>,
<3*x^6-x^5-3*x^4+3*x^3+x^2+x-1,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3+3*x^2+x+2,{2}>,
<3*x^6+3*x^4-3*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6+3*x^4+3*x^3+2*x^2+x-2,{2}>,
<3*x^6+3*x^4+3*x^3+x^2+3*x+2,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2-x-2,{2}>,
<3*x^6+3*x^4-3*x^3+2*x^2+2,{2}>,
<-2*x^6+x^5+x^4+3*x^3-3*x^2-x+3,{2,3}>,
<-2*x^6-3*x^5+x^4-3*x^3+3*x^2+3,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2+x-3,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-3*x^3+x^2+2,{2}>,
<-3*x^6-3*x^4+3*x^3-2*x^2+2,{2}>,
<3*x^6+3*x^4-3*x^3+x^2-x-1,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2-2*x+2,{2,3}>,
<3*x^6+3*x^4+3*x^3+x^2+3,{2}>,
<2*x^6-x^5+3*x^3+3*x^2+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2-x-3,{2}>,
<3*x^6+3*x^4+3*x^3-x-1,{}>,
<3*x^6+3*x^4+3*x^3+x^2-2,{2}>,
<3*x^6+3*x^4-3*x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4+3*x^3+3*x^2+3,{2}>,
<-2*x^6-x^5+x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-3*x^3+x-2,{2}>,
<2*x^6+3*x^5+x^4-3*x^3-3*x^2-3,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+3*x^2+3,{}>,
<2*x^6-2*x^5+3*x^3-3*x^2-3,{}>,
<3*x^6-x^5-3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<3*x^6+3*x^4+3*x^3-2*x-2,{}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2-3,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+3*x^2+3,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-3*x^2-3,{2,5}>,
<3*x^6+3*x^4-3*x^3-2*x^2-x-1,{}>,
<-x^6-3*x^5+3*x^4-3*x^3+3*x^2+x-3,{2}>,
<-x^6-2*x^5+x^4+3*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+3*x^3-2*x^2-2,{}>,
<-x^6-3*x^5-x^4-3*x^3+3*x^2+3,{}>,
<3*x^6+3*x^4-3*x^3+x^2+3*x-2,{}>,
<-2*x^6+3*x^5+3*x^3-3*x^2-3,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<3*x^6+3*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<3*x^6+3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-3*x^3+3*x^2+3,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2+3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<3*x^6+3*x^4+3*x^3-3*x^2+x-1,{2}>,
<-x^6-x^5+x^4-3*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4-3*x^3-2*x+2,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3+3*x^2+3,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+3*x^2+3,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3+3*x^2+3,{}>,
<-3*x^6-3*x^4+2*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-3*x^2-3,{2,5}>,
<3*x^6+3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<3*x^6+3*x^4-2*x^3+2*x^2+3*x-1,{2,3}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2-3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-3*x^2-3,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-3*x^2-3,{}>,
<-3*x^6-3*x^4+2*x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5+x^4-2*x^3+3*x^2+3,{2}>,
<2*x^6-2*x^4-2*x^3-3*x^2-3,{2}>,
<-x^6+x^5+x^4-2*x^3+3*x^2+3,{2}>,
<-2*x^6-x^5+x^4-2*x^3+3*x^2+3,{2}>,
<3*x^6-2*x^4-2*x^3-3*x^2-3,{}>,
<3*x^6+3*x^4-2*x^3+x^2+3*x-1,{2}>,
<3*x^6+x^4+2*x^3+3*x^2+3,{2,3}>,
<3*x^6+3*x^4-2*x^3+2*x^2+x-1,{2}>,
<-3*x^6-3*x^4-2*x^3-x^2+3*x+2,{2}>,
<3*x^6+3*x^4+2*x^3+3*x+2,{}>,
<-3*x^6-3*x^4+2*x^3-x^2+3,{2,3}>,
<-3*x^6-3*x^4-2*x^3-3*x-1,{2}>,
<-3*x^6-3*x^4-2*x^3+2,{2}>,
<3*x^6+3*x^4+2*x^3+x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-3*x^2-3,{2}>,
<-2*x^6-3*x^5+2*x^3+3*x^2+3,{}>,
<-2*x^6-3*x^5+x^4-2*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-3*x^6-3*x^4-2*x^3+x^2-3*x+2,{2}>,
<-x^6+2*x^5+x^4+2*x^3-3*x^2-3,{2}>,
<3*x^6-2*x^3-3*x^2-3,{2}>,
<2*x^6+x^4+2*x^3-3*x^2-3,{2}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+2*x^3-x^2-x-1,{}>,
<2*x^6-x^5+x^4+2*x^3-3*x^2-3,{2,5}>,
<3*x^6+3*x^4-2*x^3-x^2+3*x+2,{2}>,
<-3*x^6-3*x^4-2*x^3+3*x^2-2*x-2,{2,3}>,
<-3*x^6-3*x^4+2*x^3+3*x^2-1,{2}>,
<-3*x^6-3*x^4-2*x^3+3*x^2+3,{2,23,67}>,
<-3*x^6-x^5+3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+3*x^4+x^3+3*x^2-3,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-x^3+3*x^2+3,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-3*x^2-3,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2+3,{2}>,
<-x^6-3*x^5+2*x^4-x^3+3*x^2+3,{2,3}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2+3,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x^2-3,{2}>,
<3*x^6+3*x^4-2*x^3-2*x^2-x-2,{2}>,
<3*x^6+3*x^4+2*x^3-2*x^2-x+2,{2}>,
<3*x^6+3*x^4-x^3+2*x^2-x+2,{2,3}>,
<3*x^6+2*x^4+x^3+3*x^2+3,{}>,
<3*x^6+3*x^4+x^3+2*x^2-1,{2}>,
<-3*x^6-3*x^4+x^3-2*x^2+2,{}>,
<3*x^6+3*x^4+x^3+2*x^2-2,{}>,
<-3*x^6-3*x^4-x^3-2*x^2+3,{2}>,
<-x^6-x^5+2*x^4+x^3+3*x^2+3,{2}>,
<-3*x^6-3*x^4+x^3-2*x^2-x+2,{2,3}>,
<-2*x^6+x^5+2*x^4-x^3+3*x^2+3,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3+3*x^2+3,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+x^3+x^2+3*x+2,{2}>,
<-x^6+3*x^5+x^4+x^3+3*x^2+3,{2}>,
<2*x^6-3*x^5-3*x^3+3*x^2+x-3,{2}>,
<2*x^6+3*x^5-x^4+x^3-3*x^2-3,{}>,
<-x^6+3*x^5-x^4-3*x^3-3*x^2+x+3,{2}>,
<2*x^6+2*x^5+x^4+x^3+3*x^2+3,{2,3}>,
<3*x^6+3*x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6+x^4-x^3+3*x^2+3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-x^2-3*x-2,{2}>,
<-x^6-2*x^5-x^4+3*x^3-3*x^2-x+3,{}>,
<-x^6+x^4+x^3+3*x^2+3,{2}>,
<2*x^6-x^4+x^3-3*x^2-3,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+x^2+2*x+2,{2,3}>,
<-3*x^6+x^4-x^3+3*x^2+3,{2,3}>,
<-x^6+x^5+x^4-x^3+3*x^2+3,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3-3*x^2-x+3,{2}>,
<3*x^6+3*x^4+x^3+x^2-x-2,{}>,
<3*x^6+3*x^4+x^3+x^2-2*x+2,{2}>,
<3*x^6-x^5-3*x^4+3*x^3-x^2-x-1,{2,3}>,
<-x^6-2*x^5+x^4+x^3+3*x^2+3,{2}>,
<-3*x^6-3*x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6-3*x^5+x^4+x^3+3*x^2+3,{}>,
<-2*x^6+3*x^5+x^4-x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-x^3-x+2,{2}>,
<3*x^6+3*x^4+x^3+x-1,{2}>,
<3*x^6+3*x^4-x^3+3*x+2,{2}>,
<3*x^6+3*x^4+x^3-3*x-1,{}>,
<2*x^6+x^5+x^3-3*x^2-3,{2,3}>,
<3*x^6+3*x^4+x^3+x-2,{2,3}>,
<3*x^6-x^3+3*x^2+3,{2}>,
<-2*x^6+2*x^5-x^3+3*x^2+3,{2,3,5,11,13}>,
<-3*x^6-3*x^4-x^3+x^2+x+2,{2,3}>,
<-2*x^6+x^5-x^4-x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4+x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5-x^4-x^3+3*x^2+3,{2}>,
<2*x^6-2*x^5+x^4+x^3-3*x^2-3,{2,5}>,
<3*x^6+3*x^4+x^3-x^2-3*x-1,{2}>,
<2*x^6-3*x^5+x^4+x^3-3*x^2-3,{}>,
<-3*x^6+x^5+3*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-3*x^6+x^5+3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-3*x^2+x-2,{2,3}>,
<-3*x^6-3*x^4+x^3+2*x^2+3*x+2,{2}>,
<3*x^6+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<3*x^6+3*x^4+x^3-2*x^2+2*x-2,{2}>,
<-3*x^6-3*x^4+x^3+2*x^2+x-1,{2}>,
<3*x^6+3*x^4-x^3-2*x^2+3,{2}>,
<2*x^6-2*x^4-x^3+3*x^2+3,{2}>,
<-3*x^6-3*x^4-x^3+2*x^2+2,{2}>,
<3*x^6+3*x^4+x^3+3*x^2+3*x-2,{2}>,
<3*x^6+3*x^4-x^3-2*x^2+x+2,{2}>,
<-x^6-x^5+3*x^4-x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-x^3-2*x^2+x-2,{2}>,
<3*x^6+3*x^4+x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-x^3-2*x^2+2*x+2,{}>,
<3*x^6+3*x^4+x^3+3*x^2+2,{2}>,
<-3*x^6-3*x^4-x^3+2*x^2+2*x+2,{}>,
<-3*x^6-3*x^4+x^3+2*x^2-3*x-1,{2}>,
<3*x^6+3*x^4-x^3-3*x^2-3*x-1,{2}>,
<-3*x^6-3*x^4+x^3-3*x^2+2,{2}>,
<3*x^6+3*x^4+x^3-3*x^2+x+2,{2,3}>,
<-2*x^6+x^5-3*x^4+x^3+3*x^2+3,{}>,
<3*x^6-3*x^4-x^3+3*x^2+3,{2}>,
<3*x^6+3*x^4-x^3+3*x^2-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^2-3,{}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2-3,{}>,
<-3*x^6-3*x^4-2*x^2-2*x+2,{2}>,
<3*x^6+3*x^4-x^3-3*x^2+3*x-2,{2}>,
<3*x^6+3*x^4+2*x^2-x-2,{2}>,
<-3*x^6-3*x^4-3*x^2-x+2,{2}>,
<3*x^6-2*x^4-3*x^2-3,{2}>,
<3*x^6+3*x^4+x^2+3*x+2,{2,7}>,
<-2*x^6-3*x^5+x^4+3*x^2+3,{2,5}>,
<2*x^6-x^5+x^4+3*x^2+3,{2}>,
<3*x^6+3*x^4+x^2-x-1,{2}>,
<-3*x^6+x^4-3*x^2+3,{2}>,
<-3*x^6-3*x^4-x^2+2,{}>,
<3*x^6+3*x^4+x-2,{2}>,
<-x^6+3*x^5+x^4-3*x^2-3,{2,3}>,
<-3*x^6-3*x^4+x^2-2*x+2,{2}>,
<-3*x^6-3*x^4+x^2+x+2,{2}>,
<2*x^6+x^4-3*x^2-3,{2}>,
<-3*x^6-3*x^4+2*x^2-3*x-2,{2,3}>,
<3*x^6+3*x^4-2*x^2-x+2,{}>,
<3*x^6-3*x^4-2*x^2-2,{}>,
<-3*x^6-3*x^4+2*x^2+2,{2}>,
<-3*x^6-3*x^4+3*x^2-2*x-1,{2}>,
<3*x^6+2*x^4-3*x^3+3*x^2-2*x+2,{2,3}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+3*x^3-3*x^2+2*x+2,{}>,
<3*x^6+2*x^4+3*x^3+3*x^2+x+2,{2,3}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-3*x^3-3*x^2-x+2,{2}>,
<3*x^6+2*x^4+3*x^3+3*x^2+x-2,{2}>,
<3*x^6+2*x^4-3*x^3+3*x^2+2,{2,3}>,
<-3*x^6-2*x^4-3*x^3-3*x^2+2,{2}>,
<3*x^6-3*x^4-3*x^3-2*x^2-3,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2+3,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-2*x^2-3,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+3*x^3-3*x^2-2*x+2,{}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+2*x^2+3,{}>,
<-x^6+3*x^5+3*x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-3*x^3+3*x^2+3*x-2,{2,3}>,
<-3*x^6-2*x^4+3*x^3-2*x^2+3*x-1,{2,7}>,
<3*x^6+2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-x^6+x^5+2*x^4+3*x^3+2*x^2+3,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4+3*x^3+2*x^2+3,{}>,
<2*x^6-2*x^4+3*x^3-2*x^2-3,{}>,
<3*x^6+2*x^4-3*x^3+2*x^2-2,{}>,
<2*x^6-2*x^5+2*x^4+3*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4+3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6+3*x^4+3*x^3-3*x^2-x-2,{}>,
<-3*x^6-2*x^4+3*x^3-2*x^2-3*x+2,{2,5}>,
<3*x^6+3*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^4+3*x^3+2*x^2-3*x-2,{2,5}>,
<-x^6+2*x^5-x^4+3*x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-3*x^3+x^2+3,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x^2-3,{2,3}>,
<3*x^6+2*x^4-3*x^3+x^2+x+2,{2,3}>,
<-x^6+x^5+x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2-3,{2}>,
<2*x^6-x^5-3*x^3+3*x^2+x-3,{2}>,
<-2*x^6+x^5+x^4-3*x^3+2*x^2+3,{2,3}>,
<-2*x^6-2*x^5-3*x^3+3*x^2+x-3,{}>,
<3*x^6-3*x^4-2*x^3-3*x^2-3,{2}>,
<-3*x^6-2*x^4+3*x^3-x^2-2*x+2,{2,3}>,
<2*x^6-2*x^5-3*x^3-3*x^2+x+3,{}>,
<3*x^6+2*x^4-3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2-3,{}>,
<3*x^6+3*x^4-2*x^3+3*x^2+x+2,{2}>,
<-x^6+3*x^5+3*x^3+2*x^2+3,{}>,
<-3*x^6-x^5+3*x^4+3*x^3+2*x-1,{2}>,
<-3*x^6-2*x^4-3*x^3-3*x+2,{2,3}>,
<2*x^6-2*x^5-3*x^3+2*x^2+3,{2}>,
<-x^6-2*x^5-3*x^3-2*x^2-3,{}>,
<-3*x^6-2*x^4-3*x^3+2*x+2,{2}>,
<2*x^6+3*x^5-3*x^3+2*x^2+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-3*x^5+3*x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4-3*x^3-2*x+2,{2}>,
<3*x^6+2*x^4+3*x^3-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-x-1,{2}>,
<-3*x^6-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<3*x^6+2*x^4-3*x^3-2*x-2,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6-x^5+x^4-3*x^3-2*x^2-3,{2}>,
<3*x^6-x^5-3*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<3*x^6+2*x^4-3*x^3-x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2-3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x^2-x+3,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-x-2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+3*x^2+x-3,{2}>,
<-2*x^6-x^4-3*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4-3*x^3-x^2-2*x-2,{2}>,
<3*x^6+2*x^4-3*x^3+x-1,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+3*x^3+x^2+x-1,{2}>,
<-3*x^6-x^5+3*x^4+3*x^3-3*x^2+3,{2}>,
<-3*x^6-2*x^4+3*x^3+x^2-2*x+2,{2,5}>,
<-3*x^6-2*x^4-3*x^3+x+2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+2*x^2+3,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+2*x^2+3,{2,3}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-3,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2-3,{2,5}>,
<-3*x^6-2*x^4-3*x^3+2*x^2-x-2,{2}>,
<-3*x^6-2*x^4-3*x^3+2*x^2-x+2,{2}>,
<3*x^6+2*x^4+3*x^3-2*x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^3+2*x^2+3,{2}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-x+2,{2}>,
<3*x^6+x^5-3*x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+3*x^3+x^2-3*x+2,{2}>,
<3*x^6+2*x^4+3*x^3-3*x^2+3*x-1,{2}>,
<-3*x^6-2*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-3*x^3+3*x^2+x-1,{2}>,
<-x^6+x^5-3*x^4-3*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4+3*x^3-2*x^2+3*x-2,{}>,
<3*x^6+2*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+3,{2,13}>,
<2*x^6-3*x^4+2*x^3-2*x^2-3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2-3,{2}>,
<3*x^6-3*x^4-2*x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x^2+3,{2,3}>,
<-x^6+3*x^5+3*x^4-3*x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4+3*x^3+3*x^2+2*x+2,{}>,
<3*x^6+2*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3+2*x^2+3,{}>,
<3*x^6+2*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<-x^6-x^5-3*x^4-3*x^3+2*x^2+3,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-2*x^2-3,{2}>,
<2*x^6+3*x^4+3*x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-3*x^3-3*x^2+x+2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-3*x^6-2*x^4-2*x^3-x^2+x+2,{2,3}>,
<-2*x^6-x^5+x^4+2*x^3+2*x^2+3,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x^2-3,{2}>,
<2*x^6+3*x^5+2*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-2*x^3-3*x-1,{2}>,
<-3*x^6-2*x^4+2*x^3+3*x+2,{}>,
<3*x^6+2*x^4+2*x^3+3*x-2,{}>,
<-3*x^6-2*x^4-2*x^3-3*x^2-x+2,{2,3,5,31}>,
<2*x^6+3*x^4+2*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4+2*x^3-3*x+2,{2,3}>,
<-3*x^6-2*x^4+2*x^3-3*x-1,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+2*x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x^2-3,{2}>,
<3*x^6+3*x^4+2*x^3-x-2,{2}>,
<-3*x^6-3*x^4+2*x^3-3*x+2,{}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x^2+3,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-2*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6-2*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^4+2*x^3-3*x^2+3*x-1,{2,3}>,
<-3*x^6-2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<3*x^6+2*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-3*x^6-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<3*x^6+2*x^4-3*x^3-2*x^2-3,{2,3,6053}>,
<3*x^6+2*x^4-3*x^3-2*x^2+x-2,{2}>,
<-3*x^6-2*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-3*x^6-2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-3*x^6-2*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-x^3+2*x^2+3,{2}>,
<-x^6-3*x^5+3*x^4-x^3+2*x^2+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-2*x^2-3,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4-x^3+3*x^2-2*x+2,{2}>,
<-3*x^6-2*x^4+x^3-3*x^2+2*x+2,{}>,
<-3*x^6-2*x^4+x^3-3*x^2+x+2,{2}>,
<3*x^6+2*x^4-x^3+3*x^2-1,{2}>,
<2*x^6-3*x^4-x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4+x^3-3*x^2+3,{2}>,
<2*x^6-x^5+3*x^4+x^3+2*x^2+3,{2}>,
<-x^6-x^5+3*x^4+x^3+2*x^2+3,{2}>,
<2*x^6-x^5-3*x^4+x^3-2*x^2-3,{2}>,
<-2*x^6-x^5+3*x^4+x^3+2*x^2+3,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-2*x^2-3,{2}>,
<3*x^6+3*x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-2*x^3+3*x^2+x-2,{2}>,
<3*x^6+2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-3*x^6-2*x^4+x^3-2*x^2+3*x+2,{2}>,
<3*x^6+2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<3*x^6+2*x^4+x^3+2*x^2+2*x+2,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2+3,{2}>,
<2*x^6-x^5-2*x^4-x^3-2*x^2-3,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4+x^3+2*x^2+x-2,{2}>,
<3*x^6+2*x^4-2*x^3+2*x^2+x-1,{2}>,
<3*x^6+2*x^4-x^3+2*x^2+2,{2,11}>,
<3*x^6+2*x^4-x^3+2*x^2-1,{2}>,
<-3*x^6-2*x^4+2*x^3-2*x^2-x+2,{2,3}>,
<-3*x^6-2*x^4+x^3-2*x^2+3,{}>,
<-3*x^6-2*x^4-x^3-2*x^2+x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+2*x^2+3,{}>,
<-2*x^6+x^5+2*x^4-x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4-x^3+2*x^2+2*x+2,{2}>,
<3*x^6+2*x^4+x^3+2*x^2-2*x-1,{2}>,
<3*x^6+2*x^4-x^3+x^2+3,{2,3}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-3,{2}>,
<2*x^6-x^4+x^3-2*x^2-3,{2}>,
<-2*x^6+x^4-x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4-x^3+2*x^2+3*x+2,{2}>,
<3*x^6-x^4+x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4+x^3-x^2-2*x+2,{}>,
<-x^6+3*x^5-x^4+x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-x^3+x^2+2*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2+3,{2}>,
<3*x^6+2*x^4+x^3+x^2+x+2,{2}>,
<-3*x^6-2*x^4+x^3-x^2-3*x+2,{2}>,
<-x^6-x^5+x^4-x^3+2*x^2+3,{2}>,
<2*x^6-x^5-x^4-x^3-2*x^2-3,{}>,
<-2*x^6+3*x^5+x^4-x^3+2*x^2+3,{2}>,
<-2*x^6+x^5+x^4+x^3+2*x^2+3,{}>,
<2*x^6-3*x^5-x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-x^3-3*x-1,{2}>,
<-2*x^6+3*x^5+x^3+2*x^2+3,{2}>,
<-x^6-2*x^5-x^3-2*x^2-3,{2,3}>,
<2*x^6+x^5+x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4+x^3-x-2,{2}>,
<3*x^6+2*x^4-x^3+2,{2}>,
<2*x^6-2*x^5+x^3-2*x^2-3,{2}>,
<-3*x^6-2*x^4+x^3-3*x-1,{2}>,
<3*x^6+2*x^4+x^3-1,{2,3}>,
<-3*x^6-2*x^4+x^3+2,{2}>,
<-3*x^6-2*x^4-x^3+3,{2}>,
<3*x^6+2*x^4-x^3+x+2,{2}>,
<2*x^6+x^5-x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-x^3-x^2-2*x-2,{2}>,
<3*x^6+2*x^4-x^3-x^2+2,{2}>,
<2*x^6+x^5-x^4-x^3+2*x^2+3,{2}>,
<2*x^6-x^5+x^4+x^3-2*x^2-3,{2}>,
<-2*x^6+x^5-x^4-x^3+2*x^2+3,{2}>,
<2*x^6-2*x^5-x^4+x^3+2*x^2+3,{2,5}>,
<2*x^6+2*x^5+x^4-x^3-2*x^2-3,{2,3}>,
<-2*x^6-3*x^5+2*x^4-x^3-2*x^2-3,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+3,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-2*x^2-3,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+2*x^2+3,{2}>,
<-x^6-x^5+2*x^4-x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4+x^3-2*x^2+x-2,{2,3}>,
<3*x^6+2*x^4+x^3-2*x^2+3,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3-2*x^2-3,{2}>,
<3*x^6+2*x^4-x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+x^3-2*x^2-3,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4+x^3+3*x^2+2*x-2,{2}>,
<-3*x^6-2*x^4-x^3+3*x^2-x-1,{2}>,
<-3*x^6-2*x^4+x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3+2*x^2+3,{2}>,
<2*x^6-3*x^4+x^3+2*x^2+3,{2}>,
<-3*x^6-2*x^4-x^3+3*x^2+x-1,{2}>,
<-3*x^6-2*x^4-x^3+3*x^2+2*x-1,{}>,
<-3*x^6-2*x^4+x^3+3*x^2-3*x-2,{2}>,
<3*x^6+2*x^4-x^3-3*x^2+3*x+2,{2}>,
<-3*x^6-2*x^4-x^3+3*x^2+3*x-1,{2}>,
<3*x^6+2*x^4+x^3-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^2+3,{}>,
<2*x^6-3*x^5-3*x^4-2*x^2-3,{}>,
<2*x^6-2*x^5+3*x^4+2*x^2+3,{2}>,
<-3*x^6-2*x^4-3*x^2+2*x+2,{2}>,
<3*x^6+2*x^4+3*x^2-x-1,{2}>,
<-3*x^6-2*x^4-3*x^2-x+2,{2}>,
<3*x^6+3*x^4+x^3-2*x^2+3*x+2,{2}>,
<3*x^6+3*x^4-x^3-2*x^2-3*x-1,{2,7}>,
<3*x^6+2*x^4+2*x^2-x-1,{}>,
<2*x^6+x^5-2*x^4-2*x^2-3,{2}>,
<2*x^6-x^5-x^4-2*x^2-3,{2}>,
<-2*x^6-x^5+x^4+2*x^2+3,{2,3,67}>,
<-x^6-3*x^5-2*x^2-3,{2,3}>,
<3*x^6+2*x^4+x+2,{2}>,
<-3*x^6-2*x^4+x^2-3*x-1,{2}>,
<-3*x^6-2*x^4-2*x^3+3*x^2+3*x-2,{2,3,149}>,
<3*x^6+2*x^4-x^2-3*x-2,{2}>,
<-3*x^6-2*x^4+x^2-2*x-1,{2,3}>,
<3*x^6+2*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-x^5+x^4-2*x^2-3,{2}>,
<3*x^6+2*x^4-x^2-x+2,{2}>,
<-3*x^6-2*x^4+2*x^2+3*x-2,{2,11}>,
<-3*x^6-2*x^4+3*x^2-3*x-2,{2}>,
<-3*x^6-2*x^4+3*x^2-3*x+2,{2,3}>,
<2*x^6+3*x^4-3*x^3+x^2+3,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^2+3,{2}>,
<3*x^6+x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+x^2+3,{}>,
<-x^6+2*x^5+3*x^4-3*x^3+x^2+3,{2,7}>,
<2*x^6-x^5-3*x^4+2*x^2+3,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-x^2-3,{2}>,
<-x^6-x^5+3*x^4-2*x^2-3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+x^2+3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+x^2+3,{}>,
<-x^6+x^5+3*x^4+3*x^3+x^2+3,{}>,
<3*x^6+x^4+3*x^3+2*x^2+3*x-2,{2,3}>,
<3*x^6+x^4+3*x^3+2*x^2+2*x+2,{}>,
<3*x^6+x^4+3*x^3+2*x^2-x-1,{2}>,
<3*x^6+x^4+3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-x^2-3,{2,47}>,
<-2*x^6+3*x^5+3*x^3+x^2+3,{2}>,
<3*x^6+x^4+3*x^3+2*x-1,{2}>,
<-3*x^6-x^4-3*x^3-2*x+2,{2}>,
<3*x^6+x^4+3*x^3+2*x-2,{2,3}>,
<3*x^6+x^4-3*x^3-x+2,{2}>,
<-x^6+x^5+3*x^3-x^2-3,{2}>,
<3*x^6+x^4-3*x^3-x-1,{}>,
<2*x^6-x^5-3*x^3-x^2-3,{2,3}>,
<3*x^6+x^4-3*x^3-x-2,{2}>,
<-2*x^6-3*x^3+x^2+3,{}>,
<2*x^6+2*x^5-3*x^3+x^2+3,{2}>,
<2*x^6-3*x^5+3*x^3+x^2+3,{2}>,
<-2*x^6-3*x^5+3*x^3+x^2+3,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+x^2+3,{2,3}>,
<3*x^6+x^4-3*x^3-x^2-2*x-2,{2}>,
<3*x^6+x^4+3*x^3-x^2+x-1,{2}>,
<-2*x^6-x^5-x^4-3*x^3+x^2+3,{2}>,
<-3*x^6-2*x^4-x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x^2+3,{2}>,
<-x^6+3*x^5+x^4+x^3-2*x^2-3,{2}>,
<-x^6-3*x^5-x^4-x^3+2*x^2+3,{2}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+3,{2,3}>,
<-3*x^6-2*x^4+x^3+x^2+2*x-1,{}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2-3,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+x^2+3,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+3*x^2+3,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+3,{}>,
<-3*x^6-x^4+3*x^3+3*x^2+2*x-1,{2,3}>,
<-x^6+2*x^5-3*x^4+3*x^3+x^2+3,{2}>,
<-2*x^6-2*x^4-3*x^3+x^2+3,{2}>,
<3*x^6+x^4-3*x^3-3*x^2-x+2,{2,5}>,
<-3*x^6-x^4-3*x^3+3*x^2-x-1,{2}>,
<3*x^6+x^4-3*x^3-2*x^2+x+2,{2}>,
<3*x^6+x^4+3*x^3-2*x^2-x-1,{2}>,
<-3*x^6-x^4+3*x^3+2*x^2-x+2,{}>,
<3*x^6+x^4+3*x^3-2*x^2-x-2,{}>,
<-3*x^6-x^4-3*x^3+3*x^2-3*x-2,{2,3}>,
<3*x^6+x^4+3*x^3-3*x^2+3*x-2,{2}>,
<3*x^6+x^4-3*x^3-3*x^2-2*x+2,{2}>,
<3*x^6+x^4-3*x^3-3*x^2+3*x+2,{2}>,
<3*x^6+x^4+3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+x^2+3,{2}>,
<3*x^6+x^4+2*x^3+3*x^2+x-2,{2}>,
<2*x^6-3*x^4-2*x^3-x^2-3,{2,3}>,
<3*x^6+x^4+2*x^3+3*x^2-3,{2,3}>,
<3*x^6+x^4+2*x^3+3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4-2*x^3+x^2+3,{2}>,
<3*x^6+x^4-2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-x^2-3,{2}>,
<-3*x^6-x^4+2*x^3-2*x^2+2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-x^2-3,{2,3}>,
<-2*x^6-x^5+2*x^4+2*x^3+x^2+3,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3+x^2+3,{}>,
<-x^6-2*x^5-x^4-2*x^3-x^2-3,{2}>,
<3*x^6+x^4+2*x^3+x^2-x+2,{2}>,
<-3*x^6-x^4-2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^3-x^2-3,{2}>,
<3*x^6+x^4+2*x^3-x^2+3*x-2,{2}>,
<-3*x^6-x^4+2*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3-x^2-3,{2,3}>,
<-3*x^6-x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^3+x^2+3,{2}>,
<-3*x^6-x^4+2*x^3+2*x^2+3*x+2,{2,7}>,
<-2*x^6-3*x^5-2*x^3+x^2+3,{}>,
<3*x^6+x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-3*x^6-x^4+2*x^3+2*x^2+x+2,{2,3}>,
<3*x^6+x^4-2*x^3+3*x+2,{}>,
<-2*x^6-x^5-2*x^4-2*x^3+x^2+3,{2}>,
<3*x^6+x^4-2*x^3-2*x^2+x+2,{2}>,
<-x^6+x^5+x^4+2*x^3-2*x^2-3,{2}>,
<-2*x^6-x^5-x^4-2*x^3+2*x^2+3,{2}>,
<2*x^6+x^5-x^4-2*x^3+2*x^2+3,{2}>,
<2*x^6-x^5+x^4+2*x^3-2*x^2-3,{2,3}>,
<-3*x^6-x^4-2*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6+3*x^5+3*x^4+x^3+x^2+3,{2}>,
<-2*x^6+3*x^5-x^4+x^3+3*x^2+3,{}>,
<3*x^6+3*x^4+x^3-x^2+2,{2}>,
<-2*x^6-x^5-x^4+3*x^3+x^2+3,{2}>,
<3*x^6+3*x^4-x^3-x^2-1,{2}>,
<-3*x^6-3*x^4+x^3+x^2+3,{2,3}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+x^2+3,{2,3}>,
<-2*x^6-x^5+3*x^4+x^3+x^2+3,{2}>,
<3*x^6+x^4+x^3+3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4+x^3+3*x^2-3*x+2,{}>,
<3*x^6+3*x^4+x^3-x^2-x+2,{2,11}>,
<2*x^6-3*x^5-3*x^4+x^3-x^2-3,{2,3}>,
<-2*x^6+3*x^5+3*x^4-x^3+x^2+3,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-x^2-3,{2,3}>,
<3*x^6+x^4+x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3+x^2+3,{2,3,5}>,
<3*x^6+x^4-x^3+2*x^2-2,{2}>,
<3*x^6-2*x^4-x^3-x^2-3,{2}>,
<-2*x^6+x^5+x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4-x^3+x^2+2*x+2,{2,3}>,
<3*x^6+x^4+x^3+x^2-2*x-1,{2}>,
<2*x^6-3*x^5-x^4+x^3-x^2-3,{2}>,
<3*x^6+2*x^4+x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-2*x^2-3,{2}>,
<-3*x^6-x^4-x^3-3*x-1,{2,3}>,
<3*x^6+2*x^4+x^3+2*x^2+3*x+2,{2}>,
<-3*x^6-x^4-x^3+2,{2}>,
<3*x^6+x^4+x^3-x+2,{2}>,
<3*x^6+x^4-x^3+x-1,{2}>,
<-3*x^6-x^4-x^3+x+2,{}>,
<-2*x^6+x^5-x^3+x^2+3,{}>,
<3*x^6+x^4+x^3-2*x+2,{2}>,
<-3*x^6-x^4-x^3+3*x-1,{2,3}>,
<-3*x^6-x^4+x^3-3*x^2+3*x+2,{2,3}>,
<3*x^6+x^4-x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4-x^3+3*x^2-x+2,{2}>,
<3*x^6+x^4-x^3+3*x^2+2,{2}>,
<3*x^6+x^4+x^3+3*x^2-1,{}>,
<-2*x^6+3*x^5-x^4+x^3+x^2+3,{2}>,
<3*x^6+x^4-x^3-x^2-x-2,{}>,
<3*x^6+x^4-x^3-x^2+3,{2}>,
<2*x^6-3*x^5-x^4+x^3+x^2+3,{2}>,
<-3*x^6-x^4+x^3+x^2-3*x-1,{2,3}>,
<-2*x^6+3*x^5-x^4-x^3+x^2+3,{2}>,
<3*x^6-3*x^4+x^3-x^2-3,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-x^2-3,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+x^2+3,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+x^2+3,{}>,
<-x^6-2*x^5+2*x^4+x^3-x^2-3,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^2-3,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-x^2-3,{2,3}>,
<-3*x^6-x^4+x^3+2*x^2-3*x+2,{2}>,
<3*x^6+x^4-x^3-2*x^2-x+2,{2,3}>,
<3*x^6+x^4-x^3-3*x^2-3*x+2,{}>,
<-x^6-x^5-2*x^4-x^3+x^2+3,{}>,
<-2*x^6+3*x^5+2*x^4+2*x^2+3,{2}>,
<-x^6+x^5-3*x^4+x^3+x^2+3,{2}>,
<-3*x^6-x^4+x^3+3*x^2+3*x+2,{2,3,13}>,
<3*x^6+x^4+x^3-3*x^2+3,{2}>,
<-x^6+3*x^4-x^3-x^2-3,{2}>,
<3*x^6+x^4-x^3-3*x^2+x+2,{2}>,
<3*x^6+x^4-x^3-3*x^2-3*x-2,{2,3,5}>,
<3*x^6+x^4+x^3-3*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4-x^3-3*x^2+3*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4+3*x^2+3*x+2,{2,3}>,
<-3*x^6-x^4+x^3+3*x^2+x-2,{2,3}>,
<-3*x^6-2*x^4-2*x^2-2*x+2,{2}>,
<3*x^6+x^4+3*x^2-3*x-2,{2}>,
<2*x^6-x^5-3*x^4-x^2-3,{2}>,
<2*x^6+x^5+3*x^4+x^2+3,{2}>,
<2*x^6+x^5+2*x^4+2*x^2+3,{2}>,
<-3*x^6-x^4-3*x^2+2,{2}>,
<3*x^6+x^4+3*x^2-x-1,{}>,
<-x^6-3*x^4-3*x^3+x^2+3,{2}>,
<3*x^6+x^4-2*x^2+3*x-2,{2}>,
<3*x^6+x^4+2*x^2-x-2,{2,3,7}>,
<-3*x^6-x^4+2*x^2+2*x+2,{2}>,
<2*x^6-x^5-2*x^4+x^2+3,{}>,
<-x^6-x^5+2*x^4-x^2-3,{2,7,31}>,
<3*x^6+x^4-3*x^3-3*x^2-2,{2}>,
<3*x^6+x^4-3*x^2+3*x-2,{2}>,
<3*x^6+x^4-3*x^3-3*x^2+x-1,{2}>,
<-3*x^6-3*x^3-3*x^2+x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^2-3,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3+3,{2}>,
<3*x^6+x^4+x^2-x+2,{2,3,17}>,
<-x^6-x^5+x^4+x^2+3,{2}>,
<-3*x^6+3*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6-x^4-3*x^3+3*x^2+x+2,{2,3}>,
<-3*x^6-x^4+3*x^2-2*x+2,{2,3}>,
<-x^6-2*x^5+3*x^4+3*x^3-x^2-3,{2}>,
<3*x^6+3*x^3+3*x^2-2*x-2,{2}>,
<-3*x^6-x^4-x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^2+3,{2,3}>,
<2*x^6+3*x^5+2*x^4-3*x^3+3,{2}>,
<3*x^6-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-x^5+x^2+3,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+3,{2}>,
<-3*x^6-x^4-x+2,{2,3}>,
<2*x^6+3*x^5-2*x^4-3*x^3-3,{2}>,
<3*x^6-3*x^3+3*x^2+x+2,{2}>,
<3*x^6+3*x^3+2*x^2-3*x-2,{2,3}>,
<3*x^6-3*x^3+x^2+3*x+2,{2}>,
<3*x^6-3*x^3+x^2+3*x-1,{2}>,
<3*x^6-3*x^3+x^2-3*x-2,{2}>,
<-3*x^6+3*x^3-x^2-3*x+2,{2}>,
<3*x^6+3*x^3+x^2-3*x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+3,{2}>,
<-2*x^6-3*x^5-3*x^3+3,{2}>,
<-x^6+2*x^5+3*x^3+3,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+3,{}>,
<-2*x^6-3*x^5+2*x^4-x^2-3,{2}>,
<3*x^6+3*x^3+2*x-2,{2}>,
<3*x^6-3*x^3-x-1,{2}>,
<3*x^6+3*x^3-x+2,{2}>,
<3*x^6+3*x^3-x-2,{2}>,
<2*x^6-x^5-3*x^3-3,{2}>,
<-3*x^6-3*x^3+x^2-3*x-2,{2}>,
<-2*x^6+x^5+3*x^3+3,{2}>,
<3*x^6+3*x^3-x^2+3*x+2,{2}>,
<3*x^6-3*x^3+x^2-x+2,{2}>,
<-3*x^6-3*x^3+x^2-3*x-1,{2}>,
<3*x^6-3*x^3-x^2-2*x-2,{2,7}>,
<2*x^6+x^4+3*x^3-3,{2}>,
<-2*x^6+x^5+x^4+3*x^3+3,{2}>,
<-2*x^6+x^4-3*x^3+3,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+3,{2}>,
<3*x^6+3*x^3-x^2+3*x-1,{2}>,
<-3*x^6-3*x^3+2*x^2-2*x-2,{2}>,
<-3*x^6+3*x^3+x^2+3*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+3,{2}>,
<3*x^6-3*x^3-x^2-3*x-2,{2}>,
<3*x^6+3*x^3-x^2-2,{2}>,
<3*x^6-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-x^5+x^4+3*x^3-3,{2}>,
<-2*x^6+x^5-x^4-3*x^3+3,{2}>,
<-3*x^6+3*x^3+x^2-3*x-1,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3,{2}>,
<3*x^6-3*x^3-2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+3,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3-3,{2,5}>,
<3*x^6+3*x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+3,{2}>,
<-2*x^6-2*x^4+3*x^3+3,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-3,{2}>,
<3*x^6-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3,{2}>,
<-x^6+x^5-2*x^4-3*x^3+3,{2}>,
<3*x^6-3*x^3-3*x^2-2*x-2,{2}>,
<3*x^6-3*x^3-2*x^2+3*x+2,{}>,
<-2*x^6-x^5+3*x^4-3*x^3-3,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+3,{2}>,
<-3*x^6+3*x^3+2*x^2-3*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-3,{2}>,
<3*x^6+3*x^3-3*x^2+x-1,{2}>,
<3*x^6-3*x^3-3*x^2-x-2,{2}>,
<3*x^6+3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3-3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-3,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-3,{2}>,
<-3*x^6-2*x^3-2*x^2-3*x+2,{2}>,
<3*x^6-2*x^3+2*x^2-3*x-2,{2}>,
<3*x^6-2*x^3+2*x^2+x+2,{2,3}>,
<-x^6+x^5+2*x^4-2*x^3+3,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-3,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+3,{2}>,
<3*x^6+2*x^3+2*x^2-3*x-1,{2,3}>,
<3*x^6+x^4-x^3-3*x-2,{2}>,
<3*x^6+x^4-x^3-2*x-2,{2}>,
<3*x^6+x^3+x^2+3,{2,3}>,
<3*x^6+x^4-x^3+2,{2}>,
<3*x^6-2*x^3+x^2-3*x-1,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-3,{2,3}>,
<3*x^6-2*x^3+x^2-3*x-2,{2}>,
<3*x^6+2*x^3+x^2+x-2,{2}>,
<3*x^6+2*x^3+x^2-3,{2,3}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+3,{2}>,
<3*x^6-2*x^3+x^2+x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2+3,{2}>,
<2*x^6+x^5+x^4+3*x^3+x^2+3,{2}>,
<2*x^6-x^5-x^4+2*x^3-3,{2}>,
<3*x^6+x^4-3*x^3+x^2-x-2,{}>,
<3*x^6+x^4+3*x^3+x^2-x-1,{2,3}>,
<3*x^6+2*x^3+x^2-3*x+2,{2}>,
<2*x^6-x^5-x^4+3*x^3-x^2-3,{2}>,
<3*x^6+x^4-3*x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^4-3*x^3+x^2+3,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-x^2-3,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3,{2,3}>,
<-x^6-3*x^5+x^4-2*x^3-3,{2}>,
<-3*x^6+2*x^3-3*x-1,{2}>,
<-x^6-3*x^5-x^4-2*x^3+3,{2}>,
<-3*x^6-2*x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+3,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+3,{2}>,
<-3*x^6-2*x^3+2*x^2-3*x-1,{2,3,7}>,
<2*x^6-3*x^5+2*x^4-2*x^3-3,{2}>,
<2*x^6+x^5+x^4+2*x^3-3,{2,3,5}>,
<-x^6+x^5-2*x^4+2*x^3+3,{2,3}>,
<3*x^6+2*x^3-2*x^2+x-2,{2}>,
<3*x^6-2*x^3-x^2-x-2,{2,3}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-3,{2,5}>,
<-x^6+3*x^5+2*x^4-2*x^3-3,{}>,
<3*x^6+2*x^3-x^2-x+2,{2}>,
<3*x^6+2*x^3-x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4+2*x^3-3,{2}>,
<-3*x^6+2*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3+3,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-3,{2}>,
<3*x^6-2*x^3-3*x^2+3*x-2,{2,7}>,
<3*x^6+x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5-3*x^4+x^3-3,{2}>,
<3*x^6-x^3+3*x^2-x-2,{2,3}>,
<2*x^6-3*x^4+x^3-3,{}>,
<3*x^6+x^3+3*x^2-2,{}>,
<-3*x^6-x^3-3*x^2+3,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+3,{2,3}>,
<3*x^6-x^3+3*x^2+3*x+2,{2}>,
<3*x^6+x^3+3*x^2-3*x-1,{}>,
<-3*x^6+x^3-3*x^2-3*x+2,{2}>,
<3*x^6-x^3+2*x^2-3*x+2,{2}>,
<-3*x^6-x^3-2*x^2-3*x-1,{2}>,
<3*x^6-x^3+2*x^2-3*x-2,{2}>,
<-x^6-x^5+2*x^4-x^3+3,{2,3}>,
<3*x^6+x^4-x^3+2*x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4-x^3+x^2+3,{2}>,
<3*x^6+x^4-x^3+2*x^2+3*x-2,{2}>,
<-3*x^6-x^4-x^3-x^2-3*x-1,{2}>,
<3*x^6+x^4-x^3+x^2-x-1,{2}>,
<-3*x^6-x^4+x^3-x^2+x+2,{2}>,
<2*x^6-x^4-x^3-x^2-3,{2}>,
<3*x^6+x^4-x^3+x^2+x+2,{2}>,
<-x^6+2*x^4+x^3+3,{2}>,
<-3*x^6+x^3-2*x^2+2,{2}>,
<-3*x^6-x^3-2*x^2+3,{2}>,
<2*x^6+x^5-2*x^4-x^3-3,{}>,
<3*x^6-x^3+2*x^2+x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+3,{2,3}>,
<3*x^6-x^3+2*x^2+2*x-1,{}>,
<-2*x^6+3*x^5+3*x^4-3*x^2-3*x-1,{2}>,
<-3*x^6+2*x^3-3*x^2-x+2,{2}>,
<-3*x^6-x^3-2*x^2+2*x+2,{2}>,
<3*x^6+2*x^3+3*x^2-x-2,{2}>,
<3*x^6-x^3+2*x^2+3*x-1,{2}>,
<-3*x^6+2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3+3,{}>,
<2*x^6+3*x^5-2*x^4-x^3-3,{2,5}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3,{2}>,
<2*x^6+3*x^5+x^4+x^3+3,{2}>,
<2*x^6-x^5-x^4+x^3-3,{2}>,
<-2*x^6-x^5+x^4+x^3+3,{2}>,
<-x^6-3*x^5-x^4-x^3-3,{2}>,
<3*x^6-x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4-x^3-3,{2}>,
<3*x^6+2*x^3-3*x^2+3*x+2,{2}>,
<-x^6+3*x^5-x^4-x^3-3,{2}>,
<3*x^6-x^3+x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-x^3-3,{2}>,
<3*x^6+x^3+3*x-1,{}>,
<2*x^6+3*x^5-x^4+x^3-3,{2}>,
<-3*x^6+2*x^3-x^2+3*x-2,{2,7}>,
<2*x^6-3*x^5+3*x^4-2*x^3-3,{2}>,
<3*x^6-x^3+x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+3,{2}>,
<3*x^6+x^3+x-2,{2}>,
<-x^6-3*x^5+x^3-3,{2}>,
<3*x^6+x^3+x^2+2,{2}>,
<2*x^6-3*x^5-x^3-3,{2}>,
<-2*x^6+3*x^5-x^3+3,{2}>,
<-3*x^6+x^3-x^2+2,{}>,
<3*x^6-x^3-x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4-x^3+3,{2}>,
<2*x^6-2*x^5+x^4-x^3-3,{2,3}>,
<2*x^6-x^5+x^4+x^3+3,{2}>,
<-3*x^6+x^3+x^2-2*x-1,{2}>,
<3*x^6-x^3-x^2+3*x+2,{2}>,
<2*x^6-x^5-x^4-x^3+3,{2,3,5}>,
<-x^6-x^5+x^4-x^3-3,{2}>,
<-3*x^6+x^3+x^2-3*x-1,{2}>,
<3*x^6+x^3+3*x-2,{2,11}>,
<3*x^6+x^3-x^2-3*x-1,{2}>,
<3*x^6-x^3-x^2-x-1,{2}>,
<3*x^6+x^3+x+2,{}>,
<2*x^6+3*x^5+x^4-x^3-3,{2}>,
<3*x^6+x^3+x^2-x-1,{2,3}>,
<3*x^6-x^3-2*x^2-2*x-1,{2}>,
<-3*x^6-x^3+x^2-x+2,{2}>,
<-2*x^6-3*x^5-x^4+x^3+3,{2}>,
<3*x^6+x^4+x^3-x^2+3*x-1,{2}>,
<3*x^6-x^3-2*x^2-3*x+2,{}>,
<2*x^6-2*x^5+x^3-2*x^2-3*x-1,{2}>,
<3*x^6+x^3-x^2+2,{2}>,
<-3*x^6-x^4-x^3+x^2-3*x+2,{2,3}>,
<2*x^6+3*x^5+2*x^4-x^3-3,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-3,{2}>,
<-3*x^6-x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+x^3+3,{2}>,
<3*x^6-x^4+3*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-3,{2}>,
<3*x^6-x^4-3*x^3+3*x^2-x-2,{2}>,
<-x^6+x^5+3*x^4-3*x^3-x^2+3,{}>,
<2*x^6-x^5-3*x^4+3*x^3+x^2-3,{}>,
<-2*x^6+3*x^5-3*x^4+x^3+3,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3-x^2+3,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-x^2+3,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-x^2+3,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2+3,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+2*x-1,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+x+2,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+x-1,{2}>,
<-3*x^6+x^4-3*x^3-2*x^2-x+2,{2}>,
<3*x^6-x^4+3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6-x^4-3*x^3+2*x^2-2,{2}>,
<3*x^6-x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+x^2-3,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3-x^2+3,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3-x^2+3,{2}>,
<3*x^6-x^4+3*x^3+x^2+2*x-1,{2}>,
<3*x^6-x^4+3*x^3+x^2+2*x-2,{2,5}>,
<-x^6+3*x^5-2*x^4+3*x^3+3,{2,3}>,
<3*x^6-x^4+3*x^3+x^2+x-1,{2,3}>,
<3*x^6-x^4+3*x^3+x^2+x-2,{2}>,
<-3*x^6+3*x^3+2*x^2+3*x+2,{2}>,
<3*x^6-x^4-3*x^3+x^2-3,{2,3}>,
<3*x^6-x^4+3*x^3+x^2-x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3+3,{2}>,
<3*x^6-x^4-3*x^3+x^2+x-2,{2,3}>,
<-3*x^6+x^4+3*x^3+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^3-x^2+3,{2}>,
<3*x^6-x^4-3*x^3-x-1,{2}>,
<-2*x^6+3*x^5+3*x^3+x^2-3,{2}>,
<-3*x^6+x^4-3*x^3+2,{2}>,
<3*x^6-x^4+3*x^3-2,{2}>,
<2*x^6-x^5+3*x^3-x^2+3,{2}>,
<3*x^6-x^4+3*x^3+3*x+2,{2}>,
<3*x^6-x^4+3*x^3-x-1,{}>,
<-x^6+3*x^5+3*x^3+x^2-3,{2}>,
<2*x^6-2*x^5+3*x^3-x^2+3,{2}>,
<3*x^6-x^4-3*x^3-x^2-3*x-2,{2}>,
<3*x^6-x^4-3*x^3-3*x-1,{2}>,
<-3*x^6+x^4+3*x^3+x^2+2*x-2,{2}>,
<3*x^6-x^4+3*x^3+2*x-1,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-x^2+3,{2}>,
<-3*x^6+x^4+3*x^3+x^2+2*x-1,{2}>,
<-3*x^6+x^4-3*x^3+2*x^2-2*x+2,{}>,
<3*x^6-x^4+3*x^3-x^2+2*x-1,{2}>,
<3*x^6-x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-3*x^6+x^4-3*x^3+x^2-2*x+2,{2}>,
<-3*x^6+x^4+3*x^3+2*x^2+x-2,{2,3}>,
<3*x^6-x^4-3*x^3-x^2-x+2,{}>,
<2*x^6+x^5+x^4+3*x^3+x^2-3,{}>,
<3*x^6-x^4-3*x^3-2*x^2-x-1,{2}>,
<-2*x^6-x^4-3*x^3-x^2+3,{2}>,
<-x^6-x^5-x^4+3*x^3-x^2+3,{2}>,
<-3*x^6+x^4-3*x^3+2*x^2-x+2,{2,3}>,
<-3*x^6+x^4+3*x^3+x^2-x+2,{2,3}>,
<3*x^6-x^4-3*x^3-x^2+3*x-2,{2}>,
<3*x^6-x^4+3*x^3-2*x^2+x-2,{2,3}>,
<3*x^6-x^4+3*x^3-3*x^2+3*x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2+3,{2,3}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-x^2+3,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3+x^2-3,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-x^2+3,{2}>,
<-3*x^6+x^4+3*x^3+3*x^2+2*x+2,{}>,
<3*x^6-x^4+3*x^3-3*x^2+2*x-2,{}>,
<-2*x^6+x^5+3*x^4+3*x^3+x^2-3,{2,5}>,
<2*x^6+x^5-3*x^4+3*x^3-x^2+3,{2,3}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-x^2+3,{2,5}>,
<3*x^6-x^4-3*x^3-3*x^2-x-1,{2,3}>,
<-3*x^6+x^4-3*x^3+3*x^2-2,{2}>,
<-3*x^6+x^4+3*x^3+3*x^2+3*x-2,{}>,
<-3*x^6+x^4-3*x^3+3*x^2+x-1,{0}>,
<3*x^6-x^4-3*x^3-3*x^2+x-2,{}>,
<-x^6-2*x^5-3*x^4+3*x^3-x^2+3,{2}>,
<3*x^6-x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+x^2-3,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+x^2-3,{2}>,
<3*x^6-x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-3*x^6+x^4+2*x^3-3*x^2-x+2,{2,3}>,
<-3*x^6+x^4-3*x^3+3*x^2+3*x+2,{2,3}>,
<3*x^6+x^3-2*x^2+x-1,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3+x^2-3,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-x^2+3,{}>,
<2*x^6-x^5+2*x^4-x^3-3,{2,3}>,
<3*x^6-x^3-2*x^2+3,{}>,
<3*x^6-x^4+2*x^3+3*x^2-3*x-1,{2}>,
<-3*x^6+x^4-2*x^3-3*x^2-3*x+2,{}>,
<-x^6+2*x^4+x^3-3,{2}>,
<3*x^6-x^4-2*x^3+2*x^2-3*x-1,{2}>,
<3*x^6+x^3-2*x^2-x+2,{2}>,
<3*x^6-x^4-2*x^3+3*x^2-3*x-2,{}>,
<3*x^6+x^3-2*x^2-x-2,{2}>,
<3*x^6-x^4-2*x^3+2*x^2-3*x-2,{2,3}>,
<-x^6+2*x^5+2*x^4-x^3-3,{2}>,
<-3*x^6+x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-3*x^6+x^3+2*x^2-3*x-2,{2}>,
<-3*x^6+x^4+2*x^3-3*x^2+2,{2}>,
<3*x^6-x^4-2*x^3+x^2-3*x-2,{2,3}>,
<2*x^6+2*x^5-2*x^4+2*x^3+x^2-3,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+x^2-3,{2}>,
<-3*x^6+x^4-2*x^3-x^2+3,{2}>,
<-x^6-3*x^5-2*x^3-x^2+3,{}>,
<2*x^6+3*x^5+2*x^3+x^2-3,{2}>,
<3*x^6-x^4+2*x^3+x-2,{2}>,
<2*x^6+2*x^3+x^2-3,{}>,
<-3*x^6+x^4-2*x^3+x^2-2*x-1,{2,3}>,
<2*x^6-3*x^5+2*x^3-x^2+3,{2}>,
<-x^6-x^5-x^4-2*x^3-x^2+3,{}>,
<-x^6+3*x^5-2*x^3+x^2-3,{2}>,
<-2*x^6-x^5-x^4-2*x^3-x^2+3,{2}>,
<3*x^6-x^4+2*x^3-x^2+3*x-1,{2}>,
<-3*x^6+x^4+2*x^3+2*x^2+2*x-2,{2,3,5,13}>,
<-2*x^6-x^5+3*x^4-2*x^3+x^2-3,{2,5}>,
<-2*x^6+x^5-2*x^4-2*x^3-x^2+3,{}>,
<-3*x^6+x^4+2*x^3+3*x^2+x-1,{2}>,
<-3*x^6+x^4+2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-x^2+3,{2}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+x^2-3,{2,5}>,
<3*x^6-x^4-2*x^3-2*x^2+3*x-2,{2,3}>,
<-x^6+3*x^5+3*x^4+2*x^3+x^2-3,{2}>,
<3*x^6-x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-3*x^6+x^4-2*x^3+3*x^2-2*x+2,{2}>,
<-3*x^6-3*x^2-x+2,{2}>,
<3*x^6-3*x^4+x^3+x^2-3,{2}>,
<2*x^6-x^5-2*x^4-3,{2}>,
<-2*x^6-3*x^5+x^4+3,{2}>,
<-2*x^6-3*x^5+x^4-3,{2}>,
<2*x^6-3*x^5+x^4-3,{2}>,
<-2*x^6-3*x^5-x^4+3,{2}>,
<-2*x^6+x^5-3*x^4+3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+x^2-3,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-x^2+3,{2}>,
<3*x^6-x^3+2*x^2+2,{2}>,
<-3*x^6-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5+x^3-x^2+3,{2}>,
<3*x^6-x^4+x^3-3*x-1,{2}>,
<-3*x^6+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+x^3+x^2-3,{2}>,
<-2*x^6-3*x^5+x^3-x^2+3,{2}>,
<2*x^6-3*x^5-x^4-x^3-x^2+3,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+3,{2}>,
<-2*x^6-3*x^5-x^4-x^3-x^2+3,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3,{2}>,
<3*x^6-x^4-x^3-x^2-2*x-1,{2,3}>,
<3*x^6-x^4-x^3-x^2-2*x-2,{2}>,
<-3*x^6-3*x^3-2*x^2+2*x+2,{2}>,
<-x^6+x^5-x^4+x^3-x^2+3,{2}>,
<2*x^6+x^5-x^4-x^3-x^2+3,{2}>,
<-2*x^6-x^5-x^4+x^3-x^2+3,{2}>,
<-3*x^6+x^4-x^3+x^2-x+2,{2}>,
<3*x^6-x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6+3*x^5-3*x^4+x^3-x^2+3,{2}>,
<-3*x^6+x^4+x^3+3*x^2+3*x+2,{2}>,
<-3*x^6+x^4-x^3+3*x^2-2*x-2,{2,7}>,
<-x^6+2*x^5+3*x^4+x^3+x^2-3,{2,3}>,
<3*x^6-x^4-x^3-3*x^2-x-2,{2,3}>,
<-x^6-3*x^4-x^3-x^2+3,{2}>,
<-2*x^6-3*x^4+x^3-x^2+3,{2}>,
<-3*x^6+x^4+x^3+3*x^2-x+2,{}>,
<3*x^6-x^4-x^3-3*x^2+x-2,{}>,
<-2*x^6-2*x^5-3*x^4+x^3-x^2+3,{2}>,
<3*x^6-x^4-x^3-3*x^2+3*x+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3+x^2-3,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3-x^2+3,{2}>,
<-3*x^6+x^3+2*x^2+3*x+2,{2}>,
<-3*x^6+x^4+3*x-2,{2,3}>,
<3*x^6-x^4+3*x-2,{2,3}>,
<-3*x^6+x^4+2*x+2,{2,5}>,
<2*x^6+x^5-x^2+3,{2}>,
<-2*x^6+3*x^5-x^4-x^2+3,{2}>,
<3*x^6-x^4+x^3+x^2+3*x-2,{2}>,
<3*x^6-x^4+x^3+x^2+x-2,{2,3}>,
<3*x^6-x^4-x^3+x^2+3*x+2,{}>,
<3*x^6-x^4+2*x^3+2*x^2-x+2,{2}>,
<3*x^6-x^4+x^3+2*x^2+3*x+2,{2}>,
<3*x^6-x^4+x^3+2*x^2+2*x-2,{}>,
<2*x^6-x^5+3*x^4-x^2+3,{2}>,
<2*x^6+2*x^4-x^3-x^2+3,{2}>,
<2*x^6-x^5+2*x^4+x^3-x^2+3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2+3,{2}>,
<-x^6-x^5+2*x^4+x^3-x^2+3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x^3+3*x^2-x+2,{}>,
<3*x^6-x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-x^6+x^5+3*x^4+3*x^3-2*x^2+3,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+2*x^2-3,{}>,
<3*x^6-x^4-x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2+3,{2}>,
<3*x^6-x^4-x^3+2*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4-x^2+3,{2}>,
<3*x^6-x^4+x^3+3*x^2+3*x-2,{2}>,
<-3*x^6+x^4+x^3-2*x^2-2*x+2,{2}>,
<3*x^6-x^4+2*x^2-3*x-2,{2,7,29}>,
<3*x^6-2*x^4+3*x^3+3*x^2-2,{2}>,
<3*x^6-x^4+2*x^2-x+2,{}>,
<3*x^6-x^4-x^3+3*x^2+2,{2}>,
<3*x^6-2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-x^5-2*x^4+x^2-3,{}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2+3,{2,3}>,
<-x^6+3*x^4-x^3-x^2+3,{2,5}>,
<-3*x^6+2*x^4+3*x^3-3*x^2-2*x+2,{2,3,5}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2-3,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2+3,{2,5}>,
<2*x^6+3*x^5+3*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2+3,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-3,{}>,
<2*x^6-2*x^5-3*x^3-2*x^2+3,{}>,
<3*x^6-2*x^4-3*x^3+3*x^2+3*x-1,{2}>,
<-3*x^6+2*x^4-3*x^3-2*x-1,{2,3,7}>,
<3*x^6-2*x^4-3*x^3-2*x-1,{2}>,
<-2*x^6-x^5-3*x^3-2*x^2+3,{2}>,
<-x^6-x^5+x^4-3*x^3-2*x^2+3,{2}>,
<-x^6+3*x^3-2*x^2+3,{2}>,
<2*x^6+2*x^5+3*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+3*x^3+x+2,{}>,
<3*x^6-2*x^4+3*x^3-2,{2}>,
<-2*x^6+x^4-3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x^3+x-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-3*x^3+x^2+x-1,{2}>,
<2*x^6+x^5-x^4-3*x^3+2*x^2-3,{2}>,
<2*x^6+x^5+3*x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-3*x^3+x+2,{2}>,
<3*x^6-2*x^4-3*x^3+x^2+x-2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-2*x^2+3,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4+3*x^3+x^2+x-2,{2}>,
<2*x^6-x^5-x^4-3*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4+3*x^3+x^2+x-1,{2}>,
<-2*x^6+3*x^5+3*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-3*x^3-x^2-x-1,{2}>,
<-x^6-3*x^5+3*x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-3*x^3+x^2-x+2,{2}>,
<-2*x^6+3*x^5-3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x^3-x^2-x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-3,{2,3}>,
<3*x^6-2*x^4-3*x^3-x^2+2*x-2,{2,3}>,
<3*x^6-2*x^4-3*x^3-3*x-1,{2,3}>,
<2*x^6-2*x^5-x^4-3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x^3-x^2+3*x-2,{2}>,
<3*x^6-2*x^4-3*x^3-2*x^2-3*x+2,{}>,
<3*x^6-2*x^4+3*x^3-2*x^2+3*x-2,{2,3}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2+3,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+2*x^2-3,{}>,
<-3*x^6+2*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+3*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-3*x^3+2*x^2+x-1,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3-2*x^2+3,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+3*x^3-2*x^2-2*x-1,{2,3}>,
<-3*x^6+2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+3,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-3,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+2*x^2-3,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3-2*x^2+3,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+2*x^2-3,{2}>,
<-x^6-x^5-2*x^4-3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-3*x^6+2*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+2*x^2-3,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2-3,{2,11}>,
<-3*x^6+2*x^4+3*x^3+2*x^2-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-2*x^2+3,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2-3,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-2*x^2+3,{2,3}>,
<-x^6-x^5+3*x^4+3*x^3+2*x^2-3,{0,2}>,
<-3*x^6+2*x^4+3*x^3+3*x^2-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4+3*x^3+3*x^2-x+2,{2,7}>,
<2*x^6-3*x^4+3*x^3-2*x^2+3,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-2*x^2+3,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3-2*x^2+3,{2}>,
<-3*x^6+3*x^4-2*x^3-2*x^2+3,{2,3,5}>,
<3*x^6-2*x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3-2*x^2+3,{}>,
<2*x^6-3*x^5+3*x^4+2*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4-2*x^3-3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4+2*x^3-x^2-3*x-1,{2}>,
<-3*x^6+2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^3+2*x^2-3,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x^2-3,{}>,
<3*x^6-2*x^4-2*x^3+x^2-3*x-2,{}>,
<-3*x^6+2*x^4-2*x^3-x^2-x+2,{2}>,
<3*x^6-2*x^4+2*x^3+x^2-x+2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+2*x^3-x^2+3*x-2,{2}>,
<3*x^6-2*x^4+2*x^3-x^2-x-2,{2,3}>,
<-2*x^6+3*x^5+x^4-2*x^3+2*x^2-3,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+2*x^2-3,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3-x^2-3,{2,3}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+3,{}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2-3,{2}>,
<3*x^6+x^4-2*x^3-3*x^2-x-1,{2,3}>,
<3*x^6+x^4+2*x^3-3*x^2+x-2,{2}>,
<-3*x^6-x^4-2*x^3+3*x^2+2,{2,3}>,
<3*x^6+x^3-3*x^2-x-2,{}>,
<-2*x^6-2*x^5+3*x^4+x^3-3,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-3*x^6+2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<3*x^6-2*x^4+2*x^3-3*x^2+x-2,{2}>,
<3*x^6-2*x^4+2*x^3-3*x^2-x-1,{2,3}>,
<3*x^6-2*x^4-2*x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3-2*x^2+3,{2}>,
<-2*x^6+x^5-2*x^4-x^2+3,{2,3}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2-3,{2}>,
<-2*x^6-3*x^5+3*x^4+x^2-3,{2}>,
<-x^6-x^5-3*x^4-x^2+3,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-2*x^2+3,{2}>,
<-2*x^6-x^5-3*x^4-x^2+3,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4+x^3-3*x^2+3*x-1,{2,3}>,
<3*x^6-2*x^4-x^3+3*x^2-3*x-1,{}>,
<-2*x^6+x^5+3*x^4-x^3-2*x^2+3,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-x^3+3*x^2+2*x+2,{2}>,
<-x^6+3*x^5+2*x^4+x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-x^3+3*x^2-3*x-2,{2}>,
<-x^6-x^5+2*x^4-3*x^3-2*x^2+3,{2}>,
<2*x^6-x^5+2*x^4-x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<3*x^6-2*x^4+x^3+2*x^2+x-2,{}>,
<-3*x^6+2*x^4-3*x^3-2*x^2-x+2,{2}>,
<3*x^6-2*x^4+3*x^3+2*x^2+x-2,{2}>,
<2*x^6+3*x^4-x^3-2*x^2+3,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3-2*x^2+3,{2}>,
<2*x^6+2*x^5-x^4+x^3+2*x^2-3,{2}>,
<2*x^6-3*x^4+x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+x^3+x^2+2*x-2,{2}>,
<3*x^6-2*x^4-x^3+3*x^2+x+2,{2}>,
<3*x^6-2*x^4+x^3+x^2+x+2,{2}>,
<-x^6+x^5+3*x^4-x^3-2*x^2+3,{2}>,
<-x^6-x^5+x^4-x^3-2*x^2+3,{2}>,
<2*x^6+x^5-3*x^4-x^3+2*x^2-3,{2}>,
<2*x^6+2*x^5+x^4-x^3-2*x^2+3,{}>,
<-x^6-3*x^5-x^4+x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-x^3-x^2+3*x+2,{}>,
<-2*x^6-3*x^5+x^4+x^3-2*x^2+3,{}>,
<3*x^6-2*x^4+3*x^3+2*x^2-3,{2,3,191}>,
<-x^6+3*x^5+x^4+3*x^3-2*x^2+3,{}>,
<-2*x^6-x^5+x^3-2*x^2+3,{2}>,
<-x^6+3*x^5-x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^3+2*x^2-3,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-x^3+x^2-3*x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2+3,{2}>,
<-x^6+3*x^5+x^4+x^3+2*x^2-3,{2}>,
<-3*x^6+2*x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+2*x^2-3,{2,3}>,
<2*x^6+3*x^5+2*x^4+x^3+2*x^2-3,{2}>,
<-2*x^6+3*x^5-x^4+x^3-2*x^2+3,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+2*x^2-3,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-x^3-x^2-2,{2}>,
<-3*x^6+2*x^4+x^3+2*x^2+x-1,{2}>,
<3*x^6-2*x^4-x^3-2*x^2-x-2,{2}>,
<-2*x^6-2*x^4+x^3-2*x^2+3,{}>,
<3*x^6-2*x^4-x^3-x^2+x-2,{2}>,
<3*x^6-2*x^4-x^3-x^2+2*x-2,{2,3}>,
<3*x^6-2*x^4+x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5+2*x^4-x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+x^3-2*x^2-3*x-2,{2}>,
<3*x^6-x^4-x^3-2*x^2-3*x+2,{2}>,
<-x^6-3*x^5-2*x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+2*x^3+3*x-1,{2}>,
<2*x^6+3*x^5+2*x^3+2*x^2-3,{2,3}>,
<-2*x^6+x^5+2*x^3-2*x^2+3,{2}>,
<-3*x^6+2*x^4-2*x^3+3*x-1,{2}>,
<-3*x^6+2*x^4-2*x^3+x^2-3*x-2,{2}>,
<3*x^6-2*x^4-2*x^3-x^2-3*x+2,{2}>,
<-3*x^6+2*x^4-x^3+3*x^2+2,{2,3}>,
<-2*x^6-3*x^4+x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-x^3-3*x^2+x-1,{2}>,
<-2*x^6-x^5-3*x^4+x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+x^3-3*x^2-2*x-1,{}>,
<-x^6+3*x^5+3*x^4-x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4+x^3-3*x^2-3*x-1,{2}>,
<-3*x^6+2*x^4-x^3+3*x^2+3*x+2,{2}>,
<3*x^6-2*x^4+3*x^2-3*x-2,{2}>,
<3*x^6-2*x^4+3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+2*x^2-3,{2}>,
<-2*x^6-3*x^5+x^4-2*x^2+3,{2,3,5}>,
<2*x^6-x^5+x^4-2*x^2+3,{2}>,
<3*x^6-2*x^4-3*x-1,{2,3}>,
<3*x^6-2*x^4-3*x-2,{2,3}>,
<3*x^6-2*x^4-x^2-x-2,{2,3}>,
<-3*x^6+2*x^4+2*x^2+3*x-2,{2}>,
<3*x^6-2*x^4-x^3-3*x^2-2*x-2,{2,7}>,
<-2*x^6+x^5+3*x^4+x^3+2*x^2-3,{2,5}>,
<3*x^6-2*x^4+x^3-3*x^2+x+2,{2,3,5}>,
<3*x^6-2*x^4-x^3-3*x^2-x-1,{2,3}>,
<-2*x^6+x^5-3*x^4+x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4-x^3-3*x^2-1,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^2+3,{2}>,
<-x^6+x^5-3*x^4-2*x^2+3,{2}>,
<2*x^6+x^5+3*x^4+2*x^2-3,{2}>,
<3*x^6-3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<3*x^6-3*x^4+3*x^3+3*x^2+2*x-1,{2}>,
<3*x^6-3*x^4+3*x^3+3*x^2+2*x-2,{}>,
<2*x^6+x^5-3*x^4+3*x^3+3*x^2-3,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-3*x^2+3,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+3,{}>,
<3*x^6-3*x^4-3*x^3+3*x^2+x-2,{2}>,
<-3*x^6+3*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<3*x^6-3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2-3,{2,3}>,
<3*x^6-3*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+3*x^2-3,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2+3,{}>,
<-2*x^6+2*x^4+3*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-3*x^3-x^2-3*x-2,{2,5}>,
<-x^6+3*x^5+x^4+3*x^3-3*x^2+3,{2,3}>,
<3*x^6-3*x^4-3*x^3+x^2-3*x-2,{2}>,
<3*x^6-x^4-x^3-3*x-1,{2,3,23}>,
<3*x^6-3*x^4-3*x^3+x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^3+x^2-3,{2}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2+3,{2,47}>,
<3*x^6-3*x^4-3*x^3+x^2-x-2,{2,3}>,
<3*x^6-3*x^4-3*x^3+x^2-1,{2}>,
<3*x^6-x^4-x^3-2*x-2,{2}>,
<-2*x^6+x^4-3*x^3-3*x^2+3,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3-3*x^2+3,{2}>,
<3*x^6-x^4-x^3-x-2,{2,3}>,
<-3*x^6+3*x^4-3*x^3-2*x-2,{2}>,
<3*x^6-x^4-x^3+2,{}>,
<2*x^6+x^5+3*x^3-3*x^2+3,{2}>,
<2*x^6-2*x^5-3*x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+3*x^3+2*x-2,{}>,
<-2*x^6+x^5+3*x^3+3*x^2-3,{2}>,
<-3*x^6+3*x^4-3*x^3+x^2-2,{2}>,
<-3*x^6+3*x^4+3*x^3+x^2-1,{2,3}>,
<-x^6-x^5+x^4+3*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-3*x^3-x^2+x-2,{}>,
<-2*x^6-2*x^5-x^4+3*x^3-3*x^2+3,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2+3,{2,3}>,
<3*x^6-3*x^4-3*x^3-2*x^2-3*x-2,{2}>,
<3*x^6-3*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2-3,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-3*x^3+2*x^2-2,{2}>,
<3*x^6-3*x^4-3*x^3-2*x^2+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2+3,{2}>,
<-2*x^6-2*x^4-3*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4+3*x^3+2*x^2-x-2,{2}>,
<3*x^6-3*x^4+3*x^3-2*x^2-2*x-1,{}>,
<3*x^6-3*x^4+3*x^3-2*x^2-3*x-1,{2}>,
<3*x^6-3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<3*x^6-3*x^4+3*x^3-2*x^2-x+2,{2}>,
<-3*x^6+3*x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+3*x^3-2*x^2-x-1,{2}>,
<-2*x^6-3*x^4+3*x^3-3*x^2+3,{}>,
<-2*x^6-x^5-2*x^4+3*x^3-3*x^2+3,{2,3,13}>,
<3*x^6-3*x^4+3*x^3-3*x^2-3*x-2,{2}>,
<3*x^6-3*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<3*x^6-3*x^4+2*x^3+3*x^2+3*x-2,{}>,
<3*x^6-3*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-3*x^6+3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<3*x^6-3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2-3,{2}>,
<-3*x^6+2*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+3*x^2-3,{2}>,
<-x^6+x^5+x^4+2*x^3-3*x^2+3,{2,3}>,
<3*x^6-2*x^4+x^3-2*x^2-2*x-1,{2,3}>,
<-3*x^6+3*x^4-2*x^3-x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4+2*x^3+x^2+x-2,{2,13}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-2*x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4+2*x^3+x^2+2*x-2,{2,3}>,
<-3*x^6+3*x^4+2*x^3+x^2+2*x+2,{2}>,
<-3*x^6+3*x^4-2*x^3+x^2-x-2,{2}>,
<-3*x^6+3*x^4-2*x^3+x^2-1,{2}>,
<-x^6+x^5-x^4-2*x^3-3*x^2+3,{2,3}>,
<2*x^6+2*x^5+x^4-2*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-2*x^3-x^2+3*x-1,{2}>,
<3*x^6-3*x^4-2*x^3-x^2+3*x-2,{2}>,
<3*x^6-3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-3*x^6+3*x^4+2*x^3+2*x^2+3*x-1,{2,3}>,
<-x^6-3*x^5-2*x^4-2*x^3-3*x^2+3,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3+3*x^2-3,{}>,
<-3*x^6+3*x^4-2*x^3+2*x^2-x-2,{2,3}>,
<2*x^6+x^5-2*x^4+2*x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+2*x^3-2*x^2+x-2,{2}>,
<-2*x^6+2*x^4+2*x^3+3*x^2-3,{2}>,
<-3*x^6+3*x^4-2*x^3+2*x^2-1,{2,3}>,
<2*x^6+2*x^4-2*x^3+3*x^2-3,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2-3,{2}>,
<-x^6+3*x^5+x^3+2*x^2-3,{2}>,
<2*x^6+3*x^5+x^3+2*x^2-3,{2}>,
<3*x^6-2*x^4-x^3-2*x-1,{2}>,
<-2*x^6-2*x^5-x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+x^3-x+2,{2}>,
<-2*x^6+3*x^4+2*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-2*x^3-3*x^2-2,{2}>,
<3*x^6-3*x^4-2*x^3-3*x^2+x-1,{2}>,
<3*x^6-3*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-3*x^2+3,{2,5}>,
<3*x^6-3*x^4-x^3+3*x^2+3*x+2,{2}>,
<3*x^6-3*x^4-x^3+3*x^2+3*x-2,{}>,
<-x^6+3*x^5+2*x^4+x^3-3*x^2+3,{2,3}>,
<-x^6-x^5+2*x^4-x^3-3*x^2+3,{}>,
<2*x^6+x^5-2*x^4+x^3+3*x^2-3,{2,5}>,
<3*x^6-3*x^4-x^3+2*x^2-x-2,{2}>,
<2*x^6+2*x^4+x^3-3*x^2+3,{2,3}>,
<2*x^6+2*x^5+2*x^4-x^3-3*x^2+3,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-3*x^2+3,{2,3}>,
<-x^6-3*x^5+2*x^4+x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4-x^3+x^2-3*x+2,{2}>,
<-3*x^6+3*x^4+x^3-x^2+3*x-1,{2}>,
<-2*x^6+3*x^5+x^4+x^3-3*x^2+3,{2}>,
<-x^6-2*x^5+x^4-x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4-x^3+x^2-2*x-2,{2}>,
<-x^6-x^5+x^4-x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4-x^3+x^2+x-2,{2}>,
<3*x^6-3*x^4+x^3+x^2-3*x-1,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2-3,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-3,{2}>,
<2*x^6-3*x^5-x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4-x^3-3*x-1,{}>,
<-3*x^6+3*x^4+x^3+3*x+2,{2}>,
<3*x^6-3*x^4+x^3+3*x-2,{2}>,
<3*x^6-2*x^4-2*x^2+x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^2-3,{2}>,
<3*x^6-3*x^4-x^3-x^2-2,{2}>,
<3*x^6-3*x^4+x^3-x^2-x-1,{2}>,
<-3*x^6+3*x^4+x^3+x^2-x+2,{2,3}>,
<3*x^6-3*x^4-x^3-x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-x^4-x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+x^3-x^2-3*x-2,{}>,
<3*x^6-3*x^4-3*x^3+3*x-2,{}>,
<-2*x^6-3*x^5+x^4-3*x^3+3*x^2-3,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2-3,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3-3*x^2+3,{}>,
<-2*x^6-2*x^5-x^4-3*x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-3*x^3+x^2-x-2,{2}>,
<-x^6+x^5+2*x^4+x^3+3*x^2-3,{2,3}>,
<2*x^6-x^5+x^4-3*x^3+3*x^2-3,{}>,
<3*x^6-3*x^4-x^3-2*x^2-x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4+x^3-2*x^2-3*x-1,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4+x^3-2*x^2-3*x-2,{2,3}>,
<-x^6-2*x^4-x^3-3*x^2+3,{2}>,
<-3*x^6+3*x^4-x^3+3*x^2-3*x-2,{2}>,
<-3*x^6+3*x^4+x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^4-x^3-3*x^2+3,{2}>,
<-x^6-x^5-2*x^4+x^3-3*x^2+3,{2,3}>,
<-2*x^6-x^5-2*x^4+x^3-3*x^2+3,{2}>,
<3*x^6-3*x^4+x^3-2*x^2-2*x-1,{}>,
<3*x^6-3*x^4+x^3-2*x^2-2*x-2,{2}>,
<3*x^6-3*x^4-x^3-2*x^2+3*x+2,{2}>,
<3*x^6-3*x^4+x^3-3*x^2-x-2,{2}>,
<3*x^6-3*x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6-x^5-3*x^4+3*x^3-3*x^2+3,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4+x^2+3*x-1,{2}>,
<3*x^6-3*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5+x^4-3*x^2+3,{2}>,
<-3*x^6+3*x^4+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^3-3*x^2+3,{}>,
<-3*x^6+3*x^4+x^2+3*x-1,{2,3}>,
<3*x^6-3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^3+3*x^2-3,{2}>,
<3*x^6-3*x^4-3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^4+3*x^2+2*x-2,{2}>,
<3*x^6-3*x^4-3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^2+3,{2}>,
<-x^6+x^5-3*x^4-3*x^2+3,{2}>,
<-3*x^6+3*x^4-2*x^3-2*x+2,{2,3}>,
<-2*x^6+x^5-3*x^4-3*x^2+3,{2}>,
<-2*x^6+x^5-2*x^3-3*x^2+3,{2,3}>,
<2*x^6+3*x^5-3*x^4+3*x^3-3*x^2+3*x-2,{2}>,
<-3*x^6+3*x^4+2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^3-3*x^2+3,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x+2,{}>,
<-x^6-x^5+2*x^4-2*x^3+2*x^2-3,{2}>,
<-x^6-x^5-2*x^4+2*x^3-2*x^2+3,{}>,
<2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<3*x^6-2*x^4-2*x^3-2*x^2+x-2,{}>,
<3*x^6-3*x^4-2*x^2+x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-3*x^2+3,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-2*x^2+3,{2}>,
<-3*x^6+3*x^4+2*x^3+x^2+3*x-1,{2,5}>,
<-2*x^6+3*x^5-3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3-x^2-3*x-1,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+x^2+3*x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^3-3*x^2-3*x-2,{2}>,
<-x^6-x^5+x^4-3*x^3+3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-3*x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^3+3*x^2-3*x+2,{2,3}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-x^6-x^5+2*x^4-3*x^3+3*x^2-3*x+2,{}>,
<-2*x^6-2*x^5+x^4-3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-2*x-1,{2,3}>,
<-x^6-2*x^5-x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+3*x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x-1,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x-1,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-3*x^2-3*x-2,{}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x-2,{}>,
<2*x^6+3*x^5+3*x^4+3*x^3-1,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x+2,{2,5}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+x^5-3*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3-x-2,{2}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^3-2*x^2+x-2,{2,61}>,
<-2*x^6-x^5-3*x^4-3*x^3+3*x^2-3*x+2,{2,73}>,
<-2*x^6+3*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^4+3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+3*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-3*x^2+x-1,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+3*x-2,{}>,
<-2*x^6-2*x^4+3*x^3+3*x^2+3*x+2,{2,41}>,
<2*x^6-3*x^5+3*x^4-3*x^3-3*x^2+x-2,{}>,
<2*x^6-3*x^5+3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-3*x^2+2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+3*x^2-x-1,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-2*x^2+3,{2}>,
<3*x^6-2*x^4+3*x^3-3*x^2-3*x-1,{2}>,
<3*x^6-2*x^4+3*x^3-3*x^2-3*x-2,{2,3}>,
<3*x^6-2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-2*x^2+3,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^5-2*x^4-x^3-x^2+3,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3-x^2-x+2,{2}>,
<-3*x^6+x^4-x^3+2*x^2-3*x+2,{2,3}>,
<2*x^6+x^4+2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-x^4+x^3-2*x^2+3*x-2,{2}>,
<3*x^6-x^4-x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3-x^2+3,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2,{2}>,
<-2*x^6-2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-x^2-2*x+2,{2,7,59}>,
<2*x^6+3*x^5+3*x^4+2*x^3+x^2-3*x+2,{2}>,
<2*x^6+x^5-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3-x+2,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-x^2+2*x-1,{2}>,
<-2*x^6-x^5-x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6-x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3-x^2+x-1,{}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+x^2+2*x-1,{2}>,
<2*x^6-x^5+x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+x^5-x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5-x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-2*x^2-1,{2,29}>,
<-2*x^6-2*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-x^6+x^5-2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3+2*x^2+x+2,{}>,
<-2*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x+2,{}>,
<2*x^6-2*x^5+2*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^3+3*x^2-3*x-1,{}>,
<2*x^6-3*x^5+3*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-3*x^2-3*x-2,{}>,
<2*x^6-2*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{}>,
<2*x^6+3*x^5+3*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2,{2,5}>,
<-2*x^6-3*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6-x^5-3*x^4+2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+2*x^3-3*x^2+3*x-2,{2,5}>,
<-2*x^6+2*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3-3*x^2-x+2,{2}>,
<2*x^6-3*x^4-x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^4+x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3-3*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+2*x^2+2*x-2,{2}>,
<-x^6+2*x^4+x^3+3*x^2+3*x+2,{2}>,
<2*x^6-2*x^4-x^3-3*x^2-3*x-2,{2}>,
<-2*x^6-x^5+2*x^4+x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3-x^2+3*x+2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-3*x^2-3*x-2,{2,13,61}>,
<2*x^6-x^5+x^4-x^3+3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5-3*x^4-x^3-x^2+x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3+x^2+2*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-2*x-1,{2}>,
<2*x^6-x^5-x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x-2,{2}>,
<-2*x^6-x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+2*x^4-x^3-3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-2*x^2+2*x-2,{2}>,
<-x^6+x^5-2*x^4+x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+x^5-2*x^4+x^3+3*x^2+3*x+2,{2}>,
<-x^6-2*x^4+x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+2*x^2+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-2*x^2-2,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x^2-3*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-2*x^2-2*x-2,{2,7}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+x^3-3*x^2+3*x-2,{2}>,
<-x^6-2*x^5-3*x^4-x^3+3*x^2-3*x+2,{}>,
<2*x^6-2*x^5+3*x^4-x^3-3*x^2-3*x-2,{2}>,
<-x^6-x^5-3*x^4-x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3+3*x^2-x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-3*x^2+x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^2-2*x+2,{2,5}>,
<2*x^6+3*x^5+3*x^4+3*x^2+2*x-1,{2,3}>,
<2*x^6-3*x^5+3*x^4+3*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^2-x-2,{2}>,
<-2*x^6-3*x^5-3*x^4-3*x^2+2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+3*x^2-3*x+2,{}>,
<2*x^6-3*x^5-3*x^4-3*x^2+3*x-2,{}>,
<2*x^6+3*x^5+3*x^4+3*x^2-3*x-2,{}>,
<2*x^6+3*x^5+2*x^4+3*x^2+3*x+2,{}>,
<2*x^6-3*x^5+3*x^4+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^2+x+2,{2}>,
<-x^6+x^5+2*x^4+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^2+2,{2,13}>,
<-2*x^6-3*x^5-3*x^4-2*x^2+2,{}>,
<-2*x^6+2*x^4+3*x^2+3*x+2,{}>,
<2*x^6+x^5+2*x^4+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4-2*x^2+x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^2+x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^2+2*x-1,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^2+3*x-1,{}>,
<2*x^6-3*x^5-2*x^4-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^2-3*x+2,{2}>,
<-x^6+3*x^5-x^4-3*x^2+3*x-2,{2}>,
<2*x^6-x^4-3*x^2-3*x-2,{2}>,
<2*x^6-x^5+x^4+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^2-x-1,{2}>,
<2*x^6-x^5-x^4-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+x^2-x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^2+2*x-2,{2}>,
<2*x^6+3*x^5-x^4-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-3*x^2-3*x-2,{}>,
<2*x^6+3*x^5+3*x^4+2*x-2,{}>,
<2*x^6-x^5+3*x^2-3*x+2,{}>,
<-2*x^6-x^5+3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-x+2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2,5}>,
<-x^6-2*x^5+2*x^4-2*x^3+3*x^2-3*x+2,{2,3}>,
<2*x^6-2*x^5-3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^3+2*x^2-x+2,{}>,
<-x^6-3*x^5-3*x^2+3*x-2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^2-3*x-2,{2}>,
<3*x^6-3*x^4+x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+2*x^3+2*x^2-x+2,{}>,
<-2*x^6-3*x^5+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^3-x^2+2*x+2,{2,11,101}>,
<-x^6-x^5+2*x^4+2*x^3+3*x^2+3*x+2,{2,3}>,
<2*x^6+3*x^5+3*x^4-x^2+3*x-2,{2}>,
<3*x^6-3*x^4+x^3-x^2+3*x-1,{2}>,
<2*x^6-2*x^5-x^4+3*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+x^2+3*x-1,{2}>,
<2*x^6+3*x^5+3*x^4-x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3+3*x^2-3,{2}>,
<2*x^6+3*x^5+3*x^4-x^2+x+2,{2}>,
<-x^6-x^5-x^4+3*x^2-3*x+2,{}>,
<-x^6-2*x^5+x^4-x^3+3*x^2-3,{2}>,
<2*x^6-x^5-x^4-x^3-3*x^2+3,{}>,
<-2*x^6-3*x^5-3*x^4+x^2-x+2,{2}>,
<-2*x^6+3*x^5-3*x^4+x^2-3*x+2,{2,37}>,
<3*x^6-3*x^4+x^3-x^2+x-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^2-3*x-2,{2}>,
<-2*x^6-x^5-x^4+3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^2-3*x-2,{2}>,
<3*x^6-3*x^4-x^3-x^2-1,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^2-3*x-2,{2,5}>,
<2*x^6+3*x^5+3*x^4-2*x^2+2*x-1,{}>,
<2*x^6+3*x^5+2*x^4+2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^2-2*x-1,{2,7}>,
<-2*x^6-3*x^5-3*x^4+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^2-x-1,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-3*x^2-3*x-2,{2,7}>,
<2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6-2*x^4+x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^2-x-1,{2}>,
<-2*x^6+2*x^4-x^3+3*x^2+3*x+2,{2}>,
<2*x^6+x^5-3*x^4+3*x^2-3*x+2,{2}>,
<2*x^6-x^5-2*x^4-x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+x^3+3*x^2-3*x+2,{}>,
<2*x^6+3*x^5+3*x^4-x^3+2*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+x^2+2,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+2*x^2+2,{}>,
<2*x^6-3*x^5+3*x^4+x^3+x^2-1,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+2*x+2,{}>,
<2*x^6-2*x^5-x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3+2*x-2,{2}>,
<-x^6+3*x^5+x^3-3*x^2-3*x-2,{2}>,
<-x^6-3*x^5-x^4+x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2-2*x-1,{2}>,
<2*x^6-x^5+x^4-x^3-3*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+x^4-x^3-3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-x^4-x^3+3*x^2+3*x+2,{2}>,
<-x^6-3*x^5-2*x^4+x^3+3*x^2-3*x+2,{2}>,
<-x^6+2*x^5-2*x^4-x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+3*x^2+3*x+2,{2}>,
<2*x^6-x^5+2*x^4+x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-2*x^2-2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2-3*x-2,{2,7,17}>,
<-2*x^6+3*x^5-3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3+3*x^2-3*x+2,{}>,
<-2*x^6+3*x^5-3*x^4-x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-3*x^4-x^3+x^2-3*x+2,{2}>,
<-x^6+2*x^5-3*x^4-x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-x^3+3*x^2+2,{}>,
<2*x^6-3*x^5+3*x^4+x^3-3*x^2-2,{}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-x^2+x-1,{2}>,
<-2*x^6-3*x^5-3*x^4+x^3+3*x^2+3*x-1,{2}>,
<2*x^6+x^5+x^4+x^3-3*x^2+3*x-2,{2}>,
<2*x^6-x^4+x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3-x^2-1,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2+x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-3*x^2+2,{2}>,
<2*x^6-3*x^5+3*x^4-x^3-x^2+3*x+2,{}>,
<-2*x^6-3*x^5-3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+3*x^2+x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3+3*x^2-3*x+2,{2,3}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-2*x^2+2*x+2,{}>,
<-2*x^6+2*x^5+2*x^4-2*x^3+3*x^2+3*x+2,{}>,
<2*x^6-x^5-2*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+2*x^4-2*x^3+3*x^2+3*x+2,{2}>,
<-x^6+2*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-2*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2-x-1,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+x+2,{}>,
<2*x^6-3*x^5+3*x^4+2*x^3+2*x^2+x-2,{}>,
<2*x^6+3*x^5+3*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-3*x^2+3*x-2,{2,5}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-3*x^2+3,{}>,
<-x^6+x^5+x^4-2*x^3+3*x^2+3*x+2,{2}>,
<3*x^6-3*x^4+2*x^3-2*x^2-3*x-1,{}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2-3,{2,3}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<-3*x^6+3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+x^5+x^4-2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-x^2-x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-x^2-2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5-x^4-2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3+x^2-3*x-1,{2}>,
<2*x^6+x^5+2*x^4-3*x^2+3*x-2,{2,19,239}>,
<2*x^6+3*x^5-x^4+2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-3*x-2,{2}>,
<-x^6-x^5+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-x^5+2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-x+2,{2}>,
<-2*x^6+x^5+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-2*x^3+3*x^2+3*x+2,{}>,
<-x^6+2*x^5+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+2*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+2*x^3-x^2-3*x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3-3*x^2+3*x-2,{2}>,
<-x^6+3*x^5-x^4-2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+x^4-2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-x^2-x+2,{2}>,
<-x^6+x^5-x^4+2*x^3+3*x^2-3*x+2,{2,3}>,
<2*x^6-2*x^5-x^4-2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+x^2-3*x-1,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^3-2*x^2+3*x-2,{2}>,
<-x^6-2*x^5+2*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+2*x^2-x-1,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4+x^3+x^2+2*x-2,{2,11,101}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+x^5-3*x^4-2*x^3+3*x^2+3*x+2,{}>,
<-x^6-x^5+3*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-3*x^2-3*x-2,{2,5}>,
<2*x^6+3*x^5+3*x^4-2*x^3-3*x^2-2*x+2,{2,5}>,
<2*x^6+3*x^5+3*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3+3*x^2-x+2,{}>,
<2*x^6+3*x^5+3*x^4-3*x^3+3*x^2+x-2,{2,13}>,
<2*x^6-3*x^5+3*x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+x^5+3*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^4-2*x^3+3*x^2-2*x-1,{2,3}>,
<2*x^6-3*x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^3-2*x^2-x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-x^6+x^5+2*x^4+3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-3*x^6+3*x^4-2*x^3+3*x^2-3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3+x^2-x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3-x^2+2,{2}>,
<2*x^6+x^5-x^4+3*x^3-3*x^2-3*x-2,{}>,
<2*x^6-3*x^5+3*x^4+3*x^3+x^2-2*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+x^2-x-2,{}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<-x^6+x^5+2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3+x+2,{2}>,
<-x^6+x^5-3*x^3+3*x^2+3*x+2,{}>,
<2*x^6-3*x^5+3*x^4+3*x^3+2,{}>,
<2*x^6+3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+x^2-x-2,{2}>,
<2*x^6+x^5+3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6-3*x^5+x^3-3*x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3+2*x+2,{2}>,
<2*x^6-3*x^5+3*x^4+3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-x^2-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2+3*x-2,{2,5,23,83}>,
<2*x^6+x^3-3*x^2-3*x-2,{2}>,
<2*x^6+x^5-x^4+3*x^3+3*x^2-3*x+2,{}>,
<2*x^6+x^5+x^3+3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-x^3-x-1,{2}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2+3*x-2,{2,7}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2+3*x+2,{}>,
<-2*x^6-3*x^5+x^4-3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+3*x^2-3*x+2,{2,3}>,
<2*x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+3*x^2+3*x+2,{}>,
<2*x^6-2*x^5+3*x^4+3*x^3-3*x^2-3*x-2,{}>,
<2*x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x-2,{}>,
<2*x^6+2*x^5-3*x^3-3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-3*x^2-2*x-1,{}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3*x^2-3*x-2,{2,5}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-2*x^2+x-2,{2,239}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4-2*x^2+x+2,{}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-2*x^2-3*x+2,{}>,
<2*x^6+3*x^5+2*x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6+x^5-2*x^4+3*x^2-3*x+2,{2}>,
<2*x^6-2*x^4+3*x^3-2*x^2+3*x-2,{}>,
<2*x^6-3*x^5+2*x^4-3*x^3+2*x^2-2,{}>,
<2*x^6+3*x^5-2*x^4-3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3+2*x^2+3*x-2,{}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-3*x+2,{}>,
<-2*x^6+3*x^5-2*x^4+3*x^3-x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^2+2*x-1,{2,31}>,
<-2*x^6+3*x^5-2*x^4+3*x^3-2*x^2+x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3+x^2-1,{2}>,
<-2*x^6+3*x^5-3*x^4+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^3-2*x^2-3*x-2,{2}>,
<-x^6+3*x^5+3*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3+3*x+2,{}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-x^2+2,{2}>,
<-2*x^6-3*x^5-3*x^3+2*x^2-3*x+2,{}>,
<2*x^6-3*x^5+2*x^4-3*x^3+x^2+x-2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3-x-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+x^5+3*x^3-2*x^2+3*x-2,{2,3,5}>,
<2*x^6+3*x^5+2*x^4+3*x^3-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-x-1,{2}>,
<2*x^6+x^5-3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-2*x+2,{2}>,
<-x^6+2*x^5-3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3-2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^3+2*x^2+3*x+2,{2,23}>,
<-x^6+3*x^5+x^4+3*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-x^2+2*x-1,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-x^5-x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-x^6+x^4-3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3+x^2+2,{}>,
<2*x^6+3*x^5+2*x^4+3*x^3-x^2-2,{}>,
<-x^6+x^5-x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+3*x^4+x^3-x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+2*x^2+3*x+2,{}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+2*x^2-3*x+2,{2}>,
<-x^6+3*x^4+3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3+2*x+2,{2,11,163}>,
<-3*x^6+3*x^4+x^3+3*x^2+x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^3+3*x^2+2*x-2,{2,7}>,
<-x^6-2*x^5-3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-3*x^2+3,{2,3}>,
<3*x^6-3*x^4+x^3-3*x^2-1,{2}>,
<-2*x^6-3*x^4+x^3-3*x^2+3,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2+x-1,{}>,
<2*x^6-2*x^5-3*x^4-3*x^3+3*x^2+3*x+2,{2,7}>,
<2*x^6+2*x^5+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x-2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3-2*x^2-3*x-2,{0}>,
<2*x^6+3*x^5+2*x^4+3*x^3+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3-3*x^2+x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3+x+2,{}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+x^2-2*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+2*x^2-x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-3*x^2-3*x-1,{}>,
<-2*x^6-2*x^5+x^4-2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3-x^2+x+2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+x^2+2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3-x^2+2,{}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-3*x+2,{}>,
<-2*x^6+x^4-2*x^3+2*x^2-3*x+2,{}>,
<-2*x^6+3*x^5-2*x^4+2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-x^5+x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^4+2*x^3-3*x^2+x+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3-2*x^2-3*x-2,{2,7}>,
<-2*x^6+x^5+3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-3*x^2-3*x-2,{2}>,
<-x^6+3*x^5+2*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-2*x^3+2*x^2-3*x+2,{}>,
<-x^6+2*x^5+2*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-x^6-2*x^5-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+x^2-2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2+2*x-1,{2,5}>,
<-x^6-x^5-x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+x^2-2*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3-x^2-x-2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2-2*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2+x-1,{2}>,
<2*x^6-x^5+x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-x^6-x^4+2*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-x^4-2*x^3+2*x^2-3*x+2,{2,5}>,
<-x^6-x^5-2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6+2*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<-x^6-2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+2*x^4-2*x^3-2*x^2-3*x-2,{}>,
<-2*x^6-2*x^4-2*x^3+2*x^2-3*x+2,{}>,
<-x^6-x^5-2*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+3*x^2+3*x+2,{2}>,
<2*x^6+2*x^4-3*x^3-3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-2*x^2+2,{2}>,
<-x^6+2*x^4-3*x^3-2*x^2-3*x-2,{2,3}>,
<2*x^6-3*x^5+2*x^4-3*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4+3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^3-2*x^2-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^3+2*x^2+x-1,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^3+2*x^2-x+2,{}>,
<2*x^6-x^5-x^4+3*x^3-3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2+2,{}>,
<-x^6+3*x^4-x^3+2*x^2-3*x+2,{}>,
<2*x^6-3*x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-x^5-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6+2*x^3-2*x^2+3*x-2,{2,23}>,
<2*x^6-x^5+2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-2*x^3+x-2,{2}>,
<2*x^6-3*x^5+3*x^4-3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+x^2+3*x-2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+x^2-2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4-x^3+2*x^2-3*x+2,{}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2-2*x-1,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3-x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4+x^3+2*x^2+3*x+2,{}>,
<-2*x^6+3*x^5-2*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+x+2,{2}>,
<2*x^6-x^5-x^4-x^3-2*x^2-3*x-2,{}>,
<2*x^6-3*x^5-x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+x-2,{}>,
<-2*x^6+3*x^5-2*x^4+x^3+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-x-1,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3+x-2,{2}>,
<2*x^6-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-1,{2}>,
<2*x^6+x^5+x^3-2*x^2+3*x-2,{2}>,
<2*x^6-x^3-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-2,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3+x^2+2*x+2,{2,53}>,
<-x^6+3*x^5-x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+x^2-3*x-1,{2,11}>,
<2*x^6+3*x^5+2*x^4+x^3-x^2-1,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3+x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-x^2-2,{2}>,
<2*x^6+x^5+x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^3-2*x^2-3*x-2,{2,107}>,
<2*x^6-3*x^5+2*x^4-x^3-x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+3*x+2,{2}>,
<-x^6-2*x^5+x^4-x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x+2,{2}>,
<-x^6+2*x^5-2*x^4+x^3+2*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x-2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x-2,{2}>,
<-x^6-x^5-2*x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-2*x^2-1,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+2*x^2+3*x+2,{}>,
<-2*x^6-3*x^5-2*x^4-x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-2*x^4-x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3+2*x^2+2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-2*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+x^3+2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-3*x^2-x-1,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+2*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3-2*x^2+3*x-2,{}>,
<2*x^6-3*x^4+x^3+2*x^2+3*x+2,{2}>,
<-x^6-3*x^5-3*x^4-x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3+3*x^2-1,{2}>,
<-x^6+2*x^5-3*x^4+x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-3*x^2+x-1,{2}>,
<2*x^6-3*x^5+2*x^4-x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-x^5-3*x^4+x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+x^5+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<-x^6+x^5+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+x^3-3*x^2-2*x-1,{2,19}>,
<-x^6+3*x^5+3*x^4-x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3+3*x^2+2*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^2+3*x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^2+3*x-2,{2}>,
<-x^6-x^5+3*x^4+2*x^2-3*x+2,{2,31}>,
<2*x^6+3*x^5+2*x^4+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^2+3*x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^2+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^2+x-2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^2-2,{2}>,
<2*x^6-x^5-x^4-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^2-x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4+3*x^2-2*x-1,{}>,
<2*x^6-3*x^5+2*x^4-3*x-2,{2,53}>,
<2*x^6-3*x^5+2*x^4-x-1,{}>,
<-2*x^6+x^5-x^4+2*x^2+3*x+2,{2}>,
<2*x^6-x^5-2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^2+3*x+2,{2}>,
<2*x^6+x^4-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^2-x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^2-3*x-1,{2,3}>,
<-x^6+x^5-x^4+2*x^2+3*x+2,{2}>,
<2*x^6-x^5+x^4-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^2+3*x-2,{2}>,
<-2*x^6-2*x^4+2*x^2+3*x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^2+3*x-2,{}>,
<2*x^6-3*x^5+2*x^4-2*x^2+x-2,{}>,
<-x^6+3*x^5+2*x^4-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^2-3*x-2,{2,5}>,
<-2*x^6-2*x^5+3*x^4-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^2+2*x-1,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x+2,{2,5,7,307}>,
<2*x^6-x^5+3*x^4-3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-x-2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6+x^5+3*x^4-3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^2+x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^2-x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^2-x+2,{}>,
<2*x^6-3*x^5+2*x^4-3*x^2-x-2,{}>,
<2*x^6-3*x^5+2*x^4-3*x^2-1,{2,3}>,
<-2*x^6-3*x^4+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-3*x^2+x-1,{2}>,
<2*x^6+x^5+3*x^4-2*x^2-3*x-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6+3*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+3*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+2*x^2-3*x+2,{}>,
<-2*x^6+3*x^5-2*x^4-x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+2*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3-2*x^2-3*x-2,{}>,
<2*x^6+3*x^5+2*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+3*x^2+x-2,{2,3}>,
<2*x^6+3*x^5+2*x^4+2*x^3+3*x^2+x+2,{2,3}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2+3*x+2,{2}>,
<2*x^6-2*x^5+x^4+x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+2*x^2-3*x+2,{2}>,
<-x^6+x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+x^5+x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+x^2-x-1,{2}>,
<2*x^6-x^5-x^4-x^3-2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6+3*x^5+x^4+x^3+2*x^2-3*x+2,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x+2,{}>,
<2*x^6-3*x^5+2*x^4+x^3-2*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3-2*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x-2,{2}>,
<-2*x^6+x^5-x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+x+2,{2}>,
<2*x^6+2*x^5+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x-1,{}>,
<2*x^6-2*x^5-x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-3*x+2,{2}>,
<-x^6-x^5-3*x^4-2*x^3+2*x^2-3*x+2,{2,3,67}>,
<2*x^6+x^5+3*x^4+2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3-3*x^2+x-2,{2}>,
<-x^6-2*x^5+x^4-x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2+3*x-2,{2}>,
<-x^6+3*x^5+x^4+x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3+2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x^2+3*x-1,{2}>,
<-x^6-3*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x^2+3*x-2,{2,5}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+3*x^2+x-1,{2}>,
<-x^6+2*x^5-2*x^4-x^3+2*x^2+3*x+2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3-2*x^2-3*x-2,{2}>,
<-x^6-2*x^5-3*x^4+2*x^3+2*x^2+3*x+2,{2,3}>,
<2*x^6-x^5+2*x^4+x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x^2+x-2,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2-3*x-1,{}>,
<2*x^6-2*x^4+x^3+2*x^2-3*x+2,{2}>,
<-x^6-2*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-2*x^2-x+2,{}>,
<2*x^6-2*x^5+3*x^4-x^3+2*x^2-3*x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4-x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3+3*x^2-3*x-1,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3+3*x^2+2*x+2,{2}>,
<-x^6+3*x^5-3*x^4-x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+x^3-2*x^2-x+2,{2}>,
<-x^6-x^5-3*x^4+x^3+2*x^2-3*x+2,{2,3}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^5+3*x^4-x^3-2*x^2+3*x-2,{2}>,
<-x^6-3*x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3+3*x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+x^3+3*x^2+x-1,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^3-3*x^2+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-3*x^2+x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-2*x^2+3*x-2,{2,3}>,
<2*x^6+3*x^5+2*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3-3*x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-2*x^4-2*x^3-2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-2*x^2+2*x+2,{}>,
<2*x^6+3*x^5+2*x^4-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3+2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+2*x^2+2*x-2,{}>,
<2*x^6-x^5-x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-x^6+x^4-2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^3-x^2+2,{2}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2-3*x+2,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^3+3*x+2,{}>,
<-2*x^6+3*x^5-2*x^3+2*x^2+3*x+2,{}>,
<2*x^6-2*x^5+x^4-2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-2*x-2,{2}>,
<2*x^6+2*x^3+2*x^2-3*x+2,{}>,
<-2*x^6-3*x^5-2*x^4+2*x^3-2*x^2+3*x+2,{2,5}>,
<2*x^6-2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+x^5+2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4-2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-x^5-2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3+x-2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-x+2,{}>,
<2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-x-1,{2}>,
<2*x^6-2*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x^2-x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3+2*x^2-3*x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-2*x^2-3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+3*x^2-x-1,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+3*x^2-1,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x^2+2,{2}>,
<2*x^6-3*x^5+2*x^4+x^3+2*x^2-1,{}>,
<-x^6-2*x^5+2*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^2-3*x-2,{2}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3+2*x^2+3*x+2,{2,5}>,
<2*x^6+3*x^5+2*x^4-3*x^3+3*x^2-x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-2*x^4+x^3-2*x^2-3*x-2,{2,5}>,
<2*x^6+3*x^5+2*x^4-2*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3-2*x^2-x+2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x^2-x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3-2*x^2-2*x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+x^2+2,{}>,
<-2*x^6-3*x^5-2*x^4+3*x^3-x^2+2,{2}>,
<-x^6+3*x^5-x^4+3*x^3-2*x^2-3*x-2,{2,3}>,
<2*x^6-x^5+3*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+x^2-2,{2,3}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3+2*x^2+3*x+2,{2}>,
<2*x^6-x^5-x^4-3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4+2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+x^2+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3-x^2-2*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3-x^2-2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+x^2+2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3+2*x^2-3*x-2,{2,7,17,23}>,
<2*x^6+3*x^5+2*x^4-3*x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3-x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+x^2+3*x-2,{}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+x^2-3*x-1,{2}>,
<-2*x^6+3*x^5-2*x^4+2*x^3+2*x^2+x-1,{2}>,
<-x^6+x^5+3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x^2+3*x-2,{2,6521}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+x^2-3*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-2*x^2-3*x-2,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3-3*x^2+x+2,{}>,
<-2*x^6-x^5+3*x^4-3*x^3+x^2-3*x+2,{}>,
<-2*x^6+3*x^5-x^4+3*x^3-3*x^2+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2-3*x-2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-3*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+2*x^2-x-2,{2}>,
<-x^6+x^5+3*x^4+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-2*x^2+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+2*x^2-2*x+2,{}>,
<2*x^6-3*x^5+x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3+x^2-2*x-1,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-x^2-3*x+2,{}>,
<2*x^6+x^5+x^4+3*x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+x^2-x-2,{}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2+3*x+2,{}>,
<-x^6+x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+x^2-3*x+2,{}>,
<2*x^6-3*x^5+x^4-3*x^3+x^2-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-x^5-x^4+3*x^3-x^2+3*x-2,{2}>,
<-x^6+2*x^5+x^4-3*x^3+x^2-3*x+2,{2,193}>,
<-2*x^6+3*x^5-x^4+3*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3-x^2+3*x-2,{2,3,5,7}>,
<-2*x^6+3*x^5-x^4+3*x^3+x-2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+x-1,{}>,
<2*x^6-x^5-3*x^3-x^2-3*x-2,{}>,
<-2*x^6-x^5-3*x^3+x^2-3*x+2,{}>,
<-2*x^6+2*x^5+x^4-3*x^3+x^2-3*x+2,{2,113}>,
<-2*x^6-3*x^5-x^4-3*x^3-1,{2,3}>,
<2*x^6+3*x^5+x^4+3*x^3+x^2-x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-x^2+x+2,{}>,
<-2*x^6+3*x^5-x^4+3*x^3+3*x-1,{2}>,
<2*x^6+2*x^5-3*x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3-2*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+x^2-3*x-2,{2}>,
<2*x^6+2*x^5+3*x^3+x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2+3*x-1,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-x^2-x+2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2+x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+x^2-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2-3*x-2,{}>,
<2*x^6-x^4-3*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2+3*x-2,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-x^6-x^5+x^4+3*x^3-x^2+3*x-2,{2}>,
<-x^6+x^5-x^4-3*x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3-x^2-3*x-2,{2}>,
<-x^6+x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-x^2-1,{}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2-3*x-2,{2}>,
<2*x^6+x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-x^2-2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-x^2+3*x-2,{}>,
<-2*x^6-3*x^5-2*x^4+3*x^3+3*x^2-1,{2,17}>,
<-x^6-2*x^5+2*x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^4+3*x^3+2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+3*x^2-x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-2*x^2-x-1,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-2*x^2-2*x-2,{2,5}>,
<-2*x^6+3*x^5-x^4+3*x^3+2*x^2+x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2+2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-2*x^4-3*x^3+x^2-3*x+2,{}>,
<-x^6+3*x^5+3*x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2+x-2,{2}>,
<-x^6-x^5-2*x^4+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+2*x^2+x+2,{2}>,
<2*x^6+3*x^5+x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+3*x^2+x-1,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+x^2+3*x+2,{2}>,
<-x^6+3*x^4-3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+3*x^2-x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-x^2+3*x-2,{}>,
<2*x^6-3*x^5+x^4-3*x^3-3*x^2+2*x+2,{}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-2*x^5-3*x^4+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3-3*x^2+x+2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+3*x^2+2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2-x-1,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+2*x^2+x-2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3-x^2+3*x-2,{}>,
<2*x^6+3*x^5+x^4+2*x^3+x^2+3*x+2,{}>,
<-x^6+3*x^5-x^4+2*x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+x^2-3*x-1,{}>,
<-2*x^6+3*x^5-x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^3-2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+x^2-2*x-1,{2}>,
<-x^6+3*x^5-x^4-x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3-x^2+2*x+2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3+x^2+x-2,{2}>,
<-x^6+x^4-2*x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3-x^2+2,{}>,
<-2*x^6+x^4+2*x^3+x^2+3*x+2,{}>,
<2*x^6-3*x^5+x^4-2*x^3+x^2+x+2,{2}>,
<-x^6-x^5+x^4+2*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3-x^2+x+2,{2}>,
<-x^6+2*x^5-x^4-x^3+2*x^2+3*x+2,{2,3,41}>,
<-2*x^6+3*x^5-x^4+2*x^3+3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^4-x^3+x^2+x+2,{2}>,
<2*x^6-x^4+x^3+2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-x^3-x^2-2,{2}>,
<-x^6+x^5+2*x^3-x^2+3*x-2,{2,3}>,
<2*x^6+x^5+2*x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-1,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-x-1,{2}>,
<2*x^6+x^5-2*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3+x-2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+x^2-x+2,{2}>,
<2*x^6-3*x^5+2*x^4+3*x^3+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3-x^2+3*x-2,{2}>,
<-x^6+x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+x^2-3*x+2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3+2*x^2-3*x+2,{2,5}>,
<-x^6-2*x^5+x^4+2*x^3-2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-x^2-2*x-2,{2}>,
<-x^6-3*x^3+2*x^2+3*x+2,{2}>,
<-x^6-x^4+2*x^3+x^2+3*x+2,{2}>,
<2*x^6+x^4+2*x^3-x^2+3*x-2,{}>,
<2*x^6-2*x^5+x^4+2*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-x^4+2*x^3+x^2+3*x+2,{}>,
<-2*x^6-x^5+x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^3+2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+x^2-2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3-x^2+x-2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-x^2+3*x-2,{2}>,
<-x^6-2*x^5-3*x^3-2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+x^4-2*x^3-x^2-3*x-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+x^2+3*x+2,{2,11}>,
<-x^6+3*x^5+3*x^3-2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+x^2+x+2,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3-x^2+3*x-2,{2,31}>,
<-2*x^6-2*x^5-x^4+2*x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-2*x^2+2*x-1,{2,3}>,
<-2*x^6+3*x^5-2*x^4-3*x^3+x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-3*x^5+x^4+2*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+2*x^2-x-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-2*x^2+2,{2}>,
<-x^6-x^5-2*x^4-2*x^3+x^2-3*x+2,{}>,
<2*x^6-3*x^5+x^4-2*x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+2*x^2-1,{2}>,
<-2*x^6-3*x^5-2*x^4+2*x^3+x^2+3*x-1,{2}>,
<-2*x^6+x^5-2*x^4+2*x^3+x^2+3*x+2,{2}>,
<-x^6-2*x^4-2*x^3+x^2-3*x+2,{2}>,
<-2*x^6+2*x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+2*x^2+2,{2}>,
<-x^6+x^5-3*x^4-2*x^3+x^2-3*x+2,{}>,
<2*x^6+x^5-2*x^4-2*x^3+x^2-3*x+2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-2*x^3-x^2-3*x-2,{2}>,
<-x^6+x^5+2*x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6+x^5-3*x^4-2*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+3*x^2+2*x-1,{0,2}>,
<-2*x^6+x^5-2*x^4-2*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5+x^4+x^3+3*x^2-3*x-2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+x^2-3*x+2,{2}>,
<-x^6-2*x^5+2*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5-x^4+x^3-2*x^2+x+2,{2}>,
<2*x^6+3*x^5+x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5+x^4+x^3+2*x^2+2,{2}>,
<-2*x^6+2*x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5+x^4+x^3+x^2+2,{2}>,
<-x^6+3*x^5+2*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-x^3+x^2-1,{2}>,
<-2*x^6-3*x^5-x^4-x^3-x^2+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4-x^3+x^2-3*x+2,{}>,
<2*x^6-3*x^5+x^4-x^3+x^2-2,{2}>,
<2*x^6+3*x^5+x^4+x^3+x^2-x-2,{2}>,
<-x^6-3*x^5-x^4-x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3-x^2-3*x-2,{2}>,
<-x^6-3*x^5+x^4-x^3+x^2-3*x+2,{2,17}>,
<2*x^6+3*x^5-x^4+x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-x^2-x+2,{2}>,
<2*x^6+3*x^5+x^3-x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^3+x^2-x-2,{2}>,
<-2*x^6+3*x^5-2*x^4+3*x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^3-x^2+3*x-2,{2}>,
<-2*x^6-3*x^5-x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3-2*x+2,{2,3,5}>,
<2*x^6+3*x^5+x^4+x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+x^2-2*x-1,{2}>,
<2*x^6-3*x^5+x^4-x^3-2*x-2,{2,5}>,
<-x^6-x^5-x^3+x^2-3*x+2,{}>,
<-x^6-3*x^5+2*x^4-x^3-x^2-3*x-2,{2,37}>,
<-2*x^6-2*x^5+2*x^4-x^3-x^2-3*x-2,{2,7}>,
<2*x^6-3*x^5+x^4-x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+2*x+2,{}>,
<-2*x^6+2*x^5-2*x^4+x^3+x^2+3*x+2,{}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2+x-2,{}>,
<2*x^6+2*x^5+x^4+x^3-x^2+3*x-2,{2}>,
<2*x^6-x^5-2*x^4-x^3+x^2-3*x+2,{}>,
<-2*x^6-2*x^5-x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<2*x^6+3*x^5+x^4+x^3-2*x^2+x-1,{}>,
<-2*x^6-3*x^5-x^4-x^3+x^2-x-1,{2}>,
<-x^6+x^3+x^2+3*x+2,{2,31}>,
<2*x^6+3*x^5+x^4+x^3-x^2+x-2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+2*x^2-x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+2,{2}>,
<-2*x^6-x^3+x^2-3*x+2,{2}>,
<-x^6+2*x^4+x^3-x^2+3*x-2,{2}>,
<-2*x^6-2*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4-x^3-x^2-1,{2}>,
<-x^6-x^5-2*x^4+x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+x^2+x+2,{2}>,
<2*x^6+3*x^5+x^4+x^3-2*x^2-x-2,{2}>,
<-2*x^6+3*x^5-x^4+x^3+x^2-3*x-1,{2}>,
<2*x^6-x^5+x^3-x^2+3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3-x^2+3*x-2,{2}>,
<2*x^6-2*x^5+x^3+x^2+3*x+2,{}>,
<-2*x^6+3*x^5-x^4+x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4+x^3-x^2+3*x-2,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+3*x-2,{2}>,
<-2*x^6+x^5-3*x^4+x^3+x^2+3*x+2,{2}>,
<-x^6+3*x^4-x^3-x^2-3*x-2,{2}>,
<-2*x^6+x^5+3*x^4+x^2-3*x+2,{2}>,
<2*x^6+3*x^5+x^4+x^3-3*x^2-1,{2}>,
<-2*x^6-3*x^5-x^4-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4+x^3+3*x^2+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-2*x^2+2*x+2,{}>,
<2*x^6+3*x^5+x^4+x^3-3*x^2-2,{2}>,
<2*x^6-3*x^5+x^4+2*x^2-2*x-2,{}>,
<2*x^6-x^5+2*x^4+x^2-3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-x^2-3*x-2,{2,5}>,
<-2*x^6-x^5+2*x^4+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+3*x^2+x-1,{0,2}>,
<2*x^6+2*x^5+2*x^4+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-x^3+3*x^2-x-2,{2}>,
<-2*x^6+3*x^5-x^4+x^3+3*x^2-x+2,{2}>,
<-x^6-2*x^5+2*x^4+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4-3*x^2-3*x+2,{2}>,
<-2*x^6-x^5+3*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-2*x^2-2*x+2,{2}>,
<2*x^6-x^5-3*x^4-x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4+x^2-3*x-2,{2}>,
<-x^6+2*x^5-3*x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4+x^2-2*x-1,{2}>,
<2*x^6-3*x^4-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4+x^2-2*x-2,{2}>,
<2*x^6-x^5+x^4+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^2+3*x+2,{2}>,
<-x^6+2*x^5+x^2+3*x+2,{2}>,
<-x^6+x^5+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+x^2-2*x+2,{2}>,
<-2*x^6+3*x^5-x^4+x+2,{2}>,
<-2*x^6+3*x^5-x^4+2,{2}>,
<2*x^6-3*x^5+x^4+x-2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^2-x+2,{2}>,
<2*x^6+3*x^5+x^4+x^2+x-2,{2,139}>,
<-2*x^6-3*x^5+x^4-x^2-3*x-2,{2}>,
<-2*x^6-2*x^4+x^2-3*x+2,{2}>,
<-x^6-x^5-2*x^4+x^2+3*x+2,{2}>,
<-x^6-3*x^5+x^4-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^2-x+2,{2}>,
<-2*x^6+x^4+x^2+3*x+2,{2,5}>,
<-x^6+2*x^5+2*x^4-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^2-3*x-2,{}>,
<2*x^6-2*x^5-x^4-x^2+3*x-2,{2}>,
<-x^6-2*x^5-x^4+x^2-3*x+2,{}>,
<-2*x^6-3*x^5-x^4+3*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4+2*x^3+3*x^2+3*x-1,{}>,
<-2*x^6+3*x^5-x^4+3*x^2-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+3*x+2,{}>,
<-2*x^6-3*x^5-x^4+3*x^2-2*x-2,{2,5}>,
<2*x^6-3*x^5+x^4+x^2+3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6-3*x^5+x^4-3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+x^4+2*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6-3*x^5-x^4-2*x^3+3*x^2-2,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3-x^2-3*x-2,{}>,
<2*x^6-3*x^5+x^4-3*x^2-x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x+2,{2,3}>,
<2*x^6-3*x^5+x^4-2*x^3-3*x^2+x+2,{}>,
<-2*x^6-3*x^5-x^4+x^3-3*x^2-x+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^4+x^3+x^2-3*x+2,{2}>,
<-x^6-3*x^5+x^4+x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4+x^3+3*x^2+3*x-2,{2,7}>,
<-2*x^6+3*x^5+x^4-x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4-x^3+3*x^2-1,{2}>,
<2*x^6+3*x^5+x^4-x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4+x^3+x^2-3*x+2,{}>,
<2*x^6-3*x^5-2*x^4+x^3-x^2-3*x-2,{2}>,
<-x^6+x^5+3*x^4-2*x^3-x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+x^3-3*x^2+2,{2,7}>,
<-2*x^6+3*x^5-x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+x^3-x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+x^2-3*x+2,{2}>,
<2*x^6-3*x^5+x^4+x^3+2*x^2-1,{2}>,
<2*x^6-3*x^5+x^4+x^3+3*x^2-2,{2}>,
<2*x^6-3*x^5+x^4+x^3+x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-x^2-x+2,{2}>,
<2*x^6-2*x^5-x^3-x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-3*x^2-x+2,{2}>,
<-2*x^6-3*x^5-x^4+x^3+3*x-1,{2}>,
<-2*x^6-3*x^5-x^4+x^3+x^2-3*x-1,{2}>,
<-2*x^6+x^5+3*x^4+x^3+x^2-3*x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3+x^2-3*x+2,{2}>,
<2*x^6+3*x^5+x^4-x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3+x^2-3*x-1,{2}>,
<-2*x^6-3*x^5-x^4+x^3-2*x^2+2,{2}>,
<2*x^6+3*x^5+x^4-x^3+x^2-2*x-1,{2}>,
<-x^6-3*x^5-x^4+x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<-2*x^6+3*x^5-x^4-x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+x^2-3*x+2,{2}>,
<2*x^6+3*x^5+x^4-x^3-x^2+3*x-2,{2,5}>,
<-2*x^6-3*x^5-x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3-x^2+2,{}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5+x^4+x^3-x^2-1,{2}>,
<2*x^6+3*x^5+x^4-x^3+2*x^2-3*x-1,{}>,
<-2*x^6-3*x^5-x^4+x^3+x^2+2,{2}>,
<-2*x^6-x^4+x^3+x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-x^3+x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3-3*x^2-x+2,{}>,
<-2*x^6+x^5+3*x^4-2*x^3+x^2+3*x+2,{}>,
<2*x^6-3*x^5+x^4+2*x^3+3*x^2-2,{2}>,
<-2*x^6+3*x^5-x^4-2*x^3-3*x^2-x+2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2+3*x-2,{}>,
<2*x^6+3*x^5+x^4-2*x^3+3*x^2-3*x-2,{}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x^2+2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3+2*x^2-1,{2}>,
<2*x^6-3*x^5+x^4+2*x^3+2*x^2+x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+x^2+3*x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-x^2-3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+x^2-3*x+2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5-x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5+x^4+2*x^3+x^2-2*x-2,{2,5,173}>,
<2*x^6-3*x^5+x^4+2*x^3+x^2+2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3-x^2+2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3+x^2-x+2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3+x^2-x-2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3-x^2+2*x+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-3*x-2,{2}>,
<-x^6+3*x^5-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-2*x^3+2*x+2,{2,3}>,
<2*x^6+3*x^5+x^4-2*x^3+x-2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3+x+2,{2}>,
<2*x^6-3*x^5+x^4+2*x^3+3*x+2,{}>,
<-2*x^6-3*x^5-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^3+x^2-2*x+2,{2}>,
<2*x^6+x^5+x^4-2*x^3-x^2+3*x-2,{2}>,
<-2*x^6+x^5-x^4-2*x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3-x^2+2,{}>,
<-2*x^6-3*x^5-x^4+2*x^3+x^2+2*x-1,{2}>,
<2*x^6-3*x^5+x^4+2*x^3-x^2+3*x+2,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3+x^2-3*x+2,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-x^2+3*x-2,{2,3}>,
<-2*x^6+3*x^5-x^4-2*x^3+3*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4-2*x^3-x^2+3*x-2,{}>,
<-2*x^6-3*x^5-x^4+2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+x^2-3*x+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-x^2+3*x-2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-x^2+3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+x^2-3*x+2,{}>,
<2*x^6-3*x^5-x^4-x^3-x^2+3*x-2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x+2,{2,11}>,
<2*x^6-3*x^5+x^4+x^3-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4-x^3+2*x+2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+x^3+x^2-3*x+2,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-x^2-3*x-2,{2}>,
<-2*x^6-3*x^5-x^4+x^3-x+2,{2}>,
<2*x^6+3*x^5+x^4-3*x^3+2*x^2+x+2,{2}>,
<2*x^6-x^3+x^2+3*x+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+x^3+x^2-3*x+2,{2}>,
<2*x^6+2*x^4-3*x^3+x^2+3*x+2,{}>,
<2*x^6+x^5+2*x^4+3*x^3+x^2-3*x+2,{}>,
<2*x^6+3*x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2+3*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3+x^2+3*x-2,{2}>,
<-x^6-3*x^5+3*x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-x^2+3*x-2,{2}>,
<2*x^6+x^5+x^4-3*x^3+x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-2*x-2,{2}>,
<2*x^6+3*x^3-x^2-3*x-2,{2}>,
<2*x^6+x^5-x^4-3*x^3-x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^3+x^2-3*x+2,{2}>,
<-x^6+2*x^5+3*x^3-x^2-3*x-2,{2}>,
<2*x^6-x^4-3*x^3-x^2+3*x-2,{2}>,
<-2*x^6+x^4+3*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3-x^2+2*x-1,{2}>,
<2*x^6+3*x^5+3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3+x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-x^2-2*x+2,{2}>,
<-x^6+2*x^5-x^4-3*x^3+x^2+3*x+2,{2}>,
<-2*x^6+3*x^5-x^4-3*x^3+x^2+2*x+2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-x^2-2*x-2,{2}>,
<2*x^6+x^5-x^4-3*x^3+x^2+3*x+2,{2}>,
<2*x^6+3*x^5+x^4-3*x^3-x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+x^2-3*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5+x^4-3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3-x^2-3*x-2,{2}>,
<-x^6+2*x^4+3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-2*x^2-2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3-x^2+3*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+x^2+3*x+2,{}>,
<-x^6-2*x^5+2*x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3-2*x^2+2*x-2,{2}>,
<-x^6-2*x^4+x^3+x^2-3*x+2,{2}>,
<2*x^6+2*x^4-x^3-x^2+3*x-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^3-3*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4-3*x^3-3*x+2,{2}>,
<-2*x^6-3*x^4-3*x^3-3*x-2,{2}>,
<2*x^6-3*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^3-3*x^2+x-2,{2}>,
<2*x^6+3*x^5+3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-3*x^5-3*x^3-3*x^2+x-1,{2}>,
<-2*x^6-3*x^5-3*x^3-3*x^2+x+2,{2}>,
<2*x^6+3*x^5+3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2+2*x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^3-2*x^2-x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3-3*x+2,{2}>,
<-2*x^6+2*x^4+3*x^3+3*x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+3*x-2,{2}>,
<-x^6-x^5-x^4+x^2+3*x+2,{2}>,
<2*x^6+x^5+x^4-x^2-3*x-2,{2}>,
<2*x^6-3*x^5+x^4-x^2+x-2,{2}>,
<2*x^6-3*x^5+x^4-x^2+2*x+2,{}>,
<-x^6+2*x^5-x^4+3*x^3+x^2-3*x+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6+3*x^5+x^4-2*x^3-x^2-3*x-1,{}>,
<2*x^6-2*x^5-2*x^4+3*x^3+3*x-2,{2}>,
<-x^6-2*x^5-2*x^4+2*x^3+x^2-3*x+2,{2,5}>,
<2*x^6+3*x^5+3*x^3+2*x^2-2*x-2,{2}>,
<-x^6-3*x^5-2*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3+x^2+3*x+2,{2}>,
<-x^6+x^5-2*x^4-2*x^3+x^2+3*x+2,{2,3}>,
<2*x^6-x^5+2*x^4+2*x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-x^2+x-2,{2}>,
<2*x^6+3*x^5+3*x^3+x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^3-x^2+x-1,{2}>,
<2*x^6+3*x^5+3*x^3+x^2-2*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-x^2+x+2,{2}>,
<2*x^6-3*x^5-3*x^3+x^2-x-2,{2}>,
<-2*x^6-3*x^5-3*x^3-x^2-1,{2,19}>,
<2*x^6-x^4-3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3+x^2-2,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x+2,{}>,
<2*x^6+3*x^5+3*x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3-2,{2,3}>,
<-2*x^6+3*x^5+3*x^3-1,{2}>,
<-x^6-3*x^3-3*x+2,{2}>,
<2*x^6-3*x^3-3*x-2,{}>,
<-2*x^6+3*x^3+3*x+2,{}>,
<-2*x^6+3*x^5+3*x^3-x-1,{2}>,
<-2*x^6+3*x^5+3*x^3-x+2,{}>,
<2*x^6-3*x^5-3*x^3+x-2,{}>,
<-x^6+2*x^5-3*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^3-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^3+3*x-2,{}>,
<-2*x^6+3*x^5-3*x^3-3*x+2,{}>,
<-2*x^6-3*x^5-3*x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+3*x+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-x^2+2*x-2,{2}>,
<-x^6+x^5+x^4+3*x^3+3*x-2,{2}>,
<-2*x^6+x^4+3*x^3+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^3-x^2-1,{2}>,
<2*x^6+x^4-3*x^3-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-x^4-3*x^3-3*x+2,{2}>,
<-2*x^6+x^5+x^4-3*x^3-3*x-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3-x^2-3*x-2,{2}>,
<2*x^6-x^5-x^4+3*x^3+3*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2+3*x-2,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6-2*x^5+3*x^4-x^3-x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3-x^2-3*x-2,{}>,
<2*x^6-3*x^5-3*x^3-x^2+x-1,{2}>,
<2*x^6-3*x^5+x^4+x^3-3*x^2+2*x-2,{}>,
<-2*x^6+3*x^5+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^3+2*x^2+2*x-1,{}>,
<-2*x^6-3*x^5+3*x^4-x^3-x^2+3*x-2,{2}>,
<-x^6+2*x^5+x^4-3*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-2*x^2+x-1,{2}>,
<-2*x^6+3*x^5-x^4-2*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5-3*x^3+2*x^2-1,{}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x-2,{2}>,
<2*x^6+2*x^4-3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5+x^4-2*x^3+3*x^2+x+2,{2,5}>,
<-2*x^6-x^5+2*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3+3*x+2,{2}>,
<-x^6+x^5+3*x^4-2*x^3+x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-3*x-2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-3*x+2,{2}>,
<-x^6-2*x^5-2*x^4+3*x^3+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x-2,{0,2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-3*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2+x-1,{2}>,
<2*x^6+x^5+3*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-3*x-2,{2,37}>,
<-2*x^6-3*x^5-3*x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+3*x^4+3*x^3+3*x-2,{2}>,
<2*x^6-3*x^4-3*x^3-3*x+2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3-3*x+2,{2,3}>,
<-x^6+3*x^4+3*x^3+3*x-2,{2}>,
<-x^6+3*x^4-3*x^3-x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+3*x-2,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+3*x-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-x^2+3*x-2,{2}>,
<-x^6+x^5-3*x^4-3*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3+3*x+2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2-x-2,{2,5}>,
<-2*x^6+3*x^5+3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5-3*x^3+3*x^2+2*x-2,{}>,
<-2*x^6-3*x^5-3*x^3+3*x^2-x-1,{2}>,
<2*x^6+3*x^5+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^3-3*x^2-2*x+2,{}>,
<-2*x^6+3*x^5+2*x^3-2*x^2+3*x-1,{2}>,
<2*x^6+3*x^5+3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^3-2*x^2+x-1,{2,3}>,
<-2*x^6+3*x^5+2*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+x^4-2*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^3+2*x^2+x-2,{2}>,
<-2*x^6+3*x^5+2*x^3-x^2-2*x-1,{2}>,
<2*x^6+3*x^5+2*x^3+2*x^2+2*x+2,{2,3,13}>,
<-x^6+2*x^5-2*x^4+2*x^3+3*x-2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x+2,{}>,
<-2*x^6+3*x^5+2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5+2*x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^5-2*x^3+2*x^2-2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^3-x-1,{2}>,
<2*x^6+x^5+2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^3+x-2,{2}>,
<-x^6+2*x^3+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^3+2,{2}>,
<-2*x^6+2*x^3+3*x+2,{2}>,
<-x^6-x^5+2*x^3+3*x+2,{2}>,
<-2*x^6-2*x^5+2*x^3+3*x-2,{2}>,
<2*x^6-2*x^5+2*x^3+3*x-2,{2}>,
<-2*x^6-2*x^5+2*x^3+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^3+3*x-1,{0,2,3}>,
<2*x^6-3*x^5+2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-3*x+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3+3*x-2,{2}>,
<-x^6-3*x^5-x^4-2*x^3-3*x+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^3-x^2-2*x-1,{2,3}>,
<2*x^6-2*x^5+x^4-2*x^3-3*x-2,{}>,
<-2*x^6+2*x^5-x^4+2*x^3+3*x+2,{}>,
<-2*x^6-x^5+x^4-2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3-x^2-x-2,{2}>,
<-2*x^6+x^4-2*x^3-3*x-2,{2}>,
<2*x^6-x^4+2*x^3+3*x+2,{2}>,
<-x^6+x^4-2*x^3-3*x-2,{2}>,
<2*x^6+3*x^5+2*x^3-x^2-1,{2}>,
<-x^6-x^5+x^4+2*x^3+3*x-2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x-2,{2}>,
<-2*x^6-3*x^5-x^4+2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-2*x^3-x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+3*x-2,{2}>,
<-2*x^6-3*x^5-2*x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-2*x^3-3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^3+2*x^2-x+2,{}>,
<-2*x^6-x^5-2*x^4+2*x^3+3*x+2,{}>,
<-2*x^6-3*x^5-2*x^3+2*x^2+2*x-1,{0,2}>,
<-x^6-x^5+2*x^4-2*x^3-3*x-2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-3*x-2,{2,139}>,
<2*x^6-x^5+2*x^4-2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3+x^2+3*x-2,{2,5}>,
<-2*x^6-3*x^5-2*x^3-2*x-2,{2}>,
<-2*x^6+2*x^4-2*x^3-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3-2*x+2,{2}>,
<2*x^6+3*x^5+2*x^3-2*x^2+2,{2}>,
<2*x^6-3*x^5-2*x^3-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^3+3*x-2,{}>,
<2*x^6-3*x^5-2*x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^5-2*x^3-3*x+2,{}>,
<-2*x^6+3*x^5+2*x^3+3*x^2+x-2,{2}>,
<-2*x^6-3*x^4+2*x^3+3*x+2,{2}>,
<-2*x^6-3*x^5-2*x^3-x-1,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3-3*x-2,{2,7}>,
<2*x^6-x^5-3*x^4+2*x^3+3*x+2,{2}>,
<2*x^6+3*x^5+x^3+3*x^2+x-2,{}>,
<2*x^6-x^5+3*x^4+2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5+x^3+3*x^2-2,{2}>,
<-2*x^6+3*x^5+2*x^3+3*x^2-2*x-2,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-3*x-2,{}>,
<2*x^6-2*x^5-3*x^4+x^3+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^3+3*x^2-3*x-1,{0,2}>,
<-2*x^6+3*x^5+3*x^4+x^3+3*x+2,{2}>,
<2*x^6-x^5-3*x^4-x^3-3*x-2,{}>,
<-x^6-3*x^5-2*x^4-x^3-3*x-2,{2,41}>,
<2*x^6-3*x^5-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5+x^3+2*x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-3*x-2,{2}>,
<-2*x^6-3*x^5-x^3-x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+x^3-x^2+2*x-1,{2}>,
<2*x^6+2*x^5-x^4+x^3+3*x-2,{}>,
<2*x^6-3*x^5-x^3+x^2-2*x-2,{}>,
<2*x^6-3*x^5-x^3+2*x^2+2,{2}>,
<-x^6+2*x^4+x^3+3*x+2,{}>,
<2*x^6-3*x^5-x^3+x^2-x-2,{2}>,
<-2*x^6+3*x^5+x^3-2*x^2+2,{2}>,
<-2*x^6-3*x^5-x^3-x^2-2,{2}>,
<-2*x^6+2*x^4-x^3-3*x+2,{2}>,
<-x^6+x^4-x^3-3*x+2,{2}>,
<-2*x^6+x^4-x^3-3*x+2,{2}>,
<2*x^6+3*x^5+x^3+x^2-2*x-2,{2}>,
<-2*x^6-3*x^5-x^3-3*x-2,{2}>,
<2*x^6-x^4-x^3-3*x-2,{2}>,
<-2*x^6-3*x^5-x^3-2*x-2,{2}>,
<2*x^6-x^5-x^3-3*x-2,{}>,
<2*x^6-3*x^5-x^3-2*x+2,{2}>,
<-2*x^6+x^5+x^3+3*x+2,{}>,
<-2*x^6+x^5-x^3-3*x-2,{2}>,
<-2*x^6+3*x^5+x^3+2*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3+3*x+2,{2}>,
<-2*x^6-3*x^5-x^3-2*x+2,{2}>,
<2*x^6+2*x^5-x^3-3*x+2,{2,3}>,
<-2*x^6+3*x^5+2*x^3-x^2+3*x+2,{2}>,
<-x^6+2*x^5-x^3-3*x-2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3-3*x-2,{2}>,
<-x^6+2*x^5-x^3-3*x+2,{2}>,
<-2*x^6-2*x^5-x^3-3*x+2,{2}>,
<2*x^6-2*x^5+x^3+3*x-2,{}>,
<2*x^6+2*x^5+x^4+2*x^3+3*x+2,{2}>,
<2*x^6-3*x^5-x^3+2*x-2,{}>,
<-x^6-x^5-x^3-3*x-2,{2}>,
<-2*x^6+3*x^5+x^3+x^2+3*x-1,{2}>,
<2*x^6+3*x^5+x^3-x^2+3*x-1,{}>,
<-x^6+x^4+2*x^3+3*x+2,{2}>,
<2*x^6-3*x^5-x^3-x-1,{2,3}>,
<-x^6-x^5+x^4+2*x^3+3*x+2,{2}>,
<-2*x^6+3*x^5+x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4-x^3-3*x-2,{2}>,
<-x^6-2*x^5-x^4+x^3+3*x+2,{2}>,
<2*x^6-3*x^5-x^3-2*x^2+2,{2,59}>,
<-2*x^6-3*x^5-x^3+2*x^2-1,{2}>,
<-x^6-2*x^4-x^3-3*x+2,{2}>,
<2*x^6-2*x^5+x^4+x^3+3*x-2,{2}>,
<-2*x^6+3*x^5+x^3+x^2-3*x-1,{0}>,
<2*x^6+3*x^5+x^3-2*x^2-2,{2}>,
<-2*x^6-3*x^5-x^3+2*x^2+x-1,{2}>,
<-2*x^6+3*x^5+x^3+2*x^2+2*x-1,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+3*x-2,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-3*x-2,{2}>,
<-x^6-3*x^5+3*x^4-x^3-3*x-2,{}>,
<-2*x^6+3*x^5+x^3+2*x^2+x-2,{2}>,
<-2*x^6+x^5+x^4+x^3+3*x-2,{2}>,
<2*x^6+3*x^5+x^3-x^2+x+2,{2}>,
<-x^6+x^5+x^4+x^3+3*x-2,{2}>,
<-x^6-x^5-x^4-x^3-3*x+2,{2}>,
<-2*x^6-3*x^5-x^3+x^2-x+2,{2}>,
<-2*x^6-3*x^5-x^3+2*x^2-x+2,{2}>,
<-2*x^6-3*x^5-x^3+x^2-1,{2}>,
<2*x^6+x^4-x^3-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x-2,{2}>,
<-2*x^6-x^4-x^3-3*x+2,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5+x^3-2*x^2+x-2,{2}>,
<2*x^6+3*x^5+x^3-x^2-x-2,{2}>,
<2*x^6+3*x^5+x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-x-1,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2-2,{2}>,
<-2*x^6+3*x^5+x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^5-x^3+3*x^2+x-2,{2}>,
<-2*x^6+2*x^4+x^3+3*x-2,{2}>,
<2*x^6-3*x^5-x^3-3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+x^3+3*x-2,{0}>,
<-2*x^6+2*x^5-3*x^4-x^3-3*x+2,{2}>,
<-x^6-x^5+2*x^4-3*x+2,{}>,
<-2*x^6-3*x^5-3*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^3+3*x-1,{2}>,
<2*x^6-3*x^5+3*x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+3*x^3+2*x-1,{2}>,
<-2*x^6-3*x^5-3*x^3+3*x^2+3*x-1,{0,2}>,
<2*x^6-x^5-2*x^4-3*x-2,{2}>,
<-2*x^6-3*x^5-3*x^3-2*x+2,{}>,
<-x^6-2*x^5+3*x^4-2*x^3-3*x+2,{}>,
<-2*x^6+3*x^5-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5+x^2-x-1,{2}>,
<-2*x^6-2*x^5-3*x^3-3*x+2,{}>,
<2*x^6+3*x^5+2*x^2-2,{2,3}>,
<2*x^6-2*x^5+2*x^4+3*x+2,{}>,
<2*x^6-x^4+3*x-2,{2}>,
<2*x^6+x^5+x^4-3*x+2,{2}>,
<-2*x^6-x^5-3*x^3-3*x-2,{2}>,
<-x^6-3*x^5-x^4+3*x-2,{2}>,
<2*x^6+3*x^5-x-2,{2}>,
<-x^6-3*x^5+3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x-2,{}>,
<2*x^6-2*x^5-x^4-3*x+2,{}>,
<-x^6-2*x^5+x^4-3*x-2,{}>,
<2*x^6-3*x^5-3*x^3-x+2,{2}>,
<2*x^6+3*x^5-x^2+2*x-1,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5-x^2-1,{2}>,
<2*x^6-2*x^5+x^4-3*x-2,{2}>,
<-2*x^6-x^4+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x+2,{2}>,
<2*x^6-3*x^5-x^2-x+2,{}>,
<2*x^6-x^5-3*x^4-2*x^3-3*x-2,{2}>,
<2*x^6+3*x^5-x^2-x-1,{2}>,
<-x^6-x^5+x^4-3*x-2,{2}>,
<-2*x^6+3*x^5+x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^2+2*x-1,{2}>,
<-2*x^6-x^5-x^4-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-x^4+3*x-2,{2}>,
<-x^6+x^5-2*x^4+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^2-3*x-2,{2,5}>,
<-2*x^6+3*x^4-2*x^3-3*x+2,{2}>,
<-2*x^6+x^5-2*x^4+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^2+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x+2,{2}>,
<-x^6-2*x^5+3*x^4-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^3+3*x^2+x+2,{2}>,
<-x^6+2*x^5-3*x^4+3*x+2,{2,3}>,
<2*x^6-2*x^5+3*x^4-3*x-2,{}>,
<2*x^6-3*x^5-3*x^2-2*x-2,{}>,
<2*x^6-3*x^5-3*x^2-x+2,{2}>,
<2*x^6-3*x^5+x^2-3*x-2,{2}>,
<-x^6-x^5-3*x^4-3*x+2,{2}>,
<2*x^6+3*x^5+2*x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5+x^4-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^2-x+2,{2}>,
<2*x^6-3*x^5+x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+3*x^2-2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^2-1,{2}>,
<2*x^6-x^5-2*x^4-x^3+3*x-2,{2}>,
<2*x^6-x^5-3*x^4+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x+2,{2}>,
<-x^6-x^5+3*x^4+3*x-2,{0,2}>,
<2*x^6+2*x^5-2*x^4+x^3-3*x-2,{2}>,
<2*x^6-3*x^4-x^3+3*x-2,{2}>,
<-2*x^6-x^5-3*x^4+3*x+2,{2}>,
<2*x^6-3*x^5+x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^5-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5-x^4+x^3-3*x-2,{2}>,
<2*x^6+3*x^5-x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5-x^4+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-x^3+x^2+2*x-2,{2}>,
<-2*x^6+x^4-x^3+3*x+2,{2}>,
<-2*x^6+3*x^5-x^3-x^2-2*x+2,{2}>,
<-x^6+3*x^5-x^3+3*x-2,{2}>,
<2*x^6-3*x^5+x^4+3*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+3*x-2,{2}>,
<-2*x^6+3*x^5-x^3+2,{2}>,
<2*x^6-3*x^5+x^3-3*x-2,{}>,
<2*x^6+3*x^5-x^3-2,{2}>,
<2*x^6+x^5+x^3-3*x+2,{2}>,
<2*x^6+3*x^5-x^3-x^2+x-2,{2}>,
<-x^6-x^4-x^3+3*x+2,{2}>,
<-2*x^6-3*x^5+x^3+x^2-3*x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x+2,{2}>,
<2*x^6+3*x^5-x^3-x^2-2*x-2,{2}>,
<2*x^6-3*x^5+x^3-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^3+x^2+3*x-2,{2}>,
<-x^6-3*x^5+x^4+x^3-3*x-2,{}>,
<-x^6+3*x^5+x^4+x^3-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x+2,{2}>,
<2*x^6+3*x^5-x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x-2,{2}>,
<2*x^6-3*x^5+x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4-x^3+3*x-2,{2}>,
<-2*x^6-3*x^5+x^3+2*x^2-x-1,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3-3*x-2,{2}>,
<-2*x^6-2*x^5-x^4+x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+x^3+2*x^2-2*x-2,{2}>,
<-x^6-x^5-x^4+x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+x^3+2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5+x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3-3*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x-2,{2}>,
<2*x^6+3*x^5-x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4-x^3+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^3+3*x^2-3*x-2,{2}>,
<-x^6+x^5+3*x^4-x^3+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^4+2*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5-x^3+3*x^2-1,{0,2}>,
<2*x^6-3*x^5+2*x^3+3*x^2+x-2,{2}>,
<2*x^6+3*x^5-x^3-3*x^2-2,{2}>,
<-x^6-x^5-3*x^4-x^3+3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3+3*x+2,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3-3*x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3+3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^3-3*x^2-3*x+2,{2,3}>,
<-x^6+2*x^5-3*x^4+x^3-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^3+2*x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3-3*x+2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3+3*x-2,{2}>,
<2*x^6-3*x^5+2*x^3+x^2-x+2,{2}>,
<2*x^6-3*x^5+2*x^3+x^2-x-2,{2}>,
<-2*x^6-3*x^5+2*x^3-x^2+x+2,{2}>,
<-x^6-3*x^5-x^4-2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^3+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^3+3*x+2,{2}>,
<2*x^6+x^5-2*x^3+3*x+2,{2}>,
<-x^6+x^5-2*x^3+3*x+2,{2,3,23}>,
<2*x^6-x^5+2*x^3-3*x-2,{2}>,
<-2*x^6+x^5-2*x^3+3*x+2,{2}>,
<2*x^6-3*x^5+2*x^3+2*x+2,{2}>,
<-x^6+2*x^5+2*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^3-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x+2,{}>,
<2*x^6-3*x^5+2*x^3-x^2-2*x-2,{2}>,
<2*x^6-3*x^5+2*x^3-x^2-x-1,{2}>,
<-2*x^6-3*x^5+2*x^3+x^2-x+2,{2}>,
<2*x^6-3*x^5+2*x^3-x^2+x+2,{}>,
<-2*x^6-3*x^5+2*x^3+x^2+x-1,{2}>,
<-2*x^6-3*x^5+2*x^3+x^2+2*x-1,{2,3}>,
<-2*x^6-3*x^5+2*x^3+x^2+3*x-2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+3*x-2,{2}>,
<-2*x^6+3*x^5-2*x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+2*x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-3*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-3*x^4-2*x^3+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^3-3*x^2-x-1,{2}>,
<-2*x^6-3*x^5+2*x^3+3*x^2+x+2,{2,5}>,
<2*x^6+3*x^5-2*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-3*x-2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3+3*x^2+x+2,{2}>,
<-2*x^6-3*x^5+3*x^3-3*x^2+2,{2}>,
<-2*x^6+3*x^4+3*x^3-3*x+2,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-3*x+2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x+2,{}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x+2,{2}>,
<-x^6-2*x^5-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5+2,{}>,
<2*x^6+3*x^5-2,{}>,
<2*x^6-3*x^5+3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^3-2*x^2+x+2,{2}>,
<2*x^6+3*x^5-x-1,{2}>,
<-x^6+2*x^4+3*x^3-3*x+2,{2,3}>,
<2*x^6-x^5+2*x^4-3*x^3+3*x+2,{2}>,
<2*x^6-2*x^4+3*x^3-3*x-2,{}>,
<2*x^6-3*x^5+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3+2*x^2-2,{}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x+2,{2,5}>,
<2*x^6-x^4+3*x^3-3*x-2,{2}>,
<-x^6-2*x^5+3*x^3-3*x+2,{2}>,
<2*x^6-3*x^5+3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^3+2*x+2,{2}>,
<-x^6+3*x^5-x^4+3*x^3-3*x-2,{2}>,
<2*x^6-3*x^5+3*x^3-2*x-2,{2}>,
<-2*x^6+3*x^5-3*x^3-x^2-3*x+2,{2}>,
<2*x^6+x^5+3*x^3-3*x+2,{2}>,
<2*x^6-2*x^5-3*x^3+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^3-2*x-1,{}>,
<-2*x^6-3*x^5-3*x^3-x^2-3*x-1,{2}>,
<2*x^6-3*x^5+3*x^3-3*x-2,{2,7}>,
<2*x^6+3*x^5-3*x^3+2*x+2,{}>,
<-2*x^6-3*x^5+3*x^3+2*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-x^2+2,{2}>,
<-2*x^6-x^4+3*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5-3*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3-3*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-2*x^2-x-2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x-2,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+3*x+2,{2}>,
<-x^6+2*x^4-3*x^3+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^4+3*x^3-3*x+2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x-2,{2}>,
<-2*x^6+3*x^5-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2+2*x-1,{}>,
<-2*x^6+3*x^5+x^4+3*x^3-3*x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-x^6+x^5-3*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+3*x^2-3*x-2,{0,2}>,
<-2*x^6-x^5-3*x^4+3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-2*x^2+3*x-1,{2,13}>,
<-x^6+2*x^5+3*x^4+2*x^3+3*x-2,{2,7}>,
<-x^6-2*x^5-3*x^4-2*x^3-3*x+2,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5-2*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+x^2-3*x-2,{2,11}>,
<2*x^6+3*x^5-x^4+3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5-2*x^3+2*x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3-2*x^2-1,{2,7}>,
<-x^6+x^5+2*x^4+2*x^3-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+3*x^2+2*x+2,{2,5}>,
<2*x^6-2*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-3*x-2,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+x^2-3*x-2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+3*x+2,{2}>,
<-2*x^6+2*x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3-x^2-3*x+2,{2}>,
<-x^6-x^4-3*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+x^2-1,{2}>,
<-2*x^6+x^4-3*x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^5-3*x^3+x^2-3*x-2,{2}>,
<2*x^6-2*x^5-3*x^3-x^2-3*x+2,{2}>,
<-x^6-2*x^5-3*x^3+x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^3-x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^3-x^2-3*x+2,{2,3}>,
<2*x^6-3*x^5-x^4-3*x^3-x-1,{2}>,
<2*x^6+x^5+3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+x^5+3*x^3-x^2+3*x+2,{2}>,
<-2*x^6-x^5-2*x^4-x^3+3*x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-3*x-2,{2}>,
<-2*x^6-3*x^5+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+3*x+2,{2}>,
<-2*x^6+3*x^5-x^3+3*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-2*x-2,{2}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+x^2+3*x-2,{2,23}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<-x^6-2*x^5-x^4-3*x^3-x^2-3*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-x^2-2*x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<-x^6+x^5-x^4+3*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-x^2+x-2,{2}>,
<2*x^6+x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-x^2-x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-3*x-2,{2}>,
<-x^6-2*x^5+2*x^4+x^3-3*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+3*x-2,{2}>,
<2*x^6-3*x^5+x^3+2*x^2-2*x-2,{2}>,
<-x^6-2*x^5-x^4+3*x^3-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4-x^3+3*x+2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3+2*x^2-2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+x^2+3*x-2,{2}>,
<-2*x^6-2*x^4-3*x^3-x^2-3*x+2,{2,3}>,
<-x^6+x^5+2*x^4-3*x^3+x^2-3*x-2,{}>,
<-2*x^6+x^5-2*x^4-3*x^3-x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+x^2+3*x-2,{}>,
<-2*x^6-x^5-3*x^4-3*x^3-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+3*x^2-2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^4-3*x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-3*x^2-1,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-3*x^2+x-1,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+x^2-3*x-2,{0,2}>,
<-2*x^6+3*x^5+x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-3*x^2+2,{2}>,
<-2*x^6-3*x^4+3*x^3-x^2+3*x+2,{2}>,
<-2*x^6+3*x^4-2*x^3-x^2-3*x+2,{2}>,
<-x^6-x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4+3*x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+3*x^2+x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-2*x^2+x-1,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x^2-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x^2+x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-x^2-3*x+2,{2,3}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^5-2*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x^2-x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-x^2-2*x+2,{2}>,
<-x^6-2*x^5-2*x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3+x^2+3*x-2,{2}>,
<-2*x^6+x^5-x^4+2*x^3+x^2+3*x-2,{2}>,
<-x^6-x^4+2*x^3+x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+x^2-1,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3-x^2-3*x-1,{2}>,
<2*x^6-x^4-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+x^2-2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+3*x-1,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3-2*x+2,{}>,
<2*x^6+3*x^5-x^4+2*x^3+3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^3-x^2+3*x+2,{}>,
<2*x^6+3*x^5-x^4+2*x^3+x-2,{2}>,
<2*x^6+2*x^5+2*x^3-x^2+3*x+2,{2}>,
<-2*x^6+2*x^3+x^2+3*x-2,{2}>,
<-x^6+2*x^5+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3+2,{2}>,
<-x^6+2*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3+2*x-1,{2}>,
<-x^6+2*x^3-x^2+3*x+2,{}>,
<-x^6-3*x^5+2*x^3-x^2+3*x+2,{0,2}>,
<2*x^6-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-x^5+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-x^2-3*x+2,{2}>,
<-x^6+2*x^5-2*x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-x^2+x-1,{2}>,
<-2*x^6+x^5-x^4-2*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+x^2-2*x-1,{2}>,
<2*x^6-2*x^5+x^4+2*x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3-x^2-3*x+2,{}>,
<-2*x^6-3*x^5+x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3+x^2+3*x-2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+x^2-3*x-2,{2,23}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6-2*x^4-2*x^3-x^2-3*x+2,{2}>,
<-x^6+2*x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-2*x^2-x-1,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+2*x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^3-3*x^2+x-1,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3+3*x+2,{2}>,
<-x^6-3*x^4-3*x^3+3*x+2,{2}>,
<2*x^6+3*x^4+3*x^3-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^3-3*x^2-2,{2}>,
<-x^6+x^5-3*x^4+3*x^3-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+3*x^2+x-1,{2,5}>,
<-x^6-3*x^5-3*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-3*x^2-x-1,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^4+2*x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-x^2-3*x+2,{}>,
<-x^6-2*x^5-3*x^4-2*x^3+x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3-x^2+3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+x^2-3*x-2,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3-x^2+3*x+2,{2,5}>,
<2*x^6+3*x^5-x^4+x^3+3*x^2+3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-3*x^2-x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3+3*x^2+x-1,{2}>,
<2*x^6-3*x^5-x^4-x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-3*x^2-1,{2}>,
<-x^6+3*x^4+x^3-x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+x^3-3*x^2+2,{}>,
<2*x^6+3*x^5-x^4+x^3+3*x^2-2,{}>,
<-2*x^6+x^5+3*x^4-x^3-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3+x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3-x^2+3*x+2,{2}>,
<-x^6+x^5+x^4+2*x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^3+x^2-x+2,{2}>,
<-2*x^6+3*x^5+x^4+2*x^3+x^2+2,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-x^2-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-2*x^2+x+2,{2}>,
<-2*x^6+3*x^5+x^4+x^3-2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-x^3+x^2-3*x-2,{2}>,
<-x^6-2*x^5+x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-x^3+x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-x^2-x-1,{2}>,
<-2*x^6+3*x^5+x^4+x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-x^2+2*x-2,{2}>,
<2*x^6-x^5-x^4-x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3+x^2-2*x+2,{2}>,
<2*x^6+3*x^5-x^4+x^3+x^2-1,{}>,
<-2*x^6-3*x^5+x^4-x^3-x^2+2*x-1,{2}>,
<2*x^6+3*x^5-x^4+x^3+x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-3*x-1,{2}>,
<-2*x^6-3*x^5+x^4-x^3-x^2+x-2,{2}>,
<-x^6-3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+x^3-x^2+3*x+2,{}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+x^2+3*x-2,{2,3}>,
<-2*x^6-2*x^5-x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-x-1,{2}>,
<2*x^6-3*x^5-x^4-2*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^3-x-1,{2}>,
<2*x^6-3*x^5-x^4-x^3-2*x-1,{2}>,
<2*x^6+3*x^5-x^4+x^3+2,{2}>,
<2*x^6-2*x^5-x^3+x^2-3*x-2,{}>,
<-2*x^6-3*x^5+x^4-x^3-1,{2}>,
<-x^6-3*x^5+x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^3-2,{2}>,
<2*x^6-3*x^5-x^4-x^3-x^2-3*x-1,{2}>,
<-2*x^6+3*x^5+x^4+x^3+x^2+2*x-1,{2}>,
<-2*x^6+x^5-x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-1,{2}>,
<-2*x^6-x^5+x^4-x^3+x^2-3*x-2,{2}>,
<-2*x^6+x^4-x^3+x^2-3*x-2,{}>,
<-2*x^6-3*x^3-x^2-3*x+2,{2}>,
<2*x^6-x^4+x^3-x^2+3*x+2,{}>,
<-2*x^6+3*x^5+x^4+x^3-2*x-2,{2}>,
<2*x^6+x^5-3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-x-1,{2}>,
<-x^6+x^4-x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x-1,{2}>,
<-x^6-x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+x-1,{2}>,
<2*x^6+x^4+x^3+x^2+3*x-2,{}>,
<-2*x^6-x^4-x^3-x^2-3*x+2,{}>,
<2*x^6+2*x^5-3*x^3-x^2-3*x+2,{2}>,
<2*x^6+2*x^5-x^3+x^2-3*x-2,{2}>,
<-x^6+x^5+x^4-x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+x^4+x^3+x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^4-x^3+2*x^2-2,{2}>,
<-2*x^6+3*x^5+x^4+x^3+x^2-3*x-2,{2}>,
<2*x^6-2*x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+x^3-2*x^2-1,{2}>,
<-2*x^6+3*x^5+x^4+x^3+2*x^2+3*x-1,{2,5}>,
<2*x^6+2*x^4-x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+x^4-x^3+2*x^2+x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+x^2+3*x-2,{2}>,
<-x^6+x^5+2*x^4-x^3+x^2-3*x-2,{2}>,
<-x^6-2*x^5+2*x^4+2*x^3+x^2+3*x-2,{0,2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+x^2-3*x-2,{}>,
<-x^6+2*x^5+2*x^4+x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-x^2-3*x+2,{}>,
<-2*x^6+3*x^5+x^4+2*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+x^2-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3+x^2+3*x-1,{0,2}>,
<-2*x^6-2*x^5-2*x^4+x^3-x^2+3*x+2,{2,311}>,
<2*x^6-3*x^5-x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-x^2+3*x+2,{2,3}>,
<2*x^6-3*x^5-x^4-x^3-3*x^2-x+2,{}>,
<-x^6+x^5+3*x^4+x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^3-3*x^2+x-1,{2}>,
<2*x^6-3*x^5-x^4-x^3-3*x^2+x-2,{2}>,
<-x^6+2*x^5-3*x^4-x^3-x^2-3*x+2,{}>,
<2*x^6-2*x^5+3*x^4+x^3+x^2+3*x-2,{2}>,
<-2*x^6-x^5+3*x^4-x^2-3*x+2,{2,11}>,
<2*x^6-3*x^5-x^4-x^3-3*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-x^4+3*x^2-2,{2}>,
<2*x^6+2*x^5+3*x^4-x^2-3*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+3*x^2+x+2,{2}>,
<-2*x^6-3*x^5+x^4-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-x^4+2*x^2-x-2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+x^2+3*x-2,{2}>,
<-x^6-2*x^4+x^2+3*x-2,{2,5}>,
<2*x^6-x^5-3*x^4+x^2-3*x-2,{2,11}>,
<2*x^6-3*x^5-x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+x^4-x^2-2,{2}>,
<2*x^6-x^4+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^2-2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6-x^5-x^4+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^2+x+2,{2}>,
<-2*x^6+3*x^5+x^4+3*x^3-2*x-1,{2,367}>,
<-2*x^6+3*x^5+x^4+3*x^3-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-x^2-3*x-1,{2}>,
<-x^6+x^5+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6+3*x^5+x^4+x+2,{2}>,
<-2*x^6+3*x^5+x^4+2*x-2,{2,7}>,
<-2*x^6-x^5-x^2-3*x+2,{2}>,
<-x^6-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4-3*x^3-x^2-2,{2}>,
<-x^6-2*x^5+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-2*x+2,{2}>,
<2*x^6-3*x^5-x^4-3*x^3+x^2+2,{2}>,
<-2*x^6-2*x^5+x^4+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4-x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4-x^2+3*x+2,{2,5}>,
<2*x^6+2*x^5+x^4+x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3-x^2+3*x+2,{2,17,79}>,
<-2*x^6+3*x^5+x^4+x^2-3*x-2,{0,2}>,
<-2*x^6+3*x^5+x^4+x^2-3*x-1,{}>,
<2*x^6-3*x^5-x^4-x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+x^2-x-2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^2-2*x-1,{2}>,
<2*x^6+3*x^5-x^4+x^3-2*x^2+x-1,{2}>,
<-2*x^6-3*x^5+x^4+2*x^2-x-2,{}>,
<2*x^6-x^5-x^4-x^2-3*x+2,{2}>,
<2*x^6+x^5+2*x^4+x^2+3*x-2,{2}>,
<-x^6+3*x^5-2*x^4-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+x^2-x-1,{2}>,
<-x^6-3*x^5-3*x^4-x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^2+3*x-2,{2}>,
<-x^6+x^4+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-x^2-3*x+2,{}>,
<-x^6+2*x^4+x^2+3*x-2,{2,3}>,
<2*x^6+3*x^5-x^4-3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+x^4+2*x^2-x-1,{0}>,
<-2*x^6-3*x^5+x^4+3*x^2-x-1,{2}>,
<-2*x^6+3*x^5+x^4+x^2+2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^2-2,{2}>,
<2*x^6-3*x^4-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+x^2+2*x-2,{2}>,
<-x^6+x^5+3*x^4+x^2-3*x-2,{}>,
<2*x^6-3*x^5-x^4-3*x^2-2,{2}>,
<2*x^6+3*x^5-x^4-3*x^2-x-1,{2}>,
<2*x^6-x^5+3*x^4+x^2+3*x-2,{2}>,
<-x^6+2*x^5-3*x^4-x^2-3*x+2,{2}>,
<-2*x^6+x^5+3*x^4+x^2-3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2-2*x+2,{2}>,
<-x^6-2*x^5+3*x^4-x^3-x^2+3*x+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-x^2+3*x+2,{2,7}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+3*x^2+2*x-1,{}>,
<2*x^6+3*x^5-x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3+2*x^2-2,{2}>,
<-2*x^6-3*x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<-x^6-3*x^5+x^4+x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-x^3-2*x^2+x+2,{2}>,
<-x^6-2*x^5+x^4+x^3-x^2-3*x+2,{2}>,
<-2*x^6+x^5+x^4-x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3+x^2-1,{2}>,
<2*x^6+2*x^4+x^3-x^2-3*x+2,{2}>,
<2*x^6-x^4-x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+x^3-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+x^3+x^2-2,{2}>,
<2*x^6-3*x^5-x^4+x^3-3*x-1,{2}>,
<2*x^6+2*x^5-x^3+x^2+3*x-2,{2}>,
<2*x^6+x^5+x^4+x^3-x^2-3*x+2,{}>,
<2*x^6-3*x^5-x^4+x^3-2*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3-x-1,{2,3}>,
<-x^6-3*x^5-x^4-x^3+x^2+3*x-2,{2}>,
<-2*x^6-x^5+x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4+x^3+2*x-2,{2}>,
<-2*x^6-x^3+x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+x^4-x^3+x^2+3*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6-3*x^5-x^4+x^3-1,{2}>,
<2*x^6+3*x^5-x^4-x^3-x^2+2*x-1,{2}>,
<2*x^6+x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^3-x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-x^4-x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3-x^2-3*x+2,{2}>,
<2*x^6-x^5+x^4+x^3+x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4+x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5+x^4+x^3+x^2+x-2,{2}>,
<-2*x^6-x^5+2*x^4+x^3+x^2-3*x-2,{2}>,
<-2*x^6-x^5-x^4-x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5-x^4+x^3-2*x^2+2,{2}>,
<-x^6+2*x^4+x^3+x^2-3*x-2,{2}>,
<-x^6+2*x^5+x^4+x^3+x^2-3*x-2,{0,2}>,
<2*x^6+3*x^5-x^4+x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^4-x^3-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+x^3+2*x^2+2*x-2,{0,2,7,11}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2-2*x-1,{2}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2-x-1,{2}>,
<-2*x^6-3*x^5+x^4+x^3+2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3-2*x^2-2*x-2,{2}>,
<-x^6-3*x^4+x^3-x^2-3*x+2,{}>,
<-2*x^6-3*x^5+x^4+x^3+3*x^2+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3+x^2+3*x-2,{2}>,
<-x^6+3*x^5-3*x^4-x^3-x^2+3*x+2,{2,19}>,
<-2*x^6+3*x^5+x^4-x^3+3*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-x^4+x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-x^5-3*x^4+x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-x^3+3*x^2-2,{2}>,
<-2*x^6-2*x^5+3*x^4+2*x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^4-2*x^3+x^2+3*x-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-x^2+3*x+2,{2,3}>,
<2*x^6-3*x^5-x^4+2*x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+x^2-3*x-2,{}>,
<2*x^6+3*x^5-x^4-x^3-3*x^2+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x^2+x+2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-x^2+3*x+2,{}>,
<2*x^6+2*x^5-3*x^4+2*x^3+x^2-3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3-2*x^2-3*x+2,{2}>,
<-x^6+2*x^5-x^4+2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x-1,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+2*x-2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-x^2+2*x+2,{2,59}>,
<2*x^6+3*x^5-x^4-2*x^3+x-1,{2}>,
<2*x^6+x^5-2*x^3+x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-2*x-1,{2}>,
<-x^6-3*x^5-2*x^3-x^2+3*x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+x^2+3*x-2,{}>,
<-x^6-2*x^5+x^4+2*x^3+x^2-3*x-2,{2,5,83}>,
<2*x^6+3*x^5-x^4-2*x^3+x^2+2*x-2,{2,5,59}>,
<-x^6-x^5+x^4+2*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3-x^2+x+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3+x^2+2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-2*x^2-3*x+2,{}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4+2*x^3+x^2-3*x-2,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3+x^2+3*x-2,{2,7,43}>,
<2*x^6-3*x^5-x^4+2*x^3-2*x^2-x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-2*x^2-x-2,{2}>,
<-x^6-2*x^4-2*x^3-x^2+3*x+2,{}>,
<-2*x^6-2*x^4+2*x^3-x^2-3*x+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+x^2+3*x-2,{0,2}>,
<2*x^6+x^5+2*x^4+2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2-x-1,{0,2}>,
<-x^6+x^5-3*x^4-2*x^3-x^2+3*x+2,{}>,
<-2*x^6+3*x^5+x^4-2*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2-1,{2}>,
<2*x^6+3*x^4+2*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2+x-1,{2}>,
<2*x^6-3*x^5-x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+x^4-2*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+x^5+3*x^4+3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5+3*x^2+x-1,{2}>,
<-2*x^6+3*x^5-3*x^2-x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5+3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3-3*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4-3*x+2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3+3*x^2+3*x-1,{0}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-x^2+3*x+2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x-2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+x^2+3*x-2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-x^2-3*x+2,{2,59}>,
<2*x^6+3*x^5+2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-x^4-x^3-3*x^2-2*x-1,{2}>,
<2*x^6-3*x^5-x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+3*x^2-2,{2}>,
<-2*x^6-3*x^5-2*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-x^4-x^3-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4-x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3-3*x^2+x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3-2*x^2+2,{2}>,
<-x^6-3*x^5-x^4+x^2-3*x-2,{2,3}>,
<2*x^6-3*x^5-x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-x^6-x^5-3*x^3+x^2+3*x-2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3-2*x^2+3*x+2,{2,29}>,
<-x^6+3*x^5+x^4-x^2+3*x+2,{}>,
<2*x^6-2*x^5-x^4+3*x^3+x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^3+x^2-3*x-2,{2,41}>,
<2*x^6-2*x^5-3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4+x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3-x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-x^2+2*x-1,{2}>,
<2*x^6+3*x^5-x^4-3*x^3-x^2+x-2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+x^2-3*x-2,{2,7}>,
<-2*x^6+3*x^5+x^4-3*x^3+x^2-1,{2}>,
<-2*x^6+3*x^5+x^4-x^2+2*x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3+2*x^2+2*x+2,{}>,
<2*x^6+x^4+3*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4+x^2-2*x-2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3-x^2-2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-x^2-3*x+2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3+x^2-3*x-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+x^4+3*x^3+2*x^2+3*x-1,{2,3}>,
<-2*x^6-x^5-3*x^4+3*x^3-x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+x^2+3*x-2,{}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2+3*x+2,{}>,
<2*x^6+3*x^5-x^4-3*x^3-3*x^2-1,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6-3*x^4-3*x^3-x^2+3*x+2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x^2-3*x-2,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-3*x^2+x-2,{2}>,
<2*x^6+3*x^5-x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-3*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^4+3*x^3+2*x^2+3*x-2,{}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2-2,{}>,
<2*x^6-2*x^5+3*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+3*x^2-x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+2*x^2+x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-2*x^2-2,{}>,
<2*x^6+2*x^4-3*x^3-2*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-2*x^2-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-2*x^2+x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2+x-1,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+2*x^2+2*x-1,{2,11}>,
<-2*x^6+3*x^5+2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2+2*x-2,{2,11}>,
<2*x^6-3*x^5-2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2+2*x-1,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+x^5+x^4+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2+x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2-x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3-x^2-x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3+x^2+x-1,{2,3}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3+x^2-2*x+2,{2}>,
<-x^6-2*x^5-x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-x^2+2*x+2,{}>,
<-2*x^6+2*x^5+x^4-3*x^3-2*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+2*x^4-3*x^3-3*x-1,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+2*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x-1,{}>,
<2*x^6-2*x^5-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6-x^5-3*x^3+2*x^2-3*x-2,{2}>,
<-x^6-x^5-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x-2,{2}>,
<-x^6-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+x^5-3*x^3-2*x^2-3*x+2,{}>,
<2*x^6+x^5-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<-x^6-2*x^5+3*x^3+2*x^2+3*x-2,{2}>,
<-x^6+2*x^5-3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+3*x^3-2*x^2+3*x+2,{2}>,
<-x^6-3*x^5+3*x^3+2*x^2+3*x-2,{0,2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x^2-3*x-1,{}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+x^2+2*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x^2-2*x-1,{2,5}>,
<2*x^6-2*x^5+x^4-3*x^3+2*x^2-3*x-2,{}>,
<-x^6-2*x^5+3*x^3-x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x^2-2*x-2,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^3+x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2-x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+x^2+2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x^2+2*x+2,{2}>,
<-x^6-x^5+x^4-3*x^3+2*x^2-3*x-2,{2,41}>,
<2*x^6+2*x^5+x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+x^2+3*x-1,{}>,
<-2*x^6-3*x^5+x^4+3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+2*x^3-3*x^2-3*x-1,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x^2-1,{2,3}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-2*x^2-3*x+2,{2}>,
<-x^6+x^5-3*x^4+3*x^3-2*x^2+3*x+2,{}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+2*x^2+x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+3*x^2-x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x^2+x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2+x-2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-2*x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+2*x^2-3*x-2,{0,2}>,
<-x^6+3*x^4+3*x^3+2*x^2+3*x-2,{2,3}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+2*x^2-3*x-2,{2,3}>,
<2*x^6+3*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+2*x^2-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{2,3}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+2*x^2-3*x-2,{0}>,
<2*x^6-3*x^5-2*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^3+3*x^2-x-1,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+3*x^2+x-1,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-x^6-2*x^5-3*x^4+2*x^3+2*x^2+3*x-2,{2,7}>,
<2*x^6-2*x^5-3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<-x^6+2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-2*x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+2*x^2-3*x-2,{2,5}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-2*x^2+x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-x^5-x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+x^5+x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-x^2-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+x^2-2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+x^2+2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+x^2-3*x-1,{0,2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+3*x-1,{2}>,
<-x^6-3*x^5-2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x-1,{}>,
<2*x^6+3*x^5-2*x^4+2*x^3+2*x-2,{2}>,
<-2*x^6-x^4+2*x^3-x^2-3*x+2,{2}>,
<-x^6+x^5+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-x^5-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^3+2*x^2+3*x-2,{}>,
<2*x^6-2*x^3+2*x^2-3*x-2,{}>,
<2*x^6+3*x^5-2*x^4+2*x^3-2,{}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x+2,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-x^4-x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-x^5+2*x^4-x^3-x^2-3*x+2,{2}>,
<2*x^6+3*x^5-x^4+x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4+x^3+x^2+3*x-2,{2}>,
<-2*x^6+x^5-2*x^4-x^3+x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+x^4-x^3-2*x^2+x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5+x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x^2+x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-x^2+2,{2}>,
<-x^6-x^5+2*x^3+2*x^2+3*x-2,{2,79}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+x^2-1,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x^2-1,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+x-1,{2}>,
<2*x^6+x^5+x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+2*x^2-3*x-2,{0,2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-x^6-x^5-2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2+x+2,{2}>,
<2*x^6+3*x^5-x^4-x-1,{2}>,
<2*x^6-x^5+x^2+3*x-2,{2}>,
<-x^6+2*x^5+x^2-3*x-2,{0}>,
<-x^6-3*x^5+x^2+3*x-2,{2}>,
<-x^6-3*x^5+x^4+x^2-3*x-2,{2}>,
<-x^6+2*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-2*x^2-1,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2-x-1,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2,7}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3+2*x^2-3*x-2,{}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+3*x^4-2*x^3+2*x^2-3*x-2,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+3*x^2-1,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+3*x^2+x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-3*x^2-x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3+3*x^2+2*x-1,{0,2}>,
<2*x^6+3*x^5-2*x^4+x^3+3*x^2-1,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-3*x^2-2*x-2,{2,5,7}>,
<2*x^6-3*x^5-2*x^4-x^3+3*x^2+2*x+2,{2,5}>,
<-2*x^6-3*x^5+2*x^4-x^3-3*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-2*x^4+x^3+3*x^2-2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-3*x^2+3*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3+2*x^2-1,{2}>,
<-2*x^6-x^5-2*x^4+x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+2*x^2-3*x-2,{2,5}>,
<-2*x^6-3*x^5+2*x^4-x^3-2*x^2+2*x-1,{2}>,
<-x^6-3*x^5-2*x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+2*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3+x^2+3*x-1,{2}>,
<-x^6-2*x^5-2*x^4-x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-x^2-x-1,{2}>,
<2*x^6+3*x^5-2*x^4+x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^3+x^2-2,{}>,
<2*x^6-x^4-3*x^3-2*x^2-3*x+2,{}>,
<2*x^6+3*x^5-2*x^4+x^3+x^2+x-1,{2}>,
<-x^6+x^4-3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+x^5-x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6+x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^3-x^2-2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-x^2-1,{2}>,
<-x^6+3*x^5+x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3-x^2+2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-3*x-1,{2,5}>,
<2*x^6+3*x^5-2*x^4+3*x^3-x^2-x+2,{2,5}>,
<-x^6-x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-1,{2}>,
<2*x^6+x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+x^2-3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-x^3-x^2-3*x-1,{}>,
<-2*x^6+2*x^5+x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4-x^3-2*x^2-3*x+2,{}>,
<-2*x^6+2*x^5-x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+x^2-2,{2}>,
<2*x^6-x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3-x^2-1,{2}>,
<2*x^6+x^4+x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+x^2+2*x-1,{0,2}>,
<2*x^6-3*x^5-2*x^4-x^3-x^2+2*x-2,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x^2-3*x+2,{}>,
<2*x^6+3*x^5-2*x^4+x^3-2*x^2+3*x+2,{2,61}>,
<-2*x^6-3*x^5+2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3-2*x^2+2*x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3-2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+2*x^2+x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+2*x^2-1,{2}>,
<-2*x^6-x^5-2*x^4+x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3+2*x^2-2,{}>,
<2*x^6+3*x^5-2*x^4+2*x^3-2*x^2+2,{}>,
<-x^6+2*x^5+2*x^4-x^3+2*x^2-3*x-2,{}>,
<2*x^6-3*x^5-2*x^4-x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-x^2+2*x-1,{}>,
<-2*x^6+2*x^5-2*x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+x^3-2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+2*x^2-3*x-2,{}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+3*x^2+x-2,{2}>,
<-2*x^6-3*x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3-2*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+2*x^4+x^3+3*x^2-x-1,{0,2}>,
<2*x^6-3*x^5-2*x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6+3*x^5-3*x^4-x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+2*x^2-3*x-2,{0,2}>,
<-x^6+3*x^5-3*x^4+2*x^2+3*x-2,{2}>,
<-x^6-3*x^4+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^2+2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4-3*x^2+x-1,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^2+x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^2-3*x-2,{0,2}>,
<2*x^6+3*x^5-2*x^4+2*x^2+2*x-1,{2}>,
<-2*x^6-x^5-3*x^4+2*x^2-3*x-2,{2,11}>,
<2*x^6-x^5-3*x^4+2*x^2-3*x-2,{}>,
<-2*x^6-3*x^5+2*x^4-2*x^2-2*x+2,{2,5}>,
<2*x^6+3*x^5-2*x^4+2*x^2-2,{2,3}>,
<-2*x^6-x^5+3*x^4-2*x^2-3*x+2,{}>,
<-2*x^6+x^5-2*x^4+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^2+x+2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^2+2*x-2,{2,5}>,
<-2*x^6-3*x^4+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^2+x-1,{2}>,
<-2*x^6-2*x^4+2*x^2+3*x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^2+3*x+2,{2}>,
<2*x^6-2*x^4+2*x^2+3*x-2,{2}>,
<-x^6+2*x^5-2*x^4+2*x^2-3*x-2,{2}>,
<2*x^6+x^5+x^4+2*x^3+x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x-2,{2}>,
<-x^6+2*x^5-x^4+2*x^2+3*x-2,{}>,
<-2*x^6-3*x^5+2*x^4+3*x-1,{0,2}>,
<2*x^6+3*x^5-x^4-2*x^3-x^2-x-2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3+x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4+2*x^2-3*x-2,{2}>,
<-x^6+x^4+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-x^2+x-2,{2}>,
<-x^6+2*x^5-x^4-2*x^2-3*x+2,{}>,
<-2*x^6-2*x^5-x^4-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^2+3*x-2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4+2*x^2-3*x-2,{2,5}>,
<2*x^6-3*x^5-2*x^4-2*x^2-2*x+2,{2,3}>,
<-2*x^6-3*x^5+2*x^4+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^2-2,{2,3}>,
<2*x^6-3*x^5-2*x^4-2*x^2-2,{2,7}>,
<-x^6+x^5-2*x^4-2*x^2-3*x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^2+x-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^2+2*x+2,{2,5}>,
<2*x^6-3*x^5-2*x^4-2*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-x^4-2*x^3-x^2-2*x-2,{2,61}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x^2-3*x-2,{}>,
<-2*x^6+2*x^5+3*x^4+2*x^2+3*x-2,{2}>,
<-2*x^6+x^5+3*x^4+2*x^2+3*x-2,{2}>,
<-x^6-x^5+3*x^4+2*x^2-3*x-2,{2}>,
<-2*x^6-x^5-3*x^4-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^2-1,{}>,
<-2*x^6+3*x^5+2*x^4+3*x^2+2,{}>,
<2*x^6-3*x^5-2*x^4-3*x^2-2,{}>,
<-2*x^6+x^5+3*x^4+2*x^2-3*x-2,{0,2}>,
<-x^6+x^5-3*x^4-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4-3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+3*x^2-x+2,{}>,
<2*x^6-3*x^5-2*x^4-3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^2-x-2,{}>,
<-x^6-3*x^5+3*x^4+2*x^2+3*x-2,{0,2}>,
<2*x^6+3*x^5-2*x^4-x^3+3*x^2-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-2*x^4-x^3+2*x^2+3*x-2,{2}>,
<-x^6-3*x^5+3*x^4+x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3+2*x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-2*x^2-1,{2}>,
<-x^6+2*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+2*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-x^2+3*x-1,{2,7}>,
<2*x^6-3*x^5-2*x^4+x^3+x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-2*x^2-3*x+2,{2}>,
<-x^6+2*x^5-2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-3*x^2+x-1,{2}>,
<-2*x^6+3*x^5+2*x^4+2*x^3-2*x+2,{2}>,
<2*x^6-2*x^5+x^4+x^3-2*x^2-3*x+2,{2}>,
<-x^6-2*x^5-x^4+x^3+2*x^2-3*x-2,{2}>,
<2*x^6-2*x^5-x^4+x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-2*x^6-2*x^5+x^4+x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^5-x^4+x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-x^3+2*x^2+3*x-2,{}>,
<2*x^6+x^5-3*x^4-x^3+2*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-x^3-2*x^2+3*x+2,{}>,
<2*x^6-3*x^5-2*x^4+x^3-2*x-1,{2}>,
<2*x^6-2*x^5-x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3-x-1,{2}>,
<-2*x^6-2*x^5-x^3-2*x^2+3*x+2,{2}>,
<2*x^6+x^5-x^3+2*x^2+3*x-2,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-x^5+x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+x^2+2*x-2,{2}>,
<-2*x^6-x^4+x^3+2*x^2-3*x-2,{2,5}>,
<-2*x^6-3*x^5+2*x^4+x^3+x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+x^3-x^2+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+x^2+x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3-x^2-x-1,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+x^2+x-1,{}>,
<-2*x^6-x^5-x^3+2*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2+3*x+2,{}>,
<2*x^6-x^4+x^3-2*x^2-3*x+2,{2}>,
<-x^6+x^4+x^3+2*x^2-3*x-2,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2+3*x-2,{0,2}>,
<2*x^6-3*x^5-2*x^4+x^3+x^2+2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+x^3-x^2-2,{2}>,
<2*x^6-3*x^5-2*x^4+x^3-x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-2*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-2*x^2+3*x-1,{2}>,
<-2*x^6+3*x^4+x^3+2*x^2-3*x-2,{2}>,
<-x^6-3*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4+x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^3+3*x^2-2*x-1,{0,2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-2*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+2*x^2-3*x-2,{}>,
<2*x^6+3*x^5-2*x^4-2*x^3+2*x^2+x-2,{}>,
<2*x^6+3*x^5-2*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-2*x^4-x^3+x^2+x-2,{2}>,
<-x^6+2*x^5+x^4-x^3-2*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+x^2-2,{2}>,
<-2*x^6-x^5-x^4+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6+3*x^5-2*x^4+x^2-x-1,{2}>,
<-x^6-3*x^5-x^4+x^3+2*x^2+3*x-2,{0}>,
<-2*x^6-3*x^5+2*x^4-x^2+2*x-2,{2}>,
<-2*x^6+3*x^5+2*x^4-x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3+3*x-1,{2}>,
<-x^6+2*x^5-2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-2*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-2*x^3-2,{2}>,
<2*x^6+3*x^5-2*x^4+x-1,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-2,{2}>,
<-2*x^6+x^5-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4-2*x^3-3*x^2-x-1,{2,3}>,
<-x^6+x^5+2*x^3+2*x^2-3*x-2,{0,2}>,
<-2*x^6+2*x^5+x^3+2*x^2-3*x-2,{2}>,
<-x^6+2*x^5+x^3+2*x^2-3*x-2,{0,2}>,
<2*x^6+2*x^2+3*x-2,{2,3}>,
<2*x^6+x^5-3*x^4+2*x^3+2*x^2+3*x-2,{2,5}>,
<-2*x^6+x^5-x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-x^6-x^4+2*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-x^2-2,{2}>,
<2*x^6-3*x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-x^2-2*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-2*x^2+x-2,{2}>,
<2*x^6-2*x^5-x^3+2*x^2-3*x-2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x^2-3*x-2,{2,5}>,
<2*x^6-3*x^5-2*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4+2*x^3+2*x^2-3*x-2,{}>,
<-2*x^6+3*x^4+2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x+2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-x^5-x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+3*x^2-2*x-1,{}>,
<2*x^6-x^5+3*x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x^2-2*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+2*x^2+3*x-2,{}>,
<-x^6-2*x^5-3*x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4+x^3+x+2,{2}>,
<-x^6-2*x^5+x^4+2*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+2*x^3-2*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4+2*x^3+2*x^2-3*x-2,{0,2}>,
<2*x^6-3*x^5-2*x^4+2*x^3-2*x^2-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3+2*x^2+3*x-2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3-2*x^2-3*x+2,{}>,
<2*x^6+3*x^5-2*x^4-2*x^3-3*x^2-1,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3+x^2-x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^4+3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3+2*x^2+x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3-x^2-x-1,{2}>,
<2*x^6+3*x^5-2*x^4-2*x^3-3*x^2-2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^3-3*x^2+3*x-1,{2}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2+3*x-2,{0,2}>,
<2*x^6+3*x^5-2*x^4-3*x^3+x^2-2*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-x^2+x-1,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+2*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3+x-2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-x^2-1,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3-x^2+x-1,{}>,
<2*x^6+3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6+x^5-x^4+3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-x^5-3*x^3-2*x^2+3*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-3*x+2,{2,5}>,
<-2*x^6+3*x^5+2*x^4-3*x^3-3*x-1,{2}>,
<-x^6-x^5-2*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+2*x^2-3*x-2,{2,5}>,
<-2*x^6-2*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-x^6-x^5-2*x^4-3*x^3-2*x^2+3*x+2,{2,3}>,
<2*x^6-x^5+2*x^4-3*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+2*x^2+2*x-1,{0,2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2-2*x-2,{0,2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2+3*x-2,{0}>,
<-x^6-3*x^5-3*x^4-3*x^3+3*x^2-3*x-2,{2,7}>,
<2*x^6-3*x^5-3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+3*x^2+x+2,{2,3}>,
<-2*x^6-3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-x^6-3*x^4+3*x^3+3*x^2+3*x-2,{}>,
<2*x^6-3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+3*x^2+x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-3*x^2+x+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+3*x^2+x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+3*x^2+2*x-1,{}>,
<-2*x^6+3*x^5+2*x^4-x^3+2*x^2-1,{0,2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-x^6-2*x^4-x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2-3*x-1,{}>,
<-2*x^6+3*x^5+2*x^4-x^3+2*x^2+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{}>,
<-2*x^6-2*x^4-x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-2*x^4-x^2+2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-2*x^4-3*x^3+3*x^2-3*x-2,{}>,
<-2*x^6+3*x^5+2*x^4+x^2+2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2-2,{}>,
<2*x^6-x^4-2*x^3+2*x^2-3*x-2,{2,7,97}>,
<2*x^6+x^5+x^4-2*x^3-2*x^2-3*x+2,{2}>,
<2*x^6-x^5-x^4+2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+x^2-x-2,{2}>,
<2*x^6+3*x^5-2*x^4+2*x^3+x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-x^2+3*x-1,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+x^2-2*x+2,{2}>,
<-x^6+2*x^5-x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+x^5-x^4-2*x^3+2*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3+x^2-x-1,{2}>,
<2*x^6+x^5-x^4-2*x^3+2*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4+2*x^3-x^2-1,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3+x^2+x+2,{2}>,
<2*x^6-3*x^5-2*x^4+2*x^3+x^2+x-2,{2}>,
<2*x^6+x^5+x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^5+x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4-3*x^3-3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3+2*x^2-2*x-1,{}>,
<-2*x^6+3*x^5+2*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+2*x^4-x^3-2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3+x^2-2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+2*x+2,{}>,
<-2*x^6-2*x^5-3*x^3-3*x^2-3*x+2,{}>,
<2*x^6+3*x^5-2*x^4+x^3+2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x-2,{2}>,
<2*x^6-x^5-3*x^3-3*x^2-3*x+2,{2}>,
<-x^6+3*x^3+3*x^2+3*x-2,{2}>,
<-x^6+x^5+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-2,{2,3,5,7}>,
<2*x^6-3*x^5-3*x^4-3*x^3+x+2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-x-1,{2}>,
<2*x^6-x^5+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2,{}>,
<-2*x^6-2*x^5+x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+3*x^2-3*x-2,{}>,
<2*x^6+3*x^5-3*x^4+3*x^3-x^2+x+2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+x^2+x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-x^4-3*x^3-3*x^2-3*x+2,{}>,
<-x^6+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-x^2-1,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-x^2-2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+x^2-x-2,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-x^6+x^5-2*x^4+3*x^3+3*x^2+3*x-2,{2,11}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+2*x^2-1,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<-x^6+x^5-2*x^4+3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2-3*x-2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+2*x^2-1,{2}>,
<2*x^6+3*x^5-2*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+2*x^2+3*x-2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+2*x^2-x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x-2,{0,2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3+3*x^2+3*x-2,{0,2}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-3*x-2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6+3*x^4-3*x^3+3*x^2-3*x-2,{2,3}>,
<-x^6+3*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x^2+3*x+2,{2,3}>,
<-2*x^6+3*x^5+3*x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-3*x^2-3*x+2,{2,3}>,
<2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-2*x^4-x^2+x-1,{2}>,
<2*x^6+x^5+x^4+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-3*x^2+2*x-2,{2,5}>,
<-2*x^6+x^4+2*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6+3*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-x^6+x^5+3*x^4-2*x^3-3*x^2-3*x+2,{}>,
<-2*x^6-2*x^5-3*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3+2*x^2-x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x^2-x+2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-x^6+x^5+2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2-3*x+2,{0,2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+2*x^2+3*x-1,{0}>,
<-x^6-3*x^5-x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-x^6-3*x^5+x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-x^6+2*x^5+x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-x^2+x-1,{2}>,
<2*x^6+x^5-x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-x^4+2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3+x^2-2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x^2-2,{2}>,
<-x^6-x^5-x^4-3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-x^2+x-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+x^2-x-1,{2}>,
<-x^6-x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-x^5-x^4+2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+x^2-x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3-x^2+2,{2}>,
<-x^6-2*x^5-x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-x^2-2*x+2,{2}>,
<-2*x^6+x^5-x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-1,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2,{2}>,
<-x^6+2*x^5+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3+x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x-2,{2}>,
<-2*x^6-x^5-2*x^3+3*x^2-3*x-2,{2,7}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x-1,{2}>,
<-x^6+2*x^5+x^4+2*x^3+3*x^2+3*x-2,{2,3}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2-2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2+2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2-x+2,{2}>,
<-x^6-x^5-x^4-2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2+x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-x^2+2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2-1,{2}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2+3*x-1,{}>,
<-2*x^6+3*x^5+2*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-x^6-x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-2*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+x^2+x-1,{2}>,
<-2*x^6-2*x^5+x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-x^6+3*x^4+3*x^3+2*x^2-3*x-2,{0,2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2-2*x-2,{2,7,53}>,
<-2*x^6-3*x^5+2*x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-x^2-3*x-1,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^4+3*x^3-2*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-x^6-x^5-3*x^4-3*x^3-2*x^2+3*x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+3*x^2+3*x-2,{}>,
<2*x^6+3*x^5-3*x^4+2*x^3-2*x^2-x+2,{2}>,
<-x^6+x^5+2*x^4+2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+2*x^2-x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+2*x^2+x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-2*x^2+x-2,{2,5}>,
<2*x^6-3*x^5-3*x^4-3*x^3-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-3*x^2-2*x+2,{2}>,
<-x^6-2*x^5-3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3-3*x^2-x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-3*x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-3*x^2+x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+3*x^2+2*x-2,{0,2}>,
<2*x^6-3*x^5-3*x^4-2*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3+3*x^2+x-2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2-2*x-2,{2}>,
<-x^6-2*x^5+x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^3-2*x-2,{2,197}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-3*x^2+3*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-2*x^2+3*x-1,{}>,
<2*x^6-3*x^5-3*x^4-3*x^3-3*x^2+2*x-1,{}>,
<2*x^6+2*x^5+3*x^4+2*x^3-3*x^2+3*x+2,{2,3,307}>,
<2*x^6+3*x^5-3*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-2*x^3-3*x^2-x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+3*x^2+3*x-2,{0,2}>,
<2*x^6-x^5+3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+2*x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+2*x^2+x-1,{2}>,
<-2*x^6+x^5+2*x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6-x^5-3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+3*x^2-3*x-2,{}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2-3*x+2,{0}>,
<2*x^6+3*x^5-3*x^4+x^3+x^2+3*x-1,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-3*x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5-x^3+3*x^2-3*x-2,{2,5}>,
<-x^6-2*x^5-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^3-3*x^2+3*x+2,{2}>,
<2*x^6-x^5-x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-x+2,{2}>,
<-2*x^6-x^5-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^3+3*x^2+3*x-2,{2}>,
<2*x^6-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+x-2,{2,31}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2-x-1,{2}>,
<-x^6-x^5+x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-3*x^2-x-2,{2}>,
<2*x^6+2*x^5-x^3-3*x^2-3*x+2,{2}>,
<-x^6-2*x^5+x^3+3*x^2+3*x-2,{0}>,
<-2*x^6-2*x^5-3*x^4+x^3+3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-x^5-x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-3*x^2+2*x-1,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+3*x^2+2*x-1,{0,2}>,
<2*x^6-x^5+x^4-x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3-x^2+2*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3-x^2+2*x-2,{2}>,
<-x^6+3*x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2+3*x-2,{}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+2*x^2-x-1,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+2*x^2-2,{2}>,
<-2*x^6-2*x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6+2*x^4-2*x^3-3*x^2-3*x+2,{2,5}>,
<-2*x^6-3*x^5+3*x^4-x^3+2*x^2+x-1,{}>,
<2*x^6+3*x^5-3*x^4+x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x^2+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x^2-x+2,{}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6-x^5+3*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^3-2*x^2-x-1,{2,3}>,
<-2*x^6-x^5-3*x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^4+x^3+3*x^2+3*x-2,{}>,
<2*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+3*x^2-1,{0,2}>,
<-x^6-3*x^4+x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+3*x^4+x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+x^5+3*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-x^5-3*x^4+x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-3*x^2-2*x-1,{2,3}>,
<2*x^6-3*x^5-3*x^4+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+3*x^2+2*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^2+2*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^2-2*x-2,{2}>,
<-x^6+x^5+3*x^4-3*x^2+3*x+2,{2}>,
<2*x^6-x^5+2*x^4-3*x^2-3*x+2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^2-1,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^2-2,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^2-2*x-2,{2}>,
<-x^6+2*x^5-2*x^4+3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^2+x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^2-x+2,{2}>,
<-x^6+x^5+x^4-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+x^2+x-2,{2}>,
<-x^6-x^4+3*x^2+3*x-2,{2}>,
<2*x^6-x^4+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^2+3*x-1,{0,2}>,
<-x^6-3*x^5+3*x^2-3*x-2,{2}>,
<2*x^6+x^4-x^3-3*x^2-3*x+2,{2}>,
<-x^6-x^4-x^3+3*x^2-3*x-2,{2}>,
<-x^6+x^4+x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3-x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4-x^3+x^2-2,{2}>,
<-x^6+x^5-x^4-x^3+3*x^2-3*x-2,{2,11,17}>,
<-2*x^6-3*x^5+3*x^4-x^3-x^2+x+2,{2}>,
<-x^6-3*x^5-x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x-1,{2}>,
<2*x^6+x^5-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4+x-1,{2}>,
<2*x^6+3*x^5-3*x^4-x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-2,{2}>,
<-x^6+2*x^5+x^4+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4-1,{2}>,
<-2*x^6-3*x^5+3*x^4+x-1,{2}>,
<-2*x^6-x^5-3*x^2+3*x+2,{2}>,
<-x^6-2*x^5-3*x^2+3*x+2,{2}>,
<-x^6-2*x^5-x^4-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-x^2+3*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4-x^2+2,{2}>,
<-2*x^6-x^4-3*x^2+3*x+2,{2}>,
<2*x^6+x^5-x^4-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^2+x+2,{}>,
<2*x^6+3*x^5-3*x^4-x^2-x-2,{}>,
<-2*x^6+3*x^5+3*x^4+x^2+2*x-2,{}>,
<-x^6-2*x^5-x^4-3*x^2+3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^2+x-2,{2}>,
<2*x^6+3*x^5-3*x^4-x^2-2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^2+x-1,{2}>,
<-2*x^6+3*x^5+3*x^4+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^2+x-2,{2}>,
<-x^6+2*x^5-2*x^4-3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+3*x^4+2*x^2-2*x-1,{2}>,
<2*x^6-3*x^5-3*x^4-2*x^2+2*x-2,{2,5}>,
<-2*x^6+3*x^5+3*x^4+2*x^2+x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^2+3*x-1,{0}>,
<2*x^6+x^5-2*x^4-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^2+x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^2+2*x-2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^2-3*x-2,{2}>,
<-x^6+2*x^4+3*x^2+3*x-2,{0,2,13}>,
<2*x^6-3*x^5-3*x^4-3*x^2-x+2,{2}>,
<-x^6-x^5+3*x^4+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^2+x-1,{}>,
<2*x^6+x^5+3*x^4+3*x^2+3*x-2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^4+3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^2-1,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3+2*x^2+2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^2-2,{2}>,
<-x^6+x^5-3*x^4-3*x^2-3*x+2,{2,5}>,
<2*x^6+3*x^5-3*x^4+3*x^3-2*x+2,{2,197}>,
<-2*x^6+x^5-3*x^4-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4-3*x^2+2*x+2,{0}>,
<-x^6+2*x^5-3*x^4-3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^2+3*x-2,{}>,
<-2*x^6+2*x^5-3*x^4-3*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4+3*x^2-3*x-2,{0,2}>,
<2*x^6-3*x^5-3*x^4-3*x^2+3*x+2,{0,2}>,
<-2*x^6+3*x^5+3*x^4+3*x^2-3*x-1,{0}>,
<2*x^6-3*x^5-3*x^4-3*x^2+3*x-1,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-3*x^2+x-2,{2,7,23}>,
<-x^6-3*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6+x^5+3*x^4+x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-3*x^2+x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+3*x^2+3*x-2,{2}>,
<-x^6+3*x^5-2*x^4-x^3+3*x^2+3*x-2,{2,5}>,
<-x^6-3*x^5+2*x^4+x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-2*x^2-2*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+2*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3-2*x^2-2,{2}>,
<-x^6+2*x^4+x^3-3*x^2-3*x+2,{2}>,
<2*x^6-2*x^4-x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-2*x^2+x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-2*x^2+2*x-1,{2}>,
<2*x^6-3*x^4+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^2+x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^2-2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4+2*x^2+3*x-1,{}>,
<-2*x^6-3*x^5+3*x^4-2*x^2-2*x-2,{}>,
<2*x^6-3*x^5-3*x^4+2*x^2-2*x+2,{}>,
<-x^6+2*x^5-2*x^4+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-x^3-3*x^2+3*x+2,{2,7}>,
<-2*x^6+3*x^5+3*x^4-x^3-x^2-2*x-2,{}>,
<-2*x^6+3*x^5+3*x^4-x^3-x^2-2*x-1,{}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2+2*x+2,{}>,
<2*x^6+3*x^5-3*x^4-x^3+x^2-2*x-2,{}>,
<-2*x^6-3*x^5+3*x^4+x^3-3*x-1,{2}>,
<-2*x^6+2*x^5-x^3+3*x^2+3*x-2,{2}>,
<2*x^6+2*x^5-x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+2*x+2,{2}>,
<-2*x^6+x^5-x^3+3*x^2+3*x-2,{2,5}>,
<-2*x^6+3*x^5+3*x^4-x^3-1,{2}>,
<-x^6-x^5-x^3-3*x^2+3*x+2,{}>,
<-2*x^6+x^5+x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-x^3+2*x-1,{2,3}>,
<-x^6-2*x^5+x^4+x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-x^5-x^4+x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^4+x^3+3*x^2-3*x-2,{2}>,
<-x^6+x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-x^2-1,{2}>,
<2*x^6+x^4-x^3+3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2+3*x-2,{2}>,
<-x^6+3*x^5-3*x^3+3*x^2-3*x-2,{0}>,
<2*x^6-3*x^5-3*x^4+x^3-x^2+2*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-x^2+3*x-1,{0,2}>,
<-2*x^6-2*x^5+2*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-x^3-2*x^2+2*x-2,{2}>,
<-x^6+x^5+2*x^4-x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+2*x^2-x+2,{}>,
<-2*x^6-x^5-2*x^4+x^3-3*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4-x^3+2*x^2-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-2*x^2-1,{2}>,
<-x^6-x^5-2*x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+x^5-2*x^4+x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+2*x^2-2*x-1,{0,2}>,
<2*x^6+2*x^5+2*x^4+x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-3*x^2+3*x+2,{2,5}>,
<2*x^6+3*x^5-3*x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-3*x+2,{}>,
<-2*x^6-3*x^5+3*x^4+x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^4+x^3-3*x^2-3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3-3*x^2-3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-3*x^2-x-1,{2}>,
<-2*x^6+x^5-3*x^4-x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3-3*x^2+x-1,{2,17}>,
<2*x^6+x^5+3*x^4+x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-x^5-3*x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2-3*x-2,{0,2}>,
<-2*x^6-3*x^5+3*x^4+x^3+3*x^2+2*x-1,{0,2}>,
<2*x^6+3*x^5-3*x^4-x^3-3*x^2-2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+x^5-3*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<-x^6+x^5-3*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+2*x^2+2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-2*x^2-x-2,{2,5}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-2*x^2+x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-2*x^2-2,{2}>,
<-x^6-2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+2*x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4+x^3-2*x^2-1,{2}>,
<2*x^6-2*x^4-x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3+x^2-2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-x^2-x-2,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2-3*x-2,{0,2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-x^2+x-1,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-3*x^2-3*x+2,{}>,
<2*x^6+x^5-x^4+2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3-x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2-x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3+x^2-x-1,{}>,
<-2*x^6+3*x^5+3*x^4-2*x^3+2*x-2,{2}>,
<-x^6+x^5-x^4-2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+x^5+x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3+x-2,{2,5}>,
<2*x^6-3*x^5-3*x^4+2*x^3-x^2-x-2,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+2*x-1,{2}>,
<2*x^6+2*x^5+x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-x^2-1,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3+2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-x^2-x-1,{2}>,
<2*x^6-3*x^5-3*x^4+x^3+2*x-2,{2}>,
<-x^6+x^5-2*x^4-2*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-x^5-x^4-2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-2*x^2-1,{2}>,
<-2*x^6+3*x^5+3*x^4-x^3+x^2+3*x-1,{}>,
<2*x^6+3*x^5-3*x^4-2*x^3-x^2-2*x-1,{2}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2*x^2-2,{2}>,
<-x^6+x^5+2*x^4+2*x^3+3*x^2-3*x-2,{0,2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3+x^2+2*x+2,{2,5}>,
<-2*x^6-2*x^5-3*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2+x-1,{}>,
<-2*x^6-2*x^5-x^4-2*x^3-3*x^2+3*x+2,{2,5}>,
<-2*x^6+x^5-3*x^4-2*x^3-3*x^2+3*x+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3+3*x^2-3*x-2,{0}>,
<2*x^6-3*x^5-3*x^4+2*x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+x^5-x^4+x^3-3*x^2-3*x+2,{2,3}>,
<2*x^6+2*x^5+2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+3*x^2-2*x+2,{}>,
<2*x^6-3*x^5-3*x^4+2*x^3-2*x^2+x-2,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+3*x^2-3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-x^2+3*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-2*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6-x^5-x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-x^2-2,{2}>,
<-x^6-x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3-3*x-1,{2}>,
<2*x^6-2*x^5+3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3-2*x-1,{2}>,
<-x^6-2*x^5+x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6-x^4-3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3+2*x-2,{2}>,
<-x^6+2*x^5-x^4+x^3-3*x^2+3*x+2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3+x-1,{2}>,
<-x^6+3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+2,{2}>,
<2*x^6-2*x^5+x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3-3*x^2+3*x+2,{2,5}>,
<2*x^6-3*x^5-3*x^4+3*x^3+2*x-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-x-2,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-3*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+x^2+2*x-2,{0,2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-x^2-2*x+2,{0,2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3-2*x-1,{0,2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+x^2+2*x-1,{0,2}>,
<-x^6-2*x^5-x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3+3*x^2-3*x-2,{0,2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^4-3*x^3+3*x^2+3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-1,{0,2}>,
<-2*x^6+2*x^5-x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-x^6-2*x^5-x^4+2*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+2*x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3-x^2-2*x-1,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6-3*x^5+3*x^4+2*x^3-x^2-2,{2}>,
<2*x^6+3*x^5-3*x^4-3*x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2+3*x-2,{0,2}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2-3*x-2,{2}>,
<-2*x^6-3*x^5+3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<-x^6-x^5-3*x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+3*x^2+x+2,{}>,
<-x^6-2*x^5-2*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3-3*x^2+3*x+2,{}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+2*x^2-3*x-1,{}>,
<-x^6+3*x^4-3*x^3+3*x^2+3*x-2,{0}>,
<2*x^6-3*x^5-3*x^4+3*x^3-x^2-2*x-2,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+3*x^2+3*x-2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3-3*x^2-1,{2,5}>,
<2*x^6-3*x^5-3*x^4+3*x^3-x^2-1,{2}>,
<-2*x^6+3*x^5+3*x^4-3*x^3+3*x^2+2,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3-2*x^2-x-1,{}>,
<2*x^6+3*x^5-3*x^4-3*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6-3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<-x^6+x^5-x^4+3*x^3-3*x^2-3*x+2,{2}>,
<-x^6-3*x^5-3*x^4+x^3+3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-3*x^5-3*x^4+3*x^3-3*x^2-2*x-1,{2,7}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+3*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-x^2-x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+3*x^2-1,{2,3,47}>,
<-2*x^6+2*x^5-3*x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+x^2+3*x-1,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-x^6-3*x^5-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<-x^6-x^5-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+x^5+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3+2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x-2,{2,5,7,17}>,
<-2*x^6-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-x^5+3*x^3+3*x^2+2*x+2,{2}>,
<-x^6-3*x^5+3*x^3+3*x^2+2*x+2,{}>,
<2*x^6+2*x^5+3*x^4+3*x^3+x^2+3*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-3*x^2+2*x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-x^2+x-2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-x^2-1,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-x^2-x-1,{2}>,
<-x^6+x^5+2*x^4+3*x^3-3*x^2+2*x-2,{2,3}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-3*x^2+2*x-2,{2,3}>,
<-x^6+3*x^5+3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^5+x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<-x^6-2*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2,5}>,
<-x^6+3*x^5+x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-x^6+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3*x^2-1,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-x^6-x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+3*x^2-2*x+2,{2}>,
<-x^6-x^5+3*x^4-2*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^3-3*x^2-x-2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+2*x^2+3*x-1,{}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-2*x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-x+2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+3*x^2+2*x+2,{2}>,
<-x^6-3*x^5-2*x^4-x^3+3*x^2+3*x-2,{0,2}>,
<2*x^6-x^5-2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^3+3*x^2+2*x+2,{2}>,
<-x^6+2*x^5-x^4-x^3+3*x^2+3*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3-x^2-x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-3*x^5+3*x^4+x^3-x^2-2*x+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2+2*x+2,{2,5}>,
<2*x^6+2*x^5+3*x^4+2*x^3-2*x^2+x-2,{2}>,
<-x^6-x^5-x^4-2*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3+2*x^2-x+2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-x^2-x-2,{2}>,
<2*x^6-2*x^5+3*x^4-2*x^3-3*x^2-3*x-1,{}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+3*x^2-x-1,{2,5}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+x^2+3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+2*x^3-3*x^2+x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^3+2*x^2+3*x-1,{}>,
<2*x^6-x^5+3*x^4+2*x^3-3*x^2+2*x-2,{2,3}>,
<-2*x^6-2*x^5-3*x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2+2,{2,3}>,
<-2*x^6-2*x^5-3*x^4-x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3-2*x^2+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+2*x^2-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+x^2-x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+x^2+x-1,{}>,
<2*x^6-2*x^5+3*x^4-x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-x^2+x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+x^5+x^4-x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-x^2+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4-x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+3*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3+2*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5+x^3-3*x^2+2*x-2,{2}>,
<2*x^6-x^4+x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x-2,{2}>,
<2*x^6-x^5-x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-x^2-2,{2}>,
<-2*x^6-2*x^5-3*x^4-3*x^3-3*x^2+3*x+2,{2}>,
<2*x^6-x^5+x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^3+3*x^2+2*x+2,{2}>,
<-x^6+2*x^5-x^3+3*x^2-2*x+2,{}>,
<-2*x^6-2*x^5-3*x^4-x^3+x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3+2*x^2+2,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3+x^2+3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4+x^3-2*x^2-x-2,{2}>,
<-x^6+3*x^5-x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-x^3+3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2-2*x-2,{2}>,
<-x^6-3*x^5-3*x^4-x^3+3*x^2-2*x+2,{2,5}>,
<-x^6+x^5-x^4+x^3+3*x^2+2*x+2,{2}>,
<-x^6+x^5-2*x^4+x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4-x^3-3*x^2-x-1,{2}>,
<-2*x^6-x^5-x^4-x^3+3*x^2-2*x+2,{2}>,
<2*x^6+x^5+2*x^4+x^3-3*x^2+2*x-2,{2}>,
<-x^6+2*x^5+3*x^4-x^3-3*x^2-2*x-2,{2}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2+2*x-2,{2}>,
<2*x^6+3*x^4+x^3-3*x^2+2*x-2,{2,5}>,
<2*x^6-2*x^5+3*x^4-x^3-2*x^2-x-2,{2}>,
<2*x^6+2*x^5+3*x^4+3*x^2+3*x-1,{2,3}>,
<-2*x^6-2*x^5-3*x^4-2*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^2-x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^2+x+2,{2}>,
<-2*x^6-3*x^4-x^3+3*x^2-2*x+2,{2,5}>,
<2*x^6-2*x^5+3*x^4+2*x^2-x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^2+2*x-2,{}>,
<-2*x^6+2*x^5-3*x^4-x^2-2*x+2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^2-2*x+2,{}>,
<2*x^6+2*x^5-3*x^4-x^3+3*x^2-2*x+2,{2}>,
<2*x^6-x^5-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^4-3*x^2-2*x-2,{2}>,
<2*x^6-x^5-x^4+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x-1,{2}>,
<-2*x^6-2*x^5-3*x^4+x^2+x+2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-x^2+3*x-1,{2}>,
<2*x^6+x^5+2*x^4+3*x^2-2*x+2,{2}>,
<-2*x^6-x^5-x^4+3*x^2-2*x+2,{2}>,
<-x^6-x^5+3*x^4-3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^2-2*x-2,{2,7}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x^2-x-2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x^2+2*x+2,{2}>,
<-x^6+3*x^5+x^4-3*x^2-2*x-2,{2,7,59}>,
<2*x^6-2*x^5+3*x^4-2*x^2-3*x-1,{}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^4-3*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3-3*x^2+x+2,{2}>,
<-x^6+2*x^5+3*x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3+3*x^2-1,{2}>,
<-2*x^6+2*x^5-3*x^4+2*x^2+x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3-3*x^2+2*x+2,{}>,
<2*x^6+2*x^5+3*x^4-x^3+3*x^2-2*x-2,{}>,
<2*x^6-3*x^4-x^3-3*x^2+2*x-2,{}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^4+x^3+3*x^2-2*x+2,{}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3+3*x^2+x-1,{}>,
<-2*x^6+2*x^5-3*x^4+3*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3-2*x^2+x+2,{2}>,
<2*x^6-2*x^5+3*x^4-3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+2*x^2+x-2,{2}>,
<-x^6+2*x^4-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^2-x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+x^2+x-2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3+x^2-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3+3*x^2+2*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^2+x-2,{2}>,
<-x^6-3*x^5+x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+x+2,{2}>,
<2*x^6+x^5+x^3+3*x^2-2*x+2,{2}>,
<2*x^6-x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3+x+2,{2,3}>,
<2*x^6-2*x^5+3*x^4+x^3+x-2,{2}>,
<2*x^6+2*x^5+x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3-2*x-1,{2}>,
<-x^6+3*x^5+x^3-3*x^2-2*x-2,{2}>,
<-x^6-3*x^5+x^4+x^3-3*x^2-2*x-2,{}>,
<2*x^6-2*x^5+3*x^4+x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5+x^4+x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-x^5+x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6+3*x^5-3*x^4+x^3-x^2+x+2,{2}>,
<-2*x^6-3*x^5+3*x^4-x^3+x^2-x-1,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-x^2+2,{2}>,
<-x^6+x^5-x^4+x^3-3*x^2+3*x+2,{2}>,
<-x^6+x^4-x^3+3*x^2-3*x-2,{2}>,
<2*x^6+x^4+x^3-3*x^2-2*x-2,{2}>,
<2*x^6+x^5-x^4+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+x^2-x+2,{}>,
<-2*x^6+3*x^5+3*x^4+x^3+x^2-x-2,{2}>,
<-2*x^6-x^5-x^4-x^3+3*x^2+2*x+2,{}>,
<2*x^6+2*x^5-x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6+x^5-x^4-x^3-3*x^2-3*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<-2*x^6+2*x^4+3*x^3-3*x^2-3*x+2,{2}>,
<2*x^6-2*x^5+x^4-x^3-3*x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4-x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-x^6-3*x^5-2*x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-2*x^2-x-2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+2*x^2-x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4-x^3+3*x^2-3*x-1,{}>,
<-x^6-3*x^5-3*x^4-x^3+3*x^2+2*x+2,{2,79}>,
<-2*x^6+2*x^5-3*x^4-x^3-2*x^2+2,{2,167}>,
<2*x^6-x^5-3*x^4+2*x^3-3*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6-x^5-2*x^4-x^3-3*x^2+2*x-2,{2}>,
<-2*x^6+x^5+2*x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x-2,{2}>,
<2*x^6-2*x^5+3*x^4+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4+x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2+2*x+2,{2}>,
<-x^6+x^5+2*x^4-2*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+2*x^3+2*x^2+x+2,{2}>,
<-x^6-x^5+2*x^4-2*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-x^5-x^4+x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^5-2*x^3+3*x^2+2*x+2,{}>,
<-2*x^6-2*x^5-3*x^4+2*x^3-x+2,{2}>,
<2*x^6-x^5-2*x^3-3*x^2+2*x-2,{2}>,
<-x^6-2*x^5-x^4-x^3-3*x^2+3*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-2*x-1,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-3*x-1,{2}>,
<2*x^6+x^5+x^4+2*x^3-3*x^2-2*x-2,{2,31}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-2*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+2*x^3+2*x^2-3*x-1,{}>,
<-x^6-x^5+2*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-x^6-x^5+3*x^4-2*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^5+x^4-2*x^3-3*x^2+2*x-2,{2,5}>,
<2*x^6+2*x^5+3*x^4-2*x^3-x^2-x+2,{}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+3*x^2-x-1,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-x+2,{2}>,
<-x^6+3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-3*x^4+3*x^3-3*x^2-2*x-2,{}>,
<2*x^6-2*x^5+3*x^4+3*x^3+3*x^2-2,{}>,
<2*x^6+x^5+3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-x-2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x^2+2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2*x^2-1,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+2*x+2,{2}>,
<2*x^6-x^5-x^4+3*x^3-3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3-x+2,{2}>,
<-x^6+x^5+x^4+3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-x^3-1,{2,79}>,
<2*x^6-x^5-x^4-3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6+x^3-3*x^2-2*x-2,{2,5}>,
<2*x^6-2*x^5+3*x^4+3*x^3+x^2+x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+x+2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+x^5-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^3+3*x^2-2*x+2,{}>,
<2*x^6+2*x^5+3*x^4-3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3-3*x-1,{2}>,
<2*x^6+x^5-x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-x^6+x^5-x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-x^5-3*x^3-3*x^2+2*x-2,{2}>,
<2*x^6-x^4+3*x^3+3*x^2-2*x+2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+x^2+2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3-2*x^2-x-2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-x^6+2*x^5+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+3*x^2+2*x+2,{}>,
<2*x^6+2*x^5+3*x^4-3*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4+3*x^3+3*x^2+2*x-2,{2,3}>,
<-x^6-3*x^5-3*x^4-3*x^3+3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+3*x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-2*x+2,{}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+2*x^2-2*x+2,{}>,
<2*x^6+2*x^5+2*x^4+3*x^3+x^2+x-1,{2,23}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3-x^2-x+2,{2,3}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-2*x^2+x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+2*x^2+3*x-1,{}>,
<2*x^6-x^5+3*x^4-3*x^3+2*x^2-2*x+2,{2,3,31}>,
<2*x^6+x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-x^6+3*x^5-x^4+3*x^3-2*x^2+2*x-2,{2,17}>,
<2*x^6+2*x^5+2*x^4+3*x^3+3*x^2+x-2,{2,5}>,
<2*x^6-2*x^5+2*x^4-3*x^3+x^2-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-x^6-3*x^5-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+x^2-x-2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3+2*x-1,{2}>,
<-x^6-3*x^5-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-x-2,{2}>,
<2*x^6+x^5-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-x^2-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x-2,{2}>,
<-x^6+3*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-x^2-2,{2}>,
<2*x^6-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-x^2-3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2-x-1,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-2,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+x^2+x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3+x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+x^2-2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-x^2+x-2,{2}>,
<-x^6-x^5+2*x^4-3*x^3-2*x^2-2*x-2,{2,3}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-2*x^2-x-1,{}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-x^6+2*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-3*x^2-x+2,{2,5}>,
<-x^6+x^5-2*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+x^5+3*x^4+x^3+3*x^2+2*x+2,{2,11}>,
<-x^6+2*x^5-2*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3-3*x^2+2,{2}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x+2,{}>,
<-x^6+2*x^5+3*x^4-x^3+3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+2*x^2+2*x+2,{}>,
<-2*x^6-2*x^5-2*x^4-3*x^3+3*x^2-1,{2}>,
<2*x^6-2*x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-1,{2}>,
<2*x^6+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-2*x^2-x+2,{2,197}>,
<-x^6+x^5+3*x^4-3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+2*x^2-2*x+2,{}>,
<2*x^6-x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+3*x^4+x^3+2*x^2+x-1,{2}>,
<-x^6-3*x^5-2*x^4+3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^3-3*x^2-x-2,{2,5}>,
<-x^6+3*x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4+x^3-2*x^2+x+2,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-2*x^2-2*x+2,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+2*x^2-2*x+2,{}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3-x-2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-x-1,{2}>,
<-x^6+3*x^5-2*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3-2*x^2-2*x-2,{}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+x^2-2*x+2,{2,5}>,
<-2*x^6+2*x^5-2*x^4+2*x^3-3*x^2-2*x+2,{2}>,
<-x^6+x^5-x^4+2*x^3+2*x^2+2*x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+x^5-x^4+2*x^3-2*x^2+2*x-2,{}>,
<2*x^6-2*x^5+2*x^4-2*x^3-x^2-x-2,{2}>,
<-2*x^6-x^5+x^4-2*x^3+2*x^2-2*x+2,{}>,
<2*x^6-x^5+x^4+2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3-3*x-1,{2}>,
<-x^6+x^5+2*x^4+2*x^3-2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+2*x^3+3*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+2*x^2-x+2,{2}>,
<-x^6-x^5-2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3+x+2,{}>,
<-2*x^6+x^5-2*x^4+2*x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3-x-2,{}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5+3*x^4+x^3+2*x^2+2*x+2,{}>,
<-x^6-3*x^5+3*x^4-2*x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+x^5-3*x^4-x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4+2*x^3+3*x^2+x-1,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2+2*x-1,{}>,
<-x^6-x^5-3*x^4-2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-3*x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4+2*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-2*x^3-3*x^2+x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+3*x^2+x-1,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3-3*x^2+x+2,{2}>,
<-x^6-3*x^5+x^4-x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+3*x^2+2,{2}>,
<2*x^6-2*x^5-x^4-x^3-2*x^2-2*x-2,{2,3}>,
<2*x^6+2*x^5+2*x^4+x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+2*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^5+2*x^4-x^3+x^2+2*x-1,{2,3}>,
<2*x^6-2*x^4-x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+2*x^2+x-1,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+x^2-x+2,{2}>,
<2*x^6+2*x^5+x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+x^5+x^4+x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3+x^2+x-1,{2}>,
<2*x^6+2*x^5+2*x^4+x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-x^4-x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-2*x+2,{2}>,
<2*x^6-2*x^5+3*x^4+3*x^3+2*x^2+x+2,{2}>,
<2*x^6-2*x^5+x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+3*x-1,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+x^4+x^3-2*x^2+2*x-2,{2}>,
<-x^6+3*x^5+x^4-x^3-2*x^2-2*x-2,{}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+2*x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5+2*x^4-x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3-2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5+3*x^4-3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+x^5+x^4+x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-x^5-x^4-x^3+2*x^2-2*x+2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+x^2+2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^3+2*x^2-3*x-1,{2}>,
<2*x^6-x^5-3*x^4+x^3+3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+x^3-2*x^2+2*x-2,{2,5}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x^2+x+2,{2}>,
<-2*x^6+x^5-x^4-x^3+2*x^2-2*x+2,{2,7}>,
<-x^6-x^5-3*x^4+x^3+2*x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4-x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^2-x+2,{2}>,
<2*x^6-3*x^4-2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+3*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^2-2*x+2,{}>,
<-x^6-2*x^5+x^4+x^3+3*x^2+3*x-2,{0,2}>,
<2*x^6+x^5+x^4+2*x^2-2*x+2,{2}>,
<2*x^6-x^5-x^4-2*x^2+2*x-2,{2}>,
<2*x^6-x^4+2*x^3-3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6-2*x^5+3*x^4+2*x^3+x^2+x-2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^2-2*x-2,{2}>,
<-2*x^6+x^5-2*x^4+2*x^2+2*x+2,{2,3}>,
<2*x^6-x^5-2*x^4+2*x^2+2*x+2,{2}>,
<2*x^6+x^5+x^3+2*x^2+2*x+2,{2}>,
<-x^6-x^5-x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4-x^3-x-2,{2}>,
<-2*x^6-x^3+2*x^2-2*x+2,{2}>,
<2*x^6+3*x^4-x^3+2*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^5+2*x^4+x^3+3*x^2-1,{2}>,
<2*x^6-3*x^4+x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+3*x^2+x-2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4-x^3+2*x^2+x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+x^5-2*x^4-x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-2*x^2-2*x+2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5+2*x^4+x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-x-2,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3-2*x^2+2,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3-2*x^2-x+2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2-2,{2}>,
<2*x^6-x^5-2*x^4-x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-2*x^2-2*x+2,{}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x^2+2*x-2,{}>,
<-x^6+3*x^5+2*x^4+x^3+2*x^2-2*x+2,{}>,
<-x^6-3*x^5-x^4+x^3-2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3-x^2+x+2,{2}>,
<2*x^6-2*x^5+2*x^4+x^2+3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+x^2-x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-x^2+2,{2}>,
<2*x^6-2*x^5+2*x^4-3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4-x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+x^2-x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-x^2-3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+x^3-3*x-1,{}>,
<-2*x^6+2*x^5-2*x^4+x^2+x+2,{2}>,
<-2*x^6+2*x^5-2*x^4+x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-2*x^4+x^2+3*x-1,{2}>,
<2*x^6+x^3-2*x^2-2*x-2,{2}>,
<-x^6-x^5+2*x^4-x^3-2*x^2+2*x-2,{2,3}>,
<-2*x^6-2*x^5-2*x^4+x^3+x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+x^5+x^3+2*x^2-2*x+2,{2}>,
<2*x^6-x^5-x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3-2*x+2,{2}>,
<-x^6+x^5+x^3+2*x^2-2*x+2,{2}>,
<-x^6+3*x^5-x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+x^2+2*x-1,{2}>,
<-2*x^6-x^5-3*x^4-x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-x^3-3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3+2*x^2-x-2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-2*x^2-2*x-2,{2,5}>,
<2*x^6-2*x^5+2*x^4+2*x^3+2*x^2+x-2,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3+3*x^2+x+2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3+x^2+x+2,{}>,
<-x^6-2*x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3+2*x^2-2*x+2,{2,5,7}>,
<2*x^6-2*x^5+2*x^4+2*x^3+x^2-x-1,{2}>,
<-x^6-x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-2*x^4+2*x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4+x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-x^2+x+2,{2,5}>,
<-2*x^6+2*x^5-2*x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4+x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3+x^2+x+2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x^2+x-2,{2,5}>,
<-x^6+x^5+3*x^4+x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4+x^3-3*x^2-1,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3+x^2-x-1,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3+3*x-1,{2}>,
<2*x^6-x^5+2*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-2*x^3-x+2,{}>,
<-2*x^6-3*x^4-x^3+2*x^2-2*x+2,{2}>,
<-x^6+x^5+x^4+3*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3-x+2,{2}>,
<-2*x^6-2*x^5-2*x^4+2*x^3+2*x-1,{2}>,
<-x^6-3*x^5-x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+2*x^2+2*x+2,{2}>,
<-x^6-x^5+3*x^4+2*x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-x^6-x^5+3*x^4-2*x^3-2*x^2+2*x-2,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2+2*x+2,{}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-3*x^2-2*x+2,{}>,
<-x^6-3*x^5+x^4-2*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2-x-1,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+2*x-2,{}>,
<2*x^6-x^5-2*x^4+2*x^3+2*x^2-2*x+2,{}>,
<2*x^6+2*x^5+2*x^4-3*x^3+3*x^2-3*x-1,{}>,
<2*x^6+2*x^5+2*x^4-3*x^3+3*x^2+x-2,{2,3}>,
<2*x^6+3*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+3*x^2-1,{}>,
<2*x^6+2*x^5+2*x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+2,{}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^4+3*x^3+2*x^2-2*x+2,{}>,
<-x^6+3*x^5+x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2-2*x+2,{2}>,
<2*x^6-3*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2-2*x-1,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+x^2-1,{2}>,
<2*x^6+x^5-2*x^4-2*x^2+2*x-2,{2,5}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-x^2+2,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^2+x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2+x-1,{2}>,
<2*x^6-2*x^5+2*x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+2,{2}>,
<2*x^6+3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3-x^2-x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-2*x^3+2*x^2-x-1,{2,3}>,
<-x^6-2*x^5-3*x^3-2*x^2+2*x-2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-x^5+x^4+3*x^3+2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^3+2*x^2+2*x+2,{}>,
<-x^6-3*x^5+2*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3+x+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+2*x-2,{2,3}>,
<2*x^6-x^5-2*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<-x^6+3*x^5+3*x^3-2*x^2-2*x-2,{}>,
<-x^6-x^5+3*x^3+2*x^2-2*x+2,{2}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-2*x^2-x-1,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-3*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^4+3*x^3-x+2,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+2*x^2-2*x+2,{}>,
<-x^6-x^5-3*x^4+x^3+3*x^2-2*x+2,{2,7}>,
<-x^6-3*x^5-3*x^4+3*x^3+2*x^2-2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<2*x^6-x^5+x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<-2*x^6+x^5-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3-3*x^2+2*x-2,{2}>,
<-x^6+3*x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+3*x^2-x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2+3*x-1,{}>,
<-x^6-x^5-3*x^4-3*x^3+2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-2*x^5+3*x^4+x^3-3*x^2-x-2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2-2*x-2,{2}>,
<-2*x^6+x^5-x^4+3*x^3+2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2,3}>,
<-2*x^6+2*x^5-3*x^4-x^3+3*x^2-x-1,{2,3}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-x^2+2*x-2,{2}>,
<2*x^6+3*x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+2*x^2-2*x-2,{2,3}>,
<2*x^6+2*x^5+x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-x^2+2*x-2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3-x^2+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-3*x^2+2*x+2,{2,3}>,
<-2*x^6+x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2+x-1,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x^2-2*x+2,{}>,
<2*x^6-x^5-x^4+3*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-x^2+2*x-2,{2}>,
<-x^6+x^5+3*x^3-x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2-x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2+2*x-1,{}>,
<2*x^6-x^5-3*x^3-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+x^2-2*x+2,{2}>,
<-x^6+3*x^3+x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^3+x^2+2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3-2*x-2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x-1,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5+3*x^3-x^2+2*x-2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3+x^2-1,{2}>,
<2*x^6-2*x^5+x^4-3*x^3+x-2,{2}>,
<-x^6+2*x^5+3*x^3-x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+2*x+2,{2}>,
<-x^6+2*x^5-x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-2*x^2+x-2,{}>,
<-2*x^6+2*x^5-x^4+3*x^3+x^2+3*x-1,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+2*x^2-2,{}>,
<-x^6-3*x^5+2*x^4-3*x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^4+3*x^3+x^2+2*x+2,{}>,
<-2*x^6+2*x^5-x^4+3*x^3+2*x^2-1,{}>,
<-x^6+3*x^5-2*x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+x^2+x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x^3-2*x^2-1,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x^2+2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2+x+2,{}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+x^5-x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-2*x-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5+x^4+3*x^3-x^2+2*x-2,{2}>,
<-x^6+x^5+3*x^4+3*x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+3*x^2+x+2,{2}>,
<-2*x^6+3*x^4-3*x^3-x^2-2*x-2,{}>,
<-2*x^6-x^5-x^4-3*x^3+x^2-2*x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3+x^2-2*x+2,{}>,
<2*x^6-2*x^5+x^4-3*x^3-3*x^2+2,{}>,
<-x^6+x^4+3*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-3*x^3-3*x^2+x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+3*x^2+x-1,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+x^2+2,{2}>,
<-x^6-x^5-3*x^4+3*x^3+x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x^2-2*x-2,{}>,
<-2*x^6+x^5-3*x^4-3*x^3+x^2-2*x+2,{}>,
<2*x^6-x^5+2*x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^3+x^2-2*x+2,{}>,
<-x^6-x^5+x^4-2*x^3+x^2-2*x+2,{2}>,
<2*x^6+x^5-x^4+2*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+x^2+x-2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-x^2+2*x-2,{0,2,3,7}>,
<2*x^6+2*x^5+2*x^3-x^2+2*x-2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6-x^5-2*x^3+x^2-2*x+2,{2}>,
<2*x^6+x^5+3*x^4+2*x^3+x^2+2*x+2,{2,13}>,
<-2*x^6-2*x^5-x^4-2*x^3+x+2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-2*x^3-x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3-3*x^2+x+2,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3+x^2+x-1,{2}>,
<2*x^6-2*x^5+2*x^4-3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5+x^4-2*x^3-x^2-x-1,{2,3}>,
<-2*x^6+x^5-x^4+2*x^3+x^2+2*x+2,{2}>,
<2*x^6+x^5+x^4-2*x^3-x^2-2*x-2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^2+2*x+2,{2}>,
<-2*x^6-x^5-x^4+2*x^3+x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4-2*x^3+2*x^2-3*x-1,{}>,
<-x^6-3*x^5+x^4+2*x^3-x^2+2*x-2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-x^2+2*x-2,{2}>,
<-x^6-x^5-2*x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3-x^2+2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-2*x^3+2*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5-x^4+2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5+x^4+2*x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+2*x+2,{2}>,
<-x^6-x^5+2*x^4-2*x^3-x^2-2*x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-x^2-2*x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-x^3-3*x^2+2,{2}>,
<2*x^6-x^5+3*x^4+x^3+x^2+2*x+2,{}>,
<-x^6+x^5+3*x^4-2*x^3-x^2-2*x-2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-x^2+2*x-2,{2}>,
<2*x^6+x^5-2*x^4-x^3-x^2-2*x-2,{2,11}>,
<-2*x^6-2*x^5-x^4-x^3-2*x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-x^3-x^2-2*x+2,{2,5,73}>,
<-2*x^6-2*x^5+x^4-x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-x^3-3*x^2+x+2,{2,103}>,
<2*x^6-2*x^5+x^4-x^3+x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3+x^2+x-1,{}>,
<-2*x^6+2*x^5-x^4+x^3-x^2+x+2,{}>,
<2*x^6-2*x^5+x^4-x^3+x^2-x-2,{}>,
<2*x^6+2*x^5+x^4+x^3+x^2-2,{2}>,
<2*x^6-x^5-x^4+3*x^3-2*x^2-2*x-2,{2,3,157}>,
<2*x^6-2*x^5+x^4+x^3+x^2+2*x+2,{}>,
<2*x^6+2*x^5-x^4-x^3-x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^3-x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3+2*x-1,{}>,
<2*x^6+2*x^5+x^4+x^3+2*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3+x-1,{2}>,
<-2*x^6-2*x^5-x^4-x^3-x+2,{2}>,
<2*x^6-2*x^5+x^4-x^3-x-2,{2}>,
<2*x^6+x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-x^3+x+2,{2}>,
<-2*x^6-x^5+x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+x^2+2*x-1,{2,7}>,
<2*x^6-2*x^5+x^4-x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4+x^3-x^2+2*x-2,{2}>,
<2*x^6+x^4-x^3-x^2-2*x-2,{2}>,
<-2*x^6-x^4+x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3-x^2-x+2,{}>,
<-x^6+x^5-x^4-x^3+x^2-2*x+2,{2}>,
<-x^6+3*x^5+x^4-x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4-x^3-2*x^2-2,{2}>,
<-x^6+x^5-2*x^4-x^3+x^2-2*x+2,{2,3}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2+x+2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-x^2-2*x-2,{2}>,
<-x^6+3*x^5+2*x^4-x^3-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+3*x^3+2*x^2+2*x-1,{2,3}>,
<2*x^6-2*x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-x^2+2*x-2,{}>,
<-x^6+x^5+3*x^4+x^3-x^2+2*x-2,{2}>,
<-x^6+x^5-3*x^4+x^3+x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2+x-2,{2}>,
<-2*x^6-2*x^5-x^4-x^3+3*x^2-1,{2}>,
<2*x^6+3*x^4-x^3-x^2-2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-x^4-x^3-3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-x^2+2*x-2,{}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2-2*x+2,{}>,
<-2*x^6-x^5+2*x^4-x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4-3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4+2*x^2+x+2,{2}>,
<2*x^6+2*x^5+x^4+2*x^2-x-1,{2}>,
<-2*x^6-2*x^5-x^4-2*x^2+x+2,{2}>,
<2*x^6-2*x^5+x^4+x^2-3*x-1,{2}>,
<2*x^6-2*x^5+2*x^4+x^3-x^2-x-2,{2}>,
<-2*x^6+x^5+x^4+x^2+2*x+2,{2,53}>,
<2*x^6-2*x^5+x^4+x^2+x+2,{2}>,
<-2*x^6+2*x^5-2*x^4-x^3+x^2-x+2,{2}>,
<-x^6+3*x^5-x^4-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4+3*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x^2-2*x-2,{2,5}>,
<-2*x^6-2*x^5-x^4-x+2,{2}>,
<-x^6+3*x^5-x^2-2*x-2,{2}>,
<-x^6-x^5+3*x^4-x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4-3*x^2-x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2-x-1,{2}>,
<-x^6+3*x^5+x^4-x^2+2*x-2,{2}>,
<2*x^6+x^5+x^4-x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4-x^3+3*x^2+x-2,{2,23}>,
<2*x^6+2*x^5+x^4-x^3+3*x^2-2,{2,3,7}>,
<2*x^6-x^5-3*x^4-x^3-x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4+x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+x^2-2*x+2,{}>,
<-x^6+x^5+2*x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6-x^5-2*x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4-x^3+2*x^2+2,{2}>,
<2*x^6-2*x^5+x^4+x^3+2*x^2-1,{2}>,
<-2*x^6+2*x^5-x^4-x^3-2*x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4-x^3+2*x^2-x-2,{2}>,
<-x^6+2*x^5+2*x^4+x^3+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-x^2-2*x-2,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-x^4+x^3-x^2-3*x-1,{2}>,
<2*x^6-2*x^5+x^4+x^3+x^2-3*x-1,{2}>,
<-2*x^6-2*x^5+x^4+x^3+x^2-2*x+2,{2}>,
<2*x^6+x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6-x^4-x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-x^3-x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4-x^3+x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2+2*x-2,{2}>,
<2*x^6-x^5+x^3+x^2-2*x+2,{}>,
<-2*x^6+x^5-x^3+x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^3-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-x^3-3*x-1,{2}>,
<-x^6+3*x^5-x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4+x^3-x^2-x+2,{}>,
<2*x^6-x^5+x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6-x^4-x^3+x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4-x^3-x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4-x^3-x^2+2*x-2,{2}>,
<-x^6-3*x^5-x^4-x^3+x^2+2*x+2,{}>,
<-2*x^6+2*x^5-x^4-x^3+2*x^2+3*x-1,{2}>,
<-x^6-x^5-2*x^4+x^3+x^2-2*x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-x^3+2*x^2-x-1,{2}>,
<-2*x^6+x^5-2*x^4+x^3+x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4-x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^4+3*x^3+x^2-x-2,{2,3,157}>,
<2*x^6+x^4-3*x^3+2*x^2+2*x+2,{}>,
<-x^6+3*x^5-3*x^4-x^3+x^2+2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+x^3-x^2-2*x-2,{2}>,
<2*x^6-2*x^5+x^4+x^3-3*x^2-2,{2}>,
<-x^6-3*x^5-2*x^4-x^3+x^2+2*x+2,{2,29}>,
<-x^6-3*x^5+3*x^4+x^3-x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4-x^3-3*x^2-2*x+2,{}>,
<-2*x^6-x^5+3*x^4-2*x^3+x^2+2*x+2,{}>,
<2*x^6-2*x^5+x^4+2*x^3+2*x^2+x+2,{2}>,
<-x^6+x^5+2*x^4+2*x^3+x^2-2*x+2,{}>,
<2*x^6-x^5-2*x^4-2*x^3-x^2+2*x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+3*x^2+x-2,{2}>,
<-2*x^6-2*x^5-x^4+2*x^3-x^2-x+2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3-3*x^2+x+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-2*x-2,{2}>,
<-x^6-3*x^5+2*x^3-x^2-2*x-2,{2}>,
<-x^6-3*x^5-2*x^3-x^2+2*x-2,{}>,
<2*x^6-x^5-3*x^4+3*x^3-x^2-2*x-2,{2,3,7,17}>,
<2*x^6+x^5-x^4+2*x^3+x^2-2*x+2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-3*x^2+2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+3*x^2-x-1,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-2*x^2-x+2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2+x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2-2*x+2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+x^2-2*x+2,{2,5}>,
<-2*x^6+2*x^5-x^4-3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2-x+2,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6+x^5+x^4-3*x^3+x^2+2*x+2,{2,3}>,
<2*x^6-2*x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6-x^5-x^4+3*x^3-x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+2*x^2-x-1,{2}>,
<-2*x^6+x^5+x^4-3*x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5+x^4-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-x^2-3*x-1,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+x^2+3*x-1,{2}>,
<2*x^6+x^4-3*x^3+x^2+2*x+2,{2,3}>,
<2*x^6-x^5-3*x^3+x^2+2*x+2,{2}>,
<-2*x^6+x^5+3*x^3+x^2-2*x+2,{2}>,
<2*x^6-x^4-3*x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-2*x-1,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+x^2+2*x+2,{}>,
<2*x^6+x^5-x^4+3*x^3+x^2-2*x+2,{2}>,
<-x^6-x^5+x^4-3*x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3+x^2-x+2,{2}>,
<-2*x^6+2*x^5-x^4-3*x^3-2*x+2,{2,3,5}>,
<-2*x^6-2*x^5+x^4-3*x^3-x^2+2*x-2,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3+x^2+2*x+2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-3*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6-x^5-3*x^4-x^2+2*x-2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-x^2+2*x-2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-2*x^2-x-1,{2}>,
<-2*x^6-2*x^5-x^4+3*x^3+2*x^2+x+2,{2}>,
<2*x^6+2*x^5+x^4+3*x^2-x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+x^2+2*x+2,{2,3,5}>,
<-x^6-3*x^5+2*x^4-3*x^3-x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-2*x+2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3-3*x^2-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+2*x-2,{2}>,
<2*x^6+3*x^4-3*x^3-2*x+2,{2}>,
<2*x^6-3*x^4+3*x^3+2*x-2,{2}>,
<-2*x^6+3*x^4+3*x^3+2*x+2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3+2*x+2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+2*x+2,{}>,
<-x^6+3*x^5-2*x^4+3*x^3+2*x-2,{2}>,
<2*x^6+2*x^5+3*x^3+2*x^2+3*x-1,{}>,
<-x^6-2*x^5-2*x^4-3*x^3-2*x-2,{2}>,
<-x^6+2*x^5-2*x^4+x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4+x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5-x^4-x^3+2*x^2-x+2,{2}>,
<2*x^6+2*x^5+x^4+x^3-2*x^2+x-2,{2}>,
<2*x^6+2*x^5+x^4+x^3-2*x^2-1,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x-2,{2}>,
<2*x^6+2*x^5+3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^3-x^2+x-1,{2}>,
<-2*x^6+2*x^5+3*x^3-x^2+x+2,{}>,
<-2*x^6-x^5+x^4-3*x^3-2*x+2,{}>,
<2*x^6+2*x^5+3*x^3+x^2-2,{2}>,
<-x^6-x^5+x^4+3*x^3+2*x+2,{2}>,
<2*x^6-x^5-x^4+3*x^3+2*x-2,{2}>,
<-2*x^6-x^5+x^4+3*x^3+2*x+2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+x^2-2*x+2,{}>,
<2*x^6+2*x^5-x^4-3*x^3-2*x-2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3-x^2-2*x-2,{2,29}>,
<2*x^6+2*x^5+x^4-2*x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5+3*x^3+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^3+2*x-2,{}>,
<-2*x^6-2*x^5-3*x^3-2*x+2,{2}>,
<-2*x^6-x^5-3*x^3-2*x-2,{2,3}>,
<2*x^6-2*x^5-3*x^3-x+2,{2}>,
<-x^6-x^5-3*x^3-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3-x^2-2*x-2,{2,5,31}>,
<-2*x^6+2*x^5-x^4-x^3+3*x^2-x+2,{}>,
<2*x^6+2*x^5+3*x^3+x-1,{2,3}>,
<2*x^6+2*x^5+x^4-2*x^3-3*x^2-x-2,{2}>,
<2*x^6-2*x^5+x^4+x^3-3*x^2+x-2,{}>,
<-x^6-3*x^3-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2+2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3+x^2+2*x+2,{2}>,
<-2*x^6+2*x^5-x^4-2*x^3-3*x^2+x+2,{2}>,
<2*x^6+2*x^5+3*x^3-1,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3+x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-x^2-2*x-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-x^2-2*x-2,{}>,
<2*x^6-2*x^5-3*x^3-2,{2}>,
<2*x^6-2*x^5+x^4+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^3-2*x-2,{}>,
<2*x^6-2*x^5-3*x^3+2*x-2,{}>,
<-2*x^6+x^4-3*x^3-2*x-2,{2}>,
<-x^6-3*x^5+3*x^3+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^3-x^2+2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-x-1,{2}>,
<-2*x^6-2*x^5-3*x^3+2*x^2-x+2,{2}>,
<-x^6+3*x^5-3*x^3-2*x+2,{0,2,3,37}>,
<-x^6-3*x^5+x^4-3*x^3-2*x-2,{}>,
<-x^6-3*x^5-x^4-3*x^3-2*x+2,{2}>,
<-2*x^6+2*x^4+3*x^3+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^3+x^2-2*x-1,{}>,
<2*x^6-2*x^5-3*x^3-2*x^2+2,{2}>,
<-x^6-2*x^5-x^4-3*x^3-2*x+2,{2}>,
<-x^6-x^5-x^4-3*x^3-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3-2*x^2-2,{2}>,
<-x^6+x^5-2*x^4-3*x^3-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^3+2*x^2-x-2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-2*x-2,{0,2,11}>,
<-2*x^6+2*x^5+3*x^3+2*x^2-x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6+2*x^5-x^4-x^3-x^2-3*x-1,{2,3}>,
<2*x^6-2*x^5-3*x^3-3*x^2-3*x-1,{2,7}>,
<2*x^6+2*x^5+3*x^3-3*x^2+x+2,{2}>,
<-2*x^6-2*x^5-x^4+x^3-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^3+3*x^2+x-1,{}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3-2*x-2,{2}>,
<2*x^6-3*x^4-3*x^3-2*x+2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+2*x-2,{0}>,
<-x^6+3*x^5+3*x^4-3*x^3-2*x-2,{0}>,
<-x^6+3*x^4+3*x^3+2*x-2,{2}>,
<2*x^6+2*x^5+3*x^3-3*x^2-1,{}>,
<2*x^6-2*x^5-2*x^3+3*x^2-x+2,{2}>,
<-2*x^6+2*x^5+2*x^3-3*x^2+x+2,{2}>,
<2*x^6+3*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3-3*x^2-2,{2}>,
<2*x^6-2*x^5-2*x^3+3*x^2+3*x-1,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3+2*x-2,{}>,
<2*x^6+x^5+3*x^4-3*x^3-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^3+2*x^2-x-2,{2}>,
<2*x^6-2*x^5+2*x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^3+x-2,{}>,
<2*x^6+x^5-2*x^3-2*x-2,{}>,
<-2*x^6-x^5+2*x^3+2*x+2,{}>,
<-x^6+3*x^5-2*x^3-2*x-2,{2}>,
<-x^6-3*x^5+x^4-2*x^3-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^3-x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^3+x^2+x-2,{2}>,
<2*x^6+2*x^5+2*x^3-x^2+x+2,{2}>,
<-2*x^6+2*x^5+2*x^3+x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3+x^2+2*x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+x^2-2*x+2,{2}>,
<-x^6+2*x^4+3*x^3-x^2-2*x-2,{2}>,
<2*x^6+x^5+x^4+2*x^3+2*x-2,{2}>,
<-x^6+x^5-x^4-2*x^3-2*x+2,{2}>,
<2*x^6+2*x^5+x^4-3*x^3-3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5-2*x^3-x^2+x-2,{2}>,
<-x^6-3*x^5+x^4+2*x^3+2*x-2,{2}>,
<-2*x^6-2*x^5-3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3+3*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^3+2*x^2+x-2,{2}>,
<2*x^6-2*x^5-2*x^3-2*x^2-x+2,{}>,
<-2*x^6+2*x^5+2*x^3+3*x^2+3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3-2*x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^3-3*x^2-x-1,{2}>,
<-2*x^6-2*x^5-2*x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5-2*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^5+x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3-2*x-2,{2}>,
<2*x^6+2*x^5+x^3+3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4-2*x^3-2*x-2,{0}>,
<2*x^6-2*x^5-2*x^3-x^2-x-1,{2,3,5,41}>,
<-x^6+3*x^5-3*x^4-2*x^3-2*x+2,{2}>,
<2*x^6-2*x^5-x^3+2*x^2-x-2,{}>,
<2*x^6-2*x^5-x^3+3*x^2-3*x-1,{2,7}>,
<-x^6-3*x^5+2*x^4+x^3+2*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3-2*x-2,{2}>,
<2*x^6+2*x^5+x^3+x^2+2*x-1,{}>,
<2*x^6-2*x^5-3*x^4-x^3-2*x-2,{2}>,
<2*x^6-2*x^5-x^3+x^2-2*x-2,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x-2,{2}>,
<2*x^6+2*x^5+x^3+x^2+x-1,{2}>,
<-2*x^6+2*x^5+x^3+3*x-1,{2}>,
<-x^6+2*x^5+x^3+2*x-2,{2,5}>,
<-2*x^6-2*x^5-x^3-2*x+2,{2}>,
<2*x^6-x^5-x^4-x^3-2*x-2,{2}>,
<-x^6+x^5+x^3+2*x+2,{2}>,
<-2*x^6-2*x^5-x^3+2,{2}>,
<2*x^6-2*x^5-x^3-2,{2}>,
<2*x^6+2*x^5+x^3+x^2+x-2,{2}>,
<-2*x^6+2*x^5+x^3-x+2,{2}>,
<2*x^6-2*x^5-x^3+2*x+2,{}>,
<-x^6-3*x^5+x^3+2*x-2,{2}>,
<2*x^6-x^4-x^3-2*x-2,{2}>,
<-x^6-3*x^5-x^4-x^3-2*x+2,{2}>,
<-2*x^6-2*x^5-x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4-x^3-2*x+2,{2}>,
<-2*x^6-x^5+x^4+x^3+2*x+2,{2}>,
<-x^6+2*x^5+x^4+x^3+2*x-2,{2,7}>,
<-x^6-2*x^5-x^4-x^3-2*x+2,{2,5}>,
<2*x^6-2*x^5-x^3-x^2-x+2,{2}>,
<2*x^6-x^5+x^4+x^3+2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^3-x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^3-x^2+2*x+2,{}>,
<-2*x^6-2*x^5-x^3+x^2-x+2,{2}>,
<-x^6+2*x^5+x^4-x^3-2*x-2,{2}>,
<-2*x^6+2*x^5+x^3+x^2-3*x-1,{}>,
<2*x^6+2*x^5+2*x^3+x^2+x-2,{2}>,
<-x^6-x^4+x^3+2*x+2,{2,3}>,
<-2*x^6-x^4+x^3+2*x+2,{2}>,
<-x^6-x^5-x^4+x^3+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3-2*x-2,{2}>,
<-2*x^6-2*x^5-2*x^3-x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4-x^3-2*x+2,{2}>,
<-x^6+2*x^4+x^3+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x+2,{2}>,
<2*x^6+2*x^5+2*x^3+3*x-1,{2}>,
<-2*x^6-2*x^5-2*x^3-x-1,{2}>,
<-x^6-x^5-2*x^3-2*x+2,{}>,
<2*x^6-x^5-2*x^3-2*x-2,{}>,
<-x^6+3*x^4+x^3+2*x-2,{2}>,
<-2*x^6-2*x^5-x^3+3*x^2+x-1,{0}>,
<-2*x^6+x^5-3*x^4-x^3-2*x+2,{2}>,
<-x^6-2*x^5-3*x^4+x^3+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4-2*x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3+2*x^2+x-2,{2}>,
<2*x^6-2*x^5+2*x^2+x+2,{2}>,
<-x^6+2*x^4+3*x^3+2*x+2,{2}>,
<-2*x^6-2*x^5-3*x^3-2*x^2+2,{}>,
<-2*x^6+2*x^4-3*x^3-2*x+2,{}>,
<2*x^6+x^5-2*x^4-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^3+2*x^2+x+2,{2}>,
<2*x^6-2*x^5+x^2-3*x-1,{}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x-2,{2}>,
<-2*x^6-2*x^5-x^2-x+2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+2*x+2,{2}>,
<-x^6-3*x^5-x^4+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^3+2*x^2+2*x-2,{2,3}>,
<-x^6+3*x^5+2*x+2,{2}>,
<2*x^6+x^5+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^3-x^2+2*x-1,{2}>,
<2*x^6-2*x^5-x-2,{2}>,
<-2*x^6+2*x^5-3*x-1,{}>,
<-2*x^6+x^5-2*x^4-2*x+2,{2}>,
<-2*x^6+2*x^5+x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x-2,{}>,
<2*x^6+2*x^5-x^2+3*x-1,{}>,
<-2*x^6-2*x^5+3*x^2-x-1,{2}>,
<2*x^6+2*x^5-3*x^2-x-2,{2}>,
<2*x^6-2*x^5-3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5-x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4-x^3+2*x-2,{2}>,
<-x^6-3*x^5+x^4+2*x-2,{2}>,
<2*x^6+3*x^4-x^3+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^2+x-1,{2}>,
<2*x^6+2*x^5-x^3+3*x^2-1,{2}>,
<2*x^6-2*x^5+x^3+3*x^2+x-2,{2,3}>,
<2*x^6+2*x^5-x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^5+x^3-3*x^2+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-2*x-2,{2}>,
<2*x^6+2*x^5-x^3+3*x^2-3*x-1,{}>,
<2*x^6-2*x^5+x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5+x^3-3*x^2+x+2,{2,3}>,
<-x^6+3*x^5-2*x^4+x^3-2*x-2,{2,17,47}>,
<2*x^6-2*x^5+x^3+x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4-x^3+2*x-2,{2}>,
<2*x^6+2*x^5-x^3+x^2+x+2,{}>,
<2*x^6+2*x^5-x^3+x^2+x-2,{2}>,
<-x^6-3*x^5+3*x^4-x^3-2*x-2,{2}>,
<-2*x^6-2*x^5-x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-x^5+3*x^4-x^3-2*x-2,{2}>,
<2*x^6+x^5-3*x^4+x^3+2*x+2,{2}>,
<-x^6-x^5-3*x^4-x^3-2*x+2,{}>,
<-2*x^6-2*x^5-x^3+3*x^2-x+2,{2}>,
<-2*x^6+3*x^4+x^3+2*x-2,{2,23}>,
<2*x^6+x^5-x^4+x^3-2*x-2,{2,193}>,
<2*x^6-2*x^5+x^3-x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x-2,{2}>,
<2*x^6+x^5-x^3+2*x-2,{2}>,
<2*x^6+2*x^5-x^3+x-2,{2}>,
<2*x^6+x^3-2*x+2,{}>,
<2*x^6-2*x^5+x^3-3*x-1,{2,3}>,
<2*x^6+2*x^5-x^3+2*x-2,{2}>,
<2*x^6+x^5-x^3+2*x+2,{}>,
<-2*x^6-x^5-x^4-x^3+2*x+2,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x-2,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x+2,{2}>,
<-2*x^6-2*x^5+x^3+2*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-x^3-2*x^2-2,{2}>,
<-x^6+x^5+2*x^4+x^3-2*x-2,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x-2,{2}>,
<-2*x^6-2*x^5+x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5+x^3-3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5+2*x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5-2*x^3-2*x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^4-x^3+2*x-2,{2,3}>,
<2*x^6+2*x^5-x^3+2*x^2+2,{2}>,
<-2*x^6+2*x^5-x^3-2*x^2+2,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^3+3*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4-x^3-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3+2*x-2,{2}>,
<-x^6-3*x^5-x^3+2*x+2,{2,3}>,
<2*x^6+2*x^5+x^3+2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x-2,{2}>,
<2*x^6-2*x^5-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5+x^3+2*x^2+x-1,{}>,
<2*x^6+x^5-2*x^4+x^3+2*x-2,{}>,
<2*x^6-2*x^5+2*x^3-x+2,{2,11}>,
<2*x^6-2*x^5+2*x^3-x^2-3*x-1,{2,3}>,
<-2*x^6+2*x^5-2*x^3+x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+2*x-2,{2,5}>,
<2*x^6-2*x^5+3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-x^4-3*x^3-2*x+2,{2,5}>,
<-2*x^6+2*x^5-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3-2*x+2,{2,5}>,
<2*x^6+2*x^5-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6-2*x^5+3*x^3-3*x^2-x+2,{2,11}>,
<-x^6-3*x^5+2*x^4-2*x^3+2*x-2,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3-2*x-2,{2}>,
<2*x^6-2*x^5+3*x^3+3*x^2+2,{2}>,
<-x^6-x^5-3*x^4+2*x^3-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^3+3*x^2-1,{2}>,
<2*x^6-2*x^5+2*x^3-3*x^2+x-2,{2}>,
<2*x^6-3*x^4-3*x^3+2*x-2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3-2*x+2,{}>,
<-x^6+x^5+2*x^4-3*x^3+2*x+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^3+2*x-2,{2}>,
<-2*x^6+2*x^5-3*x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^3+2*x^2+2,{2}>,
<2*x^6-2*x^5+3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^3-3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+2*x-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-2*x-2,{2,3}>,
<2*x^6+2*x^5-3*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^3+2*x-2,{2}>,
<2*x^6+3*x^3-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^3+x-1,{2}>,
<2*x^6+x^5+3*x^3-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^3-x-2,{2}>,
<-x^6+3*x^5+3*x^3-2*x+2,{2}>,
<2*x^6-x^5-x^4+3*x^3-2*x+2,{2}>,
<-2*x^6+x^5-x^4-3*x^3+2*x+2,{2}>,
<-x^6-x^5-x^4-3*x^3+2*x+2,{2}>,
<2*x^6+x^5+x^4+3*x^3-2*x-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-2*x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-2*x-2,{2}>,
<-x^6-x^5+3*x^4+x^3-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^3+2*x^2-x+2,{2}>,
<2*x^6+2*x^5-x^3-3*x^2+x-2,{2}>,
<-x^6-3*x^4-x^3+2*x+2,{}>,
<2*x^6-2*x^5+x^3-3*x^2-2,{2}>,
<-2*x^6+2*x^5-x^3+3*x^2-x-2,{2}>,
<-x^6+2*x^5-3*x^4+x^3-2*x+2,{}>,
<-2*x^6+2*x^5-x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5-x^4+x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^3-2*x^2-3*x-1,{}>,
<-2*x^6+2*x^5-3*x^3+3*x^2+3*x-1,{2}>,
<-x^6+x^5-3*x^4-3*x^3+2*x+2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-2*x-2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3+2*x+2,{2}>,
<-x^6-3*x^4-3*x^3+2*x+2,{2}>,
<-x^6+x^5+3*x^4+3*x^3-2*x-2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3-2*x+2,{2}>,
<-2*x^6+2*x^5-3*x^3+3*x^2-2*x-2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x-2,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5+3*x^3+x^2+x+2,{2}>,
<-2*x^6-3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+3*x^2-1,{2}>,
<2*x^6-3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5-x^3+2*x^2-2*x-2,{2,307}>,
<-x^6-2*x^5-x^4+x^3-2*x+2,{2}>,
<2*x^6+2*x^5+3*x^3-x^2-x+2,{}>,
<-x^6-x^5-x^4+x^3-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^3+x^2-x-1,{2}>,
<2*x^6-x^5-x^4-x^3+2*x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3-2*x-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x^2-2*x+2,{2}>,
<-x^6-2*x^5-x^4+3*x^3+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+3*x^2-x-1,{2}>,
<-x^6-3*x^5-x^4+3*x^3+2*x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+x^2+2*x-2,{2,13}>,
<-x^6+2*x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2-2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+2*x^2-x-1,{2,3}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-x^2-2*x+2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-2*x-2,{2}>,
<2*x^6-2*x^5+2*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+2*x-2,{2}>,
<2*x^6-2*x^5+2*x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+2*x-2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x-2,{2}>,
<-x^6+3*x^5-x^4-2*x^3+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^3-x^2+3*x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3+x^2-2*x-2,{}>,
<-2*x^6-x^5+x^4-3*x^3-x^2-2*x+2,{}>,
<-2*x^6-2*x^5+x^4-3*x^3-x^2-1,{2}>,
<-x^6+x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6-x^4+3*x^3+x^2+2*x-2,{}>,
<-2*x^6+x^4+3*x^3-x^2+2*x+2,{}>,
<-x^6-3*x^5-2*x^4+x^2-2*x+2,{2,3,5}>,
<2*x^6+2*x^5-x^4+3*x^3+x^2-x-1,{2}>,
<2*x^6-2*x^5+x^4-2*x^2-x-1,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+x^5-2*x^4+x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+x^2-2*x-2,{2}>,
<-x^6-3*x^5-x^4+3*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5+2*x^4-x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2+3*x-1,{0,2}>,
<2*x^6+2*x^5-x^4+3*x^3+2,{2}>,
<-x^6+3*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2,{2}>,
<2*x^6-x^5+3*x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3+3*x-1,{2}>,
<-x^6-x^5+3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x-1,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5-3*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3-x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x-1,{}>,
<2*x^6-2*x^5-x^4-3*x^3+3*x-1,{0,2}>,
<-x^6+3*x^5+x^4+3*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2-2*x+2,{}>,
<-2*x^6-x^5-x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3+x^2+2*x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2-x-2,{}>,
<-x^6-x^5+2*x^4-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3-x-1,{2,3,43}>,
<-2*x^6+2*x^5+x^4+3*x^3+x+2,{2}>,
<-2*x^6+x^5+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+3*x^3+x^2+2*x-2,{2,5}>,
<-x^6-2*x^4-3*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^4+3*x^3+x^2+2*x-2,{}>,
<2*x^6-2*x^5-x^4-3*x^3-2*x^2-2,{}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6-x^5-2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-2*x-2,{2,7}>,
<-2*x^6-2*x^5+x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3-2*x^2+x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<-x^6+2*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+x^2+2*x-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-2*x-1,{0,2,3,41}>,
<-2*x^6+2*x^5+x^4+3*x^3+2*x^2-3*x-1,{0,2}>,
<2*x^6+2*x^5-x^4+3*x^3-3*x^2+2,{}>,
<-2*x^6+2*x^5+x^4+3*x^3+3*x^2-1,{}>,
<-x^6-3*x^4+3*x^3-x^2+2*x+2,{2}>,
<-x^6+x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+3*x^2+2*x-2,{}>,
<2*x^6-2*x^5-x^4-3*x^3-3*x^2+2*x+2,{}>,
<-2*x^6-2*x^5+x^4-3*x^3+3*x^2+3*x-1,{0,2}>,
<2*x^6-2*x^5-x^4-3*x^3-3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5-x^4-2*x^3+3*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+x^2-2*x-2,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+2*x^3+2*x^2+x-1,{}>,
<2*x^6-x^5-2*x^4+2*x^3+x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3-x^2-x-1,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3-x^2+x+2,{2}>,
<2*x^6+2*x^5-3*x^3-2*x^2-2,{2}>,
<2*x^6-x^5-x^4+2*x^3+x^2+2*x-2,{2,3}>,
<-2*x^6+x^5+2*x^3+x^2+2*x-2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x-2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-x-1,{2}>,
<-2*x^6-2*x^5+3*x^3+2*x^2+3*x-1,{2}>,
<-x^6-x^5+x^4+2*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+x+2,{2,7,13,17}>,
<-2*x^6-2*x^5+x^4-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4+2*x^3-x-1,{}>,
<-2*x^6+x^5-2*x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-2*x^3+x^2-3*x-1,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+x^2+2*x-1,{2}>,
<-2*x^6-x^5-x^4-2*x^3-x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3+3*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5+x^4+x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-3*x^2+x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3+3*x^2-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+x^2-x+2,{2}>,
<-2*x^6+2*x^5+x^4+3*x^3+x^2+2,{2}>,
<-2*x^6-x^4-3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^5-x^4-x^3+x^2-3*x-1,{2}>,
<-x^6-2*x^5-x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4-x^3+x^2-2*x-1,{2}>,
<-x^6+x^5+x^4+x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-x^2+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-x^2-3*x-1,{2,7}>,
<-2*x^6+x^4-x^3-x^2-2*x+2,{2,5}>,
<2*x^6-x^5+x^4+x^3-x^2+2*x+2,{2}>,
<-x^6+x^5+x^4-x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-x^2+x+2,{2}>,
<-2*x^6-x^5+x^4+x^3-x^2+2*x+2,{2,3}>,
<-2*x^6-2*x^5+x^4-x^3+x+2,{2}>,
<-x^6-3*x^5+x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+x^2+2*x-2,{}>,
<2*x^6-2*x^5-x^4-x^3-x^2-2*x+2,{}>,
<-2*x^6-2*x^5+x^4-x^3+x^2-x-2,{2}>,
<-x^6-x^5+x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-x^2+x-1,{2}>,
<-2*x^6+2*x^5+x^4+x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4+x^3-x^2+2*x+2,{2}>,
<-x^6+x^4-x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3+3*x-1,{2,3,7,67}>,
<-2*x^6+2*x^5+x^4+x^3+2*x-1,{2}>,
<2*x^6+x^4+x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4+x^3+x^2+2*x-2,{2}>,
<-x^6+2*x^5+x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+2*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-x^4+x^3+x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+x^3+x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+x^2+2*x-2,{2}>,
<2*x^6+x^5+x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-2*x^2+2*x-1,{2}>,
<-x^6-x^3-x^2-2*x+2,{2,3}>,
<2*x^6-x^5-2*x^4-x^3-x^2-2*x+2,{2}>,
<-2*x^6-x^3-x^2-2*x+2,{2}>,
<-x^6-x^5-2*x^4-x^3-x^2-2*x+2,{2}>,
<-x^6-x^5+x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5+2*x^4-x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3+2*x^2-1,{2}>,
<-2*x^6+2*x^4-x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-x^3+2*x^2+x-1,{0,2,3}>,
<-2*x^6+x^5-2*x^4-x^3-x^2-2*x+2,{2}>,
<-2*x^6+3*x^4-x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5-2*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6-3*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x^2-2,{2}>,
<-x^6-x^5+3*x^4+x^3+x^2+2*x-2,{}>,
<-2*x^6+2*x^5+x^4+x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4-x^3-x^2-2*x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6-3*x^5-3*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4+3*x^2+x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4-x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4+x^2+3*x-1,{2}>,
<-2*x^6+2*x^5+x^4-x^2+x+2,{2}>,
<2*x^6+2*x^5-x^4+x^2+x-2,{2}>,
<2*x^6-x^5+x^4-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^2+3*x-1,{2}>,
<-x^6-3*x^5-x^2-2*x+2,{}>,
<-x^6-x^5-x^2-2*x+2,{2}>,
<2*x^6-2*x^5-x^4-x-2,{2}>,
<-2*x^6-2*x^5+x^4+x^2-x+2,{2}>,
<-x^6+3*x^5+2*x^4+x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4+2*x^2-x-2,{2}>,
<-2*x^6-2*x^5+x^4+2*x^2-x-1,{2,3}>,
<2*x^6-2*x^5-x^4-2*x^2+x-1,{2}>,
<2*x^6-2*x^5-x^4-2*x^2+x-2,{2}>,
<2*x^6+2*x^5-x^4-2*x^2-3*x-1,{2}>,
<-2*x^6+x^5+3*x^4+x^2+2*x-2,{2}>,
<-x^6-x^5-3*x^4-x^2+2*x+2,{2}>,
<2*x^6+x^5+3*x^4+x^2-2*x-2,{2,5}>,
<2*x^6+2*x^5-x^4-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3+x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4-x^3+3*x^2+2*x-2,{2}>,
<-x^6-3*x^5+2*x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6+3*x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+x^2-2*x-2,{2}>,
<2*x^6-3*x^4+x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4-x^3+2*x^2+x-2,{2}>,
<-2*x^6+2*x^5+x^4-x^3-2*x^2-x+2,{2}>,
<2*x^6+2*x^5-x^4-x^3+3*x^2-x+2,{2,3}>,
<2*x^6-x^5-x^4+x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4+x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5-3*x^4+x^3+x^2-2*x-2,{}>,
<-2*x^6+x^5+x^4-x^3-x^2+2*x+2,{2}>,
<-x^6-3*x^5-x^4-x^3+x^2+2*x-2,{2}>,
<-2*x^6+x^5+3*x^4+x^3-x^2-2*x+2,{}>,
<-2*x^6-x^5-x^3-x^2+2*x+2,{2}>,
<-x^6+2*x^5+x^3+x^2-2*x-2,{2,7}>,
<-2*x^6-2*x^5+x^4+x^3-3*x-1,{2}>,
<2*x^6-2*x^5-x^4+x^3+3*x-1,{2}>,
<-2*x^6+2*x^5+x^4-x^3+x^2+3*x-1,{}>,
<-x^6-2*x^5+x^3-x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+x^4-x^3+x^2+2*x-1,{2}>,
<2*x^6+2*x^5-x^4-x^3-2*x^2-2,{2}>,
<2*x^6+x^5+2*x^4+x^3+x^2-2*x-2,{2,3}>,
<-2*x^6+x^5-2*x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6-2*x^5-x^4+x^3-x^2-2,{2,5}>,
<-2*x^6+2*x^5+x^4-x^3+2*x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2-x-2,{}>,
<2*x^6-x^5-3*x^4+x^3-x^2-2*x+2,{}>,
<-2*x^6+2*x^5+x^4-x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2-x-1,{2}>,
<-x^6-x^5+2*x^4+x^3+x^2-2*x-2,{2}>,
<-x^6-x^5-3*x^4+x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2-x+2,{}>,
<-2*x^6-x^5-2*x^4+x^3-x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4+x^3-x^2-2*x+2,{}>,
<-x^6-3*x^4+x^3-x^2-2*x+2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+x^4+x^3+3*x^2+2,{2,13}>,
<-2*x^6+2*x^5+x^4-2*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^4+x^3-x^2-2*x+2,{2,5}>,
<2*x^6-x^5+x^4-2*x^3-x^2+2*x+2,{2}>,
<-x^6-x^5-3*x^4-x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-3*x-1,{}>,
<-2*x^6+x^5-3*x^4+x^3-x^2-2*x+2,{2}>,
<-x^6+x^5+2*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^5-3*x^4-x^3-x^2+2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+x^2-2*x-2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-3*x-1,{2}>,
<2*x^6+2*x^5-x^4-2*x^3+3*x^2+x+2,{}>,
<-x^6-3*x^5+x^4+2*x^3+x^2-2*x-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-x^2+2*x+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-x^2-x-2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-2*x^2+x-1,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-2*x^2+x-1,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-x^2+2*x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+x^2-2*x-2,{}>,
<-2*x^6-x^5-x^4-2*x^3-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-2*x^2-3*x-1,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+x^4-2*x^3+3*x^2-x+2,{2}>,
<2*x^6-2*x^5-x^4-x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4-2*x^3-3*x^2-2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+x^2+2*x-2,{}>,
<2*x^6+2*x^5-x^4-3*x^3+3*x^2+x-2,{}>,
<-x^6-x^5+2*x^4-x^3-x^2-2*x+2,{2}>,
<2*x^6-2*x^5-x^4+2*x^3-3*x^2+x-1,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+2*x^2+x+2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+x^3-2*x^2+x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-x^2+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-x^2+2*x+2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+x^2-3*x-1,{}>,
<2*x^6-2*x^5-x^4-x^3+2*x^2-x-2,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x^2-2*x-2,{2}>,
<2*x^6+x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4-x^3-2*x^2+2,{2}>,
<2*x^6+x^5+x^4+3*x^3-x^2-2*x+2,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+x^2-x-1,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3-x^2+x+2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+x^2+3*x-1,{2}>,
<-2*x^6-x^5+x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+x^5+2*x^4-x^3-x^2-2*x+2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+2*x^2-3*x-1,{2}>,
<2*x^6+2*x^5-x^4-3*x^3+3*x-1,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-x+2,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-2*x^2-x-1,{2}>,
<-2*x^6-x^5+3*x^3-x^2-2*x+2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+x^2-2*x-2,{2}>,
<-x^6-2*x^4-3*x^3-x^2+2*x+2,{}>,
<-2*x^6-2*x^5+x^4+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+x-1,{2}>,
<2*x^6+2*x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^4-3*x^3-x^2+2*x+2,{2}>,
<2*x^6-x^5-3*x^3+x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3+x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6-2*x^5-x^4+3*x^3+2*x-1,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-x-2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6+x^5-3*x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3-3*x-1,{2}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+x^2+2*x-2,{2}>,
<2*x^6-x^5+x^4+3*x^3+x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+2*x^2+x-1,{2}>,
<-2*x^6-x^5+2*x^4+2*x^3+x^2+2*x-2,{2}>,
<-x^6-x^5+2*x^4+2*x^3+x^2+2*x-2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+x^4+2*x^3+3*x^2+x-2,{2}>,
<2*x^6+2*x^5-x^4+2*x^3-3*x^2+x+2,{2}>,
<2*x^6-2*x^5-x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+2*x^2-2*x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2+3*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2+2*x+2,{}>,
<2*x^6+2*x^5-2*x^4+x^3+2*x+2,{2,307}>,
<-2*x^6-2*x^5-x^3+2*x^2-x-2,{2}>,
<-x^6+x^5+2*x^4+x^3+2*x-2,{2}>,
<-x^6-x^5-2*x^4-x^3-2*x+2,{2}>,
<-2*x^6-2*x^5-x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+2*x^2+x-1,{}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-x^6+2*x^5+x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-x^5-x^4-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-x^5-x^4-3*x^3+2*x^2-2*x-2,{}>,
<-2*x^6+x^5+x^4+3*x^3-2*x^2+2*x+2,{}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-x^2-2,{}>,
<2*x^6+x^4+3*x^3-2*x^2+2*x+2,{}>,
<-x^6-x^4-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+x^2-1,{2}>,
<2*x^6-x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-x^2-x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-x^2-x+2,{}>,
<2*x^6+2*x^5-2*x^4+3*x^3+x^2-x-2,{}>,
<-x^6+3*x^5+x^4-3*x^3-2*x^2-2*x+2,{0,2}>,
<-2*x^6-2*x^5+x^4-x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^5-3*x^3+2*x^2-2*x-2,{2,7}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+2*x-1,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-2*x^5-x^4-x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+x-1,{2}>,
<-x^6+2*x^5+3*x^4+x^3+x^2+2*x-2,{2}>,
<2*x^6+x^5+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+2,{}>,
<-2*x^6-2*x^5+x^4-x^3+3*x^2-x-1,{2}>,
<-2*x^6-3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-x-1,{2}>,
<2*x^6+x^5-3*x^3+2*x^2-2*x-2,{}>,
<-2*x^6+x^5-3*x^3-2*x^2-2*x+2,{}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2+2*x-1,{}>,
<-2*x^6-x^5+x^4-3*x^3+2*x^2-2*x-2,{2,7}>,
<-x^6-x^5+x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-x^6+x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+x^2+x-2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-x^2+x+2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-x^2-x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+x^2-x+2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+x^2+x-1,{2}>,
<-x^6-x^5-x^4+3*x^3-x^2+2*x+2,{2,3}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2+x-1,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2+x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+2*x^2-2,{2}>,
<2*x^6-2*x^4-3*x^3-2*x^2-2*x+2,{}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<-x^6+x^5-3*x^4+3*x^3+2*x^2+2*x-2,{2,3}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-3*x^2+x+2,{2}>,
<2*x^6-2*x^5-x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6+3*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+3*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+3*x^2-x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-3*x^2-x-1,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3+2*x^2+3*x-1,{}>,
<-x^6-x^5+2*x^4-2*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-2*x^2+x+2,{}>,
<-2*x^6-x^5+2*x^4-2*x^3-2*x^2-2*x+2,{}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-2*x^2+x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-2*x^2+x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3+x^2+3*x-1,{}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-x^2+x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+x^2-x+2,{2}>,
<-x^6+x^5-x^4+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^3+x^2-x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+2*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3-x^2-3*x-1,{0}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+3*x-1,{2}>,
<-x^6+2*x^5+2*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3-x+2,{}>,
<-2*x^6+x^5+2*x^3-2*x^2+2*x+2,{}>,
<-x^6-x^5+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-x^5+2*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-x^5-x^4-2*x^3-2*x^2-2*x+2,{2,3}>,
<2*x^6-x^5+3*x^4-3*x^3+x^2-2*x-2,{2}>,
<-x^6+x^5+x^4+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-x^4+3*x^3-3*x^2+x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^5+x^4-3*x^3+3*x^2-2,{}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+x^2-x-1,{2}>,
<-x^6+3*x^5-x^4-2*x^3-2*x^2-2*x+2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+2*x^2-x-2,{}>,
<-2*x^6-2*x^5+2*x^4-x^3-3*x^2-3*x-1,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3+3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+2*x^2-x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+2*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x^2+2,{2,5}>,
<-2*x^6+2*x^5+2*x^4+2*x^3+3*x^2+x-1,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+2*x^2-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^3+3*x^2+x-1,{0,2}>,
<-2*x^6+2*x^5+2*x^4+x^3-2*x^2-x-1,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3+x^2-1,{}>,
<-x^6+3*x^5+x^4+x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+x^2-2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-x^2+x-2,{2}>,
<-x^6-2*x^5-x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+x^5-x^4-x^3+2*x^2-2*x-2,{2,5,7}>,
<2*x^6-2*x^5-2*x^4-x^3+x^2-2*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-x^2+2*x-1,{2,13}>,
<-x^6-x^5-2*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-x^6-3*x^5-x^4+x^3+2*x^2+2*x-2,{2}>,
<-x^6+x^5+2*x^4+3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-x^5-x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5+x^3-2*x^2+2*x+2,{2}>,
<-x^6+2*x^5-2*x^4+x^3-2*x^2+2*x+2,{2}>,
<-x^6-x^5+2*x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+2*x^2+x-2,{2}>,
<2*x^6+2*x^5-2*x^4+x^3-2*x^2-x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5+2*x^4+x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+x^2+3*x-1,{0,2}>,
<-2*x^6+2*x^5+2*x^4+x^3+x-1,{2,101}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x^2+2*x-1,{2}>,
<2*x^6+x^5+x^3+2*x^2+2*x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-2*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-x-2,{2}>,
<-x^6+3*x^5-2*x^4-x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6-x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-3*x-1,{0,2}>,
<-x^6-3*x^5+3*x^4-x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+x^4+x^3+2*x^2+2*x-2,{2,3}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2+2*x-1,{2,5}>,
<-2*x^6-2*x^5+2*x^4-x^3+3*x^2+3*x-1,{0}>,
<-2*x^6+x^5+3*x^4+x^3+2*x^2+2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^2+2*x+2,{}>,
<-x^6+2*x^5+x^4+x^3+2*x^2+2*x-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^2+2*x-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2-2*x+2,{2}>,
<-x^6+2*x^5-x^4+x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-2*x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4+x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-2*x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6-x^5+2*x^4-2*x^2+2*x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^2+3*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^2+2*x-2,{2}>,
<-x^6+3*x^4+x^3+2*x^2+2*x-2,{0,2}>,
<-2*x^6-x^5+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2+2,{2}>,
<-x^6+x^5+x^4-2*x^2+2*x+2,{2,3}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2-2,{2}>,
<-2*x^6+x^5+x^4-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5+x^4+2*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+2*x^2+x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-3*x^2+x-1,{2}>,
<-2*x^6-x^5-2*x^4-2*x^2-2*x+2,{2,5}>,
<-2*x^6-2*x^5+2*x^4+2*x^2+x+2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^2-2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^2-x-1,{2}>,
<2*x^6-2*x^5-2*x^4-2*x^2+x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3+2*x^2-2*x-2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^2+2*x+2,{2}>,
<-2*x^6+x^5+3*x^4-x^3-2*x^2+2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+2*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^2+x-1,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4+2*x^2-2*x-2,{2}>,
<-x^6-x^5+2*x^4+x^3-2*x^2-2*x+2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+2*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-2*x^2-2*x+2,{}>,
<2*x^6+x^5-x^4-x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-x^5+x^4-x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-x-1,{2,5}>,
<2*x^6+2*x^5-2*x^4-x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3-x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3-3*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-2,{2}>,
<-x^6+3*x^5-x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-x^5-x^3+2*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+2*x-1,{2}>,
<-x^6+3*x^4+3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+x^5+x^4+x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3+x-2,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-x^2+2*x-1,{2,3,11}>,
<-2*x^6+2*x^5+2*x^4-x^3+x^2-3*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+2*x^2+3*x-1,{}>,
<2*x^6-2*x^5-2*x^4-3*x^3-3*x^2+x-2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3+x^2-2,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2-2*x-2,{2}>,
<-x^6+x^4-x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-x^3+2*x^2+2*x-2,{2,5,17,23}>,
<-x^6-x^5+2*x^4+x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2+x-1,{}>,
<2*x^6-2*x^5-2*x^4-x^3-x^2+x+2,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+2*x^2-2*x-2,{2,17}>,
<-x^6+x^5+x^4-x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-x^2+x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+2*x^2+3*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+x^3-2*x^2-1,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3+2*x^2+2*x-2,{}>,
<2*x^6+2*x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-2*x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3+2*x^2+2*x-2,{}>,
<2*x^6-2*x^5-2*x^4+x^3-3*x^2-1,{2}>,
<-x^6+3*x^5-2*x^4+x^3-2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-3*x^2-2,{2}>,
<-x^6+x^5+3*x^4+x^3+2*x^2-2*x-2,{0}>,
<-x^6+3*x^5+3*x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3-2*x^2-2*x+2,{}>,
<2*x^6+x^5+3*x^4+x^3+2*x^2-2*x-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3+2*x^2-2*x-2,{2}>,
<-2*x^6-x^5-3*x^4-x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+2*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6+2*x^5-2*x^4-x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5-3*x^4+x^3-2*x^2-2*x+2,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3+2*x^2-x+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2+2*x-2,{2}>,
<-x^6-3*x^5+x^4+2*x^3-2*x^2-2*x+2,{2}>,
<-x^6-3*x^5+x^4-2*x^3-2*x^2+2*x+2,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+2*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<-x^6-x^5-3*x^4+2*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-2*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-3*x^2+x+2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+2*x^2-2*x-2,{2,3}>,
<2*x^6+2*x^5-2*x^4+x^3+3*x^2+x-2,{2,3}>,
<2*x^6-2*x^5-2*x^4+3*x^3+x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4+x^3-3*x^2+2,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3+x^2-x-2,{2}>,
<-x^6-x^5+x^4-3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-2*x^4-x^3+3*x^2+x+2,{2}>,
<-2*x^6-2*x^5+2*x^4-x^3-2*x^2-3*x-1,{2}>,
<-x^6+2*x^5-2*x^4+x^3+2*x^2+2*x-2,{2}>,
<-x^6+2*x^5+3*x^3+2*x^2-2*x-2,{2}>,
<-x^6+3*x^5+3*x^3+2*x^2-2*x-2,{}>,
<2*x^6-2*x^5-2*x^4+3*x^3+3*x-1,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3-x^2-x+2,{2,89}>,
<2*x^6+2*x^5-2*x^4-3*x^3+x^2-2*x-1,{}>,
<-x^6+3*x^5-x^4+3*x^3+2*x^2-2*x-2,{2,41}>,
<2*x^6+x^5-3*x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3+x-2,{2}>,
<-2*x^6-3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-x-1,{}>,
<2*x^6-2*x^5-2*x^4+3*x^3-2*x^2-x-2,{2}>,
<2*x^6-2*x^5-x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-x^5-3*x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3-x^2-2*x+2,{2}>,
<-x^6-3*x^4+3*x^3-x^2-2*x+2,{2}>,
<-2*x^6+x^5-3*x^4-x^3-2*x^2+2*x+2,{2,5,7}>,
<-2*x^6+2*x^5+x^4-3*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4-3*x^3-x^2+2*x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2-2*x-2,{}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-3*x^2+x-2,{2,3}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6-3*x^4+3*x^3+3*x^2+2*x-2,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x^2-2,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+2*x^2+x-1,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-2*x^2-1,{2,7}>,
<2*x^6-2*x^5-3*x^4-3*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-2*x^2+x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+2*x^2+2*x-1,{}>,
<2*x^6+2*x^5-2*x^4-2*x^3-x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+x^2+3*x-1,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3-x^2-x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6-x^5-x^4-2*x^3-2*x^2+2*x+2,{2}>,
<-x^6+x^5-x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-x^6+3*x^5+x^4+2*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-x^2+x+2,{2}>,
<-2*x^6-x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4+2*x^3-2*x^2-x-1,{2}>,
<2*x^6+x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-x^2+2,{2}>,
<2*x^6+2*x^5-2*x^4-2*x^3-2*x^2-x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3+x^2-2,{2}>,
<-x^6+2*x^5-x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-3*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3-1,{2}>,
<-x^6+3*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+3*x^3-3*x^2+2*x+2,{2}>,
<-x^6+2*x^5-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2+x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2-x-1,{2}>,
<-2*x^6+x^5-x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2+2,{2}>,
<-x^6+x^4+3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-x^2-1,{2}>,
<2*x^6-2*x^5-2*x^4+3*x^3-x^2-2*x-1,{2}>,
<-2*x^6-2*x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3+3*x^2-2*x-2,{0,2}>,
<-2*x^6-x^4-3*x^3-2*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-x^2-x+2,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6+2*x^5-3*x^4+3*x^3-2*x^2-x-2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+3*x^2+2*x-2,{0,2}>,
<-x^6+3*x^5-2*x^4-3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-3*x^2-2*x+2,{}>,
<-x^6-2*x^5+3*x^4-3*x^3+3*x^2-2*x-2,{}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+3*x^2-x-2,{2}>,
<-x^6+x^5+x^4+3*x^3+2*x^2-2*x-2,{2}>,
<-x^6+3*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2+2*x-2,{2}>,
<-x^6+2*x^4-3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+x^5-x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-2,{}>,
<2*x^6+2*x^5-3*x^4+3*x^3-3*x^2-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3+3*x^2+2*x-2,{}>,
<-x^6+2*x^5+x^4+3*x^3+2*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-2*x^4-3*x^3-2*x^2-1,{2}>,
<-x^6+x^5+2*x^4-3*x^3+2*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+3*x^2-x+2,{2}>,
<-x^6-x^5-3*x^4+3*x^3-3*x^2+2*x+2,{}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2-2*x+2,{}>,
<-2*x^6-x^5-3*x^4+3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-2*x-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2+2*x-2,{}>,
<-2*x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-2*x^2-x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+3*x^3+3*x^2-2*x-2,{0,2,3}>,
<-2*x^6-x^5+2*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-2*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-x^6-2*x^5-x^4-2*x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-x^2+x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-x^2+x-1,{2}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+2*x^4+3*x^3+2*x^2-3*x-1,{0,2}>,
<-x^6+3*x^5+2*x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-3*x^2-3*x-1,{2,3}>,
<-x^6+x^5+3*x^4+2*x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+3*x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-3*x^2-x-1,{2}>,
<-x^6+2*x^5-3*x^4-2*x^3-3*x^2-2*x+2,{2}>,
<-x^6-3*x^5-3*x^4+2*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-3*x^2+3*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+3*x^2+x-1,{2}>,
<-2*x^6-3*x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2+x-2,{2,3}>,
<-2*x^6-2*x^5+3*x^4-x^3-3*x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4+x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-2*x^2+2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2+2*x+2,{2}>,
<-x^6+x^5-2*x^4+x^3+3*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3-3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3+2*x^2-1,{2,3}>,
<2*x^6-2*x^5-3*x^4-x^3+2*x^2-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-2*x^2+x-2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4+x^3+3*x^2+2*x-2,{2}>,
<-x^6+2*x^5-2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<2*x^6+2*x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+2*x^2+x+2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-2*x^2-x-2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-x-2,{}>,
<2*x^6+2*x^5-3*x^4+x^3+x+2,{}>,
<-x^6-x^5-x^3-3*x^2-2*x+2,{2}>,
<2*x^6+x^5+x^3+3*x^2+2*x-2,{2,7}>,
<-2*x^6-2*x^5+3*x^4-x^3-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-1,{2,5}>,
<-2*x^6-2*x^5+3*x^4-x^3+x-1,{2}>,
<-2*x^6-x^5+x^3-3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^3-3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-3*x-1,{0,2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2-3*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2-2*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+x^2+x-1,{2}>,
<-2*x^6+x^4+x^3+3*x^2+2*x-2,{2}>,
<2*x^6-x^4-x^3-3*x^2-2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2-2,{2}>,
<-x^6-x^5+x^4+x^3+3*x^2+2*x-2,{0,2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2+x-1,{}>,
<-2*x^6-2*x^5+3*x^4-x^3+x^2+x+2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-x^2+2*x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+3*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3+2*x^2+x-2,{}>,
<2*x^6-2*x^5-3*x^4-x^3-2*x^2+2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2+2*x-2,{0,2}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2+2*x-2,{2}>,
<-x^6+2*x^5+3*x^4+x^3+3*x^2+2*x-2,{2}>,
<-x^6-x^5+3*x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-x^3-3*x^2-x-1,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+3*x^4-x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^4-x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-3*x^2-2,{2}>,
<2*x^6+2*x^5-3*x^4+x^3-3*x^2-2*x+2,{}>,
<2*x^6-2*x^5-3*x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4+x^3+3*x^2+2*x-2,{0,2}>,
<-x^6-3*x^5-3*x^4+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4-3*x^2-x-2,{2,3}>,
<2*x^6+x^5-3*x^4+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^2-x-2,{2}>,
<-x^6-x^5+3*x^4+3*x^3+2*x^2-2*x-2,{0}>,
<-2*x^6-2*x^5+3*x^4-2*x^2-3*x-1,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+2*x^2+2*x-2,{2}>,
<-x^6+x^5+2*x^4-3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-2*x^4-3*x^3-3*x^2+x-2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^2-x-1,{2}>,
<-x^6-3*x^5-2*x^4+3*x^2+2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^2+x-1,{2}>,
<-2*x^6+x^5-x^4+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x-1,{2}>,
<-x^6+3*x^5-3*x^2-2*x+2,{0,2}>,
<-2*x^6+2*x^5+2*x^4+x^2+x-2,{2}>,
<-x^6-x^5+x^4+2*x^2-2*x-2,{2}>,
<-x^6-x^5-x^4-2*x^2+2*x+2,{}>,
<-2*x^6-x^5-x^4-2*x^2+2*x+2,{2}>,
<-x^6-3*x^5+2*x^4+2*x^2-2*x-2,{}>,
<-2*x^6-2*x^5+3*x^4+2*x^2-3*x-1,{2}>,
<-x^6+x^5+2*x^4+3*x^2+2*x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^2-x-2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^2+2*x+2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^2-2*x-2,{2,3}>,
<2*x^6+2*x^5-3*x^4-3*x^2-1,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^2+x+2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+x^3+3*x^2-x-1,{}>,
<2*x^6+3*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-3*x^2+3*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-x^2+3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-x^3+2*x^2+2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-x^3+x^2+3*x-1,{}>,
<-2*x^6-x^5-2*x^4+x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3-x^2-2,{2}>,
<-x^6+x^5-x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6+x^5+2*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-x^3-3*x^2+2*x+2,{2}>,
<2*x^6-x^5-2*x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6+x^5+x^4-x^3+2*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3+3*x-1,{2}>,
<-2*x^6-x^5-x^4+x^3-2*x^2-2*x+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3+x-1,{2}>,
<-x^6+2*x^5-x^3+3*x^2+2*x-2,{2,3}>,
<-x^6-x^4+x^3-2*x^2-2*x+2,{2}>,
<2*x^6-x^5+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3+2*x^2-3*x-1,{2}>,
<-2*x^6-x^5+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-1,{2}>,
<-2*x^6-x^4+x^3-2*x^2-2*x+2,{2}>,
<2*x^6-x^5-x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-x^2-x-1,{2}>,
<-x^6-x^5-x^4-x^3-2*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3-x+2,{2}>,
<-x^6-x^5+x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x^2+3*x-1,{}>,
<2*x^6+2*x^5-3*x^4-x^3-x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-x^3-3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^5-x^3+3*x^2+2*x-2,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2-2*x-2,{2}>,
<2*x^6-3*x^4+x^3-3*x^2-2*x+2,{0,2,5}>,
<-2*x^6-2*x^5+3*x^4+x^3+2*x^2-x-2,{2}>,
<-x^6+3*x^5+x^4-x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-3*x^2-1,{2}>,
<-x^6-x^5-2*x^4+x^3-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^4+x^3+3*x^2-2*x-2,{2}>,
<-x^6-2*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^4-x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+2*x^2-x-1,{0,2}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2+2*x-1,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-3*x^2+3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+x^3-2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3+2*x^2+3*x-1,{2,3}>,
<-x^6+3*x^5-x^4-2*x^3+3*x^2+2*x-2,{2}>,
<-x^6-3*x^5+3*x^4+x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^3-3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3+x^2+x-2,{2,17}>,
<-2*x^6+x^5-x^4-2*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-x^4+2*x^3-3*x^2-2*x+2,{2,3}>,
<-2*x^6+2*x^5+3*x^4-2*x^3+x^2-x+2,{2,5}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2-2*x-2,{2}>,
<-x^6-3*x^5+2*x^3+3*x^2-2*x-2,{}>,
<-2*x^6-x^5-x^4-2*x^3-3*x^2+2*x+2,{2,5}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+2*x^2-3*x-1,{}>,
<-2*x^6-x^5-2*x^4+2*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6-3*x^4+3*x^3-2*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+2*x^2+3*x-1,{0,2}>,
<-2*x^6-2*x^5+2*x^4+3*x^3+3*x^2+x-2,{2}>,
<2*x^6+x^5+x^4+x^3-3*x^2+2*x+2,{2}>,
<-x^6-x^5-x^4-x^3+3*x^2-2*x-2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^3-x^2+x+2,{2}>,
<-2*x^6+2*x^5+2*x^4-3*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^5-3*x^4-2*x^3-3*x^2+x+2,{0,2}>,
<-2*x^6+x^5+x^4+x^3-3*x^2+2*x+2,{2}>,
<-x^6-x^4-x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3-3*x^2-x-1,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+2*x^3+3*x^2-x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-2*x^3+3*x^2-x+2,{2}>,
<2*x^6-2*x^5-3*x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3+3*x^2+2*x-2,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2-2*x+2,{}>,
<-2*x^6-2*x^5+3*x^4-x^3-x^2+3*x-1,{0,2}>,
<2*x^6+x^5-x^4-3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+3*x^2+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3+x^2+x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-x^3+x^2+x+2,{2,3,131}>,
<2*x^6+2*x^5-3*x^4-3*x^3+x^2-2,{2}>,
<-x^6-3*x^5-x^3+3*x^2-2*x-2,{2}>,
<-x^6-x^4+x^3-3*x^2-2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+x-1,{2}>,
<2*x^6+x^4-x^3+3*x^2+2*x-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3-x^2+3*x-1,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+3*x-1,{0,2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-x^2-x+2,{}>,
<2*x^6+2*x^5-3*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+3*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-x^2-2,{2}>,
<-2*x^6-2*x^5+3*x^4-x^3-2*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+x^2-x-1,{2,3}>,
<-2*x^6+x^5+2*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-x^5+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-x^2-x-1,{2}>,
<-2*x^6+3*x^3-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+x^2+2,{2}>,
<-x^6-3*x^3-3*x^2+2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4+2*x^3-x^2+x-1,{2}>,
<-2*x^6-x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-2*x^6+x^5+x^4+3*x^3+3*x^2-2*x-2,{}>,
<-2*x^6-x^5-2*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2-x+2,{}>,
<2*x^6-2*x^5-3*x^4-2*x^3-x^2+x-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-2*x^2-1,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-x^2-x-1,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+2*x^2+x-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-2*x^2+x-1,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+x^5-x^4+x^3-3*x^2-2*x+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^3-x^2-2*x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3+2*x^2-x-2,{2}>,
<-x^6-3*x^5+x^4-x^3+3*x^2+2*x-2,{0}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x^2-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-3*x^2-2*x+2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<2*x^6+3*x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-2*x^2+2,{2,7,13}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3+3*x^2-1,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2+x-2,{}>,
<2*x^6+x^5+3*x^4+3*x^3+2*x^2-x-2,{}>,
<-2*x^6-x^5-3*x^4-3*x^3-3*x^2+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-3*x^2-x-2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^4+3*x^3+3*x^2+x+2,{}>,
<-x^6-2*x^5-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3-x+2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^3+3*x^2-x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3+3*x^2+x+2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3+2,{2,3}>,
<-2*x^6+3*x^3+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+x^2+3*x-1,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3-x^2-x+2,{2,13}>,
<-x^6+x^5-x^4+3*x^3+3*x^2+x+2,{2}>,
<-x^6-3*x^5-3*x^3+3*x^2-x+2,{}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4-3*x^3-x^2-1,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-2*x^2-1,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3+2*x^2+2,{2,5}>,
<-2*x^6-x^5-3*x^4-3*x^3+x^2+2,{2}>,
<-2*x^6-2*x^4-3*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4-3*x^3+2*x^2+x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4+3*x^3+2*x^2-x-1,{0,2,3,31}>,
<-x^6-x^5+3*x^4-3*x^3-3*x^2-x-2,{2}>,
<-2*x^6+2*x^5+3*x^4-3*x^3+2*x^2+x+2,{2}>,
<-x^6-3*x^4+3*x^3+3*x^2+x+2,{2,3}>,
<-2*x^6+x^5-3*x^4+3*x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^3+3*x^2+x+2,{2,13,17,31}>,
<-2*x^6-x^5-3*x^4+3*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+3*x^2-x+2,{}>,
<-x^6-x^5+2*x^4-2*x^3+3*x^2-x+2,{}>,
<-2*x^6-x^5-3*x^4-3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-3*x^2+x-2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2+x-2,{}>,
<2*x^6+2*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+2*x^2-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3-2*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+2*x^2+x-2,{2}>,
<2*x^6-3*x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^3+2*x^2-2*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x^2-x-2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3-x^2+2,{2}>,
<2*x^6+x^5-x^4-2*x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3+x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^3-x-1,{}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5-x^4-2*x^3+3*x^2-x+2,{2}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^4-2*x^3-3*x^2-x-2,{2}>,
<-2*x^6-x^5-3*x^4-2*x^3+x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-2*x^2+x-2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3+3*x^2+3*x-1,{}>,
<2*x^6-x^5+3*x^4-2*x^3-x^2-x-2,{2}>,
<-2*x^6+x^5-3*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6-x^4-2*x^3+3*x^2-x+2,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-x^2+3*x-1,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-3*x^2-2,{2}>,
<2*x^6-x^5+3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-x^6+x^5-3*x^4-2*x^3+3*x^2-x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-x^5-3*x^4-2*x^3+3*x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-2*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4-2*x^3+3*x^2-x+2,{2}>,
<2*x^6+2*x^4+x^3+3*x^2+x+2,{}>,
<-2*x^6-x^5-3*x^4-2*x^3+3*x^2+3*x-1,{2,5}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2-3*x-1,{2,3}>,
<-x^6-3*x^5-x^4-3*x^2-2*x+2,{2}>,
<-2*x^6+2*x^5+3*x^4+x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4-x^3+3*x^2-2*x-1,{2}>,
<2*x^6+2*x^5-3*x^4-x^2+x-2,{2}>,
<-2*x^6+x^5-3*x^4+x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5+x^4+3*x^2+2*x-2,{2}>,
<-2*x^6+x^5-x^4-3*x^2-2*x+2,{2}>,
<2*x^6+3*x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6-2*x^5+3*x^4-2*x^3-3*x^2-x-1,{2,5}>,
<2*x^6-x^5-3*x^4-2*x^3+3*x^2-2*x-2,{2}>,
<2*x^6-2*x^5-3*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6+2*x^5-3*x^4-x^2-3*x-1,{0,2,7,29}>,
<-2*x^6-x^5-3*x^4-x^3-x^2+2,{2}>,
<2*x^6+x^5+3*x^4+x^3+x^2-2,{2}>,
<2*x^6+x^5+3*x^4+x^3+x^2-x-2,{2}>,
<-x^6+2*x^5+x^3-3*x^2+x-2,{2,11}>,
<-2*x^6+2*x^5+3*x^4+2*x^3-3*x^2-x-2,{2,7}>,
<-x^6+x^3+3*x^2+x+2,{2}>,
<2*x^6-x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+3*x-1,{2}>,
<2*x^6-x^5+3*x^4-x^3+x+2,{2}>,
<-2*x^6+x^5-3*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+x^5-x^3+3*x^2-x+2,{2}>,
<-x^6+2*x^5-x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4+x^3-x^2+x-2,{2}>,
<2*x^6-x^5-x^4+x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3+3*x-1,{2}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2-x-2,{2,3,89}>,
<-2*x^6-x^5-3*x^4-x^3+x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+x^3-3*x^2+x-2,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2+x+2,{}>,
<2*x^6+x^5+3*x^4+x^3-2*x^2-2,{2,7}>,
<2*x^6+x^5+3*x^4+x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5-x^4+x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5+x^4-x^3-3*x^2-x-2,{2}>,
<-2*x^6-x^5-3*x^4-x^3-x^2-x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+x^5-3*x^4+x^3+2*x^2-3*x-1,{2}>,
<2*x^6+x^4+x^3+3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3+3*x^2-3*x-1,{2}>,
<-2*x^6+x^5-3*x^4+x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5+3*x^4-x^3+x^2-1,{}>,
<2*x^6+x^5+3*x^4+x^3-3*x^2+3*x-1,{2}>,
<-x^6-3*x^4+x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5+3*x^4+x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-x^5-3*x^4-2*x^2-x+2,{2,5}>,
<2*x^6-x^5+3*x^4+2*x^2-x-2,{2}>,
<2*x^6-x^5+3*x^4-x^3-3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4-x^3+3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^2-2,{2}>,
<2*x^6+x^5+3*x^4+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4+3*x^2+x-1,{2}>,
<2*x^6-x^5+3*x^4+3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^2+3*x-1,{2}>,
<2*x^6+x^5+3*x^4+x^3-3*x^2+x-2,{2,3,17,113}>,
<2*x^6+x^5+2*x^4+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4-x^3-3*x^2+2,{2}>,
<2*x^6+x^5+3*x^4+x^2-2,{2}>,
<-x^6+3*x^4-x^3-3*x^2-x-2,{2}>,
<-2*x^6-x^5-3*x^4-x^2+x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4+x^2+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x-1,{2,5}>,
<-x^6-x^5-x^4+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4+x+2,{2}>,
<-2*x^6+x^5-x^4+3*x^2-x+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4-1,{2,3}>,
<2*x^6-3*x^2-x-2,{2}>,
<-2*x^6+x^5-2*x^4+3*x^2+x+2,{2,11}>,
<2*x^6+x^5+3*x^4-3*x-1,{}>,
<2*x^6-x^5+3*x^4-x^2-3*x-1,{}>,
<2*x^6-x^5+3*x^4-x^2+2,{2}>,
<2*x^6-3*x^4+x^3-3*x^2-x-2,{2}>,
<-2*x^6+3*x^4-x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4+x^3-3*x^2-x-2,{2}>,
<-2*x^6-x^5+3*x^4-x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5+3*x^4+x^3+2*x^2-x-1,{2}>,
<-2*x^6+x^5-3*x^4-x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-3*x^2-x-2,{2}>,
<2*x^6-2*x^4+x^3-3*x^2-x-2,{2}>,
<2*x^6-3*x^4+3*x^3-3*x^2-2*x+2,{0,2}>,
<-2*x^6+2*x^4+x^3+3*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3+2*x^2-x-1,{2}>,
<-x^6-3*x^4-3*x^3-3*x^2+2*x+2,{2}>,
<-x^6-2*x^5+x^4+x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5-x^4+x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4-x^3+x^2+x-2,{2}>,
<2*x^6+3*x^4+3*x^3+3*x^2-2*x-2,{2}>,
<2*x^6-x^4+x^3-3*x^2-x-2,{2}>,
<-2*x^6+x^5-3*x^4-x^3-x^2-x+2,{}>,
<2*x^6+x^5-x^3-3*x^2+x-2,{2}>,
<2*x^6+x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4+x^3+x^2+x-2,{}>,
<-2*x^6+x^5-3*x^4-x^3+2,{2}>,
<-x^6-3*x^5-x^4-x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4+x^3-2*x-1,{2}>,
<2*x^6-x^5+3*x^4+x^3-x^2-1,{2}>,
<-2*x^6+x^5-3*x^4-x^3+x^2+2,{}>,
<2*x^6-x^5+3*x^4+x^3-x^2-2,{}>,
<2*x^6-x^5+x^4-x^3-3*x^2+x-2,{2}>,
<-x^6+2*x^5+x^4+x^3-3*x^2-x-2,{2}>,
<-2*x^6+x^5-3*x^4-x^3+x^2-3*x-1,{2}>,
<-2*x^6-x^5-3*x^4+x^3+2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2+x-2,{2}>,
<2*x^6+2*x^4-x^3-3*x^2+x-2,{2}>,
<-2*x^6+x^5-3*x^4-x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+x^5-3*x^4-2*x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<2*x^6-x^5+3*x^4+2*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+2*x^2+2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3+2*x^2-1,{2}>,
<2*x^6-2*x^4+2*x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+2*x^2-x+2,{}>,
<-x^6+3*x^5+2*x^4+2*x^3+3*x^2-x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^4+2*x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+x^2-x-1,{}>,
<-2*x^6+x^5+x^4+2*x^3+3*x^2-x+2,{2}>,
<-x^6+3*x^5-2*x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+x-2,{2}>,
<2*x^6+2*x^3+3*x^2-x+2,{}>,
<-x^6-2*x^3+3*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^5-2*x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-x^2-x-1,{2}>,
<2*x^6-x^4+2*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4+2*x^3-x^2+3*x-1,{}>,
<-2*x^6-x^5-3*x^4+2*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3+3*x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3+3*x^2-3*x-1,{}>,
<2*x^6+x^5+3*x^4-3*x^2+2,{2,3}>,
<-x^6-3*x^5-3*x^4+2*x^3+3*x^2-x+2,{2}>,
<-2*x^6+x^5-3*x^4+3*x^2-2*x-1,{2}>,
<-2*x^6+x^5-3*x^4-x^3-3*x^2+x+2,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3+3*x^2-2*x-1,{2}>,
<2*x^6+x^5+3*x^4-x^3+3*x^2+x-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^4+2*x^3+3*x^2-x+2,{2,3}>,
<-2*x^6-x^5-3*x^4+2*x^3+3*x^2-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2-2*x-1,{2,11}>,
<2*x^6+x^5+3*x^4-2*x^3-3*x^2-x-1,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2-x-1,{2,5}>,
<-x^6+3*x^5-3*x^4+2*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-x-2,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2-x-2,{}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2-2,{}>,
<-x^6+3*x^5+3*x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6+2*x^4+3*x^2+x+2,{}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2-x+2,{2}>,
<2*x^6-2*x^4-3*x^2+x-2,{2}>,
<-x^6-x^5+2*x^4+3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3-3*x^2+x+2,{2}>,
<-2*x^6+x^5-3*x^4-2*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-3*x^2-x-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4+2*x^2-x-2,{2}>,
<2*x^6-3*x^4-3*x^3-3*x^2+x-2,{2}>,
<-2*x^6-x^5-3*x^3-3*x^2+2*x+2,{2}>,
<2*x^6-x^5+3*x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4+3*x^2+x+2,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2-2*x-2,{2}>,
<-x^6-2*x^5+3*x^4-x^3-3*x^2+x-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2+x-2,{2}>,
<2*x^6+2*x^5-3*x^4-3*x^3-3*x-1,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3+3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-3*x^2+x-2,{2}>,
<-x^6+3*x^5+x^4-3*x^3+3*x^2+2*x-2,{2}>,
<2*x^6-x^5+3*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-x^2-2*x-1,{2}>,
<-2*x^6-x^5-3*x^4+2*x^3-3*x^2-x+2,{2,3}>,
<2*x^6-x^5+3*x^3-3*x^2-x-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-1,{2}>,
<2*x^6-x^5+3*x^4+x^2-x+2,{2}>,
<2*x^6+3*x^3-3*x^2-x-2,{2}>,
<2*x^6-2*x^5-3*x^4+3*x^3-x^2-x-1,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3+2*x-1,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-2*x^2-2,{2}>,
<2*x^6+x^5+3*x^4-2*x^3+3*x^2+x-2,{2,3}>,
<2*x^6-2*x^5-3*x^4+3*x^3-x^2-x-2,{2}>,
<-2*x^6+x^5-3*x^4-3*x^3+2*x^2-x-1,{2,5}>,
<-2*x^6-x^5-3*x^4+3*x^3+x^2-3*x-1,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3+2*x^2+x+2,{2}>,
<-x^6+2*x^5-x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-3*x^2+x-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-x^2+x+2,{}>,
<-x^6+3*x^4+2*x^3+3*x^2-x+2,{2}>,
<-x^6+x^5+x^4+3*x^3-3*x^2-x-2,{2}>,
<-2*x^6-x^5-3*x^4+3*x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+x^4-3*x^3+3*x^2+x+2,{2}>,
<2*x^6-3*x^4-2*x^3-3*x^2+x-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3+3*x^2-x+2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2-x-2,{2}>,
<2*x^6+x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2+x-2,{2,5}>,
<-2*x^6+3*x^4+2*x^3+3*x^2-x+2,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-3*x^2+x-2,{2,3}>,
<-x^6+x^4+3*x^3+3*x^2-x+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-3*x^2+x-2,{2,5}>,
<-x^6+3*x^5-3*x^4+3*x^3+3*x^2-x+2,{2}>,
<2*x^6-x^4-3*x^3-3*x^2+x-2,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x^2-x-2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-x^5+3*x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3+x^2-2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+3*x^2+2,{2}>,
<-x^6+3*x^4+3*x^3-3*x^2-x-2,{2}>,
<-x^6-3*x^4-3*x^3+3*x^2+x+2,{2}>,
<-x^6+3*x^4+3*x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+x^2-x+2,{2,17}>,
<-2*x^6-x^5-3*x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3-3*x^2+2,{2}>,
<2*x^6-x^5-x^4-3*x^3-3*x^2+x-2,{2}>,
<-2*x^6+x^5-2*x^4+3*x^3-x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-2,{2}>,
<2*x^6+x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2+x-2,{2}>,
<-2*x^6+x^5+x^4+3*x^3+2*x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^4+3*x^3+2*x^2+x+2,{2}>,
<-x^6+3*x^5-3*x^3+3*x^2+x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-x+2,{2}>,
<-x^6+x^5-3*x^4+3*x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3+x^2-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2+x-2,{2}>,
<-x^6-x^5-3*x^4+3*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4+2*x^3-2*x^2+2,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+2*x^2-x+2,{2}>,
<-x^6+3*x^5+x^4-3*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-3*x^3+x-2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+3*x^2+3*x-1,{}>,
<2*x^6+x^5+2*x^4+2*x^3+2*x^2-x+2,{}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2-x-2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6-x^5-x^4-3*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<2*x^6-x^5+2*x^4-3*x^3-x^2-1,{2}>,
<2*x^6-x^5+2*x^4-2*x^3+3*x^2+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3-x^2-2*x-1,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+x^2+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-2*x^2-x-2,{2}>,
<-2*x^6-x^4+3*x^3+2*x^2+x+2,{2,5}>,
<-2*x^6-x^5+3*x^4+2*x^3+2*x^2+x+2,{2}>,
<-x^6-3*x^5-3*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3-2*x^2-x-2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-2*x^2-x-2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3-2*x^2-x-2,{}>,
<-x^6-3*x^5+3*x^4+2*x^3+2*x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3-x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-x-1,{}>,
<2*x^6-x^5+x^4-2*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^4+2*x^3-2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^3-2*x^2-x-2,{2}>,
<2*x^6-3*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+x-2,{2}>,
<2*x^6+x^5-x^4-2*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-1,{}>,
<2*x^6+x^5+2*x^4+2*x^3+x^2-x-1,{2,3,11}>,
<-2*x^6-2*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3-2*x^2+x-2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3+x^2-2*x-1,{2}>,
<-2*x^6-x^5-2*x^4-2*x^3+2*x^2-3*x-1,{2,3}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3-2*x^2+x-2,{2}>,
<-x^6-2*x^5-2*x^4-2*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^3+2*x^2-x+2,{2}>,
<-x^6+x^5-2*x^4+2*x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-3*x-1,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3-2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4+x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-x^2+2*x-1,{2}>,
<2*x^6-x^5+2*x^4-2*x^3-2*x^2+x-1,{2}>,
<2*x^6-x^5+2*x^4-x^3+2*x^2+2,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^3-x^2+x-1,{2}>,
<-x^6+2*x^4-x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+x^3+x-2,{2}>,
<2*x^6-x^5+2*x^4-x^3+x+2,{}>,
<2*x^6-2*x^4-x^3-2*x^2-x-2,{2}>,
<-2*x^6-x^5-2*x^4-x^3+x^2-x+2,{2}>,
<-2*x^6+2*x^4+x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5+x^4-2*x^3-2*x^2-x-2,{}>,
<2*x^6-x^4-x^3-2*x^2-x-2,{2}>,
<-2*x^6+x^5-x^4+2*x^3+2*x^2+x+2,{}>,
<-2*x^6+x^5-2*x^4+x^3-x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^4+x^3-2*x^2+x-2,{2}>,
<-x^6-3*x^5-x^3+2*x^2-x+2,{2,3}>,
<-2*x^6-x^4-x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+x^3-3*x^2+x-1,{}>,
<-x^6+3*x^5+x^4-x^3-2*x^2-x-2,{2}>,
<2*x^6+x^5+2*x^4+x^3-3*x^2-1,{2}>,
<-2*x^6-x^5-2*x^4-x^3+2*x^2+2,{2}>,
<-x^6-2*x^5-x^3+2*x^2-x+2,{2}>,
<2*x^6+3*x^4+x^3-2*x^2+x-2,{2}>,
<2*x^6+x^5+2*x^4+x^3-2*x^2-2,{2}>,
<-2*x^6-x^5-2*x^4-x^3+3*x^2+2*x-1,{2,5}>,
<-x^6-3*x^5+3*x^4+x^3-2*x^2+x-2,{}>,
<-x^6-2*x^5+2*x^4+x^3-2*x^2+x-2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^2+x+2,{2}>,
<-x^6+3*x^5+2*x^4-x^3-2*x^2-x-2,{}>,
<-2*x^6-x^5+3*x^4+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4+x^3+3*x^2+3*x-1,{2}>,
<2*x^6+3*x^4+2*x^2+x+2,{2}>,
<2*x^6-3*x^4-2*x^2+x-2,{2}>,
<-x^6+x^5+3*x^4+2*x^2-x+2,{}>,
<-2*x^6+x^5+3*x^4+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4+3*x^2-1,{2}>,
<2*x^6-x^5+2*x^4+3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4+2*x^2+x+2,{2}>,
<-x^6-x^4-3*x^3-3*x^2+2*x+2,{2,5,7,59}>,
<-x^6+3*x^5-x^4-2*x^2+x-2,{2}>,
<2*x^6-2*x^2+x-2,{2}>,
<-x^6+x^5+x^4+2*x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4+x+2,{2}>,
<2*x^6+x^5-x^4-2*x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^2-x-1,{2}>,
<2*x^6+x^5+2*x^4+x^2+2,{2}>,
<2*x^6+x^5-2*x^4-2*x^2+x-2,{}>,
<2*x^6-x^5+2*x^4+x^2-1,{2,5}>,
<2*x^6+x^5+2*x^4+2*x^2+x-2,{}>,
<2*x^6+x^5+2*x^4+x^2-2*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4-2*x^2+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^2-x+2,{2}>,
<-x^6+3*x^5-2*x^2+x-2,{2}>,
<-x^6-x^5+2*x^2+x+2,{2}>,
<-2*x^6+2*x^4+2*x^2+x+2,{2}>,
<-x^6-3*x^5-2*x^2+x-2,{2,5}>,
<-x^6+x^5-3*x^4+2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4-x^2+3*x-1,{2}>,
<2*x^6-x^5+2*x^4-3*x^2+x+2,{2,5}>,
<-x^6-2*x^5+x^4-2*x^2-x-2,{2}>,
<-x^6+x^5+3*x^4-x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4+2,{2,5,17}>,
<2*x^6-x^5+2*x^4-x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3+2*x^2-2*x-1,{}>,
<2*x^6+x^5+2*x^4-x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4+x^3+x^2-2*x-1,{2}>,
<2*x^6-x^5+x^4+x^3+2*x^2-x+2,{2}>,
<-x^6+x^5+x^4-x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5+x^4-2*x^2-x-2,{2}>,
<2*x^6+x^5-x^4-x^3-2*x^2+x-2,{2,3}>,
<2*x^6-x^5+2*x^4-2*x^2-3*x-1,{2}>,
<-2*x^6-x^5-2*x^4+x^3-x^2+2,{2}>,
<-2*x^6+x^5-2*x^4-x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3+3*x^2-2,{2}>,
<2*x^6+x^5+2*x^4-x^3-1,{2}>,
<-x^6+x^5+3*x^4+x^3+2*x^2-x+2,{}>,
<2*x^6+x^5+2*x^4-x^3+x^2-2,{2}>,
<-2*x^6+x^5-2*x^4-x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4-x^3+x^2-2*x-1,{}>,
<-x^6-3*x^5-x^4-x^3-2*x^2+x-2,{}>,
<2*x^6+x^5+2*x^4-x^3+2*x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4+x^3-x+2,{2}>,
<-2*x^6+x^5-2*x^4-x^3-2*x^2+2,{2}>,
<-x^6+x^5+2*x^4+x^3-2*x^2-x-2,{2}>,
<-2*x^6-x^5-2*x^4+x^3+2,{2}>,
<-2*x^6-x^5-2*x^4+x^3+2*x^2+2*x-1,{2}>,
<-2*x^6-x^3+2*x^2+x+2,{2}>,
<-x^6-2*x^5-2*x^4-x^3+2*x^2+x+2,{2}>,
<2*x^6-x^5-x^3-2*x^2+x-2,{2}>,
<-x^6-3*x^5+x^4+x^3-2*x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4-x^3-2*x^2+x-2,{2}>,
<-x^6-3*x^5-3*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6+x^4+x^3-2*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4+x^3+2*x^2-x+2,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x^2-x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2-x-1,{2}>,
<-2*x^6-x^5-2*x^4+x^3+x^2+3*x-1,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-2*x^2-x-2,{2}>,
<-x^6-2*x^5-2*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+3*x^2-x-2,{2}>,
<2*x^6+3*x^4+2*x^3+2*x^2-x+2,{}>,
<2*x^6-x^5-2*x^4+x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+3*x^2-1,{}>,
<2*x^6-3*x^4-x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3-3*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+2*x^2-2,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x^2-2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x^2-x-1,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4-x^3+3*x^2-x-1,{2,7}>,
<-2*x^6+x^5-2*x^4-2*x^3-2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5+2*x^4-x^3-3*x^2-2*x-1,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+x^2+x+2,{}>,
<-x^6-2*x^5+3*x^4+2*x^3+2*x^2-x+2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+2*x^2+x+2,{2}>,
<2*x^6+x^5-x^4-2*x^3-2*x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3-x-1,{2}>,
<2*x^6+x^5+2*x^4-2*x^3+x-2,{2}>,
<-x^6+x^5-2*x^4+2*x^2+x+2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3+2,{2}>,
<2*x^6-x^4+2*x^3-2*x^2-x-2,{2}>,
<2*x^6-2*x^3-2*x^2+x-2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3-2*x^2-x+2,{2}>,
<-x^6-3*x^5+x^4+2*x^3-2*x^2-x-2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6+x^5+x^4-2*x^3-2*x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-2*x^3+2*x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-2*x^6+x^5-2*x^4+2*x^2+x+2,{2}>,
<-x^6-2*x^5+x^4-2*x^3-2*x^2+x-2,{2}>,
<2*x^6-x^5+2*x^4-2*x^2+2,{}>,
<-x^6+3*x^5-2*x^3-2*x^2+x-2,{2}>,
<-x^6+3*x^5-x^4+2*x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4+2*x^2-2*x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2+x-2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3+2*x^2+x+2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3+3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^2-x-2,{2}>,
<-2*x^6-x^5-2*x^4+2*x^3+3*x^2-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-2*x^2+x-2,{2}>,
<-x^6-2*x^5+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+2*x^2+2,{2}>,
<2*x^6+x^5-3*x^3+2*x^2+x+2,{}>,
<2*x^6-x^5+2*x^4-2*x^2+3*x-1,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+x+2,{2}>,
<-x^6+x^5-3*x^4+2*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3+x-2,{2}>,
<2*x^6-x^5+2*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+3*x^3-2*x^2-x-2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^2-x-2,{2}>,
<-x^6+2*x^5+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5+2*x^4-3*x^3-x^2-2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+2*x^2-x+2,{2}>,
<-x^6+2*x^5-3*x^4+2*x^2+x+2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+2*x^2-2,{2}>,
<2*x^6+3*x^4-3*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3-2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2-x-2,{2}>,
<2*x^6-x^5+2*x^4+3*x^3-2*x^2+2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+3*x^2-x-2,{2}>,
<-x^6+2*x^4+3*x^3-2*x^2-x-2,{2}>,
<-x^6+x^5+x^4-3*x^3+2*x^2+x+2,{2}>,
<-x^6-2*x^4+3*x^3+2*x^2-x+2,{2}>,
<2*x^6+x^5+2*x^4-3*x^3+x^2-1,{}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+x^5+x^3+3*x^2-x+2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^4+3*x^3-x^2+2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-2*x^2+x-2,{2,7,23}>,
<-x^6-3*x^5+3*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+3*x^4-x^3-x-1,{2}>,
<-2*x^6+x^5-x^4+3*x^3-3*x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+x^4+3*x^3+2*x^2-2,{2}>,
<-x^6-x^5+x^4-3*x^3-2*x^2+x-2,{2}>,
<2*x^6-x^5-x^3-3*x^2+x-2,{2}>,
<-x^6-2*x^5-x^4-3*x^3-2*x^2+x-2,{2,13}>,
<2*x^6-x^5+x^4-3*x^3-2*x^2+x-2,{2}>,
<-x^6+x^4-3*x^3+x^2-x+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+x^4+3*x^3-2*x^2+3*x-1,{}>,
<-2*x^6-x^5-3*x^4+x^3+x^2-3*x-1,{2}>,
<2*x^6-x^5+x^4-3*x^3+x^2-3*x-1,{2}>,
<-2*x^6-x^5-x^4-3*x^3+2*x^2-x-2,{2,7,17}>,
<-2*x^6+x^5-x^4+3*x^3-x^2+x+2,{}>,
<-2*x^6+x^5-x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5+x^4+3*x^3+x^2+x-2,{}>,
<2*x^6+x^5+x^4+3*x^3-2*x^2+x-1,{2}>,
<-2*x^6-x^5+3*x^4-x^3+3*x^2+2*x-2,{0,2}>,
<-2*x^6+x^5-3*x^4-x^3+x^2+x+2,{2}>,
<2*x^6-2*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6-x^4-3*x^3-x^2-x-2,{2}>,
<-x^6+2*x^4+3*x^3-x^2+x-2,{2}>,
<-x^6-x^5+3*x^4-x^3+3*x^2+2*x-2,{0,2}>,
<2*x^6+x^5+x^4+3*x^3+x^2-2,{2,11}>,
<2*x^6+2*x^4-3*x^3-x^2-x-2,{2}>,
<-x^6+3*x^5+3*x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+2*x^5+3*x^3-x^2+x-2,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3+x^2-x+2,{2}>,
<2*x^6-x^5+x^4-3*x^3+x^2+2,{}>,
<2*x^6+x^5+x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6-x^4+x^3+3*x^2-x+2,{2,3}>,
<-x^6+2*x^5+x^4+2*x^3+x^2+x+2,{2}>,
<-x^6-x^5+x^4-2*x^3+x^2-x+2,{}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-x-2,{2}>,
<-2*x^6-x^5+2*x^3+x^2+x+2,{2}>,
<-x^6+3*x^5-2*x^3-x^2-x-2,{2}>,
<-x^6+3*x^5+x^4+2*x^3-x^2+x-2,{}>,
<2*x^6-x^5-x^4-2*x^3-x^2-x-2,{2}>,
<2*x^6-x^5+x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+x^5+x^4+2*x^3-x^2+3*x-1,{}>,
<-2*x^6+x^5-x^4+3*x^3+3*x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-2*x^3+x^2-2*x-1,{2}>,
<2*x^6-x^5+x^4-2*x^3+x^2-2,{2}>,
<2*x^6+3*x^4+2*x^3-x^2+x-2,{2}>,
<-x^6+x^5-x^4+2*x^3+x^2+x+2,{2}>,
<2*x^6-x^5+x^4-3*x^3-x-2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-x^2-x-2,{2,5}>,
<-x^6-3*x^5-2*x^3-x^2-x-2,{2}>,
<2*x^6-x^5+x^4-3*x^3-1,{2}>,
<2*x^6+x^5-3*x^4+x^3-x^2+x-2,{2}>,
<2*x^6-x^5+x^4-2*x^3-x^2-2,{2}>,
<2*x^6+3*x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-2*x^3+x^2+x+2,{2}>,
<-x^6-2*x^5-2*x^3+x^2-x+2,{2,7,11}>,
<2*x^6-x^5+x^4-3*x^3-2,{2}>,
<2*x^6-x^5+x^4-2*x^3-x^2+x-2,{2}>,
<-x^6-2*x^5-x^4+3*x^3+x^2+x+2,{2}>,
<-x^6-x^5-2*x^3+x^2-x+2,{2}>,
<-x^6-3*x^5+2*x^4+x^3+x^2+x+2,{2}>,
<-x^6+3*x^5+x^4-2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5+x^4+x^3+3*x^2+2,{2}>,
<2*x^6-x^5+x^4-x^3+x^2-2*x-1,{2}>,
<-2*x^6+3*x^4-x^3+x^2-x+2,{2}>,
<-2*x^6+x^5+x^4+x^3+x^2+x+2,{2}>,
<2*x^6+x^5+x^4+x^3-x^2+2,{2}>,
<2*x^6-x^5-3*x^4+x^3-x^2+x-2,{2}>,
<-x^6-x^4-x^3+x^2-x+2,{2}>,
<2*x^6-x^5-x^4+x^3+x^2+x+2,{2,3}>,
<-2*x^6-x^5-x^4-x^3+x^2+3*x-1,{2}>,
<-2*x^6+x^5-x^4+x^3+2*x^2+3*x-1,{}>,
<-x^6+2*x^5+2*x^4+2*x^3-x^2+x-2,{2,109}>,
<2*x^6-x^5+x^4-x^3-2*x^2-1,{2}>,
<-x^6-2*x^5-2*x^4-2*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+x^4-x^3+x^2-x+2,{2}>,
<2*x^6-x^5+x^4-2*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5-x^4+x^3+3*x^2+2*x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5+x^4+2*x^3-2*x^2-1,{2}>,
<-2*x^6+x^5-x^4+x^3-x^2-x+2,{2}>,
<-2*x^6-2*x^4+2*x^3+x^2+x+2,{2}>,
<-x^6+2*x^5-3*x^4+x^3+x^2+x+2,{2}>,
<-x^6-3*x^5-x^3+x^2-x+2,{2}>,
<-x^6-x^5-2*x^4+2*x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4+2*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-x^5-x^4-x^3-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-2*x^3+3*x^2-1,{2}>,
<-2*x^6+x^5-x^4+x^3+3*x^2+x-1,{2,7}>,
<2*x^6+x^5-3*x^4-x^2+x-2,{2}>,
<2*x^6-x^5+x^4-x^3-2,{2}>,
<-2*x^6-x^5+3*x^4+x^2-x+2,{2}>,
<-2*x^6+x^5-x^4-3*x^2+2,{2}>,
<2*x^6+x^5+x^4+3*x^2-3*x-1,{2}>,
<-x^6-x^5+2*x^4+x^2-x+2,{}>,
<-2*x^6+x^5-x^4-2*x^2+x+2,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2+x+2,{2,7}>,
<-2*x^6-x^5-x^4-x^3+3*x^2+2*x-1,{2,19}>,
<2*x^6-2*x^4-x^2-x-2,{2}>,
<-x^6-3*x^5+x^4+x^2-x+2,{}>,
<-2*x^6-x^5-x^4-2*x^2+x+2,{2}>,
<2*x^6+x^4+x^2-x+2,{2}>,
<2*x^6+x^5+x^4+2*x^2-x-2,{2}>,
<2*x^6+x^5+x^4+x^2-x+2,{2,23}>,
<2*x^6+x^5+x^4+x^2-x-1,{2}>,
<-2*x^6-x^5-x^4-x^2-3*x-1,{2}>,
<2*x^6+x^5-x^4-x^2-x-2,{}>,
<-2*x^6-x^5+x^4+x^2+x+2,{}>,
<2*x^6+x^5-x^2-x-2,{2}>,
<2*x^6-x^5+x^4-x^3-x^2-x-2,{2,5,13,37}>,
<-x^6+3*x^5-x^4-x^2-x-2,{2}>,
<2*x^6+x^5+x^4-x^2+x+2,{2}>,
<-x^6+x^5-x^4+x^2+x+2,{2}>,
<-x^6+3*x^5+3*x^4-x^2+x-2,{2}>,
<-x^6+2*x^5+3*x^4-x^2+x-2,{2}>,
<2*x^6+x^5+x^4-3*x^2-2,{2}>,
<2*x^6-x^5+x^4+x^3+3*x^2-2*x-1,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2+x-2,{2}>,
<-2*x^6+x^5-x^4-x^3-3*x^2+2,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5+x^4-x^3+3*x^2-2*x-1,{}>,
<2*x^6-x^5+x^4+x^3+2*x^2+2,{2}>,
<2*x^6-x^5+x^4-3*x-1,{2}>,
<-2*x^6-x^5-x^4-2*x-1,{2}>,
<2*x^6+x^5+x^4+x-2,{2}>,
<-2*x^6+2*x^4-x^3+x^2+x+2,{2}>,
<-2*x^6+x^5-x^4-x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5-x^4-x^3-2*x^2+2,{2}>,
<-x^6+2*x^5+2*x^4+x^3+x^2-x+2,{2}>,
<2*x^6-x^5+x^4+x^3-x^2+2*x-1,{}>,
<2*x^6+x^5+x^4-x^3+x^2+x+2,{2,3}>,
<-2*x^6-x^5-x^4+x^3-x^2-x+2,{2}>,
<2*x^6+x^5+x^4-x^3+x^2-1,{2}>,
<2*x^6+x^5+x^4-x^3+x^2-2,{2}>,
<2*x^6-x^5+x^4+x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+x^5-x^4-x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5+x^4-x^3-2*x^2+2,{2}>,
<-2*x^6-x^5-x^4+x^3-3*x-1,{2,5,7}>,
<-2*x^6+x^5-x^4+x^2+x+2,{2,877}>,
<-2*x^6+x^5-x^4-x^3+2,{2}>,
<-2*x^6-2*x^4-x^3+x^2+x+2,{2,43}>,
<-x^6-2*x^5-2*x^4-x^3+x^2+x+2,{2,3}>,
<-2*x^6+x^5-x^4-x^3-3*x-1,{2}>,
<2*x^6+x^5+x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6-3*x^4+x^3+x^2-x+2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3+x^2+x+2,{}>,
<-2*x^6-x^5-x^4+x^3+3*x^2-3*x-1,{2}>,
<2*x^6-3*x^4+2*x^3-x^2-x-2,{2}>,
<-2*x^6+3*x^4-2*x^3+x^2+x+2,{2}>,
<-x^6+3*x^4-x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-x^4+2*x^3-3*x^2+x+2,{2,5}>,
<-2*x^6+x^5+3*x^4+2*x^3+x^2-x+2,{2}>,
<2*x^6-x^5+x^4+2*x^3+2*x^2-3*x-1,{}>,
<2*x^6+3*x^4+x^3-x^2-x-2,{2}>,
<2*x^6-x^5+x^4+2*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-2*x^4+2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5+x^4-2*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-x^2+x-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5-x^4-2*x^3-x^2+x-2,{2}>,
<2*x^6+x^5+x^4-2*x^3+x^2+x-2,{2}>,
<2*x^6+x^4+2*x^3+x^2-x+2,{}>,
<-2*x^6+x^5-x^4-2*x^3-x^2+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-x-2,{}>,
<-x^6+3*x^5+x^4+2*x^3+x^2-x+2,{2}>,
<2*x^6+x^5-2*x^3-x^2+x-2,{2}>,
<2*x^6+x^5+2*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+x^4-2*x^3-x-2,{2}>,
<-x^6-2*x^5-2*x^3-x^2+x-2,{2}>,
<-x^6+3*x^5+2*x^3+x^2-x+2,{2}>,
<-2*x^6-x^5-x^4+2*x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^3+x^2-x+2,{}>,
<2*x^6+x^5+x^4-2*x^3-x^2+2,{2}>,
<2*x^6+x^5-x^4+2*x^3+x^2-x+2,{2}>,
<-x^6-x^5+x^4-2*x^3-x^2+x-2,{2}>,
<-x^6-x^5-x^4-2*x^3+x^2+x+2,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3-x^2+x-2,{2,11}>,
<-x^6+2*x^4+2*x^3-x^2-x-2,{2}>,
<-2*x^6+x^5-x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5+x^4-2*x^3-3*x^2-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3-x^2+x-2,{2}>,
<-2*x^6+x^5-x^4+2*x^3-3*x^2+2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3-x^2+x-2,{2,5}>,
<2*x^6+3*x^4-3*x^3+x^2+x+2,{}>,
<2*x^6-x^5+x^4+3*x^3+3*x^2-1,{2}>,
<2*x^6-x^5+x^4-2*x^3+3*x^2+x-2,{2}>,
<-2*x^6+x^5-x^4-3*x^3-3*x^2+2,{}>,
<2*x^6-x^5+x^4+3*x^3+3*x^2-2,{}>,
<-2*x^6+x^5-x^4-3*x^3-3*x^2-x+2,{2}>,
<-x^6+x^5+2*x^4-3*x^3+x^2+x+2,{}>,
<2*x^6-2*x^4-3*x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-x^4-2*x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5-x^4+3*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+x^2+x+2,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3+x^2-x+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2+x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3+x^2-x+2,{2}>,
<-x^6+x^5+3*x^3-x^2-x-2,{2}>,
<-2*x^6-x^5-x^4+3*x^3+x+2,{2}>,
<2*x^6+3*x^3+x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^3+x^2-x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3-3*x-1,{2}>,
<-2*x^6-3*x^3+x^2+x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3+x^2+x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3-2*x^2-x-1,{}>,
<-x^6-2*x^5+2*x^4-3*x^3-x^2+x-2,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-x^2+x-2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+x^2-x+2,{2}>,
<-2*x^6-x^5-x^4+3*x^3+3*x^2-2*x-1,{}>,
<-2*x^6+x^5-x^4-3*x^3+3*x^2-x-1,{2}>,
<2*x^6+x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+x+2,{2,3}>,
<2*x^6-x^5-3*x^3+3*x^2-2*x-1,{2,3}>,
<2*x^6-x^5-3*x^4-3*x^3-x-2,{2}>,
<2*x^6+3*x^4-3*x^3-x+2,{2}>,
<-2*x^6+3*x^4+3*x^3+x+2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+x+2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+x-2,{2}>,
<2*x^6-x^5-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3-x+2,{2}>,
<2*x^6+x^5+3*x^3+2*x^2+x-2,{2}>,
<2*x^6+2*x^4+3*x^3+x+2,{2}>,
<-x^6+2*x^4+3*x^3+x+2,{2}>,
<2*x^6-2*x^4+3*x^3+x-2,{2,11}>,
<-2*x^6-x^5+2*x^4+3*x^3+x+2,{2}>,
<-2*x^6+x^5+3*x^3-x^2+2*x-1,{2}>,
<-x^6-x^5+x^4-3*x^3-x+2,{2}>,
<-x^6+x^4-3*x^3-x+2,{2}>,
<-2*x^6-x^5-3*x^3-x^2+2,{2}>,
<-2*x^6+x^4-3*x^3-x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3-x-2,{2}>,
<2*x^6-x^5-3*x^3-3*x-1,{2}>,
<-x^6-2*x^5-3*x^3-x-2,{2}>,
<2*x^6-x^5-3*x^3-2*x-1,{2}>,
<2*x^6+x^5+x^4+2*x^3+x-2,{2}>,
<-2*x^6-x^5-3*x^3-x-1,{2}>,
<2*x^6+x^5+3*x^3-1,{2,3}>,
<-2*x^6-x^5-3*x^3+x+2,{2}>,
<2*x^6-2*x^3-x^2-x-2,{2}>,
<2*x^6+x^5+3*x^3-x-2,{2}>,
<-2*x^6-x^5-3*x^3+x^2-3*x-1,{2}>,
<2*x^6-x^5-3*x^3-x^2-x-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-x+2,{2}>,
<-x^6-2*x^5-x^4-3*x^3-x+2,{2}>,
<-2*x^6-x^5+x^4-3*x^3-x-2,{2}>,
<2*x^6-x^5-3*x^3-x^2-x+2,{2}>,
<2*x^6-x^5-3*x^3-x^2+2,{2,7,11,59}>,
<-2*x^6+x^5+3*x^3+x^2-1,{2}>,
<2*x^6+x^4+3*x^3+x-2,{2}>,
<-2*x^6-x^4+3*x^3+x+2,{2}>,
<-x^6-x^5-x^4+3*x^3+x+2,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3+2*x^2-x+2,{}>,
<2*x^6-x^5+2*x^4-2*x^3-3*x^2-1,{2,3}>,
<2*x^6-x^5+2*x^4-2*x^3-3*x^2-2,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-2*x^2-x-2,{}>,
<-2*x^6+x^5-2*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5+2*x^4+x^3+3*x^2-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+x-2,{2}>,
<-2*x^6-x^5-3*x^3+2*x^2-2,{2}>,
<2*x^6+x^5+3*x^3-2*x^2+2,{2}>,
<2*x^6+x^5+x^4+x^3+2*x^2-1,{}>,
<-2*x^6+x^5+3*x^3+2*x^2-1,{2}>,
<-x^6-2*x^4-3*x^3-x+2,{2}>,
<-x^6-x^5+2*x^4+x^3+x^2+x+2,{2}>,
<2*x^6+2*x^4-3*x^3-x-2,{2}>,
<-2*x^6-2*x^4-3*x^3-x+2,{2}>,
<-2*x^6-x^5-x^4-x^3-2*x^2+x+2,{2}>,
<-2*x^6+x^5+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+x+2,{2}>,
<-2*x^6+x^5+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^4-2*x^3+x^2+x+2,{2}>,
<2*x^6-x^5-2*x^3+2*x^2-x-1,{2}>,
<-x^6+3*x^5+x^4-x^2-x-2,{2}>,
<-x^6+3*x^5+2*x^3+x+2,{}>,
<2*x^6+x^5+2*x^3+2*x-1,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+x+2,{2}>,
<-2*x^6+2*x^3+x+2,{2}>,
<-2*x^6+x^5-x^4+2*x^2+3*x-1,{2}>,
<-2*x^6+2*x^4-2*x^3-x+2,{2,3}>,
<-2*x^6-x^5-2*x^3+x+2,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-x+2,{2,3}>,
<2*x^6+x^5+2*x^4+3*x^3-2*x^2+x-2,{2,5}>,
<2*x^6+x^5+2*x^4+3*x^3-2*x^2-1,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+2*x^2-x+2,{2}>,
<-2*x^6-x^5-2*x^3-x^2-3*x-1,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3+2*x^2-x+2,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-2*x^2+x-2,{}>,
<2*x^6-x^5-x^4-2*x^3-x-2,{2}>,
<-2*x^6-x^5-2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+2*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^3+x^2-x-2,{2}>,
<2*x^6+x^5+2*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-2*x^2-x-2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+x-2,{2}>,
<2*x^6-x^5+x^4-2*x^2-2*x-1,{2}>,
<-2*x^6+x^5+2*x^3+2*x^2+x-2,{2}>,
<-2*x^6+x^5+2*x^3-x^2+2,{2}>,
<2*x^6+x^5+2*x^3+x^2-x-2,{2}>,
<-x^6-3*x^5-2*x^3-x-2,{2}>,
<-x^6+x^5+3*x^4-2*x^3-x-2,{0,2}>,
<-x^6+3*x^5-3*x^4-2*x^3-x+2,{2}>,
<-x^6+x^5+2*x^4-x^2-x-2,{2}>,
<-x^6+3*x^4+x^3+x+2,{2}>,
<-2*x^6+x^5+x^3-3*x^2+2,{2}>,
<-2*x^6+x^5-x^4+2*x^2-2*x-1,{2}>,
<2*x^6+x^5+x^3+3*x^2-x-1,{2}>,
<-x^6-3*x^5+3*x^4+x^3+x+2,{}>,
<2*x^6-x^5-x^3+2*x^2-3*x-1,{2}>,
<2*x^6-x^5-x^3+2*x^2-2*x-1,{}>,
<2*x^6+x^5+x^3+2*x^2-2*x-1,{2}>,
<2*x^6+x^5+x^3+2*x^2+x-2,{2}>,
<-2*x^6+x^5+x^3-2*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-x+2,{2}>,
<-x^6+2*x^4-2*x^3-x-2,{2}>,
<-2*x^6+x^5+2*x^3+2*x^2+2,{2}>,
<2*x^6-x^5-x^3+x^2-3*x-1,{}>,
<-x^6-2*x^5+x^4-x^3-x+2,{2}>,
<2*x^6-x^5-x^3-1,{2}>,
<2*x^6+x^3+x-2,{}>,
<2*x^6+x^5-x^4+x^3+x-2,{2}>,
<2*x^6-x^5-x^3-2,{}>,
<2*x^6+x^5+x^3+x^2+2,{}>,
<2*x^6-x^5+x^3+x+2,{2}>,
<-2*x^6+x^4-x^3-x+2,{2}>,
<-x^6+3*x^5+x^3+x-2,{2}>,
<2*x^6+x^5+x^3+2*x-1,{2}>,
<2*x^6-x^5-x^3-x-2,{2,3}>,
<2*x^6+x^5+x^3+2,{2,3}>,
<-x^6+x^5+2*x^4+x^3+x-2,{2}>,
<-x^6+2*x^5+2*x^4-x^3-x-2,{2}>,
<-2*x^6-x^4-3*x^3+x^2+x+2,{2}>,
<2*x^6+x^5+x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^4+3*x^3+x^2-x+2,{2}>,
<2*x^6+2*x^4-3*x^3-x^2+x-2,{2}>,
<-2*x^6-x^5-3*x^2-x+2,{2}>,
<2*x^6-x^5+3*x^2+2,{2}>,
<2*x^6+x^5+3*x^2-1,{2}>,
<-2*x^6+x^5-3*x^2+2,{2}>,
<2*x^6+x^5+3*x^2-3*x-1,{}>,
<2*x^6-x^5+2*x^2-3*x-1,{2}>,
<2*x^6+2*x^4-x+2,{2}>,
<-2*x^6-x^5-x^2+x+2,{2}>,
<-2*x^6-x^5-x^2+3*x-1,{2}>,
<2*x^6+x^5+2,{}>,
<-x^6-2*x^5+x-2,{2}>,
<-2*x^6+x^5-3*x-1,{2}>,
<-x^6-3*x^5+x+2,{2}>,
<-2*x^6-x^5+x^2-3*x-1,{2}>,
<2*x^6+x^5-x^2+2*x-1,{2}>,
<2*x^6+x^5-x^2+x-1,{2}>,
<-x^6-2*x^5+x^4+x-2,{2}>,
<-x^6-2*x^5+2*x^4-x-2,{2,3}>,
<-2*x^6+x^5+2*x^2-x-1,{2}>,
<-x^6-3*x^4-x+2,{2}>,
<2*x^6-x^5-3*x^2-2,{2}>,
<-x^6-x^5-3*x^4+x+2,{2,3}>,
<-x^6+3*x^5+3*x^4-x-2,{2}>,
<-x^6-2*x^5+3*x^4+x^3-x+2,{2}>,
<-2*x^6-x^5+x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^4-x^3+x+2,{2}>,
<2*x^6-3*x^4+x^3-x-2,{2}>,
<2*x^6+x^5-x^3+3*x^2-2,{2}>,
<-x^6-x^5+3*x^4-x^3+x+2,{2}>,
<2*x^6-x^5-3*x^4-x^3+x-2,{2}>,
<2*x^6+x^5-2*x^4-x^3+x-2,{2}>,
<2*x^6+x^5-x^3+2*x^2+2,{2}>,
<2*x^6-x^5+x^3+2*x^2-1,{2}>,
<-2*x^6+2*x^4-x^3+x+2,{2}>,
<2*x^6+x^5-2*x^4+x^3-x-2,{2}>,
<-x^6+3*x^5-x^4-x^3+x-2,{2}>,
<2*x^6-x^4+x^3-x-2,{2}>,
<-2*x^6+x^5-x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5+x^3-x+2,{2}>,
<-x^6-2*x^5-x^4+x^3-x+2,{2}>,
<2*x^6-x^4-x^3+x+2,{2}>,
<2*x^6+x^5-x^3-x^2-2,{2}>,
<-2*x^6-x^5+x^3+x^2+x-1,{2}>,
<-x^6+2*x^5-x^4+x^3-x+2,{2}>,
<-x^6+3*x^5-x^4+x^3-x+2,{2}>,
<-2*x^6+x^5+3*x^3+3*x^2-2,{2}>,
<2*x^6+x^5+3*x^3-3*x^2+2,{2}>,
<-2*x^6-x^5-3*x^3+3*x^2+2,{2}>,
<-x^6-2*x^5-3*x^4-x^3-x+2,{2}>,
<-2*x^6-x^5+3*x^4-x^3-x-2,{2}>,
<-2*x^6+x^5+x^3+3*x^2+x-1,{2}>,
<2*x^6+x^5+x^3-3*x^2+2,{2}>,
<-2*x^6-x^5-x^3+3*x^2-1,{2}>,
<2*x^6-x^5-x^3-3*x^2+x-1,{2}>,
<2*x^6-x^5-x^3-3*x^2+2*x-1,{2}>,
<2*x^6-x^5+x^3-2*x^2-2,{2}>,
<-x^6+3*x^5+3*x^4-x^3+x-2,{2}>,
<2*x^6+x^5-x^3-3*x^2-1,{2}>,
<2*x^6+3*x^4-x^3+x-2,{2}>,
<2*x^6-x^5+x^3-3*x^2-2,{2}>,
<2*x^6-x^5+x^3-3*x^2+x-1,{2}>,
<-x^6+2*x^5+3*x^4+x^3-x-2,{2}>,
<-x^6-3*x^5+3*x^4-x^3+x-2,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3+x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+x-2,{2,3}>,
<2*x^6-x^5+2*x^3+3*x^2+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3-x+2,{2,31}>,
<2*x^6+x^5-3*x^4+2*x^3-x-2,{2}>,
<2*x^6-x^5+2*x^3+2*x^2-x-1,{2}>,
<-2*x^6-x^5+2*x^3-2*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^3+2*x^2+x-2,{2}>,
<2*x^6+2*x^4-2*x^3+x+2,{2}>,
<-2*x^6-x^5+2*x^3-2*x^2+2,{2,5}>,
<-x^6+3*x^5+2*x^4+2*x^3-x+2,{2}>,
<-x^6+3*x^5-2*x^3+x+2,{2}>,
<-x^6+x^5+2*x^3-x-2,{2}>,
<-x^6+x^5+2*x^3-x+2,{2}>,
<2*x^6+x^5-2*x^3-3*x-1,{2}>,
<2*x^6+x^5-2*x^3-x^2-x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^3+x-2,{2}>,
<-2*x^6-2*x^4-2*x^3+x+2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3+x-2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-x-2,{2}>,
<-x^6-2*x^5-3*x^4+2*x^3-x+2,{2,5}>,
<2*x^6-x^5+2*x^3-3*x^2-x-1,{2}>,
<2*x^6+x^5-2*x^3-3*x^2-1,{2}>,
<2*x^6+x^5-2*x^3-3*x^2-2,{2}>,
<-x^6-x^5+3*x^4-2*x^3+x-2,{2}>,
<-x^6-x^5-3*x^4-3*x^3+2*x^2+x+2,{2}>,
<-2*x^6+x^5-2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-x+2,{}>,
<-x^6+3*x^5+2*x^4+3*x^3-x+2,{2}>,
<2*x^6+x^5-3*x^3+x^2+2,{2}>,
<2*x^6-x^5+3*x^3+x^2-2,{2}>,
<2*x^6+x^5-x^4+3*x^3-x-2,{2}>,
<2*x^6+x^5-3*x^3+x^2-2*x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3+x+2,{2}>,
<2*x^6-x^5+3*x^3+2,{2}>,
<-2*x^6-x^5+2*x^4+x+2,{2}>,
<2*x^6+x^5-3*x^3-1,{2}>,
<-2*x^6-x^5+x^4-x+2,{2}>,
<-2*x^6-x^5+3*x^3+2,{2}>,
<2*x^6+x^5-3*x^3-2,{2}>,
<-x^6+3*x^5+3*x^3-x-2,{2}>,
<-x^6+3*x^5+3*x^3-x+2,{2}>,
<2*x^6+x^5-3*x^3-x^2-1,{2}>,
<2*x^6+x^4-3*x^3+x-2,{2}>,
<-x^6-x^5-x^4-3*x^3+x+2,{2}>,
<-2*x^6-x^5+3*x^3+x^2+3*x-1,{}>,
<2*x^6+x^5-3*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6+x^5-3*x^3+2*x^2+2*x-1,{2}>,
<-x^6-3*x^5-3*x^4+3*x^3-x+2,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3+x+2,{2}>,
<2*x^6-3*x^4-3*x^3+x+2,{2}>,
<2*x^6-x^5+3*x^3-3*x^2-2,{2}>,
<-x^6+x^5+2*x^4+3*x^3-x-2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-x-2,{2}>,
<-2*x^6+x^5-3*x^3+3*x^2-x-2,{2}>,
<-2*x^6+x^5+x^4+3*x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^3-3*x^2-3*x-1,{}>,
<2*x^6+3*x^4-3*x^3-x^2-x+2,{}>,
<2*x^6+x^5-x^4+3*x^3+3*x^2-1,{2}>,
<2*x^6-x^5-x^4-3*x^3+3*x^2-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6+x^5-x^4+3*x^3+2*x^2-1,{2}>,
<-2*x^6-x^5+x^4-3*x^3-2*x^2+2,{2}>,
<2*x^6+x^5-x^4+3*x^3+2*x^2-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3-2*x^2+x+2,{2,5}>,
<-x^6+3*x^5+x^4+3*x^3-x^2+x+2,{2}>,
<-x^6+2*x^5-x^4+3*x^3+x^2+x-2,{}>,
<2*x^6-x^5-x^4-3*x^3+x^2-2*x-1,{2}>,
<-x^6-x^5-x^4-3*x^3+x^2-x-2,{2}>,
<2*x^6-x^5-x^4-3*x^3+x^2-x-2,{2,5}>,
<-x^6+x^4+3*x^3-x^2+x+2,{2}>,
<-x^6+2*x^5+x^4-3*x^3-x^2-x+2,{2}>,
<-x^6-3*x^5-3*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4+3*x^3+2*x-1,{2}>,
<-x^6-x^5+3*x^4+3*x^3+x-2,{2}>,
<-2*x^6+x^5+x^4+3*x^3+x-1,{2}>,
<-2*x^6+x^5+3*x^3+3*x^2-2*x-1,{0,2}>,
<-x^6+3*x^3+x^2+x-2,{2}>,
<2*x^6-3*x^3+x^2-x-2,{2}>,
<2*x^6-x^5-3*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6+3*x^3-x^2+x+2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-x+2,{2}>,
<-x^6+x^5-3*x^3-x^2-x+2,{2}>,
<2*x^6-x^5-x^4-3*x^3+2*x-1,{2}>,
<-2*x^6-x^5+3*x^3-3*x^2-x+2,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3-x+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-3*x^3+3*x^2-1,{2}>,
<-2*x^6-x^5+x^4-3*x^3+x^2-2*x-1,{}>,
<-2*x^6+x^5+x^4+3*x^3+x^2+2,{}>,
<2*x^6-x^5+3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3-x^2-2,{}>,
<-2*x^6+x^5+x^4+3*x^3+x^2-x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<2*x^6+x^5-x^4+3*x^3-x^2+2,{2}>,
<-2*x^6-x^5+3*x^3-2*x^2-x+2,{2}>,
<-x^6+x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3-x+2,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-x-2,{2}>,
<2*x^6-x^5-x^4-3*x^3-x^2-1,{2}>,
<2*x^6+2*x^4+3*x^3+x^2+x-2,{2}>,
<-2*x^6+x^5+x^4+3*x^3+2*x^2-x-1,{2,3}>,
<-x^6-2*x^5+2*x^4+3*x^3+x^2+x-2,{0}>,
<-2*x^6-x^5+x^4-3*x^3+3*x^2-1,{2}>,
<2*x^6+x^5-x^4+3*x^3-2*x^2-3*x-1,{}>,
<-2*x^6+x^5+3*x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+3*x^2-3*x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-x^2+x+2,{}>,
<-2*x^6+x^5+x^4+3*x^3+3*x^2+2*x-1,{}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-x-2,{2,3,37}>,
<2*x^6-x^5-x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-2*x^6+x^5+x^4+3*x^3+3*x^2-2*x-1,{0,2}>,
<-x^6-2*x^5-3*x^4+3*x^3-x^2+x+2,{}>,
<-2*x^6-x^5+x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-x^2-x+2,{2}>,
<-x^6+x^5-2*x^4+3*x^3-x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3-x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+x^2-x-2,{}>,
<-x^6-x^5+3*x^4-3*x^3+x^2-x-2,{2}>,
<-2*x^6-x^5+x^4-3*x^3+2*x^2-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-x^2-x+2,{}>,
<2*x^6-x^5-x^4-3*x^3-2*x^2+2,{}>,
<2*x^6-x^5-x^4-3*x^3-3*x^2-x-1,{2}>,
<-x^6-2*x^4-3*x^3-x^2-x+2,{2}>,
<-2*x^6+3*x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6-x^5-x^4-2*x^3-1,{2}>,
<-2*x^6-2*x^3-x^2-x+2,{2}>,
<2*x^6-x^5-x^4-2*x^3+x-1,{2,3}>,
<-2*x^6+x^5+x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3-x^2+x+2,{2,5}>,
<-x^6+3*x^5+3*x^4+2*x^3+x-2,{2}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2+3*x-1,{}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-2*x^6+x^5+x^4+2*x^3+x^2+x-2,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3-x+2,{2}>,
<-2*x^6+3*x^4-2*x^3-x-2,{2}>,
<2*x^6+x^5-x^4+2*x^3-x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-x+2,{2}>,
<-x^6-x^5-x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6+x^5-x^4+2*x^3-3*x^2+2*x-1,{2}>,
<2*x^6+x^5-x^4+2*x^3-2*x^2+2*x-1,{2,31}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2+x-2,{2}>,
<-2*x^6-x^5+x^4-2*x^3+x^2-1,{2}>,
<-2*x^6+3*x^4+2*x^3+x^2+x-2,{2}>,
<2*x^6+x^5-x^4+2*x^3-2*x^2+x-1,{2}>,
<2*x^6-3*x^4-2*x^3-x^2-x+2,{2,3}>,
<-2*x^6+x^5+x^4+2*x^3+2*x^2-2,{2}>,
<2*x^6+x^4-2*x^3+x^2-x-2,{2}>,
<-x^6+2*x^4+2*x^3+x^2+x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-2*x^3+x^2+3*x-1,{2}>,
<-x^6+2*x^5-2*x^4-2*x^3-x^2-x+2,{2}>,
<2*x^6+x^5-x^4+x^3+2*x^2+3*x-1,{}>,
<2*x^6+x^5-x^4+2*x^3-3*x^2-2,{2}>,
<2*x^6+x^5-x^4+x^3+2*x^2+2*x-1,{2}>,
<-x^6-3*x^5-2*x^4+2*x^3-x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4-x^3+x^2-x-2,{2}>,
<-2*x^6+2*x^4-x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+x^4+2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-x^4+x^3+3*x-1,{}>,
<-2*x^6+x^5+x^4+x^3-x^2+3*x-1,{2}>,
<2*x^6-x^5-x^4-2*x^3-3*x^2+x-1,{2,3}>,
<-x^6-2*x^5-x^3+x^2-x-2,{2}>,
<-x^6+x^5+x^3-x^2+x+2,{2}>,
<-x^6-x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-x^3+2,{2}>,
<-2*x^6-x^5+x^4-x^3-x^2-x+2,{2,3,11,43}>,
<-x^6+3*x^5-x^3+x^2-x-2,{2}>,
<2*x^6-x^4+x^3+x^2+x-2,{2}>,
<-2*x^6-x^5+x^4-x^3+x^2-2*x-1,{2}>,
<-x^6-2*x^5-x^4-x^3-x^2-x+2,{2}>,
<-2*x^6+x^4+x^3-x^2+x+2,{2}>,
<-2*x^6-x^5+x^4-x^3+x^2-x-1,{2}>,
<-2*x^6+x^5+x^4+x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^3+x^2-x-2,{2}>,
<-2*x^6+x^5+x^4+x^3+x^2-2*x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2+x-2,{2}>,
<-2*x^6-x^5+x^4-x^3+2*x^2-x-1,{2,3}>,
<2*x^6+3*x^4+x^3+x^2+x-2,{2}>,
<-x^6+2*x^4-x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4+x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-3*x^4+x^3-x^2+x+2,{2}>,
<-2*x^6-x^5+x^4-x^3+3*x^2-3*x-1,{2}>,
<-x^6+x^5-3*x^4-x^3-x^2-x+2,{2}>,
<-x^6-2*x^5-3*x^4+x^3-x^2+x+2,{2}>,
<-x^6-3*x^5+x^4+3*x^3+x-2,{2}>,
<2*x^6-x^5-x^4-x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-x^5-3*x^3+2*x^2-3*x-1,{}>,
<-x^6+2*x^5+3*x^4+x^3+x^2+x-2,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+x+2,{2}>,
<-x^6+3*x^5+x^4-x^2+x+2,{2}>,
<2*x^6+x^5-x^4+x^3-3*x^2-3*x-1,{2}>,
<2*x^6-x^5-x^4+x^2+3*x-1,{2}>,
<2*x^6+x^5-x^4+3*x^2+3*x-1,{2}>,
<2*x^6-x^5-x^4-x-1,{2}>,
<-x^6-3*x^5-x^2+x+2,{2}>,
<2*x^6-x^5-x^4+3*x^2+2,{2}>,
<-2*x^6+x^5+3*x^4+x^3+x^2+x-2,{2,71}>,
<-x^6-3*x^5+x^4+x^2-x-2,{2}>,
<-x^6-x^5+3*x^4-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4+x^3+3*x^2-1,{2}>,
<-2*x^6+x^5+x^4+x^2+2*x-1,{2}>,
<-x^6-3*x^4+x^3-x^2+x+2,{2}>,
<-2*x^6-x^4-x^2-x+2,{2}>,
<-x^6+2*x^5-2*x^4-x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4-x^2+x+2,{}>,
<-2*x^6+x^5+2*x^4-x^2+x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^2+x-2,{2}>,
<-2*x^6-x^5+3*x^4+x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-x^2+x+2,{2}>,
<-x^6+x^5-3*x^4-x^2+x+2,{}>,
<-2*x^6-x^5+x^4-2*x^2+x+2,{2}>,
<-x^6-3*x^4-x^2+x+2,{2}>,
<-x^6-3*x^5+3*x^4+x^2+x-2,{2}>,
<2*x^6-x^5-x^4-3*x^2+3*x-1,{2}>,
<2*x^6+x^5-3*x^4-x^3+x^2+x-2,{2}>,
<2*x^6+3*x^4+x^3-x^2-x+2,{2}>,
<2*x^6-x^5-x^4+x^3+3*x^2-1,{2}>,
<-2*x^6+x^5+x^4-x^3-3*x^2+2,{2}>,
<-2*x^6+3*x^4-x^3-x^2+x+2,{2}>,
<-x^6-2*x^4-x^2-x+2,{2,101}>,
<2*x^6+x^5-3*x^4+x^3+x^2-x-2,{2}>,
<2*x^6-x^5-x^4-2*x^2+x-1,{2}>,
<2*x^6-2*x^4-x^3+x^2+x-2,{2}>,
<-x^6-2*x^5+x^4+x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+x^3-2*x^2+3*x-1,{2}>,
<-x^6+2*x^5-x^4+x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-x^3+x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-x^3+2*x-1,{2}>,
<-x^6-x^5-2*x^4+x^3-x^2-x+2,{2}>,
<-x^6-2*x^4+x^3-x^2-x+2,{2}>,
<2*x^6+x^5-x^4-x^3+2,{2}>,
<-2*x^6-x^5+x^4+x^3+2*x^2+2,{2}>,
<-2*x^6-x^3-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4-x^3+x^2+2,{2}>,
<2*x^6-x^5-x^4+x^3-x^2-2,{2}>,
<-2*x^6-2*x^4-x^3-x^2+x+2,{2,43}>,
<-x^6-3*x^5+x^4-x^3+x^2+x-2,{2}>,
<2*x^6+2*x^4-x^3+x-2,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4-x^3+2*x^2+3*x-1,{}>,
<-x^6-3*x^4-x^3-x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4-x^3+x^2+x-2,{2,3}>,
<2*x^6-x^5-x^4+x^3-3*x^2-2,{2}>,
<-2*x^6-x^5+x^4+x^3+3*x^2+2*x-1,{}>,
<2*x^6-x^5-x^4+2*x^3+x-1,{2}>,
<2*x^6-x^5-x^4+x^3-3*x^2+2*x-1,{2}>,
<2*x^6-x^5-x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x^2+x-2,{2}>,
<-x^6+3*x^5+2*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2+x-2,{2}>,
<-2*x^6-x^5+x^4+3*x^2+2,{2,5,67}>,
<2*x^6+x^5-x^4-2*x^3-x^2-2,{2}>,
<2*x^6+x^5-x^4-2*x^3-3*x^2-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3+x^2-x-2,{2}>,
<-x^6-2*x^5+x^4-2*x^3+x^2+x-2,{2}>,
<2*x^6+3*x^4-2*x^3+x^2+x-2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-x^2-x+2,{2}>,
<2*x^6+x^5-x^4-x^3-3*x^2+2*x-1,{2}>,
<2*x^6-x^5-x^4+2*x^3-3*x^2-2,{2}>,
<-2*x^6-x^5+x^4+2*x^3+2*x^2-3*x-1,{2,5}>,
<2*x^6+3*x^4+2*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+2*x^3+3*x^2+x-2,{2}>,
<-x^6-x^5-3*x^4+x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+x^4-2*x^3-3*x^2+2,{2}>,
<2*x^6-x^5-x^4+2*x^3-2*x^2-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-x^2-x+2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-x^2-x+2,{2,3}>,
<-x^6+2*x^5+2*x^4+2*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2+x+2,{2}>,
<-2*x^6+x^5+x^4-2*x^3+3*x^2+3*x-1,{2}>,
<2*x^6-x^5-x^4+3*x^3+2*x^2+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-x^2+x+2,{2,5}>,
<-2*x^6+2*x^4+3*x^3-x^2-x+2,{2}>,
<-x^6+2*x^5-3*x^4-2*x^3-x^2+x+2,{2}>,
<2*x^6-x^5-x^4+2*x^3+2*x^2+3*x-1,{2}>,
<2*x^6-x^5-2*x^4-3*x^3+x^2+x-2,{2}>,
<-x^6+3*x^5-2*x^4-3*x^3-x^2+x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-x^6-x^5-2*x^4+3*x^3-x^2-x+2,{}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2+2,{}>,
<2*x^6+x^5-x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^4+3*x^3+x^2-x-2,{2}>,
<-2*x^6-2*x^4-3*x^3-x^2+x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3+x^2+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+x^2-x-2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+3*x^3-3*x-1,{2}>,
<-2*x^6-x^5+x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5-x^4+3*x^3+x^2-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-x^2+x+2,{2}>,
<2*x^6+x^5-x^4-3*x^3-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+x^2+x-2,{2}>,
<2*x^6+3*x^3+x^2-x-2,{2}>,
<-x^6-x^5-3*x^3-x^2+x+2,{}>,
<2*x^6+x^5-x^4-3*x^2-2,{2,5,67}>,
<-2*x^6+x^5+x^4-3*x^3-x^2+2,{2}>,
<-x^6+x^5-3*x^4-x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^3+x^2-x-2,{2,5}>,
<-2*x^6+x^5+x^4-3*x^3-3*x-1,{}>,
<-x^6+2*x^5-3*x^4-x^2-x+2,{2}>,
<-x^6+2*x^5+x^4-3*x^3+x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-x^2+x+2,{2}>,
<-2*x^6+x^4+3*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+3*x^3+3*x^2+2*x-1,{2}>,
<2*x^6+x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<2*x^6+x^5-x^4-3*x^3-3*x^2+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-x^5-x^4+3*x^3-3*x^2-x-1,{2}>,
<-2*x^6-x^5+x^4+3*x^3+3*x^2-2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^4+3*x^3+x^2-x-2,{2}>,
<2*x^6-x^5-x^4+3*x^3-3*x^2-1,{}>,
<2*x^6-x^5-2*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-3*x^4-3*x^3+2*x^2-x-2,{}>,
<-2*x^6+x^5+2*x^4+3*x^3-2*x^2+x+2,{}>,
<-2*x^6+x^5+x^4-3*x^3+3*x^2+2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+3*x^2-2,{}>,
<-2*x^6-x^5+2*x^4-3*x^3-x^2-3*x-1,{2}>,
<-2*x^6-3*x^4+3*x^3-x^2-x+2,{2}>,
<-x^6+3*x^5+x^4+3*x^3-2*x^2+x+2,{}>,
<-x^6-x^5-x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^4-3*x^3-2*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+2*x^2+x-2,{2}>,
<-2*x^6-x^5+x^4+3*x^3+3*x^2+x-2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3-x^2-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+x^2-x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^3+x^2-2*x-1,{2}>,
<-x^6+3*x^5+3*x^3-2*x^2+x+2,{2}>,
<-2*x^6+x^4-3*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+2*x-1,{2,3}>,
<-x^6+3*x^3+2*x^2+x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-1,{2}>,
<-2*x^6+x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^4-3*x^3+2*x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+x^2-x-1,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+x^2-2*x-1,{0,2}>,
<-x^6-x^5-2*x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^3+2*x^2-x-2,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3-2*x^2-x+2,{}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4-2*x^3-2*x^2+2,{2}>,
<2*x^6+x^5-x^4+2*x^3+x^2+2*x-1,{2}>,
<2*x^6-x^4-2*x^3+x^2-x-2,{2}>,
<2*x^6-x^5-x^4-2*x^3+x^2+x-1,{}>,
<2*x^6+x^5-x^4+2*x^3+x^2-x-2,{2}>,
<2*x^6-x^5-x^4-2*x^3-3*x-1,{}>,
<-x^6+2*x^5+2*x^3+x^2+x-2,{2}>,
<-x^6-x^5-2*x^3+x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^4-2*x^3+2*x^2-x-2,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x^2-x-2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3-2*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+2*x^2-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+2*x^2+x-2,{2}>,
<-2*x^6+x^5+2*x^4-2*x^3-2*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3-x^2-x+2,{}>,
<2*x^6-x^5-x^4-x^3+3*x^2-2*x-1,{}>,
<-2*x^6-x^5+3*x^4-x^3-x^2-x+2,{2}>,
<-2*x^6-x^5+x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+x^2-2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+2*x^2+x-2,{}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x^2+x+2,{}>,
<-2*x^6+x^5+2*x^4+2*x^3+x^2-1,{2,3}>,
<-x^6-x^5-2*x^4+2*x^3-2*x^2+x+2,{2}>,
<-x^6-2*x^5-2*x^4+2*x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+2*x^2-x-2,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-x-2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+3*x^2+x-2,{2}>,
<-x^6+3*x^4-2*x^3+2*x^2-x-2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4+2*x^3-2*x^2+x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6+x^5-3*x^4-2*x^3-2*x^2-x+2,{2}>,
<-x^6-2*x^5-3*x^4+2*x^3-2*x^2+x+2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3+2*x^2+x-2,{0,2}>,
<-x^6+2*x^5+3*x^4+x^3-2*x^2+x+2,{2}>,
<2*x^6+3*x^4+x^3-2*x^2+x+2,{2}>,
<-2*x^6+3*x^4-x^3-2*x^2-x+2,{2}>,
<-x^6+2*x^4+x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^5-x^4+x^3+2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-x^5-2*x^4-x^3+x^2-3*x-1,{2}>,
<-x^6+x^4-x^3-2*x^2-x+2,{2}>,
<-2*x^6-x^5+2*x^4-x^3-x^2+2,{2}>,
<-2*x^6+x^5+2*x^4+x^3-x^2-3*x-1,{2}>,
<-2*x^6+x^5+2*x^4+x^3+x-1,{2}>,
<-x^6-2*x^5+x^3+2*x^2+x-2,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4+x^3-x^2+2*x-1,{2}>,
<2*x^6-x^4+x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4-x^3+x^2-1,{2}>,
<2*x^6+x^5-2*x^4+x^3-x^2-2,{2}>,
<2*x^6+x^5-2*x^4+x^3-x^2-x-1,{2,3,5}>,
<2*x^6+x^5-2*x^4+x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2+x-2,{2}>,
<-2*x^6+2*x^4-x^3+2*x^2-x-2,{2,5,13}>,
<-2*x^6-x^5+2*x^4-x^3+2*x^2-1,{}>,
<2*x^6+x^5-2*x^4+x^3-2*x^2-1,{2}>,
<2*x^6+2*x^4+x^3+2*x^2+x-2,{}>,
<2*x^6-x^5-2*x^4-x^3-2*x^2-2,{}>,
<-x^6+x^5+3*x^4+x^3+2*x^2+x-2,{2}>,
<2*x^6+x^5-2*x^4+x^3-3*x^2-1,{2}>,
<-x^6+2*x^5+3*x^4-x^3+2*x^2-x-2,{0,2}>,
<2*x^6+x^5-2*x^4+3*x^2+3*x-1,{2}>,
<2*x^6+x^5-2*x^4+3*x^2+x-2,{2}>,
<2*x^6+x^5-2*x^4+2*x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4+2*x^2-x-2,{2}>,
<-x^6-3*x^5-x^4+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4+x^2+2*x-1,{2}>,
<-x^6+x^5+x^4-2*x^2+x+2,{2,23}>,
<2*x^6-x^5-2*x^4+x^2+3*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3+x-2,{2}>,
<-2*x^6-x^5+2*x^4-3*x-1,{2}>,
<-x^6-x^4+x^3+x+2,{2}>,
<2*x^6-x^5-2*x^4-3*x-1,{2}>,
<-x^6+2*x^5+2*x^2+x-2,{2}>,
<-2*x^6-x^5-x^3+x^2+2,{2}>,
<-2*x^6-x^5+2*x^4+x^2-2*x-1,{2}>,
<-2*x^6-x^5-x^3+2*x^2-2*x-1,{2}>,
<2*x^6+x^5-x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+x^5+x^4+2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4-x^2+2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-x^3-x+2,{2}>,
<-2*x^6+x^5+x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^2-x-2,{2}>,
<-x^6-x^5+2*x^4+2*x^2-x-2,{2}>,
<2*x^6-x^5-x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^4-2*x^2+x+2,{2}>,
<-x^6+3*x^5+2*x^4+2*x^2+x-2,{2}>,
<2*x^6+2*x^4+2*x^2-x-2,{2}>,
<-2*x^6-2*x^4-2*x^2+x+2,{2}>,
<-2*x^6-x^5+x^4+3*x^3-3*x^2-x+2,{2}>,
<-x^6-3*x^4-2*x^2-x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^2-x-2,{0,2,3}>,
<-2*x^6-x^5+2*x^4+2*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4-3*x^2-3*x-1,{2}>,
<2*x^6-3*x^4+x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4-x^3-2,{2}>,
<-2*x^6-x^5+2*x^4+x^3+3*x-1,{2}>,
<-x^6+x^5-2*x^4-2*x^2-x+2,{2,3,47}>,
<2*x^6+x^5-2*x^4-2*x^2-2*x-1,{2}>,
<-x^6+3*x^5-2*x^3-x-2,{2}>,
<-x^6-2*x^5+x^4-2*x^3-x-2,{2,5}>,
<-2*x^6-x^5+2*x^4+2*x^2+3*x-1,{2}>,
<2*x^6-x^5-2*x^3-x^2-1,{2}>,
<2*x^6+x^5-2*x^4-2*x^2-3*x-1,{2}>,
<-2*x^6-x^4+2*x^3+x+2,{2}>,
<-2*x^6+x^5+2*x^4+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^4-2*x^3-x-2,{}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2-1,{2}>,
<-2*x^6+x^5+2*x^4+3*x^2+2*x-1,{}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2-2,{2}>,
<2*x^6-x^5-2*x^4+x^3-2*x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2-2,{2}>,
<-2*x^6+x^5+2*x^4-x^3+2*x^2-2*x-1,{2}>,
<2*x^6-x^5-2*x^4+x^3-3*x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4+x^3-2*x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^3+2*x^2+x-2,{2}>,
<-x^6+2*x^5-3*x^4+x^3-2*x^2-x+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+2*x^2-x-2,{}>,
<2*x^6+x^5-2*x^4-x^3-3*x^2+2*x-1,{2}>,
<-x^6+x^5-3*x^4-x^3-2*x^2+x+2,{}>,
<2*x^6-x^5-3*x^4+2*x^3+2*x^2-x-2,{2}>,
<-2*x^6-x^5+2*x^4+x^3+3*x^2-1,{0}>,
<2*x^6+x^5-2*x^4-2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+2*x^4+2*x^3-2*x^2-x+2,{}>,
<2*x^6+3*x^4-x^3+2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+2*x^2+3*x-1,{}>,
<2*x^6+x^5-2*x^4-2*x^3+x^2-x-1,{2}>,
<-x^6-2*x^4-2*x^3-2*x^2+x+2,{2}>,
<2*x^6+2*x^4+2*x^3+2*x^2-x-2,{}>,
<2*x^6+x^5-2*x^4-2*x^3-2*x^2-2,{}>,
<-2*x^6-x^5+2*x^4+2*x^3+2*x^2+x-1,{2}>,
<-x^6+x^5-2*x^4+2*x^3-2*x^2-x+2,{2}>,
<-2*x^6-x^5+2*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3-2*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-3*x^2-2*x-1,{}>,
<-x^6+x^5+3*x^4-2*x^3+2*x^2+x-2,{0}>,
<-2*x^6+x^5+3*x^4+2*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3+2*x^2-x-2,{}>,
<2*x^6-x^5-2*x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+2*x^2-x-2,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-2*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3-2*x^2+2,{2}>,
<-2*x^6+2*x^4-3*x^3-2*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3+2*x^2-x-2,{2}>,
<-x^6+x^5-2*x^4+3*x^3-2*x^2+x+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3+x^2-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2+x-1,{2}>,
<-x^6+2*x^4+3*x^3+2*x^2-x-2,{2}>,
<-x^6-2*x^4-3*x^3-2*x^2+x+2,{}>,
<2*x^6-x^5-2*x^4+3*x^3-2*x^2-2,{2}>,
<-2*x^6+x^5+2*x^4-3*x^3+2*x^2-2*x-1,{2,5}>,
<2*x^6+x^5-2*x^4-3*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+3*x^2-2*x-1,{0,2}>,
<-x^6+x^5-3*x^4-3*x^3-2*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-x^2+2*x-1,{}>,
<-x^6-3*x^5+2*x^4-2*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-2*x^2+2*x-1,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+2*x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4+2*x^3-2*x^2-2,{2}>,
<2*x^6+3*x^4-3*x^3+2*x^2+x-2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+3*x^2+x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2-x-2,{2,7}>,
<-x^6-x^5+3*x^4-3*x^3+2*x^2-x-2,{2}>,
<-2*x^6-x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-3*x^2-1,{2,31}>,
<-x^6+2*x^5+2*x^4+3*x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5-2*x^4+3*x^3-3*x^2-2,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-2*x^2-x-1,{2,7}>,
<2*x^6+x^5-3*x^4+3*x^3+2*x^2+2,{2}>,
<-x^6-2*x^4+3*x^3+3*x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+2*x^2+x-1,{}>,
<2*x^6+x^5-2*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3-2*x^2-x+2,{}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2-3*x-1,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^3+2*x^2+x-2,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-x^2-2,{2}>,
<-x^6-x^4+3*x^3+3*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+x^2-1,{2}>,
<2*x^6+x^4+3*x^3-3*x^2+x+2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2*x-1,{2}>,
<2*x^6-x^4-3*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5+3*x^3-3*x^2+x+2,{}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5-3*x^4-3*x^3+x^2-2,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3-3*x-1,{2}>,
<-x^6+x^5+x^4+3*x^3+3*x^2+x-2,{2}>,
<-x^6+3*x^5+3*x^3-3*x^2+x+2,{}>,
<2*x^6-x^5-3*x^4-3*x^3-x^2-x-1,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3+x^2-1,{2}>,
<-2*x^6+x^5+3*x^4+3*x^3-2,{2,5}>,
<-x^6+2*x^5-x^4-3*x^3-3*x^2-x+2,{2}>,
<-x^6+3*x^3-3*x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-x-2,{2}>,
<-2*x^6+2*x^4+3*x^3+3*x^2+x-2,{}>,
<2*x^6-2*x^4-3*x^3-3*x^2-x+2,{}>,
<2*x^6-x^5-3*x^4-3*x^3-2*x^2-2,{2,3,7}>,
<-2*x^6-x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+3*x^2+x-2,{}>,
<-2*x^6-x^5+3*x^4-3*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^4+3*x^3-3*x^2+x+2,{2,3}>,
<-x^6+3*x^4-3*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3+3*x-1,{2}>,
<2*x^6+x^5-3*x^4+3*x^3-3*x^2-1,{2}>,
<-2*x^6-x^5+3*x^4-3*x^3+3*x^2+x-2,{2,3}>,
<2*x^6-x^5-3*x^4-3*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3-3*x^2+3*x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+3*x^2-3*x-1,{}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+3*x^2+x-1,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+3*x^2+x-2,{2}>,
<-x^6-x^5+3*x^3+2*x^2+x-2,{2}>,
<-x^6+3*x^5+x^4+3*x^3+2*x^2+x-2,{2,17}>,
<2*x^6+x^5-3*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-x^6-x^5-2*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3+2*x^2-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+2*x^2-2,{2}>,
<-x^6+x^5+2*x^4-2*x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3-2*x^2+2*x-1,{2}>,
<-x^6-x^5-x^4-2*x^3+3*x^2-x-2,{2}>,
<-x^6+x^5+x^4+2*x^3-3*x^2+x+2,{2}>,
<-x^6-x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+3*x^3+3*x^2+x-2,{2,5}>,
<2*x^6+x^5-3*x^4-3*x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+3*x^2+x-2,{2}>,
<-x^6-3*x^5-x^4+2*x^3+3*x^2+x-2,{0,2}>,
<-x^6+3*x^5+2*x^3+3*x^2+x-2,{2}>,
<-x^6-2*x^5-2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3+2*x-1,{2}>,
<-2*x^6-2*x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^3+3*x^2-x-2,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3+x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3+3*x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5-x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6-x^5+x^4-2*x^3+3*x^2-x-2,{2}>,
<-2*x^6+x^4-2*x^3+3*x^2-x-2,{2,3}>,
<2*x^6+x^5-3*x^4+2*x^3-x^2+2,{2,3}>,
<-2*x^6-x^4-2*x^3-3*x^2-x+2,{2}>,
<-x^6+x^5+x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-x^2+2*x-1,{2,17}>,
<2*x^6-x^5-3*x^4-2*x^3-x^2+3*x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3+3*x^2-x-2,{}>,
<-x^6+2*x^4-2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+2*x^3-2*x^2-2*x-1,{2}>,
<-2*x^6-x^5+3*x^4-2*x^3+2*x^2+3*x-1,{0}>,
<-2*x^6+x^5+3*x^4+2*x^3+3*x^2+2*x-1,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+3*x^2+x-2,{2}>,
<-x^6+2*x^5-x^4-2*x^3-2*x^2+x+2,{}>,
<2*x^6+x^5-2*x^4-2*x^3-x^2+x-1,{2}>,
<2*x^6+x^5-2*x^4-2*x^3-x^2-1,{2,5}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x^2-x-2,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x^2-3*x-1,{2}>,
<2*x^6-x^5-2*x^4+2*x^3-2*x^2-2*x-1,{2}>,
<2*x^6+x^5-3*x^4+x^3+3*x^2+3*x-1,{2}>,
<2*x^6+x^5-3*x^4+x^3+3*x^2+2*x-1,{2}>,
<2*x^6-x^5-3*x^4-x^3+3*x^2+2,{2}>,
<-x^6+3*x^4-x^3-3*x^2-x+2,{}>,
<2*x^6+x^5-3*x^4+x^3+3*x^2-2,{2}>,
<-x^6-3*x^5-2*x^4-x^3+3*x^2-x-2,{2,5}>,
<-2*x^6-x^5+3*x^4-x^3-2*x^2-2*x-1,{2}>,
<2*x^6-x^5-3*x^4-x^3+2*x^2-1,{2}>,
<-2*x^6+x^5+3*x^4+x^3-2*x^2+2,{2}>,
<-2*x^6-x^5+3*x^4-x^3-3*x-1,{}>,
<2*x^6+x^5-3*x^4+x^3+3*x-1,{2}>,
<-2*x^6+x^5+3*x^4+x^3+x-1,{2}>,
<2*x^6+x^5-3*x^4+x^3+2,{2,3}>,
<-2*x^6+x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4-x^3+x-1,{2}>,
<-x^6+2*x^5-x^3-3*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4-x^3+3*x-1,{0,2}>,
<-x^6-3*x^5+x^4-x^3+3*x^2-x-2,{2}>,
<-x^6+x^4+x^3+3*x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-x^2-1,{2}>,
<-2*x^6-x^4-x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4+x^3-x^2-x-1,{2}>,
<-x^6+2*x^5-x^4-x^3-3*x^2-x+2,{}>,
<-x^6-3*x^5-x^4+x^3-3*x^2+x+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-x-2,{2}>,
<-2*x^6+x^5+3*x^4+x^3+2*x^2+x-1,{2}>,
<-2*x^6-x^5+3*x^4-x^3+2*x^2-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2-1,{2}>,
<-2*x^6+x^5+3*x^4+x^3+2*x^2+2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2-2,{2}>,
<2*x^6-x^5-3*x^4-x^3-2*x^2+x-1,{2}>,
<-2*x^6-x^5+3*x^4-x^3+2*x^2+2*x-1,{0,2}>,
<-x^6+3*x^5-2*x^4-x^3-3*x^2-x+2,{}>,
<-x^6-2*x^5+3*x^4-x^3+3*x^2-x-2,{}>,
<-x^6-2*x^5-3*x^4-x^3-3*x^2-x+2,{2}>,
<-2*x^6-x^5+3*x^4-x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4+x^3-3*x^2-1,{2}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2-2,{2}>,
<2*x^6+x^5-3*x^4-x^3-3*x^2-x+2,{0}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2+x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3+3*x^2+x-2,{0,2,3}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2+2*x-1,{2}>,
<2*x^6-x^5-3*x^4-x^3-3*x^2+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4+3*x^2+x-2,{2}>,
<2*x^6+3*x^4-3*x^2-x+2,{2}>,
<-x^6+3*x^5+3*x^4-3*x^2-x+2,{2}>,
<2*x^6+x^5-2*x^4-x^3+2*x^2-2*x-1,{2}>,
<-x^6+3*x^5-2*x^4+3*x^2+x-2,{2}>,
<-2*x^6+x^4-x^3-2*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+2*x^2-2*x-1,{2}>,
<2*x^6+x^5-3*x^4+2*x^2-3*x-1,{2}>,
<-2*x^6+x^5+2*x^4-x^3+3*x-1,{2}>,
<-2*x^6+x^5+3*x^4-x^2+3*x-1,{2}>,
<-x^6-2*x^5-x^4+3*x^2-x-2,{2}>,
<-x^6-3*x^5-3*x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^2+x-2,{2}>,
<2*x^6+x^3+2*x^2-x-2,{2}>,
<-x^6-x^5+3*x^2-x-2,{2}>,
<-x^6-x^5+x^4+3*x^2-x-2,{}>,
<2*x^6-x^5-3*x^4-x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4-1,{2}>,
<-x^6-x^4-3*x^2+x+2,{2}>,
<2*x^6+x^4+3*x^2+x-2,{2}>,
<2*x^6-x^5-3*x^4-2,{2}>,
<2*x^6-x^5-3*x^4-x^2+x-1,{2}>,
<2*x^6-x^5-2*x^4-2*x^3+x^2-1,{2}>,
<-x^6-3*x^5+3*x^2+x-2,{2}>,
<-x^6-2*x^5-x^4-3*x^2+x+2,{2}>,
<-x^6-3*x^5+x^4+3*x^2+x-2,{2}>,
<-2*x^6-x^5+3*x^4+x^2-3*x-1,{}>,
<-x^6-3*x^5-2*x^3+2*x^2-x-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^2-1,{}>,
<-2*x^6-2*x^4-3*x^2+x+2,{2}>,
<-x^6-x^5+2*x^4+3*x^2+x-2,{0}>,
<-x^6-x^5-2*x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-2*x^2-2*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^2+x+2,{2}>,
<-2*x^6-x^5+2*x^4-2*x^3-1,{2}>,
<-x^6-3*x^5+2*x^4+3*x^2-x-2,{2}>,
<-x^6+2*x^5+2*x^4+3*x^2+x-2,{2}>,
<-x^6-x^5-2*x^4-3*x^2-x+2,{2}>,
<-2*x^6+x^5+2*x^4+2*x^3+2,{2}>,
<2*x^6+3*x^4+3*x^2+x-2,{}>,
<2*x^6+x^5-3*x^4-3*x^2-2,{}>,
<-x^6-3*x^5+3*x^4+3*x^2-x-2,{2}>,
<-x^6+3*x^5-3*x^4-3*x^2+x+2,{}>,
<-2*x^6-x^5+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<-2*x^6-x^5+3*x^4+3*x^2+x-2,{0,2,3}>,
<-x^6+2*x^5-3*x^4-3*x^2+x+2,{2,3}>,
<2*x^6+x^5-3*x^4-3*x^2-x-1,{2}>,
<2*x^6+x^5-3*x^4-3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2-x+2,{}>,
<-2*x^6+x^5+2*x^4+2*x^3+x^2+2*x-1,{2}>,
<2*x^6+x^5-3*x^4-3*x^2+2,{0,2}>,
<2*x^6+x^5-3*x^4-x^3+2*x^2+3*x-1,{2,3}>,
<-x^6-3*x^4-3*x^2-x+2,{2}>,
<2*x^6-x^5-2*x^4-2*x^3-x^2-x-1,{2}>,
<-2*x^6-x^5+3*x^4+x^3-x^2-3*x-1,{2}>,
<2*x^6+x^5-3*x^4-x^3+2*x^2-2,{2}>,
<-x^6-x^5-x^4-x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+x^3+2*x^2+2*x-1,{2}>,
<2*x^6-x^4+x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5+x^4-x^3+3*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4-x^3-x^2-2*x-1,{2}>,
<-2*x^6+x^4+x^3-3*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-x-2,{2}>,
<-2*x^6-x^5+3*x^4+x^3-x^2+3*x-1,{2}>,
<-x^6-2*x^5-2*x^4+x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4-x^3-1,{2,11}>,
<-x^6+x^5-2*x^4-x^3-3*x^2+x+2,{2}>,
<-x^6+2*x^4-x^3+3*x^2+x-2,{0,2}>,
<-2*x^6-x^5+3*x^4+x^3+2*x^2+2,{}>,
<-x^6-3*x^5-3*x^4+x^3-3*x^2-x+2,{2}>,
<-x^6-2*x^5-3*x^4+x^3-3*x^2-x+2,{}>,
<-2*x^6-2*x^4+x^3-3*x^2-x+2,{}>,
<-2*x^6-x^3-3*x^2+x+2,{2}>,
<-2*x^6+3*x^4-x^3+3*x^2+x-2,{0,2}>,
<-x^6+3*x^5+2*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-x^3-3*x^2-1,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6+x^4+2*x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-x^3-x-1,{2,31}>,
<2*x^6+x^5-3*x^4-x^3-3*x^2-x-1,{2}>,
<-x^6-2*x^5+x^4+x^3+3*x^2-x-2,{2}>,
<2*x^6-x^5-3*x^4+2*x^3+3*x^2-3*x-1,{2}>,
<2*x^6+x^5-3*x^4-x^3-x^2+2*x-1,{2}>,
<-x^6-2*x^5-x^4-2*x^3+3*x^2+x-2,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6-3*x^5+x^4-2*x^3-3*x^2+x+2,{}>,
<-x^6-x^4+x^3-3*x^2-x+2,{2,3}>,
<-x^6-3*x^5+2*x^3+3*x^2-x-2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+3*x^2+2,{2}>,
<-x^6+2*x^5+2*x^3+3*x^2-x-2,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3+2*x-1,{2,29}>,
<-x^6+2*x^5-x^4-2*x^3-3*x^2+x+2,{2}>,
<-x^6+x^5-2*x^3-3*x^2+x+2,{2}>,
<-x^6+x^5+3*x^4+2*x^3-3*x^2-x+2,{2,7}>,
<-x^6+x^5-x^4-2*x^3-3*x^2+x+2,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3+x^2+3*x-1,{2,43}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2+x+2,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-x^2-1,{2}>,
<2*x^6+x^4+2*x^3+3*x^2-x-2,{2,5}>,
<2*x^6-x^5-3*x^4+2*x^3-x^2-2,{2,5}>,
<-x^6+2*x^3-3*x^2-x+2,{2,3,37}>,
<-x^6+x^5+x^4+2*x^3+3*x^2-x-2,{2}>,
<-x^6-x^5-2*x^3+3*x^2+x-2,{2,7}>,
<2*x^6-x^5-3*x^4+2*x^3-x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+x^2+2*x-1,{}>,
<2*x^6-x^5-3*x^4+3*x^3-2*x-1,{2}>,
<-x^6-x^4+3*x^3-3*x^2-x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x^2+2,{0,2,3,73}>,
<-2*x^6+x^5+3*x^4-3*x^3+x^2+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3+2,{2}>,
<-2*x^6-x^4-3*x^3-3*x^2+x+2,{2}>,
<-x^6+3*x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+3*x^2+x-2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2+x-2,{2}>,
<-x^6+3*x^5-x^4-3*x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-x^2-3*x-1,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-x^2+2*x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-2*x^2-3*x-1,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+3*x^2-x-2,{0}>,
<-x^6-x^5-x^4+3*x^3-3*x^2-x+2,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-2*x^2-1,{2}>,
<-2*x^6+x^5+3*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-3*x^2-1,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+3*x^2-x-2,{2}>,
<-x^6-2*x^5-3*x^4-2*x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-3*x^3-3*x^2+2*x-1,{2,3}>,
<-2*x^6-x^5+3*x^4+2*x^3+3*x^2+3*x-1,{}>,
<2*x^6+x^5-3*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6-x^5-3*x^4-3*x^3-3*x^2+x+2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2-x-2,{2}>,
<-x^6+3*x^4+3*x^3-3*x^2-x+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+x^5+3*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-3*x^2-x+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+3*x^2+2,{2}>,
<-x^6+x^5+3*x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+2*x^2-1,{2}>,
<2*x^6+3*x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-x^5+3*x^4+3*x^3-2*x^2+2,{2}>,
<-2*x^6-3*x^4+3*x^3-3*x^2+2,{2}>,
<2*x^6+3*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6+3*x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6-x^5-3*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6+2*x^4-3*x^3+3*x^2+2,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2-2,{}>,
<2*x^6+3*x^4+3*x^3+2*x^2-2,{}>,
<-x^6+2*x^5-x^4+3*x^3-3*x^2-2,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-3*x^2-x-1,{2,3}>,
<-2*x^6-3*x^4-3*x^3-x^2+2,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+3*x^2+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3+3*x^2+2,{}>,
<-2*x^6+x^5+3*x^4+2*x^3+3*x^2-2,{2}>,
<-x^6+x^5+x^4-3*x^3+3*x^2+2,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+3*x^4+3*x^3+3*x-1,{2}>,
<2*x^6+3*x^4-3*x^3-2*x^2-2*x-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-3*x^2-1,{2}>,
<-x^6+x^5-2*x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6+3*x^4+3*x^3-x-1,{2}>,
<-2*x^6-3*x^4+3*x^3+2*x^2-1,{2}>,
<2*x^6-x^5-3*x^4-2*x^3-3*x^2-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3+3*x^2+2,{2}>,
<2*x^6+2*x^4-3*x^3-3*x^2-2,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<2*x^6+3*x^4-3*x^3-x^2-x-1,{2}>,
<-x^6+x^5-3*x^4-2*x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^4-3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6+x^5+3*x^4+2*x^3+3*x^2-3*x-1,{0}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2-2,{2}>,
<-2*x^6-x^4+3*x^3+3*x^2+2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+3*x^2+2,{2}>,
<-x^6-x^5-3*x^4+3*x^3+3*x^2+2,{2}>,
<-2*x^6-3*x^4+3*x^3+3*x^2-2*x-1,{}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2+2,{2,3}>,
<-2*x^6-3*x^4-3*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2-2,{2}>,
<-x^6+x^5+3*x^4-2*x^3+3*x^2+2,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^4-3*x^3+3*x^2+2,{2,7}>,
<-2*x^6-3*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<2*x^6+3*x^4+2*x^3-x^2+3*x-1,{2}>,
<-x^6-3*x^5+x^4+2*x^3-3*x^2-2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+3*x^2+2,{}>,
<2*x^6-2*x^4+2*x^3-3*x^2-2,{2}>,
<-x^6+x^5+2*x^4+2*x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^4-2*x^3+3*x^2-3*x-1,{2,11}>,
<2*x^6+3*x^4-x^3+2*x^2+2,{2}>,
<2*x^6+3*x^4+x^3+2*x^2-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2+x-2,{2}>,
<-2*x^6-3*x^4-2*x^3+3*x^2+3*x-1,{2,7}>,
<-x^6+2*x^5+3*x^3+2*x^2-x-2,{2}>,
<-2*x^6-3*x^4+x^3-3*x^2+2,{2}>,
<2*x^6-x^5-2*x^4+3*x^3-x^2-2*x-1,{2}>,
<2*x^6+3*x^4-x^3+3*x^2-2,{2}>,
<-2*x^6-x^5+2*x^4+3*x^3+x^2-1,{2}>,
<2*x^6+3*x^4-x^3+3*x^2+x-1,{}>,
<-2*x^6-x^4-3*x^3-2*x^2+x+2,{2}>,
<2*x^6+3*x^4+x^3+3*x^2-2*x-1,{}>,
<-2*x^6+x^5+3*x^4-2*x^3+2*x^2+x-1,{0,2}>,
<-2*x^6+x^5+2*x^4-3*x^3+x^2-x-1,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3+3*x^2+x-2,{2}>,
<2*x^6+x^5-3*x^4-2*x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^4-x^3+2*x^2-2*x-1,{}>,
<-2*x^6-3*x^4+x^3+2,{2}>,
<-x^6+x^5-2*x^4+2*x^3-3*x^2-x+2,{2}>,
<2*x^6+3*x^4+x^3-2*x-1,{2}>,
<-2*x^6-3*x^4+x^3+2*x^2+x-1,{2}>,
<-2*x^6-3*x^4+x^3-3*x-1,{2}>,
<-2*x^6-x^5+3*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-2*x^6+x^5+3*x^4-2*x^3+2*x^2-3*x-1,{}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^4-x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4-x^3+3*x^2+2,{}>,
<-x^6+3*x^5-3*x^4-2*x^3-3*x^2+x+2,{2}>,
<-2*x^6-3*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^4-x^3-2*x^2+2,{2}>,
<-x^6-x^5+3*x^4-x^3-3*x^2-2,{2}>,
<2*x^6-x^4-x^3+3*x^2+2,{2}>,
<2*x^6-x^5-3*x^4+2*x^3-3*x^2-2*x-1,{2}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2+3*x-1,{2}>,
<-x^6-x^5+3*x^4+2*x^3+3*x^2-x-2,{0}>,
<-x^6+x^5-3*x^4+x^3+3*x^2+2,{2,3}>,
<2*x^6+x^4-x^3-3*x^2-2,{2}>,
<-2*x^6-3*x^4-x^2+3*x-1,{2,5}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2-2,{2}>,
<-x^6+x^5-x^4-x^3+3*x^2+2,{2,3}>,
<2*x^6+x^5-2*x^4-3*x^3-2*x^2+2*x-1,{2,3}>,
<-x^6+3*x^5+3*x^4-x^3-3*x^2-2,{2}>,
<-x^6-x^5+2*x^4+x^3+3*x^2+2,{2}>,
<-x^6+2*x^5+2*x^4-x^3+3*x^2+2,{}>,
<2*x^6+3*x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^4+3*x^3+2*x^2+2,{}>,
<-x^6-3*x^5-x^4-x^3-3*x^2-2,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+2*x^2+2,{}>,
<2*x^6+3*x^4+3*x^2+x-1,{2}>,
<2*x^6+2*x^4-3*x^3-x-1,{2}>,
<2*x^6-x^4-x^3-3*x^2-2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+2*x^2+2,{2}>,
<2*x^6+3*x^4+2*x^2-x-1,{2}>,
<-x^6-3*x^5+x^4+x^3+3*x^2+2,{2}>,
<2*x^6+2*x^4+3*x^3-3*x^2+3*x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2-2,{}>,
<-x^6+3*x^5+x^3-3*x^2-2,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+2*x^2+2,{2}>,
<2*x^6+2*x^4-3*x^3-2,{2}>,
<-x^6-3*x^4-3*x^3+2*x^2+2,{2}>,
<-x^6-x^5-x^3+3*x^2+2,{2}>,
<2*x^6-x^4-3*x^2-2,{2,431}>,
<-x^6-3*x^5+3*x^3+2*x^2+2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-2*x^2-2,{}>,
<-2*x^6-2*x^4+3*x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6+2*x^4-2*x^3+x^2+x-1,{2}>,
<-x^6-2*x^5-x^4-3*x^3+2*x^2+2,{}>,
<-x^6+3*x^5+x^4-2*x^3+2*x^2+2,{2}>,
<-x^6-x^5-x^4-3*x^3+2*x^2+2,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3-2*x^2-2,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2-2,{2}>,
<2*x^6+2*x^4-2*x^3-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3-2*x^2-2,{2}>,
<-x^6+3*x^5-2*x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^4+2*x^3-3*x^2+2,{2}>,
<2*x^6+3*x^4+x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^2-2,{2}>,
<-2*x^6-3*x^4+x^2-2*x-1,{2}>,
<2*x^6+2*x^4-2*x^3-x^2-3*x-1,{2,5,19}>,
<2*x^6+2*x^4+2*x^3+3*x^2-x-1,{}>,
<-x^6-x^5+x^4-2*x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^4+2*x^3+x^2-3*x-1,{2}>,
<2*x^6+2*x^4-2*x^3+3*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+2*x^2+2,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2-2,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3-2*x^2-2,{2}>,
<2*x^6+2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+x^5+x^4+x^3+2*x^2+2,{2}>,
<-x^6-3*x^5+3*x^4-x^3+2*x^2+2,{}>,
<2*x^6+2*x^4-x^3+x^2+2,{2}>,
<-x^6+x^4-x^3+2*x^2+2,{2}>,
<-x^6+3*x^4+x^3+2*x^2+2,{2}>,
<-2*x^6-2*x^4-x^3-x^2+2,{2}>,
<-2*x^6-x^4-3*x^2+2,{2}>,
<2*x^6+2*x^4-x^3+x^2+2*x-1,{2}>,
<2*x^6+2*x^4-x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^3+2*x^2+2,{}>,
<-x^6+2*x^5+x^3-2*x^2-2,{2}>,
<2*x^6+x^3+2*x^2+2,{2}>,
<2*x^6-3*x^4+x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^4+x^3+2,{2}>,
<-x^6+x^5+3*x^4-x^3+2*x^2+2,{2}>,
<-x^6+2*x^5+3*x^4-x^3+2*x^2+2,{2}>,
<-2*x^6-3*x^4+2*x^2+3*x-1,{2}>,
<2*x^6+2*x^4+x^3+2*x^2+x-1,{2}>,
<2*x^6+2*x^4+x^3-x-1,{2,3,31}>,
<2*x^6-2*x^4-x^3-2*x^2-2,{}>,
<-2*x^6-2*x^4-x^3+3*x-1,{2}>,
<-2*x^6+2*x^4+x^3+2*x^2+2,{}>,
<-2*x^6-2*x^4-x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4-x^3-2*x^2-2,{2}>,
<-x^6-3*x^5+x^4+x^3-2*x^2-2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+2*x^2+2,{}>,
<-x^6-3*x^5-x^4-x^3-2*x^2-2,{2}>,
<-2*x^6-2*x^4-x^3+2*x^2-x-1,{2}>,
<-x^6-3*x^5+3*x^4-x^3-2*x^2-2,{2}>,
<-x^6+2*x^5-3*x^4+x^3+2*x^2+2,{2,3}>,
<-x^6-x^5-3*x^4-x^3+2*x^2+2,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3-2*x^2-2,{2,7}>,
<-2*x^6-2*x^4-x^3+3*x^2-1,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2+2,{}>,
<-2*x^6-2*x^4+x^3+3*x^2-x-1,{2}>,
<-2*x^6-2*x^4+x^3+3*x^2-2*x-1,{2}>,
<-2*x^6-2*x^4+3*x^3-3*x^2+2,{}>,
<-x^6-3*x^5-3*x^4+x^3+2*x^2+2,{2}>,
<-x^6-x^5+3*x^4-2*x^2-2,{2,5}>,
<-x^6-3*x^5-x^4-2*x^2-2,{2,3}>,
<-x^6-x^5-2*x^4-x^3+2*x^2+2,{2}>,
<2*x^6-x^5-2*x^4+x^3-x^2-x-1,{}>,
<-x^6+3*x^5-2*x^2-2,{2}>,
<2*x^6-2*x^4+x^3+2*x^2+2,{2}>,
<-x^6-3*x^5+x^4-2*x^2-2,{2}>,
<-x^6-x^4-x^3-2*x^2+x+2,{2}>,
<-x^6-2*x^5+2*x^4+x^3-2*x^2-2,{2}>,
<2*x^6-3*x^3-x^2-2,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3+x^2+2,{2}>,
<-2*x^6-x^4-x^3-2*x^2+x+2,{2}>,
<-x^6+3*x^5-3*x^3-x^2-2,{2}>,
<-2*x^6-x^4-3*x^3-3*x^2-3*x-1,{2}>,
<-2*x^6-x^4-3*x^3+2*x^2-x-1,{2}>,
<-2*x^6-x^4-3*x^3+x^2-3*x-1,{2}>,
<2*x^6+x^4+3*x^3-2*x^2-x-1,{2}>,
<2*x^6-3*x^4-3*x^3-x^2-2,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3-x^2-2,{2}>,
<-2*x^6-x^4-3*x^3+x^2-2*x-1,{2}>,
<-x^6-x^5+3*x^4+3*x^3+x^2+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-x^2-2,{2}>,
<-x^6-2*x^5-x^4-3*x^3+x^2+2,{2}>,
<2*x^6+x^4+3*x^3+2*x^2-x-1,{2}>,
<-2*x^6-x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-x^2-2,{}>,
<2*x^6+x^4+3*x^3-x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+x^2+2,{2}>,
<-x^6-x^5-3*x^4-3*x^3+x^2+2,{2}>,
<-2*x^6+x^5+2*x^4-x^3+x^2-2*x-1,{2}>,
<-2*x^6-x^4-3*x^3+x^2+2,{2}>,
<-x^6+2*x^5+x^4+3*x^3+x^2+2,{2}>,
<2*x^6+x^4+3*x^3-x^2-x-1,{}>,
<-x^6-2*x^5+2*x^4+x^3+2*x^2-x-2,{2}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2+2*x-1,{}>,
<2*x^6+x^4-3*x^3+x^2-2,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2-2,{2}>,
<-2*x^6-x^4-3*x^3+2*x^2-2*x-1,{2}>,
<2*x^6+x^5-2*x^4-x^3-2*x^2+x-1,{2,3}>,
<-2*x^6-x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6-x^4+3*x^3+3*x-1,{2,3}>,
<-x^6-3*x^5+2*x^4+2*x^3+x^2+2,{2}>,
<-x^6+3*x^5+x^4+2*x^3-x^2-2,{2}>,
<2*x^6+x^4+2*x^3-x^2+3*x-1,{2}>,
<-2*x^6-x^4-x^3-3*x^2+2,{2}>,
<2*x^6+x^4+3*x^3+2*x-1,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3-x^2-2,{2}>,
<2*x^6+x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-2*x^6+3*x^4+x^3+x^2+2,{2}>,
<-2*x^6-x^4+x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^3+x^2+2,{2}>,
<2*x^6+x^4-x^3-3*x-1,{2}>,
<2*x^6+x^4-x^3+2*x^2-1,{2}>,
<-x^6+2*x^5+x^3-x^2-2,{2}>,
<2*x^6+x^4-2*x^3-2*x^2-x-1,{2,5,11,17}>,
<2*x^6-2*x^4-x^3-x^2-2,{2}>,
<-2*x^6-x^4-2*x^3+2*x^2+3*x-1,{}>,
<-x^6-3*x^5+x^3-x^2-2,{2}>,
<-x^6-x^5+3*x^4-2*x^3-x^2-2,{2}>,
<-x^6-3*x^5-x^4-x^3+x^2+2,{2}>,
<2*x^6+x^4-x^3+2*x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4+x^3+x^2+2,{2}>,
<-x^6+3*x^5-x^4+x^3-x^2-2,{2}>,
<-x^6-2*x^5-2*x^4-x^3+x^2+2,{2}>,
<2*x^6-x^4+x^3+x^2+2,{2}>,
<-x^6-x^5-2*x^4-x^3+x^2+2,{2}>,
<-2*x^6-x^4+x^3+2*x^2-2*x-1,{2}>,
<2*x^6+x^4-x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+x^3+x^2+2,{2}>,
<-2*x^6-x^4+x^3+x^2-2*x-1,{2}>,
<-2*x^6-x^4-x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4-x^3-x^2-2,{2}>,
<2*x^6-x^4-x^3-x^2-2,{2}>,
<2*x^6+x^4-x^3-x^2+3*x-1,{2}>,
<-x^6+x^5+x^4-x^3+x^2+2,{2}>,
<-x^6-3*x^5+2*x^4-x^3-x^2-2,{2}>,
<-x^6-3*x^5+3*x^4-x^2-2,{2}>,
<-x^6+3*x^5+3*x^3-2,{2}>,
<2*x^6+3*x^3+3*x-1,{2}>,
<-x^6-2*x^5-3*x^3-2,{2}>,
<-x^6+2*x^5+3*x^3+2,{2}>,
<-x^6+x^5+3*x^3+2,{2}>,
<-x^6+x^5+3*x^4-3*x^3+2,{2,53}>,
<2*x^6+3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-3*x^3-2,{2,5}>,
<-x^6-x^5+3*x^3+2,{}>,
<-x^6-x^5+2*x^4-3*x^3+2,{2}>,
<-x^6-3*x^5+3*x^3-2,{2}>,
<2*x^6+3*x^3-x^2+3*x-1,{2}>,
<-2*x^6-3*x^3+x^2-2*x-1,{2}>,
<2*x^6-3*x^3-x^2-2*x-1,{}>,
<-x^6-x^5+x^4-3*x^3-2,{2}>,
<-x^6-x^4+3*x^3+2,{2}>,
<2*x^6-3*x^3-x^2+x-1,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2,{2}>,
<-2*x^6+3*x^3+2*x^2+3*x-1,{2}>,
<-2*x^6-3*x^3+2*x^2-x-1,{2,7}>,
<2*x^6-3*x^3-2*x^2-x-1,{2}>,
<-2*x^6+3*x^3+2*x^2-1,{2}>,
<-2*x^6-3*x^3+2*x^2+3*x-1,{}>,
<-x^6-3*x^5+3*x^4-3*x^3-2,{2}>,
<-2*x^6+3*x^3+3*x^2+2*x-1,{2,5}>,
<2*x^6-3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-3*x^3-3*x^2-x-1,{2}>,
<-2*x^6+3*x^4+3*x^3-2,{2}>,
<-x^6+3*x^4+3*x^3-2,{2,7}>,
<-x^6-x^5+3*x^4+3*x^3-2,{2}>,
<2*x^6+3*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+2,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3-2,{2}>,
<-x^6-x^5+3*x^4+2*x^3+2,{2}>,
<2*x^6-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-2*x^3+x^2-3*x-1,{}>,
<-x^6-3*x^5-2*x^3-2,{2}>,
<-x^6-3*x^5+x^4-2*x^3-2,{2}>,
<-x^6-3*x^5-x^4-2*x^3+2,{}>,
<2*x^6-2*x^3-x^2-x-1,{2}>,
<-2*x^6-2*x^3+2*x^2-x-1,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-2,{2,5}>,
<-2*x^6+2*x^3+3*x^2+x-1,{2}>,
<-x^6-x^5-3*x^4+2*x^3+2,{2}>,
<2*x^6-x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^4+x^3-2,{2}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2-2,{2}>,
<2*x^6-x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^4+x^3-2,{2}>,
<2*x^6-x^3+2*x^2+x-1,{2}>,
<-x^6-3*x^5+x^4-x^3+2,{2}>,
<2*x^6-x^5-3*x^4+3*x^3-x^2+2,{2}>,
<-x^6+x^4+3*x^3+3*x^2-x-2,{}>,
<-x^6-3*x^5+x^3-2,{2}>,
<-x^6-2*x^5-x^4-x^3-2,{2,11}>,
<-x^6-3*x^5-x^4+x^3-2,{2}>,
<-x^6+x^5+x^3+2,{2}>,
<-x^6+2*x^5-3*x^4-x^3+2,{2}>,
<-x^6+3*x^5+3*x^4-x^3-2,{2}>,
<-2*x^6-x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+2,{2}>,
<-2*x^6-x^4+3*x^3+3*x^2-3*x-1,{2}>,
<-2*x^6+2*x^2-3*x-1,{2,7}>,
<-x^6+3*x^5+3*x^4-3*x^3-x^2+2,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+x^2-2,{2}>,
<2*x^6-x^4+3*x^3+2*x^2+2*x-1,{2}>,
<2*x^6-x^4+3*x^3+2*x^2+x-1,{2}>,
<2*x^6-2*x^4-3*x^3+x^2-2,{2,7}>,
<-2*x^6+x^4+3*x^3-x^2+3*x-1,{2}>,
<2*x^6-x^4+3*x^3+x^2+3*x-1,{}>,
<-x^6+2*x^5-x^4+3*x^3+x^2-2,{2}>,
<-2*x^6+x^4-3*x^3-2*x-1,{2}>,
<-x^6-x^5+3*x^3+3*x^2+x-2,{2}>,
<-x^6+x^5+3*x^3+x^2-2,{2}>,
<-x^6-3*x^3-x^2+2,{}>,
<2*x^6-x^4-3*x^3-2*x-1,{2}>,
<2*x^6-x^4+3*x^3-x-1,{2}>,
<-2*x^6+x^4+3*x^3+2*x^2-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3+x^2-2,{2}>,
<-2*x^6+x^4-3*x^3+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+x^2-2,{2}>,
<2*x^6-x^4+3*x^3-3*x^2+3*x-1,{}>,
<-2*x^6+x^4-3*x^3+x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3+x^2-2,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3-x^2+2,{2}>,
<2*x^6-2*x^4-3*x^3-2*x^2-2,{2}>,
<-x^6+x^5+2*x^4-3*x^3+2*x^2+2,{}>,
<-2*x^6+x^4+3*x^3+3*x^2+x-1,{2}>,
<2*x^6+2*x^4+3*x^3+x^2+3*x-1,{2}>,
<-2*x^6+3*x^4-3*x^3+x^2-2,{2}>,
<-x^6+2*x^5-x^4+3*x^3-2*x^2-2,{2}>,
<-x^6+x^5-3*x^4+2,{}>,
<2*x^6-3*x^4+3*x^3-x^2+2,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-x^2+2,{2}>,
<2*x^6-x^4-3*x^3+3*x^2-x-1,{}>,
<2*x^6+2*x^4-3*x^3-2*x-1,{2,17}>,
<-2*x^6+x^4+3*x^3+3*x^2-x-1,{0,2}>,
<2*x^6-x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6-x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-2*x^6-2*x^4-3*x^3-x-1,{2}>,
<-x^6+x^5+2*x^4+2*x^3+x^2-2,{2}>,
<-x^6+x^5-2*x^4-2*x^3-x^2+2,{}>,
<2*x^6-x^4-2*x^3+3*x^2-3*x-1,{2}>,
<-x^6-x^5+x^4-x^3-x^2+2,{2}>,
<-x^6-3*x^5-x^4+x^3+x^2-2,{}>,
<-x^6-3*x^5+2*x^4-2*x^3-x^2+2,{}>,
<-x^6+3*x^5+2*x^4-3*x^3+2,{2}>,
<2*x^6-x^4-x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^3-x^2+2,{2}>,
<2*x^6-x^4-x^3-2*x-1,{2,3}>,
<-x^6-2*x^5+x^3+x^2-2,{2}>,
<-x^6+3*x^5-x^4-2*x^3+x^2-2,{2}>,
<-x^6+3*x^5-x^4+3*x^3-2,{2}>,
<2*x^6-x^4+x^3-3*x-1,{2}>,
<-x^6+3*x^5+2*x^3+x^2-2,{2}>,
<-x^6-x^5+2*x^3+3*x^2+2,{2,11,73}>,
<-x^6-3*x^5+x^4-x^3+x^2-2,{2}>,
<-x^6-3*x^5-2*x^3-x^2+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+2,{2}>,
<2*x^6-x^4+2*x^3+x-1,{2,3}>,
<-2*x^6+x^4-x^3+x^2-2*x-1,{2}>,
<-x^6-3*x^5-2*x^4+2*x^3-x^2+2,{2}>,
<-x^6+3*x^5-2*x^3-3*x^2-2,{2}>,
<2*x^6-x^4+x^3-2*x^2+3*x-1,{2}>,
<-x^6-2*x^5+2*x^4-x^3+x^2-2,{}>,
<-x^6+x^5+x^4+3*x^3+2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+x^2-2,{2}>,
<-2*x^6+x^4-x^3+2*x^2-x-1,{2}>,
<2*x^6-x^4+2*x^3-3*x^2-x-1,{2}>,
<2*x^6-x^4-x^3-2*x^2-1,{2}>,
<-2*x^6-3*x^3-x^2+2,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3-x^2+2,{2}>,
<2*x^6-x^4-x^3-2*x^2+x-1,{2}>,
<-x^6-3*x^5+3*x^4-x^3-x^2+2,{}>,
<2*x^6-2*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<2*x^6-x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+2*x^2-2,{2}>,
<-2*x^6+x^4+x^3+3*x^2-3*x-1,{}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2+2,{2}>,
<-2*x^6+x^4-x^3-3*x^2+2,{2}>,
<2*x^6-x^4+x^3-3*x^2-3*x-1,{}>,
<-x^6-x^5+2*x^4-3*x^3-2*x^2+2,{2}>,
<-x^6+3*x^5+2*x^4-x^3+x^2-2,{2}>,
<-2*x^6+2*x^4-3*x^3-2*x^2+2,{2}>,
<-x^6-3*x^5-2*x^4+x^2-2,{2}>,
<2*x^6-x^4-x^3+3*x^2+x-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3+2*x^2-2,{2}>,
<-2*x^6+x^4-x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^2+2,{2}>,
<2*x^6-x^4+x^3+x^2+3*x-1,{}>,
<-x^6-x^5-3*x^4-x^3-x^2+2,{2}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2+2,{2,3}>,
<-2*x^6+x^4+x^2-3*x-1,{2}>,
<-x^6+3*x^3+2*x^2-2,{2}>,
<-2*x^6+2*x^4+3*x^3-3*x-1,{}>,
<-2*x^6+2*x^4+3*x^3-x^2+x-1,{2}>,
<-x^6-3*x^4-x^3-x^2+2,{2}>,
<2*x^6-x^4-3*x^2+x-1,{2}>,
<-2*x^6+2*x^4+3*x^3+3*x-1,{2}>,
<-x^6+3*x^5+x^4+3*x^3+2*x^2-2,{2}>,
<-2*x^6+2*x^4-3*x^3+x^2-2*x-1,{2}>,
<-2*x^6+2*x^4-3*x^3-3*x^2-3*x-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2-2,{2}>,
<2*x^6-x^4-x^3-3*x^2+x-1,{2,3}>,
<-x^6+3*x^5+x^4-3*x^3+x^2-2,{2}>,
<2*x^6-2*x^4-3*x^3+3*x^2-2*x-1,{}>,
<2*x^6-2*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+2*x^2-2,{}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2+2,{2}>,
<-x^6-x^5-x^4-3*x^3-2*x^2+2,{2}>,
<2*x^6-x^4-x^3-3*x^2+2*x-1,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2-1,{2}>,
<-x^6+2*x^5-2*x^4+3*x^3-2*x^2+2,{2}>,
<-x^6+3*x^5+2*x^4-3*x^3-2*x^2-2,{2}>,
<2*x^6-2*x^4-3*x^3-3*x^2+x-1,{2}>,
<-2*x^6+2*x^4-3*x^3-3*x^2+2,{2,3}>,
<-2*x^6+2*x^4-3*x^3+2*x^2-x-1,{2}>,
<2*x^6-2*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<2*x^6-2*x^4+2*x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-3*x^3+2*x^2-2,{0,2}>,
<-x^6-x^5+x^4-2*x^3+2*x^2-2,{2}>,
<2*x^6-2*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<-2*x^6+2*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<2*x^6-2*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+x^2-2,{2,3}>,
<-x^6-x^5-2*x^4+2*x^3-2*x^2+2,{2}>,
<-x^6+x^4+3*x^3+2*x^2-2,{2}>,
<-x^6+3*x^5-2*x^4-2*x^3-2*x^2+2,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+x^2-2,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x^2-2,{}>,
<-2*x^6+2*x^4+3*x^3+x^2-x-1,{2}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2-2,{}>,
<-x^6-3*x^5-2*x^4-3*x^3+2*x^2-2,{}>,
<2*x^6-2*x^4-3*x^3-x^2+2*x-1,{}>,
<-x^6-x^5-3*x^4+2*x^3-2*x^2+2,{2}>,
<-2*x^6+2*x^4-3*x^3+x^2-2,{2}>,
<2*x^6-2*x^4+x^3+2*x^2+3*x-1,{}>,
<-2*x^6+2*x^4-3*x^3+2*x^2-2,{2}>,
<-x^6-3*x^5-x^4+3*x^3-2*x^2+2,{2}>,
<2*x^6-2*x^4+x^3+2*x^2-3*x-1,{2}>,
<-2*x^6+2*x^4-x^3+x^2-x-1,{2}>,
<-x^6-x^4-x^3-2*x^2+2,{}>,
<2*x^6+x^4+2*x^2+x-1,{2}>,
<-2*x^6+2*x^4-3*x^3+2*x^2+x-1,{2}>,
<2*x^6-2*x^4+x^3-2*x^2-3*x-1,{2}>,
<2*x^6-2*x^4+3*x^3-2*x^2-x-1,{}>,
<-2*x^6+2*x^4+x^3+3*x^2+2*x-1,{2}>,
<2*x^6-2*x^4-2*x^3-3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4-x^2-2,{2,5,7}>,
<2*x^6-2*x^4-x^3-3*x^2-x-1,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+3*x^2-2,{2}>,
<-2*x^6-x^4-3*x-1,{2}>,
<-2*x^6-x^4+2*x^2+x-1,{2}>,
<2*x^6-3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<2*x^6-3*x^4-3*x^3+3*x^2-x-1,{2}>,
<2*x^6-3*x^4-3*x^3+2*x^2-1,{2,3}>,
<2*x^6-3*x^4+3*x^3+2*x^2-x-1,{2}>,
<2*x^6-2*x^4-x^3-3*x^2-1,{2,31}>,
<-x^6-x^5-x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4-3*x^3+3*x^2-2,{2,11}>,
<-2*x^6+2*x^4-x^3+3*x^2+x-1,{0,2}>,
<-x^6-x^5+x^4-3*x^3-3*x^2+2,{2}>,
<2*x^6-2*x^4+x^3-3*x^2-2*x-1,{}>,
<-x^6+x^5+3*x^4-3*x^3-3*x^2+2,{2}>,
<-2*x^6+2*x^4+3*x^3+3*x^2+3*x-1,{2,3,29}>,
<-x^6-x^4-3*x^3+3*x^2-2,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2+3*x-1,{2}>,
<2*x^6-3*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<-2*x^6+2*x^4+x^2+3*x-1,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2-2,{}>,
<-x^6-2*x^5+3*x^4-3*x^3+2*x^2-2,{2}>,
<-x^6-2*x^5-3*x^3-3*x^2+2,{2}>,
<-x^6+x^5-x^4-2*x^2+2,{2}>,
<-2*x^6+2*x^4-3*x^3+3*x^2-x-1,{}>,
<-2*x^6+3*x^4-3*x^3+x-1,{2}>,
<-x^6-2*x^5+3*x^3-3*x^2+2,{2}>,
<2*x^6-2*x^4-2*x^2+x-1,{2}>,
<2*x^6-3*x^4+3*x^3+x-1,{2}>,
<-x^6+3*x^5-3*x^3-3*x^2+2,{2}>,
<-x^6-3*x^5+x^4-3*x^3+3*x^2-2,{2}>,
<-x^6+3*x^5-x^4+3*x^3-3*x^2+2,{}>,
<-x^6-3*x^3+3*x^2-2,{2}>,
<-x^6-2*x^5+x^4-3*x^3+3*x^2-2,{2}>,
<-x^6-3*x^5+3*x^4+2*x^2-2,{2}>,
<2*x^6-3*x^4+3*x^3-x^2+2*x-1,{2}>,
<2*x^6-3*x^4-3*x^3-x^2+2*x-1,{2}>,
<-x^6+x^5+x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4+3*x^3-3*x^2-1,{2}>,
<2*x^6-3*x^4+3*x^3-x^2-3*x-1,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4+3*x^3-3*x^2-x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4-3*x^3-x^2+x-1,{2,7}>,
<2*x^6-3*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6-x^5+2*x^3-3*x^2+2,{2}>,
<-x^6+2*x^4-3*x^3+3*x^2-2,{2}>,
<-2*x^6+3*x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+3*x^2-2,{0,2}>,
<-x^6-3*x^5-x^4-2*x^3-3*x^2+2,{2}>,
<-x^6-x^5-x^4+2*x^3-3*x^2+2,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+3*x^2-2,{2}>,
<-2*x^6+3*x^4+2*x^3-3*x^2+3*x-1,{2}>,
<-2*x^6+3*x^4-2*x^3+2*x^2-x-1,{2}>,
<2*x^6-3*x^4-2*x^3-2*x^2+x-1,{}>,
<-x^6-3*x^5+3*x^4-2*x^3+3*x^2-2,{2}>,
<-x^6+3*x^5-2*x^4+x^3+3*x^2-2,{2}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2+2,{}>,
<-x^6-x^5+2*x^4-x^3-3*x^2+2,{2}>,
<2*x^6-3*x^4+x^3+2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^4-x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3-3*x^2+2,{2}>,
<-2*x^6+3*x^4+x^3-x^2+2*x-1,{2}>,
<-x^6-2*x^5-x^3+3*x^2-2,{2}>,
<-x^6+x^5+x^3+3*x^2-2,{2}>,
<-x^6-x^5+x^3-3*x^2+2,{2}>,
<-x^6-2*x^5+x^3-3*x^2+2,{2}>,
<-x^6+3*x^5-x^3+3*x^2-2,{2}>,
<-x^6-3*x^5+x^4-x^3+3*x^2-2,{2}>,
<-x^6+x^5+x^4+x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4+x^3-x^2+x-1,{2}>,
<2*x^6-3*x^4+x^3-x^2-1,{2}>,
<2*x^6-3*x^4+x^3-x^2-2*x-1,{2}>,
<-2*x^6+3*x^4+x^3+x^2-3*x-1,{2}>,
<2*x^6-3*x^4+x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+3*x^2-2,{2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-2,{2}>,
<2*x^6-3*x^4+x^3-2*x^2-1,{2}>,
<-2*x^6+3*x^4+x^3+2*x^2-x-1,{0,2}>,
<2*x^6-3*x^4+x^3-2*x^2-2*x-1,{2,5}>,
<-2*x^6+x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+x^3-3*x^2+2,{2}>,
<-x^6+3*x^5+3*x^4+x^3+3*x^2-2,{2}>,
<-x^6-x^5-x^4-3*x^2+2,{2}>,
<-x^6-x^5-2*x^4-3*x^2+2,{2}>,
<2*x^6-3*x^4-x^3-3*x^2-2*x-1,{2}>,
<2*x^6-3*x^4-3*x^2+3*x-1,{2}>,
<-x^6+x^5-3*x^4+x^3-3*x^2+2,{2}>,
<-x^6+x^5+3*x^4-x^3+3*x^2-2,{0}>,
<-x^6-2*x^5-3*x^4-3*x^2+2,{2}>,
<-x^6+x^5-3*x^4-x^3-3*x^2+2,{2}>,
<-x^6+2*x^5-3*x^4-x^3-3*x^2+2,{2}>,
<-x^6-3*x^5-x^4+3*x^2-2,{2}>,
<-x^6-x^5-3*x^4-3*x^2+2,{2,3,61}>,
<-x^6-3*x^5-3*x^4-3*x^3-3*x^2-x-1,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^3-3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^3-3*x^2+3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-3*x^3+2*x^2-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2+3*x-1,{0,2,5}>,
<-x^6-3*x^5-3*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+2*x^2+3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3-3*x^2-3*x-1,{}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-x^3+2*x^2-3*x-1,{}>,
<-x^6+3*x^5-x^4+2*x^3-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+x^2-2*x-1,{2,7}>,
<-x^6+3*x^5-3*x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+2*x^2-x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+2*x^2-2*x-1,{}>,
<-x^6-3*x^5-3*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-2*x^3+3*x^2-2*x-1,{}>,
<-x^6+3*x^5-x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3-2*x-1,{2}>,
<-x^6+3*x^5+3*x^3-3*x^2-3*x-1,{2,5}>,
<-x^6+2*x^5+x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-3*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^4+3*x^3+3*x^2-1,{2}>,
<-x^6+3*x^5-3*x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3-2*x^2-3*x-1,{}>,
<-x^6+3*x^5-2*x^4+3*x^3-2*x^2-x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6+x^5-x^4+3*x^3-2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+3*x^3-x^2-2*x-1,{}>,
<-x^6+3*x^5-x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-x^6+x^4-3*x^3-2*x^2-3*x-1,{2,3}>,
<-x^6+3*x^5+2*x^4+3*x^3-2*x^2+3*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-x^6+x^5+2*x^4-3*x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+3*x-1,{}>,
<-x^6+3*x^5-2*x^4+3*x^3+3*x^2+x-1,{2}>,
<-x^6-3*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3-2*x^2-3*x-1,{}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2-1,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3-2*x^2-x-1,{2}>,
<-x^6+2*x^5-2*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-3*x^4+3*x^3+3*x^2+x-1,{}>,
<-x^6+2*x^5-x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-x^6+x^5+3*x^4-3*x^3-3*x^2-3*x-1,{2,3}>,
<-x^6-3*x^5-3*x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-3*x^5-x^4+2*x^3-2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-3*x^4-2*x^3+x-1,{2}>,
<-x^6+2*x^5+2*x^3-2*x^2+3*x-1,{}>,
<-x^6+3*x^5-2*x^4+2*x^3+x^2+x-1,{}>,
<-x^6+3*x^5-3*x^4+2*x^3+x^2-3*x-1,{0,2}>,
<-x^6-3*x^5+2*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+x^2-1,{2}>,
<-2*x^6+3*x^4-3*x^3+2*x^2+3*x-1,{0}>,
<-x^6+3*x^5+x^4-2*x^3-2*x^2-3*x-1,{}>,
<-x^6+2*x^4-2*x^3-3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3-3*x^2-3*x-1,{}>,
<-x^6-2*x^5+2*x^4-x^3-3*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+3*x^5-2*x^4+2*x^3+2*x^2-1,{2}>,
<-x^6-3*x^5-2*x^4-2*x^3+3*x^2-3*x-1,{}>,
<-x^6-3*x^5-2*x^4-2*x^3+3*x^2-2*x-1,{}>,
<2*x^6-3*x^4-3*x^3-3*x^2-x-1,{2}>,
<-x^6-2*x^4-x^3-2*x^2-3*x-1,{2}>,
<-x^6-x^4-x^3-2*x^2-3*x-1,{2}>,
<-2*x^6+3*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6-2*x^5+x^4-x^3-2*x^2-3*x-1,{}>,
<-x^6+3*x^5-2*x^4+x^3+3*x-1,{2}>,
<-x^6-x^5+x^4-x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-x^3+x^2+2*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3-2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-2*x^4-x^3+2*x-1,{2}>,
<-x^6+2*x^4+x^3-2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5-3*x^3-x^2-3*x-1,{}>,
<-x^6+2*x^5+3*x^4-x^3-2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+x^3+3*x^2-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-1,{2}>,
<-x^6+2*x^5+x^4-2*x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3-2*x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^4+2*x^2+2*x-1,{2}>,
<-x^6-2*x^5+2*x^4-2*x^2+3*x-1,{0,2}>,
<-x^6-3*x^5-x^4-3*x^3+x-1,{2,11}>,
<-x^6-3*x^5-2*x^3-2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-2*x^4+3*x^2-x-1,{}>,
<-x^6-3*x^5-x^4-3*x^3+2*x^2-2*x-1,{}>,
<-x^6-3*x^5-2*x^4+2*x^3+x^2+2*x-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6-x^5+x^4-3*x^3-2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-x^6-x^5-2*x^4+2*x^3-x^2+3*x-1,{}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3-2*x^2-2*x-1,{}>,
<2*x^6-x^3-x^2-2*x-1,{2}>,
<-x^6-3*x^5-x^4-3*x^3-3*x^2-2*x-1,{2,7}>,
<-x^6-x^5-2*x^3-x^2-3*x-1,{2}>,
<-x^6-x^5-x^4-x^3+2,{2}>,
<-x^6-x^5+3*x^4-3*x^3-x^2-3*x-1,{2,7}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2+3*x-1,{}>,
<-x^6-2*x^3-x^2-3*x-1,{2}>,
<-x^6+2*x^5-3*x^4-3*x^3-x^2-3*x-1,{2}>,
<-x^6+2*x^5+x^4-x^3-2,{2}>,
<-x^6-3*x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4+3*x^3-x^2+x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3+x^2+2*x-1,{}>,
<-2*x^6-x^3+2*x^2-3*x-1,{2}>,
<-x^6-x^5-3*x^4+2*x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3+x^2-1,{2}>,
<-x^6+x^5+2*x^4-2*x^3-x^2-3*x-1,{2}>,
<2*x^6-x^3-2*x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3+3*x^2+2*x-1,{2}>,
<-x^6+x^5+x^4-2*x^3-x^2-3*x-1,{2}>,
<-x^6+2*x^5-x^3-x^2-3*x-1,{2}>,
<-x^6+x^5+3*x^4+2*x^3-x^2+3*x-1,{2,3}>,
<-x^6-3*x^5+x^4-x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^2-3*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3-2,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-x^2-3*x-1,{0,2,3}>,
<-x^6+x^5+x^4+x^3-x^2+3*x-1,{2}>,
<-x^6-x^5-3*x^4-x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4-2*x^3+3*x^2+3*x-1,{0,2}>,
<-x^6-x^5-3*x^4-x^3-x^2-3*x-1,{}>,
<-x^6-x^5+2*x^4+x^3-2,{2}>,
<-x^6-3*x^4-x^2-3*x-1,{2}>,
<-x^6+x^4-x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3+x^2-3*x-1,{}>,
<-x^6+3*x^5-x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5-x^4-2*x^2-1,{2}>,
<-x^6+3*x^5-x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4+x^3-2,{2}>,
<-x^6+2*x^5-x^4-x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4-x^3-2*x^2-1,{2}>,
<-x^6-3*x^5-x^4-3*x-1,{}>,
<-x^6+2*x^4+x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x^2-x-1,{2}>,
<-x^6+x^5-x^2-3*x-1,{2}>,
<-x^6+3*x^5-x^4-x^3-2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-x^2-3*x-1,{2}>,
<-x^6-2*x^5-x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-x^2+3*x-1,{}>,
<-x^6-x^4+x^3-x^2-3*x-1,{2}>,
<-x^6-3*x^5-x^4+3*x^2-1,{2}>,
<-x^6-3*x^5-x^4+x^3-1,{2}>,
<-x^6-2*x^5+3*x^4-x^3-x^2-3*x-1,{2}>,
<-x^6+x^4+2*x^3-x^2-3*x-1,{2}>,
<-x^6+2*x^5+x^4+2*x^3-x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^3+2*x-1,{2}>,
<-x^6-3*x^5-x^4+2*x^3+3*x^2+3*x-1,{0,2}>,
<-x^6-2*x^5+3*x^4+x^3-x^2+3*x-1,{0,2}>,
<2*x^6-3*x^4-2*x^3+2*x^2-3*x-1,{}>,
<-x^6-3*x^5-x^4+3*x^3-x^2+2*x-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3+3*x-1,{2}>,
<-x^6-3*x^5-x^4+3*x^3+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+3*x-1,{2,5}>,
<-x^6-3*x^5-3*x^3-3*x^2-x-1,{}>,
<-x^6+3*x^5+3*x^3-3*x^2-2*x-1,{}>,
<-x^6+3*x^5+3*x^3-x^2+2*x-1,{}>,
<2*x^6-3*x^4+2*x^3+2*x^2+x-1,{2}>,
<-x^6-3*x^5-x^4+x^3+x-1,{2}>,
<-x^6-3*x^5-3*x^3-x^2-1,{2}>,
<-x^6+3*x^5+3*x^3+x-1,{}>,
<-x^6+3*x^5+2*x^3+3*x^2-2,{}>,
<-x^6-3*x^5-x^4+x^3+2*x-1,{0,2}>,
<-x^6+x^5-3*x^3-3*x-1,{2}>,
<-x^6+2*x^5-3*x^3-3*x-1,{}>,
<-x^6+3*x^5+3*x^3+2*x^2-3*x-1,{0,2,3,5,29}>,
<-x^6+2*x^5+x^4+3*x^3+3*x-1,{2}>,
<-x^6-3*x^5-3*x^3+x^2-x-1,{}>,
<-x^6-3*x^5-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6+3*x^5+3*x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3+3*x-1,{2}>,
<-x^6+3*x^5+2*x^3-2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-x^4+2*x^3+2*x^2-2,{2}>,
<-x^6+x^5+2*x^4+3*x^3+3*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3-x^2-3*x-1,{0,2,7,17}>,
<-x^6-3*x^5+x^4+x^3+2*x^2-2,{2}>,
<-x^6+2*x^4+3*x^3+3*x-1,{2}>,
<-x^6+3*x^5-x^4-x^3+x^2-3*x-1,{0,2}>,
<-x^6+3*x^5+2*x^4+x^3+2*x^2-2,{2}>,
<-x^6+3*x^5+2*x^3+2*x^2-1,{2}>,
<-x^6+3*x^5-x^4-x^3+3*x^2-1,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2+2*x-1,{2}>,
<-x^6+x^5+2*x^4+x^3+2*x^2-2,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2+x-1,{2}>,
<-x^6-x^5-2*x^3+3*x^2-2,{2,17}>,
<-x^6-2*x^5-2*x^3-x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^3+3*x^2-x-1,{2}>,
<2*x^6-2*x^4-x^3-2*x^2-x-1,{2}>,
<-x^6+3*x^5+x^3-3*x^2-1,{2}>,
<-x^6+x^5-x^4+2*x^3+3*x-1,{2,3}>,
<-x^6+3*x^5-x^4-2*x^3-3*x-1,{2}>,
<-x^6+3*x^5+x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+x^3+x-1,{2}>,
<-x^6+2*x^5-2*x^4-x^3-3*x-1,{2}>,
<-x^6+3*x^5+x^3-x^2+2*x-1,{}>,
<-x^6-3*x^4+3*x-1,{2}>,
<-x^6-x^4-2*x^3-3*x-1,{2}>,
<-x^6-x^5-3*x^4+3*x-1,{2}>,
<-x^6-3*x^5-2*x^3-2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-3*x-1,{2,3}>,
<-x^6-x^5-2*x^4+3*x-1,{2}>,
<-x^6-3*x^5-2*x^3+x-1,{2}>,
<-x^6-3*x^5-2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-x^4+3*x-1,{2}>,
<-x^6+3*x^5-x^2-2*x-1,{2}>,
<-x^6-3*x^5-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x-1,{2}>,
<-2*x^6+2*x^4-2*x^3-x^2+3*x-1,{2,13,19}>,
<-x^6-3*x^5-x^3+x^2-1,{2,5}>,
<-x^6+3*x^5+x^3-x^2+x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3-3*x-1,{}>,
<-x^6+2*x^5-x^4-x^3-3*x-1,{}>,
<-x^6+3*x^5+2*x^3+x^2+2*x-1,{2}>,
<-x^6-x^5-3*x-1,{2}>,
<-x^6+3*x^5+x^2+x-1,{2}>,
<-x^6-2*x^5+2*x^4-x^3-3*x-1,{2}>,
<-x^6-2*x^5+3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+3*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x-1,{}>,
<-x^6-3*x^5-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+2*x^4-3*x-1,{}>,
<-x^6+x^5+2*x^4-3*x-1,{0,2}>,
<-x^6+3*x^5+3*x^2+2*x-1,{}>,
<-x^6-3*x^5+3*x^2-x-1,{}>,
<-x^6-3*x^5-2*x^3+2*x^2-2*x-1,{2,3,7}>,
<-x^6-3*x^5+x^3-3*x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3-3*x-1,{}>,
<-x^6-2*x^4-x^3+3*x-1,{2,37}>,
<-2*x^6+2*x^4+2*x^3+x-1,{2}>,
<-x^6+3*x^5-x^3+2*x^2-1,{2}>,
<-x^6-x^5+2*x^4+x^3+3*x-1,{2}>,
<-x^6+2*x^5+3*x^4-x^3+3*x-1,{2}>,
<-x^6-x^5-2*x^4-x^3+3*x-1,{2}>,
<-x^6+3*x^5-2*x^3-3*x^2+2*x-1,{2}>,
<-x^6+3*x^5-2*x^3-3*x^2+x-1,{2}>,
<-x^6+3*x^5+x^3+2*x^2-2*x-1,{0,2,17}>,
<-x^6-2*x^5-3*x^4-2*x^3+3*x-1,{2}>,
<-x^6+3*x^5-2*x^3-2*x^2-1,{2}>,
<-x^6-x^5-3*x^4+x^3-3*x-1,{}>,
<-x^6-2*x^5+3*x^4-x^3-3*x-1,{2}>,
<-x^6-3*x^5-x^3+3*x^2-x-1,{}>,
<-x^6-3*x^5+2*x^3-2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-x^3-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^3-x^2-x-1,{2}>,
<-x^6-x^4+2*x^3-3*x-1,{2}>,
<-x^6+3*x^5-2*x^3-x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3+3*x-1,{0,2}>,
<-2*x^6+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2+2*x-1,{2}>,
<-x^6+3*x^5-2*x^3+2*x^2-3*x-1,{0,2}>,
<-x^6-x^5-3*x^4-3*x-1,{2}>,
<-x^6-x^5+3*x^4+2*x^3-3*x-1,{}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x-1,{}>,
<-x^6+3*x^5-x^3-x^2-1,{2}>,
<-x^6-3*x^5+2*x^3-x^2+2*x-1,{0,2}>,
<-x^6+x^5-x^4+x^3-3*x-1,{2}>,
<-x^6-3*x^5+x^3-x^2+2*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3-2*x^2+x-1,{2}>,
<-x^6-2*x^5+x^3-3*x-1,{2}>,
<-x^6-x^5-x^3+3*x-1,{2}>,
<-x^6-3*x^5+x^3+x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3-3*x-1,{}>,
<-x^6-3*x^5+3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-3*x^5+x^3+2*x^2-x-1,{2}>,
<-x^6+3*x^5-3*x^3-x^2+2*x-1,{}>,
<-x^6-2*x^5+2*x^4+3*x^3-3*x-1,{2}>,
<-x^6+2*x^5+3*x^4-3*x^3+3*x-1,{}>,
<-x^6+3*x^5-3*x^3-x^2+x-1,{2}>,
<-x^6+2*x^5-2*x^4+x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^3-x^2-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-3*x-1,{0,2}>,
<-x^6+3*x^5+x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6+3*x^3-3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3-2*x^2-1,{2}>,
<-x^6-3*x^5+x^4-x^3-x^2-1,{2}>,
<-x^6-x^4+2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^3+x-1,{}>,
<-x^6-3*x^5+3*x^3+x-1,{0,2}>,
<-x^6+3*x^5+x^4+x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^4+x^3+x^2+2*x-1,{}>,
<-x^6-3*x^5+x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+2*x^3+x^2-1,{}>,
<-x^6+3*x^5+x^4-2*x^2+2*x-1,{2}>,
<-x^6+x^5+x^4-x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^2+x-1,{2}>,
<-x^6+2*x^5+x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-2*x^2+2*x-1,{2}>,
<-x^6+2*x^5+x^4-x^3+x^2-3*x-1,{0,2}>,
<-x^6+2*x^4-2*x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4-x^2-2*x-1,{2}>,
<-x^6-3*x^5+x^4-x^3+2*x^2-1,{2}>,
<-x^6-3*x^5+x^4-x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3+x^2-3*x-1,{0,2}>,
<-x^6+2*x^5-x^4+x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^2-3*x-1,{}>,
<-x^6+x^5+3*x^4-2*x^3+x^2-3*x-1,{0,2}>,
<-x^6+3*x^5+x^4+2*x^2-x-1,{0,2}>,
<-x^6-2*x^4+x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5+x^4+3*x^2-2*x-1,{}>,
<-x^6+3*x^5+x^4-x^3-2*x^2-x-1,{2}>,
<-x^6+2*x^5-2*x^4+x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4-x^3-x^2-2*x-1,{2}>,
<-x^6+3*x^5+x^4-x^3-3*x^2-1,{2}>,
<-x^6-3*x^5+x^4-3*x^2+x-1,{2}>,
<-x^6+3*x^5+x^4-x^3+x^2+x-1,{2}>,
<-x^6+3*x^5+x^4-x^3+x^2-1,{2}>,
<-x^6-3*x^5+x^4+x^3+2*x^2-3*x-1,{}>,
<-x^6-3*x^5+x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^2+2*x-1,{2}>,
<-x^6+3*x^5+x^4-x^3+2*x^2-1,{2}>,
<-x^6-2*x^4-2*x^3+x^2+3*x-1,{2,5}>,
<-x^6+x^5-3*x^4-2*x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^4-2*x^3-2*x^2-2*x-1,{2,3}>,
<-x^6-3*x^5+x^4+2*x^3-3*x^2-1,{2,7}>,
<-x^6-x^4-2*x^3+x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x^2+x-1,{2}>,
<-x^6-x^5+x^4+2*x^3+x^2-3*x-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+x^2-3*x-1,{}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2+x-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+x^2+3*x-1,{0,2}>,
<-x^6-3*x^5+2*x^4-3*x^3-x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+x^2-3*x-1,{0,2,7}>,
<-x^6+2*x^5-x^4-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2+x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2-1,{2}>,
<-x^6-2*x^5-3*x^4-3*x^3+x^2+3*x-1,{2}>,
<-x^6+3*x^5+x^4-3*x^3-x^2-x-1,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+3*x^3+x^2-3*x-1,{0,2}>,
<-x^6-3*x^5+x^4+3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-3*x^5+x^4+3*x^3+2*x^2+2*x-1,{0,2}>,
<-x^6+3*x^5+2*x^4+3*x^3-3*x^2+2*x-1,{}>,
<-x^6-3*x^5+2*x^4-3*x^3-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+2*x^2+x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x^2+3*x-1,{2}>,
<-x^6+x^5+3*x^4-3*x^3+2*x^2-3*x-1,{0,2}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x^2+x-1,{2}>,
<-x^6-3*x^5+x^4+3*x^3-2*x^2-x-1,{2,3,7,149}>,
<-x^6+3*x^5+2*x^4+2*x^3-3*x^2-1,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3-2*x^2-2*x-1,{2,5}>,
<-x^6+3*x^5+2*x^4+2*x^3-x^2+2*x-1,{2}>,
<-x^6-2*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6+x^5-x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+x^5-2*x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+2*x^3+2*x^2+3*x-1,{2,5}>,
<-x^6+3*x^5+2*x^4+2*x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^5+x^4-x^3-2*x^2+2,{2}>,
<2*x^6-2*x^4+x^3+x^2+x-1,{2}>,
<-x^6+3*x^5+x^4-x^3-2*x^2+2,{2}>,
<-2*x^6+2*x^4+x^3+3*x-1,{2}>,
<-2*x^6+2*x^4+x^3+2*x-1,{2}>,
<-x^6+3*x^5-x^4+x^3-2*x^2+2,{}>,
<-x^6+2*x^5+x^4+x^3+2*x^2-2,{2}>,
<-x^6-3*x^5+2*x^4-x^3-2*x-1,{2}>,
<-x^6-x^5-x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3+x-1,{2}>,
<-x^6-2*x^5+x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2+x-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+x^2-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3+2*x^2-1,{2}>,
<-x^6-3*x^5+3*x^4-x^3+2*x^2-3*x-1,{2}>,
<-x^6+x^5+3*x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^4+x^3+2*x^2+3*x-1,{0,2}>,
<-x^6-2*x^5-3*x^4+2*x^2-3*x-1,{2,97}>,
<-x^6-2*x^5-3*x^4+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^2+x-1,{}>,
<-x^6+2*x^5+2*x^2+3*x-1,{2,7}>,
<-x^6+3*x^5+2*x^4-1,{2}>,
<-x^6-3*x^5+2*x^4+x-1,{2}>,
<-x^6-2*x^5+2*x^4+2*x^2-3*x-1,{2}>,
<-x^6+2*x^5+3*x^4+2*x^2+3*x-1,{2}>,
<-x^6-x^5+3*x^4+2*x^2-3*x-1,{}>,
<-x^6+3*x^5+2*x^4-x^3-3*x^2-1,{}>,
<-x^6+x^5-3*x^4+x^3+2*x^2-3*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+2*x^2+3*x-1,{2,3}>,
<-x^6-3*x^5+2*x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3-2*x^2+x-1,{2}>,
<-x^6-2*x^5-2*x^4-x^3+2*x^2+3*x-1,{2}>,
<-x^6-2*x^5-x^4+x^3+2*x^2-3*x-1,{2}>,
<-x^6+x^5-x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3+x^2+2*x-1,{}>,
<-x^6-3*x^5+2*x^4+x^3+x^2-1,{2,13}>,
<-x^6+3*x^5+3*x^3+3*x^2-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^4-x^3+2*x^2+2*x-1,{}>,
<-x^6+3*x^5+3*x^4-x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5-3*x^3+3*x^2+x-1,{2}>,
<-x^6-3*x^5+2*x^4+x^3+3*x^2-2*x-1,{}>,
<-x^6-2*x^5+3*x^4-x^3+2*x^2+3*x-1,{0,2}>,
<-x^6-3*x^5-3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6+x^5-3*x^4-2*x^3+2*x^2+3*x-1,{2}>,
<-x^6+3*x^5+2*x^3-3*x^2+2*x-1,{}>,
<-x^6-3*x^5-2*x^3-3*x^2+x-1,{}>,
<-x^6-3*x^5+2*x^4+2*x^3-3*x^2-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2-x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^4+2*x^3+3*x-1,{2}>,
<-x^6-2*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2-x-1,{}>,
<-x^6+3*x^5+2*x^4-2*x^3-2*x^2-2*x-1,{2}>,
<-x^6-3*x^4-3*x^3+2*x^2+3*x-1,{2}>,
<-x^6-2*x^5+2*x^3+2*x^2-3*x-1,{2}>,
<-x^6-x^5+x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4+3*x^3-3*x^2+2*x-1,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+2*x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4+2*x^3+3*x^2-3*x-1,{}>,
<-x^6-2*x^5+3*x^3+2*x^2-3*x-1,{2,5}>,
<-x^6-3*x^5+2*x^4+2*x^3+3*x^2+x-1,{0,2}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2+2*x-1,{}>,
<-x^6+3*x^5+2*x^4-3*x^3-3*x^2+x-1,{}>,
<-x^6+3*x^5+3*x^4+3*x^3-3*x^2+2*x-1,{2,3}>,
<-x^6-x^4-3*x^3+3*x^2-3*x-1,{}>,
<-x^6-x^5-x^4+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3-3*x^2+x-1,{2}>,
<-x^6-x^5+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x-1,{2}>,
<-x^6+x^5-3*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3-3*x^2+2*x-1,{}>,
<-x^6+3*x^5+3*x^4+3*x^3+x^2+2*x-1,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6-x^5-2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^3+x^2+2*x-1,{0,2}>,
<-x^6-3*x^5+3*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6+3*x^5+3*x^4+3*x^3+2*x^2+x-1,{}>,
<-x^6-2*x^5-2*x^4+3*x^3+3*x^2+3*x-1,{2}>,
<-x^6+x^5+2*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6-2*x^5+2*x^4+3*x^3+3*x^2+3*x-1,{}>,
<-x^6+3*x^5+3*x^4+3*x^3+3*x^2+2*x-1,{}>,
<-x^6+x^5-x^4+3*x^3+3*x^2+3*x-1,{2,7}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2-3*x-1,{2}>,
<-x^6+2*x^5-3*x^4+2*x^3+3*x^2+3*x-1,{}>,
<-x^6+3*x^5+3*x^4+2*x^3-2*x^2-x-1,{2}>,
<-x^6+3*x^5+3*x^4+2*x^3-x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2-1,{}>,
<-x^6+3*x^5+3*x^4+2*x^3-x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x^3-x^2-1,{}>,
<-x^6-3*x^5+3*x^4-2*x^3+x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4+2*x^3+3*x^2+3*x-1,{2}>,
<-x^6+2*x^5-x^4-2*x^3+3*x^2-3*x-1,{2,3}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x^2-x-1,{}>,
<-x^6+3*x^5+3*x^4+2*x^3+2*x-1,{}>,
<-x^6-3*x^5+3*x^4-x^3+2*x-1,{0,2}>,
<-x^6+3*x^5+3*x^4+x^3+x^2-1,{2}>,
<-x^6+3*x^5+3*x^4+x^3-3*x^2+x-1,{2,3,7,17}>,
<-x^6+3*x^5+3*x^4+x^3+2*x^2-1,{2}>,
<-x^6-3*x^5+3*x^4-x^3-2*x^2-1,{2}>,
<-x^6+3*x^5+3*x^4+x^3+3*x^2+2*x-1,{2}>,
<-x^6+x^5-x^4+x^3+3*x^2+3*x-1,{2}>,
<-x^6+2*x^5+3*x^4-x^3+3*x^2-3*x-1,{0,2}>,
<-x^6-3*x^5+3*x^4-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-3*x^2-x-1,{2,3}>,
<-x^6+3*x^5+3*x^4-3*x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4-3*x^3+x^2-1,{2}>,
<-x^6+3*x^5+2*x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6-3*x^5+3*x^4-2*x^2-x-1,{2,17}>,
<-x^6-3*x^5+3*x^4-x^2+x-1,{2}>,
<-x^6+3*x^5+3*x^4+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^2-1,{2,3}>,
<-x^6+2*x^5+x^4+3*x^2+3*x-1,{2}>,
<-x^6+x^5+2*x^4+3*x^2+3*x-1,{2}>,
<-x^6+3*x^5+3*x^4-x^3-2*x^2+2*x-1,{2}>,
<-x^6+x^5+3*x^4+3*x^2-3*x-1,{0,2,3}>,
<-x^6+2*x^5+3*x^4+3*x^2-3*x-1,{}>,
<-x^6-2*x^5-3*x^4+x^3+3*x^2-3*x-1,{}>,
<-x^6-3*x^5+3*x^4+x^3-x^2-x-1,{2,3}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2+x-1,{2,3}>,
<-x^6-3*x^5+3*x^4+x^3-3*x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3+3*x^2+x-1,{0,2}>,
<-x^6+2*x^5+3*x^4+2*x^3+3*x^2-3*x-1,{0,2}>,
<-x^6+3*x^5+3*x^4-3*x^3-3*x^2+x-1,{}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2-1,{}>,
<-x^6-3*x^5+3*x^4+3*x^3-3*x^2+x-1,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+3*x^2-2*x-1,{2}>,
<-x^6+3*x^4+2*x^3+2*x^2+3*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+2*x^2-3*x-1,{2,3}>,
<-x^6+x^5-3*x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3-3*x^2+2*x-1,{2,5}>,
<-x^6+x^5-2*x^4+x^3+2*x^2+3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-x^3-2*x^2-1,{2}>,
<-x^6+3*x^5+2*x^4+x^3-x^2-1,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+3*x^2-3*x-1,{0,2}>,
<-x^6-2*x^5-3*x^3+x^2-3*x-1,{2}>,
<-x^6+3*x^5+x^4+3*x^3-2*x-1,{2}>,
<-x^6-x^5+x^4-3*x^3+x^2-3*x-1,{2}>,
<-x^6+2*x^5-2*x^3+2*x^2-3*x-1,{2,3}>,
<-x^6+x^5+x^4-3*x^3+x^2-3*x-1,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+x^2-2*x-1,{2}>,
<-x^6-3*x^5+2*x^4-2*x^3+x^2-x-1,{2}>,
<-x^6+x^4-2*x^3+2*x^2-3*x-1,{2}>,
<-x^6+3*x^5+2*x^4+2*x^3+2*x^2+3*x-1,{}>,
<-x^6+2*x^4-2*x^3+2*x^2-3*x-1,{}>,
<-x^6-2*x^5+2*x^4-x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^4-x^3+2*x^2+2*x-1,{2}>,
<-x^6-x^5+3*x^4-x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6+x^5+3*x^4+x^3-3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-3*x^4-2*x^3-2*x-1,{2,5}>,
<-x^6-x^5+2*x^4-2*x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+3*x^3-3*x^2-2*x-1,{2,3}>,
<-x^6+2*x^5-3*x^4-3*x^3+x^2-x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^4+3*x^3+2*x^2+x-1,{2}>,
<-x^6+3*x^4-3*x^3-3*x^2+2*x-1,{2}>,
<-x^6-2*x^5-x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-x^5+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6+x^4-3*x^3-2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-2*x^4-3*x^3+2*x^2-2*x-1,{}>,
<-x^6+2*x^5-2*x^4+3*x^3+2*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4+3*x^3-2*x^2+2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+2*x^3+x^2+x-1,{2}>,
<-x^6+x^5+2*x^4+2*x^3-2*x^2+2*x-1,{2,3}>,
<-x^6-2*x^5-2*x^4-x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5-2*x^4+x^3+2*x^2+2*x-1,{2}>,
<-x^6-x^5+3*x^4-x^3-2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6+x^5+2*x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2+3*x-1,{0,2,3,5,13,131}>,
<-x^6+2*x^5-2*x^4-2*x^3+2*x^2-x-1,{2}>,
<-x^6+2*x^5-2*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-3*x^2+2,{2}>,
<-x^6+x^5+x^4+3*x^3-2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-2*x^2+2*x-1,{2}>,
<-x^6-x^5-2*x^4-3*x^3+3*x^2-2,{2}>,
<-x^6-3*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-3*x^5+3*x^4+3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-2*x^5+2*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3-x^2+2*x-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3-2*x^2-x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-x^2-2*x-1,{}>,
<-x^6-2*x^5-x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^4-3*x^3-3*x^2-2*x-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3-1,{2,5}>,
<-x^6-2*x^5+3*x^4+3*x^3-x^2+2*x-1,{0,2}>,
<-x^6+2*x^5-3*x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5-x^4+2*x^3+3*x^2+x-1,{2}>,
<-x^6+2*x^5-x^4+3*x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5-3*x^4+3*x^3+3*x^2-1,{2}>,
<-x^6+2*x^5+x^3-x^2+2*x-1,{2}>,
<-x^6+x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6+x^5+2*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+x^4-x^3-x^2-2*x-1,{0,2}>,
<-x^6-2*x^5+3*x^4-x^3-x^2-2*x-1,{2}>,
<-x^6+x^5+3*x^4+2*x^3-3*x^2+2*x-1,{2}>,
<-x^6+3*x^4+x^3-x^2+2*x-1,{2}>,
<-x^6-2*x^5-x^4+3*x^2-x-1,{}>,
<-x^6+2*x^5+3*x^4+3*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5-x^4-x^3-2*x-1,{2}>,
<-x^6+2*x^5+3*x^3-x^2+x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-x^2-2*x-1,{2}>,
<-x^6-2*x^5-3*x^3-x^2-1,{2}>,
<-x^6+2*x^5+3*x^3+2*x-1,{}>,
<-x^6-x^5+3*x^4+x^3-x^2-2*x-1,{2}>,
<-x^6-3*x^3-2*x-1,{2}>,
<-x^6+2*x^5-x^4-2*x^3+x^2-x-1,{2}>,
<-x^6-2*x^5-3*x^3+x^2-2*x-1,{2}>,
<-x^6+x^5+3*x^3-x^2-2*x-1,{2}>,
<-x^6+2*x^5-x^4+x^3+x^2+2*x-1,{2}>,
<-x^6-2*x^5-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5-x^4+3*x^3+3*x^2+x-1,{2}>,
<-x^6+2*x^5-x^4+x^3+x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x-1,{2}>,
<-x^6+2*x^4+x^3+2*x-1,{2,3}>,
<-x^6+2*x^5+x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^5-3*x^3+2*x^2-x-1,{}>,
<-x^6+x^5+3*x^4+x^3+2*x-1,{2}>,
<-x^6+2*x^4+3*x^3+2*x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-2*x-1,{0,2}>,
<-x^6+2*x^5+2*x^4-x^3+2*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3-x^2+x-1,{2}>,
<-x^6-x^5+3*x^4+x^3-2*x-1,{2}>,
<-x^6-x^5+3*x^3+x^2+2*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-x-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3+2*x-1,{2}>,
<-x^6-2*x^5+x^4-3*x^3+x^2-1,{2}>,
<-x^6+2*x^5+x^4+3*x^3+x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^3+2*x^2+2*x-1,{2,3}>,
<-x^6+2*x^5+2*x^4+3*x^3+x^2+2*x-1,{2}>,
<-x^6+x^5-2*x^4+3*x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5+x^4+3*x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^4-3*x^3+x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+3*x^3+3*x^2-1,{2}>,
<-x^6-2*x^5+x^4-2*x^3-x^2-x-1,{2}>,
<-x^6+2*x^5+x^4+2*x^3+x^2+x-1,{2,5}>,
<-x^6+2*x^5+x^4+2*x^3+2*x^2+x-1,{2}>,
<-x^6-2*x^5+x^4+x^2-x-1,{}>,
<-x^6+2*x^5+x^4-x^3-2*x^2-1,{2}>,
<-x^6-x^5+3*x^4-2*x^3+x^2-2*x-1,{2}>,
<-x^6-x^4+x^3+x^2-2*x-1,{2}>,
<-x^6-x^5+x^4+x^3+x^2-2*x-1,{2}>,
<-x^6-x^5-2*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6-2*x^5+x^4+3*x^3+x^2+x-1,{2}>,
<-x^6+x^5+2*x^4+3*x^3+x^2-2*x-1,{0,2}>,
<-x^6-x^5-3*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3+x^2+2*x-1,{2,3}>,
<-x^6-2*x^5+2*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6+x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+x^2+2*x-1,{2}>,
<-x^6+2*x^5+x^4+x^3+2*x^2-x-1,{}>,
<-x^6-2*x^5+x^4-x^3+3*x^2-2*x-1,{2,7}>,
<-x^6-2*x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5+x^4-x^3+3*x^2-x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3-2*x^2-x-1,{2}>,
<-x^6+2*x^5+2*x^4+3*x^3+x-1,{2}>,
<-x^6-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6+x^4+3*x^3+2*x^2+2*x-1,{2}>,
<-x^6+x^5-2*x^4+x^2-2*x-1,{2,7}>,
<-x^6+2*x^5+2*x^4+2*x^3-3*x^2+x-1,{2}>,
<-x^6-2*x^5+2*x^4-2*x^3+x-1,{2}>,
<-x^6+x^5+2*x^4+2*x^3+2*x^2+2*x-1,{2}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2-2*x-1,{2}>,
<-x^6+x^5+x^4-3*x^3+2*x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+2*x^2+x-1,{}>,
<-x^6+x^5-2*x^4+x^3+2*x^2+2*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3-x^2+x-1,{2}>,
<-x^6-2*x^5+2*x^4-3*x^3+3*x^2+x-1,{0,2}>,
<-x^6-3*x^5+3*x^4+3*x^3-x^2+2*x-1,{0,2}>,
<-x^6+x^3+2*x^2+2*x-1,{2}>,
<-x^6+2*x^5+2*x^4+x^3+2*x^2+2*x-1,{}>,
<-x^6+2*x^5-3*x^3+3*x^2+3*x-1,{2}>,
<-x^6+2*x^5+3*x^4+x^3+2*x^2+2*x-1,{2}>,
<-x^6+x^5-x^3+2*x^2-2*x-1,{2}>,
<-x^6+2*x^5+3*x^3+3*x^2-3*x-1,{0,2}>,
<-x^6-2*x^5+2*x^4-x^3+3*x^2-x-1,{2}>,
<-x^6-x^5+x^4-x^3+2*x^2-2*x-1,{2}>,
<-x^6+x^5-3*x^4+2*x^2-2*x-1,{2}>,
<-x^6+2*x^4+3*x^3+3*x^2-3*x-1,{0,2}>,
<-x^6+x^5-2*x^4+2*x^2-2*x-1,{2}>,
<-x^6+x^5+x^4-x^3+2*x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^2-2*x-1,{2}>,
<-x^6+x^5-3*x^4-2*x^3+2*x^2+2*x-1,{2}>,
<-x^6+x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4-2*x^3-2*x^2-x-1,{2}>,
<-x^6-x^5+x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6+2*x^5+2*x^4-x^3-3*x^2+x-1,{2}>,
<-x^6+2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3-x-1,{0,2}>,
<-x^6-2*x^5+3*x^4-3*x^3+2*x^2+x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3-3*x^2-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3+3*x^2-2*x-1,{2,3}>,
<-x^6-x^5+3*x^4+3*x^3+2*x^2-2*x-1,{0,2}>,
<-x^6-2*x^5+2*x^4+x^3-2*x^2+x-1,{2}>,
<-x^6-2*x^5+3*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2+x-1,{0,2}>,
<-x^6+x^5-2*x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+x^5-3*x^4+2*x^3+3*x^2+2*x-1,{2,43}>,
<-x^6+2*x^5+3*x^4+2*x^3-x^2+x-1,{2}>,
<-x^6-x^5-x^4-3*x^3+3*x^2-2*x-1,{2}>,
<-x^6+2*x^5+3*x^4+2*x^3-x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4-x^3-3*x^2-x-1,{}>,
<-x^6-x^4+3*x^3+3*x^2+2*x-1,{2}>,
<-x^6-x^5-2*x^3+3*x^2-2*x-1,{2}>,
<-x^6-x^4-x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4-2*x^3+x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4-x^3-x-1,{2}>,
<-x^6+x^5+x^4+x^3+3*x^2+2*x-1,{}>,
<-x^6+2*x^5+3*x^4+3*x^3+x-1,{2,3}>,
<-x^6-2*x^5+3*x^4-3*x^3-1,{}>,
<-x^6-x^5+x^3+3*x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4-x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-x^5+2*x^4-x^3+3*x^2-2*x-1,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3+3*x^2-1,{0,2}>,
<-x^6+x^5+3*x^4-x^3+3*x^2+2*x-1,{0,2,11}>,
<-x^6-x^5+2*x^4-3*x^3-3*x^2-x-1,{2}>,
<-x^6+2*x^5+3*x^4-x^3+3*x^2-2*x-1,{0,2}>,
<-x^6+2*x^5+3*x^4-x^3+3*x^2-1,{0,2}>,
<-x^6-x^5-3*x^4-3*x^3+3*x^2-1,{2}>,
<-x^6+2*x^5+3*x^4-2*x^3-3*x^2+x-1,{}>,
<-x^6+x^5-x^4+3*x^2+2*x-1,{2}>,
<-x^6-x^5+3*x^4+2*x^3+3*x^2-2*x-1,{0,2}>,
<-x^6-x^5-3*x^4+2*x^2-x-1,{2,5}>,
<-x^6+x^5-3*x^4-x^3+2*x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x^2-x-1,{2}>,
<-x^6-2*x^5+3*x^4+x^3-3*x^2-1,{2}>,
<-x^6-2*x^5+3*x^4+3*x^3-3*x^2-1,{2}>,
<-x^6-x^5-x^4-3*x^3+3*x^2+2*x-1,{0,2}>,
<-x^6-x^5-x^4+x^3+3*x^2-2*x-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3+3*x^2-2*x-1,{0,2}>,
<-x^6+x^5+x^4+3*x^3-x^2+x-1,{2}>,
<-x^6+3*x^4+x^3-x^2+x-1,{2}>,
<-x^6+x^5-x^4+3*x^3+x^2-1,{2}>,
<-x^6+x^5-x^4+3*x^2+x-1,{2}>,
<-x^6+x^5-x^4-3*x^3+3*x^2-x-1,{2,3}>,
<-x^6+x^5-x^4+3*x^3+2*x^2-1,{2}>,
<-x^6+x^5+3*x^4+3*x^3+2*x-1,{2,3,17,19,181}>,
<-x^6+3*x^3+x-1,{2}>,
<-x^6-x^5-x^4-3*x^3+3*x^2-x-1,{2}>,
<-x^6+x^5+3*x^3+x^2-1,{2}>,
<-x^6-x^5+3*x^4+3*x^3-x^2+x-1,{2}>,
<-x^6-x^5-3*x^3+2*x^2+x-1,{2}>,
<-x^6-x^5+x^4-2*x^3-x^2-x-1,{2}>,
<-x^6-x^5-2*x^3+2*x^2-1,{2,3}>,
<-x^6-x^5+2*x^4-2*x^3-x^2-x-1,{2}>,
<-x^6+x^5+2*x^4-2*x^3-x-1,{2}>,
<-x^6+x^5-x^4+2*x^3+3*x^2-1,{2}>,
<-x^6+x^5+3*x^4-2*x^3-x-1,{0,2}>,
<-x^6+3*x^4-3*x^3-2*x-1,{}>,
<-x^6+x^5+x^3+2*x^2-1,{2}>,
<-x^6-2*x^5-2*x^3-x^2-x-1,{2}>,
<-x^6+2*x^5+2*x^3+x-1,{2}>,
<-x^6+x^5+3*x^4-2*x^3-x^2-x-1,{0,2}>,
<-x^6+x^5+2*x^4-2*x^3-2*x-1,{2}>,
<-x^6-x^5-x^4-x^3+3*x^2-x-1,{}>,
<-x^6+3*x^4-x^3-x-1,{2}>,
<-x^6+x^5+3*x^4+2*x^3+2*x-1,{2,5}>,
<-x^6-x^5+x^4-2*x^3+x^2-1,{2}>,
<-x^6+2*x^5+x^3-3*x^2+x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3+x-1,{2}>,
<-x^6+x^5-2*x^3+3*x^2-x-1,{2}>,
<-x^6-x^5+x^4-2*x^3+3*x^2-x-1,{2}>,
<-x^6+x^5-2*x^4-x^3-2*x-1,{2}>,
<-x^6+2*x^4-x^3+x^2-x-1,{2}>,
<-x^6+2*x^5-x^3-2*x-1,{2}>,
<-x^6+x^5+2*x^4+x^2+x-1,{2}>,
<-x^6-x^5+3*x^3+2*x^2-1,{2,7}>,
<-x^6-x^5+2*x^4-2*x^3+x^2+x-1,{2}>,
<-x^6-x^5+3*x^3+2*x^2+x-1,{2}>,
<-x^6-2*x^5-x^3+x^2-x-1,{2}>,
<-x^6-x^5+x^4+3*x^3+x^2-1,{2}>,
<-x^6-2*x^4-3*x^3+2*x^2-x-1,{}>,
<-x^6+3*x^4-3*x^3+x-1,{2}>,
<-x^6-x^4-3*x^3+2*x^2-x-1,{2}>,
<-x^6+x^5+2*x^4+3*x^3+3*x^2-1,{2,7}>,
<-x^6-3*x^3+x^2-x-1,{2}>,
<-x^6+x^4+3*x^3+2*x^2+x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^3-1,{2}>,
<-x^6-x^5+3*x^4-2*x^3+2*x^2-x-1,{}>,
<-x^6-x^5+2*x^4-3*x^3+2*x^2-x-1,{}>,
<-x^6-3*x^4+x^3+2*x^2+x-1,{2}>,
<-x^6-x^5+x^4-3*x^3+x^2-x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-2*x^2-1,{2}>,
<-x^6-x^3+2*x^2-x-1,{2}>,
<-x^6+x^5+3*x^4+3*x^3-1,{2}>,
<-x^6-x^5+2*x^4-3*x^3+x^2-x-1,{2}>,
<-x^6-x^5+2*x^4-2*x^2-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3+x^2-1,{2}>,
<-x^6+3*x^4+x^3+2*x^2-x-1,{0,2}>,
<-x^6+x^5+x^4+3*x^3+3*x^2+x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3+2*x^2-1,{2}>,
<-x^6+3*x^4+3*x^2-x-1,{0,2}>,
<-x^6-x^5+3*x^4-2*x^3-x^2-1,{2,3}>,
<-x^6+3*x^3+2*x^2-x-1,{2}>,
<-x^6-x^5+3*x^4-x^3-x^2-1,{2}>,
<-x^6-2*x^4-3*x^3+x^2-3*x-1,{2}>,
<-x^6-x^5+2*x^4+3*x^3+x^2-1,{2}>,
<-x^6+x^5+3*x^4+x^3-1,{2}>,
<-x^6-x^5-2*x^4+3*x^3+x^2+3*x-1,{2}>,
<-x^6-x^5+3*x^4-3*x^3-3*x^2-1,{2}>,
<-x^6+3*x^4+x^3+3*x^2+x-1,{0,2,3}>,
<-x^6-3*x^5+x^4-3*x^3-x^2-2*x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3-x^2-x-1,{}>,
<-x^6+x^5+3*x^4-x^3+3*x^2-x-1,{0,2}>,
<-x^6-3*x^4+x^3+3*x^2-x-1,{2}>,
<-x^6-3*x^4+3*x^2+x-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3-x^2+x-1,{2}>,
<-x^6+2*x^4+x^3+3*x^2-x-1,{0,2}>,
<-x^6-x^4+3*x^3+3*x^2-x-1,{2}>,
<-x^6-3*x^3+3*x^2+x-1,{0,2}>,
<-x^6+x^5+3*x^4-3*x^3+3*x^2-1,{0,2}>,
<-x^6+3*x^4+3*x^3-x^2-1,{2}>,
<-x^6+3*x^3+2*x^2-1,{2}>,
<-x^6-3*x^5+x^4-3*x^3+2*x^2+x-1,{2}>,
<-x^6+2*x^5+2*x^4-3*x^3+x^2-3*x-1,{0,2}>,
<-x^6+2*x^5+3*x^4-3*x^3+x^2-3*x-1,{}>,
<-x^6+3*x^5+x^4+2*x^3-3*x^2+2*x-1,{}>,
<-x^6-3*x^5+3*x^4-x^3-x-1,{2}>,
<2*x^6-2*x^4+x^3-2*x^2-2*x-1,{2}>,
<-x^6-2*x^5+2*x^4+x^3+3*x^2-3*x-1,{}>,
<-x^6+3*x^5+3*x^4-x^3+2*x^2-2*x-1,{0,2}>,
<-x^6+3*x^5+3*x^4-2*x^3-3*x^2-2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-x^2+2*x-1,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3-x^2+x-1,{2}>,
<-x^6-3*x^5+3*x^4+2*x^3-x-1,{2}>,
<-x^6+3*x^5+3*x^4-2*x^3+2*x^2-x-1,{0,2}>,
<-x^6+2*x^4+3*x^3-3*x^2-x-1,{2}>,
<-x^6+x^5-2*x^4+3*x^3+2*x^2+x-1,{2}>,
<-x^6-x^5+x^4-2*x^3-2*x^2+x-1,{2}>,
<-x^6-x^5-3*x^3-x^2-x-1,{2}>];
