// Rank2Data is a list of entries
//  <f, rank, tors, bas, deg3, run, primes>, where
// * f is the polynomial defining the curve  C: y^2 = f(x)
// * rank is the Mordell-Weil rank of J(Q), where J is the Jacobian of C
// * tors is the sequence of invariants of the torsion subgroup of J
// * bas is a sequence of polynomials of degree 2 such that
//     [Rep(Points(J, a, 2)) : a in bas]
//   is a sequence of generators of J(Q) modulo torsion
// * deg3 = <a, c, b> specifies a rational degree-3 divisor on C:
//     f(x) - b(x)^2 = l*a(x)*c(x) ,
//   the divisor is given by  a(x) = 0, y = b(x)
// * run = [q1, q2, ..., qn] is a sequence of primes such that
//     B0 = 1, B1 = q1, B2 = q1*q2, ..., Bn = q1*q2*...*qn = B
//   is a suitable sequence for the successive computation of bounds
//   on the image of C(Q) in J(Q)/Bj*J(Q), such that the last bound is empty
// * primes = {p1, p2, ..., pm} is a set of primes or prime powers such that
//   the information coming from J(Z/pj*Z) is sufficient to get the empty
//   bound with B as above

_<x> := PolynomialRing(Rationals());

Rank2Data := [
// no. 1
<3*x^6 - 2*x^4 + x^3 - 2*x^2 - x - 1, 2, [],
  [x^2 + 1/2,
   x^2 + 69036/60601*x + 194377/121202],
  <x^3 - 3*x^2 - 3*x - 1, x^3 + 3*x^2 - 2/3*x + 1/3, 6*x^2 + 2*x>,
  [ 2, 3, 2, 7, 2, 41, 2 ],
  { 11, 13, 19, 41, 71, 137, 157, 269 }>,

// no. 2
<2*x^6 + 3*x^5 + x^4 - 3*x^3 - 3*x^2 + x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 34/383*x + 2857/2681],
  <x^3 + 5/2*x^2 + 1/2*x + 1, x^3 - x^2 - 2*x - 3, 3*x^2 + 2*x + 2>,
  [ 23, 7, 7, 3, 2, 2, 11, 19 ],
  { 7, 11, 17, 43, 59, 67, 73, 79, 97, 139, 181, 773, 797, 821, 991 }>,

// no. 3
<-x^6 + 2*x^5 + 2*x^4 + 2*x^3 + 3*x^2 + x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 8466275/5050302*x + 69284533/60603624],
  <x^3 + 4/3*x^2 + 71/9*x - 59/9, x^3 - 10/3*x^2 + 32/9*x - 23/9, -3*x^2 + 
43/9*x - 40/9>,
  [ 3, 3, 2, 7, 2, 2, 23, 5, 7 ],
  { 5, 7, 11, 13, 19, 43, 47, 137, 563, 587, 593, 653, 751, 761, 1187, 1523 }>,

// no. 4
<2*x^6 - 3*x^5 + 2*x^4 - 3*x^2 - 2*x - 1, 2, [],
  [x^2 - 2*x - 2,
   x^2 - 28/23*x - 40/23],
  <x^3 + x + 1, x^3 - 3/2*x^2 - 1/2*x - 1/2, x^2 + x>,
  [ 2, 3, 47, 41, 3, 2, 5, 7, 7, 7, 19 ],
  { 3, 5, 7, 11, 13, 23, 41, 53, 71, 83, 101, 131, 157, 163, 223, 251, 257, 349,
457, 617, 2003, 2081, 2143, 2377, 3853 }>,

// no. 5
<-x^6 - 3*x^5 + 2*x^4 + x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 + 7/2*x + 2,
   x^2 + 769641/192917*x + 3091881/1543336],
  <x^3 + 7/2*x^2 + 2*x + 7/2, x^3 - 1/2*x^2 - 2*x + 2, 1/2*x^2 - 3/2*x + 2>,
  [ 3, 2 ],
  { 13, 19, 53, 157 }>,

// no. 6
<-2*x^6 - x^5 - 3*x^4 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 + 2/3*x + 1/3,
   x^2 + 148152/133873*x + 100248/133873],
  <x^3 - 1/4*x - 1/2, x^3 + 1/2*x^2 + 15/8*x + 3/4, -1/2*x^2 - 1/4*x - 3/2>,
  [],
  { 11 }>,

// no. 7
<-2*x^6 - x^5 + 2*x^4 - 3*x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 19/33*x - 1/3],
  <x^3 + 1/2*x^2 - 3/2*x + 1, x^3 + x - 1, -x^2 + x + 1>,
  [ 3, 19 ],
  { 5, 13, 19 }>,

// no. 8
<2*x^6 - x^4 - x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 3*x - 3,
   x^2 + 5/3*x - 803/369],
  <x^3 - x^2 + x - 1/2, x^3 + x^2 - x - 2, x^2 + 1>,
  [ 2, 2 ],
  { 11, 43 }>,

// no. 9
<-x^6 + 2*x^5 - 2*x^4 + 2*x^3 - x^2 + 2*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 111/89*x - 73/89],
  <x^3 + x^2 + 2*x + 1, x^3 - 3*x^2 + 4*x - 3, -x^2 + x>,
  [ 2, 5, 17, 7, 2, 19 ],
  { 3, 5, 7, 13, 43, 151, 191, 233, 733, 1051 }>,

// no. 10
<-2*x^6 + 3*x^4 - x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 19/11*x + 19/22,
   x^2 - 316/2057*x + 35692/18513],
  <x^3 - 3*x^2 + 3*x + 3, x^3 + 3*x^2 + 9/2*x + 2, 6*x + 3>,
  [ 3, 7, 23, 11, 17 ],
  { 5, 7, 11, 17, 19, 23, 67, 71, 163, 193, 421, 479, 491 }>,

// no. 11
<2*x^6 + x^5 - 2*x^4 + x^3 - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 1863/2329*x + 481/2329],
  <x^3 + x^2 - x + 1, x^3 - 1/2*x^2 - 3/2*x - 3/2, 2*x^2 + x>,
  [],
  { 17 }>,

// no. 12
<-2*x^6 + 3*x^5 - 2*x^4 - x^3 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 + 1/2*x + 1,
   x^2 + 406816/1703649*x - 833192/1703649],
  <x^3 + x - 2/3, x^3 - 3/2*x^2 + 9/8*x + 23/12, 3/2*x^2 - 1/2*x + 2/3>,
  [ 3, 7, 2, 31 ],
  { 7, 11, 37, 71, 113, 239, 887, 2719 }>,

// no. 13
<-3*x^6 + x^5 + 3*x^3 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 + 1/4*x + 3/2,
   x^2 - 855367/2643159*x + 4643987/3524212],
  <x^3 - 5/4*x^2 + 2*x - 3, x^3 + 11/12*x^2 - 1/3*x - 2/3, -5/4*x^2 + 1/2*x + 
2>,
  [ 3, 5, 2, 23, 2, 19 ],
  { 3, 7, 11, 13, 17, 29, 31, 37, 53, 59, 101, 139, 269, 463 }>,

// no. 14
<-3*x^6 + x^5 + x^3 + 3*x^2 + x - 1, 2, [],
  [x^2 + 1/4*x + 1/2,
   x^2 + 86893/99463*x + 102065/397852],
  <x^3 - 1/4*x^2 + 3/2*x - 5/4, x^3 - 1/12*x^2 + 1/6*x - 5/12, -9/4*x^2 + x - 
3/4>,
  [ 3 ],
  { 3, 13 }>,

// no. 15
<-3*x^6 + 3*x^5 - 2*x^4 - 3*x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 - 3/4*x + 1/2,
   x^2 + 527/1732*x + 841/2598],
  <x^3 - 2*x^2 + x + 1, x^3 + x^2 + 2*x + 5/3, -x^2 + 2*x + 2>,
  [ 3, 5, 11, 3, 7, 2 ],
  { 11, 13, 19, 23, 31, 43, 53, 59, 83, 89, 103, 149, 151, 311, 509, 521 }>,

// no. 16
<-x^6 - 3*x^5 - 3*x^3 + x^2 - 2*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 194/373*x + 429/373],
  <x^3 + 2*x^2 - 2*x + 2, x^3 + x^2 + x - 1, -x^2 + x + 1>,
  [ 2, 7, 2, 2, 2, 13, 5 ],
  { 19, 23, 43, 89, 107, 113, 127, 163, 211, 281, 421, 461, 487 }>,

// no. 17
<3*x^6 + 3*x^5 - x^4 - 2*x^3 + 2*x^2 + 2*x - 2, 2, [],
  [x^2 + 2*x + 2,
   x^2 - 63478/4801*x + 49457/4801],
  <x^3 - 3/4*x + 3/4, x^3 + x^2 + 1/3*x - 1, 1/2*x^2 + x - 1/2>,
  [ 2, 11, 5, 13, 17, 5, 7, 3, 2 ],
  { 41, 47, 61, 71, 73, 101, 107, 167, 211, 227, 229, 523, 643, 739, 853, 887, 
947, 1013, 1451, 1669 }>,

// no. 18
<2*x^6 - 2*x^5 - 2*x^4 + 2*x^3 - x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 86/1271*x - 23377/1271],
  <x^3 + 2*x^2 + x + 1, x^3 - 3*x^2 + 7/2*x - 2, x^2 - 2*x + 1>,
  [ 2, 3, 31, 5, 7, 3, 11 ],
  { 3, 7, 17, 23, 29, 41, 73, 107, 139, 197, 211, 229, 281, 373, 463, 467, 509, 
619, 967 }>,

// no. 19
<-x^6 + x^5 - x^4 + x^3 - 3*x^2 + 2*x + 3, 2, [],
  [x^2 - 4/5*x - 2/5,
   x^2 + 152/389*x - 44/389],
  <x^3 - x^2 + x + 1, x^3 + x - 3, -x^2 + x>,
  [],
  { 29 }>,

// no. 20
<-x^6 + 3*x^5 + 3*x^4 + 3*x^3 + 2*x^2 + 3*x - 3, 2, [],
  [x^2 + 3/2*x + 2,
   x^2 + 1050058395/676733522*x + 390570302/338366761],
  <x^3 - 3*x^2 - 3/2*x - 1/4, x^3 + 47/2*x - 169/4, 5*x^2 - 11*x - 11/4>,
  [],
  { 11 }>,

// no. 21
<2*x^6 - 2*x^5 - 3*x^4 + x^3 - x^2 - x + 3, 2, [],
  [x^2 + 2*x - 1/2,
   x^2 + 8*x + 491/46],
  <x^3 - 3*x^2 + 1, x^3 + 2*x^2 - 7/2*x + 1, -4*x^2 + 3*x + 1>,
  [ 2, 3, 7, 2, 2, 2, 31 ],
  { 17, 29, 31, 331, 487, 673 }>,

// no. 22
<-2*x^6 - 3*x^5 + 2*x^4 - 2*x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 + x + 2,
   x^2 + 788/2273*x + 388/2273],
  <x^3 + 1/2*x^2 - 1/2*x + 1, x^3 + x^2 + x + 2, 2*x^2 + x + 1>,
  [ 7, 3, 2, 5, 2, 7, 19, 3 ],
  { 3, 5, 11, 19, 37, 103, 139, 199, 223, 257, 467, 521, 683, 797, 1949 }>,

// no. 23
<-3*x^6 + 3*x^5 + 2*x^4 + 3*x^3 + x^2 - x + 2, 2, [],
  [x^2 - x - 2/3,
   x^2 - 52/17389*x - 2104/17389],
  <x^3 - x^2 + 2/3*x + 1/3, x^3 - x - 1, -x^2 - 2*x + 1>,
  [],
  { 17 }>,

// no. 24
<-x^6 - x^5 - 3*x^4 - x^3 - x + 3, 2, [],
  [x^2 + x + 2,
   x^2 + 18220/14869*x + 294241/118952],
  <x^3 - 1/2*x^2 + 2*x - 1/2, x^3 + 3/2*x^2 + 2*x - 2, 1/2*x^2 - 3/2*x + 2>,
  [ 3 ],
  { 3, 7, 19 }>,

// no. 25
<-3*x^6 - 2*x^5 - 3*x^3 + 2*x^2 + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 6928/10363*x - 4922/10363],
  <x^3 + 1/2*x^2 + 2, x^3 + 1/6*x^2 - 1/2, -1/2*x^2 - 3/2*x>,
  [ 2, 2, 11, 3, 2, 23, 5, 29, 13 ],
  { 5, 7, 17, 19, 37, 47, 61, 97, 101, 137, 179, 281, 311, 401, 421, 443, 457, 
499, 503, 547, 887, 997 }>,

// no. 26
<-x^6 - x^5 + 2*x^4 - 3*x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 - x + 1,
   x^2 + 3107/1093*x + 1513/1093],
  <x^3 + 3/2*x^2 - 3/2*x + 1, x^3 - 1/2*x^2 + 1/2*x + 3, -1/2*x^2 - 5/2*x + 1>,
  [ 3, 7, 3, 5, 7, 13 ],
  { 5, 7, 11, 23, 29, 47, 101, 277, 349, 419, 773, 1217, 1523, 3253 }>,

// no. 27
<-2*x^6 + x^5 - 2*x^4 - 2*x^3 - 3*x^2 - 2*x + 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 12452/13491*x + 37972/40473],
  <x^3 - 3/2*x^2 + 2*x + 1/2, x^3 + x^2 + 1/2*x - 3/4, 3/2*x - 3/2>,
  [],
  { 11 }>,

// no. 28
<-3*x^6 - x^5 + x^4 - 2*x^3 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 + 45/37*x + 46/37,
   x^2 - 6495/8713*x + 1174/8713],
  <x^3 + 2*x + 1, x^3 + 1/3*x^2 - x + 1/3, -2*x^2 - x + 2>,
  [ 2, 2, 2, 2, 3, 3, 2, 2, 37, 19 ],
  { 5, 7, 23, 47, 61, 67, 73, 113, 127, 167, 199, 269, 941, 947, 1657 }>,

// no. 29
<-x^6 - 3*x^3 + 2*x^2 + 2*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 82634/35677*x + 138493/35677],
  <x^3 - 2*x^2 + 6*x + 37/2, x^3 + 2*x^2 + 2*x + 1/2, -2*x^2 - 6*x - 7/2>,
  [ 2, 3, 17, 7 ],
  { 37, 41, 59, 191, 211, 251, 353 }>,

// no. 30
<3*x^6 + x^5 + x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 - x + 28/13,
   x^2 + 5466/1213*x + 4809/1213],
  <x^3 - 1/2*x^2 - 1/2*x + 2, x^3 + 5/6*x^2 + 1/6*x - 2/3, -3/2*x^2 + 1/2*x + 
1>,
  [],
  { 31 }>,

// no. 31
<-3*x^6 + 3*x^5 + x^4 - 2*x^3 - 3*x^2 + 2, 2, [],
  [x^2 + 8/7*x + 2/7,
   x^2 - 3/7*x + 1/28],
  <x^3 - x^2 + 1, x^3 - 1/3, -x^2 + 1>,
  [ 2, 7, 2, 3, 5, 3 ],
  { 7, 11, 13, 23, 29, 59, 103, 349, 373, 397, 691, 863 }>,

// no. 32
<3*x^6 - 2*x^5 + 2*x^3 - 3*x - 1, 2, [],
  [x^2 - x - 1,
   x^2 + 11954/2267*x - 22829/2267],
  <x^3 + x^2 + x + 2, x^3 - 5/3*x^2 + 2/3*x - 1/3, -3*x + 1>,
  [ 2, 2, 5, 7, 3, 7 ],
  { 3, 7, 11, 13, 19, 31, 73, 97, 107, 113, 163, 173, 499, 643, 1667 }>,

// no. 33
<3*x^6 - 2*x^5 + 2*x^3 - 3*x - 3, 2, [],
  [x^2 - x - 4,
   x^2 + 11010588/9104353*x + 15513708/9104353],
  <x^3 - 7/4*x - 1, x^3 - 2/3*x^2 + x + 4, -3/2*x^2 + 7/2*x + 3>,
  [ 11, 13, 3, 2 ],
  { 5, 17, 23, 31, 41, 61, 103, 163, 179, 307 }>,

// no. 34
<-2*x^6 + 2*x^5 + 2*x^4 + 3*x^3 - 2*x^2 + x - 2, 2, [],
  [x^2 + 1,
   x^2 + 17/32],
  <x^3 - x^2 + 2*x - 3/2, x^3 - x - 1, -2*x^2 + 1>,
  [ 13, 5, 5, 2, 3, 11 ],
  { 3, 11, 19, 23, 37, 89, 103, 107, 139, 283, 313, 457, 607, 983 }>,

// no. 35
<-x^6 - 2*x^5 + x^4 + 3*x^3 + 3*x^2 - 3*x + 2, 2, [],
  [x^2 + x - 1,
   x^2 + 2321/2866*x - 1679/11464],
  <x^3 - x^2 + x + 1, x^3 + 3*x^2 + 5*x + 2, 2*x^2 + x + 2>,
  [ 2, 2, 2, 3, 19, 29, 7, 3 ],
  { 11, 13, 17, 43, 47, 101, 109, 151, 257, 277, 353, 673, 811, 829, 1283, 1373 
}>,

// no. 36
<-3*x^6 - 3*x^5 - 2*x^4 - 3*x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 4392208/7850473*x - 4448552/7850473],
  <x^3 + x^2 + 7/4*x + 3/2, x^3 + x - 2/3, -5/2*x^2 - 1/2*x>,
  [],
  { 163 }>,

// no. 37
<-x^6 - 3*x^5 - x^4 - x^3 - x^2 + 3*x - 2, 2, [],
  [x^2 + 11/2*x + 17/2,
   x^2 + 27/146*x + 81/146],
  <x^3 + 2*x^2 + x + 1, x^3 + x^2 - 2*x + 3, 2*x + 1>,
  [ 3, 3, 5 ],
  { 5, 7, 13, 43, 73, 277, 461 }>,

// no. 38
<2*x^6 + 3*x^5 - 3*x^4 + 2*x + 2, 2, [],
  [x^2 - 3*x + 1,
   x^2 - 4040/18737*x - 9992/18737],
  <x^3 - 4*x^2 - 37*x - 7, x^3 + 11/2*x^2 + 15/2*x + 1/2, 10*x^2 + 24*x + 3>,
  [ 2 ],
  { 3, 7 }>,

// no. 39
<-x^6 - x^5 + 3*x^3 + 3*x^2 - 2*x + 3, 2, [],
  [x^2 - 2,
   x^2 - 932/2281*x + 1126/2281],
  <x^3 - x^2 + 7*x - 11, x^3 + 2*x^2 - x - 3, 2*x^2 + x - 6>,
  [ 5, 29, 3, 2 ],
  { 3, 11, 37, 43, 53, 61, 157, 809 }>,

// no. 40
<-3*x^6 - x^5 + x^4 + 3*x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 + 1/3*x + 1,
   x^2 + 266956/251733*x + 31768/83911],
  <x^3 + 3*x^2 + x - 6, x^3 - 8/3*x^2 + 8*x - 17/3, 2*x^2 + 8*x - 10>,
  [ 3, 2, 5, 41, 2, 7, 47 ],
  { 3, 5, 23, 31, 41, 43, 113, 181, 263, 313, 359, 401, 601, 607, 1063, 1213 }>,

// no. 41
<-2*x^6 - x^5 + x^4 + 2*x^3 + 3*x^2 - 2*x + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 108774562/70072937*x + 16571689/70072937],
  <x^3 + 19/32*x - 73/32, x^3 + 1/2*x^2 - 5/16*x + 7/16, -5/4*x^2 + 7/16*x - 
1/16>,
  [ 2, 7, 5 ],
  { 11, 29, 71 }>,

// no. 42
<3*x^6 + 3*x^5 + x^3 - 2*x^2 + 3*x + 3, 2, [],
  [x^2 + 1/2*x + 1/6,
   x^2 - 1449/694*x + 1269/694],
  <x^3 + x^2 + 2*x + 1, x^3 - 7/3*x - 1/3, x^2 + 3*x + 2>,
  [ 2, 3, 5, 13 ],
  { 5, 7, 11, 241, 337, 433 }>,

// no. 43
<-2*x^6 - 3*x^5 - 2*x^4 + 3*x^3 + x^2 - 2*x + 3, 2, [],
  [x^2 + 2/3*x + 1/3,
   x^2 + 76718/62633*x + 14401/62633],
  <x^3 - 1/2*x^2 + 4*x - 3/2, x^3 + 2*x^2 - 2, -2*x^2 - 3*x + 3>,
  [ 3, 5, 11, 2, 31, 13 ],
  { 3, 5, 43, 47, 59, 71, 83, 101, 167, 199, 283, 659, 701 }>,

// no. 44
<-2*x^6 + 2*x^5 + 2*x^4 - 3*x^3 - 3*x + 3, 2, [],
  [x^2 - 1/3*x - 1/3,
   x^2 + 1/3*x + 169/12],
  <x^3 - 1/9*x^2 - 5/9*x + 2/9, x^3 - 8/9*x^2 - 4/9*x + 23/18, 4/9*x^2 + 11/9*x 
- 17/9>,
  [ 3, 3, 2, 2, 7, 19, 5, 11, 31, 13 ],
  { 5, 7, 13, 17, 19, 41, 61, 97, 109, 149, 151, 227, 359, 397, 563, 797, 809, 
1019, 1039, 1231, 1289, 1327, 1531, 1747, 1979 }>,

// no. 45
<3*x^6 - x^5 + 2*x^4 + 2*x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 34488/18803*x - 46272/18803],
  <x^3 - 1/2*x^2 - 6*x - 6, x^3 + 1/6*x^2 + 1/6, -9/2*x^2 - 5/2*x>,
  [ 13, 7, 11, 3, 2 ],
  { 5, 13, 53, 73, 89, 101, 107, 109, 181, 229, 547, 617, 883, 937 }>,

// no. 46
<-2*x^6 - 3*x^5 - 3*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 + 3*x + 4,
   x^2 + 3576/1297*x + 2128/1297],
  <x^3 - x + 1, x^3 + 3/2*x^2 + 3/2*x + 2, x^2 + 1>,
  [ 3, 11, 19, 2, 17, 2, 13, 5, 43 ],
  { 3, 5, 11, 13, 17, 23, 29, 31, 37, 71, 131, 149, 179, 211, 233, 271, 283, 
353, 367, 503, 1259, 1291 }>,

// no. 47
<-3*x^6 + 3*x^5 - 3*x^4 - 2*x^3 - 2*x^2 + 2, 2, [],
  [x^2 + x + 1,
   x^2 - 4590/43633*x - 11007/43633],
  <x^3 - 2*x^2 + 6*x + 1, x^3 + x^2 - 1/3, -3*x^2 - 3*x + 1>,
  [ 3, 5, 13, 7, 47 ],
  { 11, 17, 53, 181, 211, 277, 311, 367, 379, 401, 443, 773 }>,

// no. 48
<-2*x^6 - 2*x^5 + 2*x^4 - 3*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 + x + 2,
   x^2 + 13177/5049*x + 2474/1683],
  <x^3 + x^2 + 1, x^3 + x + 3/2, 2*x^2 + x>,
  [ 2, 2, 7, 2, 11, 31, 2, 3, 23 ],
  { 3, 17, 29, 41, 53, 79, 101, 191, 463, 509, 919, 1013, 1087, 1321, 1847, 
2063, 2267, 2963 }>,

// no. 49
<2*x^6 + 3*x^5 + 2*x^4 + 2*x^3 - 3*x^2 + 3*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 22544/10889*x + 9751/43556],
  <x^3 - 9/2*x^2 - 3*x - 1/2, x^3 + 6*x^2 - x - 1, -8*x^2 - 2*x + 1>,
  [],
  { 19 }>,

// no. 50
<-3*x^6 + 2*x^5 + 2*x^4 - 3*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 120/18697*x + 8737/18697],
  <x^3 - x^2 + 1, x^3 + 1/3*x^2 + x + 1, 2*x^2>,
  [],
  { 5 }>,

// no. 51
<3*x^6 + 2*x^5 + 3*x^4 - 2*x^3 - 2*x^2 + 3*x - 2, 2, [],
  [x^2 + x + 2,
   x^2 - 694647/820657*x + 327666/820657],
  <x^3 + 1/4*x + 3/2, x^3 + 2/3*x^2 - 4/3, -3/2*x^2 + x + 2>,
  [ 2, 3, 5, 3, 2 ],
  { 3, 29, 31, 43, 59, 73, 103, 107, 109, 179, 373, 383, 401 }>,

// no. 52
<-x^6 + 3*x^5 + 2*x^4 + 2*x^3 - 1, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 56/13*x + 32/13],
  <x^3 - 3*x^2 - 2, x^3 - x - 1, x^2 + x + 1>,
  [ 2, 2, 2, 3, 2, 7, 13 ],
  { 5, 11, 31, 41, 43, 53, 61, 73, 79, 83, 151, 293, 337, 397, 733, 787, 911 }>,

// no. 53
<-3*x^6 - 2*x^5 + 2*x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 + 1/2*x + 1,
   x^2 - 1351/866*x + 257/433],
  <x^3 + 1/2*x^2 + 5/2*x - 3, x^3 + 1/6*x^2 - 1/2*x - 1/3, -5/2*x^2 + 3/2*x + 
1>,
  [ 3, 3, 17, 13, 7, 2, 5 ],
  { 5, 7, 19, 31, 83, 97, 113, 157, 163, 353, 359, 383, 479, 593, 941, 1451, 
1549 }>,

// no. 54
<3*x^6 + 2*x^4 + 3*x^2 + x - 2, 2, [],
  [x^2 + x - 1,
   x^2 - 696/263*x - 688/263],
  <x^3 - 3*x - 6, x^3 - 5/12*x + 1/6, -7/2*x^2 - 5/2*x + 1>,
  [ 2, 3, 5, 23, 2, 11, 29 ],
  { 5, 13, 37, 71, 101, 181, 283, 347, 659, 677, 683, 1217, 1669, 1801 }>,

// no. 55
<3*x^6 + 2*x^5 + x^4 + 2*x^3 - x^2 + x - 2, 2, [],
  [x^2 - 1/3*x + 1/3,
   x^2 - 1100/3237*x + 1416/1079],
  <x^3 + 5/3*x^2 - 1/2*x + 1, x^3 - x^2 - 1/2*x - 1, 3*x^2 + 1/2*x + 1>,
  [ 2, 5, 3, 7, 2, 13 ],
  { 3, 5, 23, 43, 89, 103, 127, 293, 1721 }>,

// no. 56
<-2*x^6 + 3*x^5 + x^4 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 3/2*x + 3/2,
   x^2 - 11514/18961*x - 12611/18961],
  <x^3 - 2*x^2 + 2*x + 1, x^3 + 1/2*x^2 + 1/2*x - 1, 2*x^2 + 1>,
  [ 2, 2, 3, 3, 5, 11, 7 ],
  { 5, 7, 31, 37, 43, 137, 229, 251, 373, 421, 439, 1153 }>,

// no. 57
<-3*x^6 + 2*x^5 + 2*x^4 + x^2 + x - 1, 2, [],
  [x^2 - x + 2,
   x^2 + 203/97*x + 146/97],
  <x^3 - 2/3*x^2 + 2/3*x - 1/3, x^3 - x - 1, -x^2 + x>,
  [],
  { 53 }>,

// no. 58
<-x^6 - 3*x^5 + 3*x^4 - 3*x^2 + 2*x - 3, 2, [],
  [x^2 + 2,
   x^2 + 307/65*x + 21/5],
  <x^3 + 1/2*x^2 + 1, x^3 + 5/2*x^2 - 2*x + 3, 3/2*x^2 + x>,
  [],
  { 11 }>,

// no. 59
<-3*x^6 - 2*x^5 + 2*x^4 + 2*x^3 + 2*x^2 + 2*x + 3, 2, [],
  [x^2 + 2*x + 3,
   x^2 - 5/3*x + 97/36],
  <x^3 + 1/2*x^2 + 1, x^3 + 1/6*x^2 - 2/3*x - 1, 1/2*x^2 + x>,
  [ 2 ],
  { 3, 127 }>,

// no. 60
<-3*x^6 + 3*x^5 - 3*x^3 - 3*x^2 + x + 3, 2, [],
  [x^2 - 7/4*x + 3/2,
   x^2 - 421911/3255403*x - 5226911/13021612],
  <x^3 - 2*x^2 + x + 3/4, x^3 + x^2 + 4/3*x + 11/12, x^2 - 3/2*x - 9/4>,
  [ 3, 7, 19, 5, 17 ],
  { 5, 11, 47, 79, 89, 139, 179, 233, 239, 373, 503 }>,

// no. 61
<2*x^6 + 2*x^5 + 2*x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 + x + 1/2,
   x^2 - 148/41*x + 88/41],
  <x^3 - 3*x^2 - 8*x - 9, x^3 + 4*x^2 + 15/2*x + 19/2, -5*x^2 - 11*x - 13>,
  [ 7, 3, 2, 2 ],
  { 3, 5, 13, 19, 41, 59, 137 }>,

// no. 62
<-3*x^6 + x^5 - 3*x^4 - x^3 + 2*x + 2, 2, [],
  [x^2 + 2,
   x^2 + 15248/37677*x + 33262/37677],
  <x^3 - 1/4*x^2 + x + 1, x^3 - 1/12*x^2 - 2/3, 1/4*x^2 - 1/2*x>,
  [ 2, 2, 7, 11, 3, 3, 3, 5, 13, 5, 23, 41, 17 ],
  { 3, 5, 13, 17, 23, 41, 53, 61, 73, 89, 97, 107, 127, 149, 163, 173, 233, 257,
271, 277, 283, 373, 457, 571, 653, 719, 769, 1013, 1019, 1091, 1423, 1823 }>,

// no. 63
<-2*x^6 + 2*x^4 - 3*x^3 + 2, 2, [],
  [x^2 + x + 1/2,
   x^2 + 16/27*x + 56/81],
  <x^3 - 4/9*x^2 + 7/9*x + 1/9, x^3 + 4/9*x^2 - 23/18*x + 7/18, -7/9*x^2 + 1/9*x
+ 13/9>,
  [ 2, 2, 3, 5 ],
  { 13, 19, 109, 139, 149, 373, 769 }>,

// no. 64
<2*x^6 + 2*x^5 + x^4 + 2*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 4196/2017*x + 2812/2017],
  <x^3 + 4*x^2 + 1, x^3 - 3*x^2 + 9/2*x - 2, 4*x^2 - 4*x + 1>,
  [],
  { 5 }>,

// no. 65
<2*x^6 + 2*x^5 - 2*x^4 - x^3 - x^2 + x - 3, 2, [],
  [x^2 + x + 7,
   x^2 - 80/73*x + 64/73],
  <x^3 + 3*x^2 + x + 1, x^3 - 2*x^2 - 4*x - 7/2, 4*x^2 + 4*x + 2>,
  [ 2 ],
  { 11, 13 }>,

// no. 66
<2*x^6 + 2*x^5 + x^4 + x^2 + 3*x - 3, 2, [],
  [x^2 - x + 1/2,
   x^2 - 286253/13271*x - 5546797/185794],
  <x^3 + 1/3*x^2 + 1/18*x - 14/9, x^3 + 2/3*x^2 + 2/9*x + 13/9, -13/9*x - 11/9>,
  [ 2, 5, 47, 5, 3, 37, 2, 13, 11 ],
  { 11, 23, 29, 59, 71, 127, 163, 167, 193, 211, 227, 269, 349, 389, 431, 577, 
883 }>,

// no. 67
<3*x^6 + 2*x^5 + x^4 - x^3 + x^2 + 3*x - 2, 2, [],
  [x^2 + 2*x + 3/2,
   x^2 - 22/181*x + 9/181],
  <x^3 - 1/2*x + 1, x^3 + 2/3*x^2 + 5/6*x - 1, -1/2*x + 1>,
  [ 3, 3, 5, 23, 2, 2, 2, 13, 11, 7 ],
  { 3, 5, 23, 37, 59, 71, 139, 163, 277, 311, 1303, 2089, 2161, 3463, 4943 }>,

// no. 68
<-3*x^6 - 3*x^5 + 2*x^4 - 3*x^3 - x^2 + x - 1, 2, [],
  [x^2 - 1/4*x + 1/6,
   x^2 - 46/61*x + 17/61],
  <x^3 + x^2 + 1, x^3 - 1/3*x + 1/3, x^2>,
  [ 3, 3, 3, 7, 7 ],
  { 7, 17, 47, 59, 349, 409, 647, 719 }>,

// no. 69
<-3*x^6 - 3*x^5 + 2*x^4 - 2*x^3 + x^2 - 2*x - 1, 2, [],
  [x^2 + 2*x + 2/3,
   x^2 + 1123/2779*x + 2689/11116],
  <x^3 + x^2 + 2, x^3 - 1/3*x + 1/3, -x^2 - 2*x + 1>,
  [ 2, 41, 43, 3, 2 ],
  { 31, 101, 131, 389, 449, 641, 829, 991 }>,

// no. 70
<-3*x^6 + x^5 + x^4 + 3*x^3 + 3*x - 3, 2, [],
  [x^2 - 6/7*x + 3/7,
   x^2 + 129/76*x + 129/76],
  <x^3 + x^2 - 1, x^3 - 4/3*x^2 + x - 1, x>,
  [ 2, 2, 2, 3, 3, 31, 5, 7, 13 ],
  { 5, 19, 29, 43, 53, 71, 89, 101, 109, 131, 139, 181, 257, 293, 419, 607, 727,
1049 }>,

// no. 71
<2*x^6 - 3*x^5 + 3*x^4 - 3*x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 - 1/2*x - 2,
   x^2 - 29/618*x + 698/927],
  <x^3 + x^2 + 1, x^3 - 5/2*x^2 - 1/2*x - 2, 3*x^2 + 1>,
  [ 3, 5, 47, 2 ],
  { 3, 7, 13, 19, 29, 37, 83, 97 }>,

// no. 72
<3*x^6 + x^5 + 3*x^4 - 3*x^3 + x^2 - 2*x - 1, 2, [],
  [x^2 - 2/3*x + 1/3,
   x^2 - 18*x - 45],
  <x^3 + 1/3*x^2 + 2/3*x + 1/3, x^3 - 2, x^2 + x + 1>,
  [ 3, 3, 31, 2, 5, 7 ],
  { 3, 19, 59, 73, 127, 149, 223, 283, 317, 461, 613 }>,

// no. 73
<-3*x^6 - 3*x^4 + x^3 + 2*x^2 + 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 7/3*x + 13/9],
  <x^3 + x + 1, x^3 + 1/3*x - 2/3, x^2 + x + 1>,
  [ 2, 7, 13, 5 ],
  { 5, 7, 37, 41, 53, 211, 479, 953 }>,

// no. 74
<-2*x^6 - 2*x^5 - x^4 - 2*x^2 + x + 3, 2, [],
  [x^2 - x + 1/2,
   x^2 + 8794/16529*x + 5809/16529],
  <x^3 + 1/2*x + 1/2, x^3 + x^2 + 2*x - 3, -2*x^2 + x>,
  [ 2, 3 ],
  { 11, 107 }>,

// no. 75
<-2*x^6 + 2*x^5 - x^3 - 2*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 1/9*x + 25/36],
  <x^3 + 2*x + 2, x^3 - x^2 + 1/2, -2*x^2 + 1>,
  [ 3, 2, 3, 19, 7, 2, 13 ],
  { 5, 11, 37, 89, 103, 193, 433, 467, 661, 673, 1151, 1619 }>,

// no. 76
<-3*x^6 + x^5 - 3*x^4 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 + 300/109*x + 657/109,
   x^2 - 1504/741*x + 292/247],
  <x^3 + 2/3*x^2 - 1/3*x - 2/3, x^3 - x^2 + 2*x - 1, x>,
  [ 5 ],
  { 3, 13 }>,

// no. 77
<3*x^6 + 3*x^5 + x^4 + 2*x^3 - 2*x^2 + x + 3, 2, [],
  [x^2 - x - 1,
   x^2 + 330/59*x - 277/59],
  <x^3 - x + 1, x^3 + x^2 + x + 2/3, -x^2 + 1>,
  [],
  { 29 }>,

// no. 78
<3*x^6 + 3*x^5 + x^4 + 2*x^3 - 2*x^2 - x - 3, 2, [],
  [x^2 + 1/2*x - 2,
   x^2 - 5944897/11489998*x + 4518326/5744999],
  <x^3 - 3/2*x^2 - 2*x - 19/2, x^3 + 5/2*x^2 + 2*x + 2/3, 7/2*x^2 + 15/2*x + 4>,
  [ 3, 3 ],
  { 5, 149 }>,

// no. 79
<-x^6 - 3*x^5 - x^3 - 2*x^2 + 3*x - 2, 2, [],
  [x^2 + 3*x + 3,
   x^2 + 7/37*x + 11/37],
  <x^3 + 2*x^2 - 2*x + 1, x^3 + x^2 + x + 2, x^2 + x>,
  [ 3, 3, 2, 13, 2, 2 ],
  { 3, 5, 17, 23, 43, 53, 83, 163, 199, 241, 263, 491 }>,

// no. 80
<-3*x^6 - x^5 + 3*x^4 - x^2 - 2*x + 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 86/21*x + 118/7],
  <x^3 - x + 1, x^3 + 1/3*x^2 - 2/3, 1>,
  [ 3, 3 ],
  { 3, 5, 19 }>,

// no. 81
<2*x^6 - x^5 - x^4 + 2*x^2 - x - 3, 2, [],
  [x^2 - x - 3,
   x^2 - 25058497/82499977*x - 88486171/82499977],
  <x^3 - 1/2*x^2 - 8*x - 21/2, x^3 - 1/2*x + 1/4, 4*x^2 + 5/2*x - 3/2>,
  [ 3, 3, 5, 2, 2, 2, 2, 29, 11 ],
  { 3, 5, 23, 41, 67, 83, 191, 293, 409, 457, 463, 661, 1163, 1499, 2137, 2297, 
2917, 3541 }>,

// no. 82
<-3*x^6 - 3*x^5 + 3*x^3 - 3*x^2 + x + 3, 2, [],
  [x^2 - 7/4*x + 3/2,
   x^2 - 3143/3292*x + 59/1646],
  <x^3 + 1/3*x - 1/3, x^3 + x^2 - 1, -x^2 + 2>,
  [ 3, 3, 3, 2, 5, 19, 23 ],
  { 5, 11, 61, 67, 83, 107, 157, 223, 347, 359, 401, 571, 1279, 1669 }>,

// no. 83
<-3*x^6 + x^5 + x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 - x + 2,
   x^2 - 903610/92325693*x - 24752471/92325693],
  <x^3 - 3*x^2 + 22*x + 13, x^3 + 8/3*x^2 + 7/3*x + 1/3, 7*x^2 + 14*x + 4>,
  [ 2, 2, 7, 47, 19, 3 ],
  { 3, 5, 13, 19, 59, 67, 157, 179, 233, 359, 409, 1321 }>,

// no. 84
<2*x^6 - 3*x^5 - 2*x^4 + x^3 - 2*x^2 - x - 2, 2, [],
  [x^2 + 3/2*x + 3/2,
   x^2 - 29718/5983*x - 41481/5983],
  <x^3 + 3*x^2 - 6*x - 9, x^3 - 9/2*x^2 + 1/2*x + 11, -6*x^2 + 5*x + 14>,
  [ 3, 5 ],
  { 3, 41, 191 }>,

// no. 85
<-x^6 + 3*x^5 + x^4 - x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 - x + 2,
   x^2 + 123136/468649*x + 266668/468649],
  <x^3 - 1/2*x^2 + 6*x - 12, x^3 - 5/2*x^2 - 2*x - 1/2, -5/2*x^2 + 11/2*x + 2>,
  [ 2, 2, 2, 2, 3, 3, 5, 5, 13 ],
  { 29, 31, 43, 47, 61, 107, 181, 211, 337, 379, 503, 757, 797 }>,

// no. 86
<3*x^6 - x^5 - 2*x^4 + 3*x^3 + 3*x^2 + 2*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 11720/7773*x + 7648/7773],
  <x^3 - 4/3*x^2 + 2/3*x - 2/3, x^3 + x^2 - 3*x - 1, 3*x^2 - x + 1>,
  [],
  { 17 }>,

// no. 87
<-3*x^6 - 2*x^5 - 2*x^4 - 2*x^3 - 3*x^2 + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 29/19*x + 13/19],
  <x^3 - 5/6*x^2 + 8/3*x - 1/3, x^3 + 3/2*x^2 - 1, -3/2*x^2 - 2*x + 2>,
  [ 2, 3, 31, 37, 7, 19, 29 ],
  { 5, 7, 23, 37, 41, 53, 61, 67, 131, 151, 223, 383, 467, 827, 947, 1201, 2287 
}>,

// no. 88
<-2*x^6 + 2*x^5 + x^4 + 3*x^3 - x^2 - 3*x + 2, 2, [],
  [x^2 - x - 1,
   x^2 - 122/473*x - 487/473],
  <x^3 + 5*x - 2, x^3 - x^2 + 5/8*x + 1/4, 7/2*x^2 - 3/2*x + 1>,
  [],
  { 3 }>,

// no. 89
<-x^6 + 3*x^5 - x^4 + 2*x^3 + x^2 + 3*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 180/73*x - 108/73],
  <x^3 + 5*x + 2, x^3 - 3*x^2 + 9/4*x - 3/2, 5/2*x^2 - 5/2*x>,
  [ 2 ],
  { 5, 193 }>,

// no. 90
<2*x^6 + x^5 - 2*x^4 - 3*x^3 - x^2 + 3*x - 3, 2, [],
  [x^2 - 3*x + 3,
   x^2 + 737/409*x + 511/409],
  <x^3 - 2/7*x^2 - 12/7*x - 3, x^3 + 11/14*x^2 - 11/14*x + 1/2, 13/7*x^2 + 
8/7*x>,
  [ 3, 19, 31, 23 ],
  { 13, 31, 41, 59, 67, 103, 109, 199, 239, 269, 1381 }>,

// no. 91
<3*x^6 - 3*x^5 - x^4 - 3*x^3 + 2*x^2 - 2*x - 2, 2, [],
  [x^2 - x - 1,
   x^2 + 61892/10417*x + 1371889/250008],
  <x^3 - 1/2*x^2 + 2*x + 3/2, x^3 - 1/2*x^2 - 8/3*x - 4/3, -1/2*x^2 + 9/2*x + 
2>,
  [ 2, 3, 43, 17, 5 ],
  { 7, 13, 17, 29, 41, 53, 97, 229, 251, 263, 269, 281, 359 }>,

// no. 92
<-x^6 + 2*x^4 - 2*x^3 - x^2 - 3*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 622/2713*x - 827/2713],
  <x^3 + x^2 + 1, x^3 - x^2 + 3*x - 2, -2*x^2 + 1>,
  [ 3, 19, 2, 7, 5 ],
  { 7, 11, 41, 59, 79, 89, 191, 239, 269, 281, 349 }>,

// no. 93
<2*x^6 - x^5 - 2*x^3 - x^2 - x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 6393/4153*x + 2481/4153],
  <x^3 - x + 3, x^3 - 1/2*x^2 - x - 1/2, -2*x^2 + 2*x + 1>,
  [ 2, 2, 3, 2, 2 ],
  { 3, 7, 23, 29, 43, 113, 223, 499 }>,

// no. 94
<3*x^6 + x^5 - x^4 + x^3 + x^2 + 3*x - 3, 2, [],
  [x^2 - 19/26*x + 1/2,
   x^2 + 1052/481*x + 916/481],
  <x^3 + 1/2*x^2 - 3/2*x + 2, x^3 - 1/6*x^2 + 1/2*x - 2/3, 3/2*x^2 - 3/2*x + 1>,
  [ 19, 3, 3, 23 ],
  { 7, 13, 17, 19, 47, 53, 59, 71, 199 }>,

// no. 95
<-3*x^6 - 2*x^5 - 2*x^4 - 3*x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 5/2*x + 2,
   x^2 + 48/13],
  <x^3 + x^2 + 9/4*x + 3, x^3 - 1/3*x^2 + 1/12*x + 1/3, -2*x^2 - 5/4*x>,
  [ 3, 2, 7, 2, 2, 19, 17 ],
  { 5, 7, 13, 17, 23, 29, 31, 103, 241, 499, 1109, 1747 }>,

// no. 96
<-3*x^6 - 2*x^5 + 3*x^4 - 2*x^3 - x - 3, 2, [],
  [x^2 - x + 3/2,
   x^2 - 687/6517*x + 6019/6517],
  <x^3 - x^2 - 1/2*x + 2, x^3 + 5/3*x^2 + 7/6*x + 2/3, 5/2*x + 1>,
  [ 2, 7, 3 ],
  { 3, 11, 31, 41, 47, 71, 229 }>,

// no. 97
<-x^6 + x^5 + x^4 + x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 3/2*x + 1,
   x^2 - 166/377*x + 193/377],
  <x^3 - 2*x^2 + x + 1, x^3 + x^2 - 3, 2*x>,
  [],
  { 47 }>,

// no. 98
<-2*x^6 - 2*x^5 + x^4 - 3*x^3 - x^2 - 3*x - 1, 2, [],
  [x^2 + 1/3,
   x^2 + 446/1129*x + 197/1129],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 + x + 1/2, x^2 + x>,
  [ 5, 3, 31, 2, 19, 3, 3, 2, 11, 47 ],
  { 3, 7, 13, 19, 31, 113, 293, 379, 509, 523, 601, 641, 659, 1399, 1753 }>,

// no. 99
<2*x^6 + 3*x^5 + x^4 + 3*x^3 - 2, 2, [],
  [x^2 - x + 1,
   x^2 + 6935/4073*x + 4169/4073],
  <x^3 + 7*x^2 + 7*x - 9, x^3 - 11/2*x^2 - 17/2*x + 19/2, -9*x^2 - 11*x + 13>,
  [ 2, 2, 3, 41 ],
  { 3, 11, 29 }>,

// no. 100
<-2*x^6 - 2*x^5 + 3*x^4 - 3*x^3 - 2*x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 29408/130497*x + 25608/43499],
  <x^3 + 4*x + 3, x^3 + x^2 - x + 1/2, -3*x^2 - 2*x + 1>,
  [ 2, 2, 2, 2, 2, 5, 3 ],
  { 11, 41, 73, 79, 137, 577, 1511 }>,

// no. 101
<-3*x^6 + 3*x^5 - 2*x^4 - 2*x^3 - 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 12/13*x + 9/13],
  <x^3 - x^2 + 1, x^3 + x + 2/3, -x^2 + 1>,
  [],
  { 11 }>,

// no. 102
<-2*x^6 - 3*x^5 + x^4 - 2*x^3 - x - 3, 2, [],
  [x^2 + 1,
   x^2 - 20294/219321*x + 25339/73107],
  <x^3 + 3/2*x^2 + 2*x + 2, x^3 - 1/2*x + 3/4, -2*x^2 - 1/2*x>,
  [ 2, 19, 11, 2, 2, 3, 17, 3, 5 ],
  { 3, 13, 17, 43, 59, 137, 197, 269, 359, 389, 431, 439, 599, 853 }>,

// no. 103
<2*x^6 - 2*x^5 - 2*x^4 + 3*x^3 - 3*x^2 - 2*x - 1, 2, [],
  [x^2 - 9/7*x + 5/7,
   x^2 + 45/47*x + 113/376],
  <x^3 + 2, x^3 - x^2 - x - 1/2, x + 1>,
  [ 2, 2, 5, 19, 3, 2 ],
  { 3, 31, 47, 73, 89, 97, 127, 137, 149, 179, 239, 491, 929 }>,

// no. 104
<-2*x^6 + 2*x^5 + x^4 - 2*x^3 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 50340/29161*x + 2172/2651],
  <x^3 - 2*x^2 + 11/4*x - 11/4, x^3 + x^2 - 9/8*x - 11/8, 1/2*x^2 - 1/4*x - 
13/4>,
  [ 3, 3, 3, 7, 19, 13, 23 ],
  { 5, 13, 37, 83, 101, 107, 113, 131, 257, 569, 787, 821, 1553 }>,

// no. 105
<-x^6 + x^5 - x^4 - x^2 + x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 4220/3497*x + 5316/3497],
  <x^3 - x^2 + 9/4*x - 1/2, x^3 + 5*x - 2, 5/2*x^2 - 3/2*x + 2>,
  [ 3, 3, 2, 19, 2, 11, 13 ],
  { 3, 5, 11, 139, 191, 233, 269, 311, 331, 383, 401, 443, 769, 797, 1019, 1877 
}>,

// no. 106
<-3*x^6 - 2*x^5 - 2*x^4 + 3*x^3 + 2*x^2 + 2*x - 2, 2, [],
  [x^2 + 1/2,
   x^2 + 2/3*x + 3/2],
  <x^3 + 2/3*x^2 - 2/3, x^3 + x - 1, x^2>,
  [],
  { 3 }>,

// no. 107
<3*x^6 - x^5 - 2*x^4 - x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 - 5/2*x - 1,
   x^2 - 503/726*x - 941/1089],
  <x^3 + 5/3*x^2 + 4/3*x + 1/3, x^3 - 2*x^2 + x - 1, x^2 + 2*x>,
  [ 3, 11, 5 ],
  { 3, 5, 7, 17, 19, 43, 73, 101 }>,

// no. 108
<-3*x^6 + x^5 - 3*x^4 + 3*x^3 - x^2 + 2*x - 1, 2, [ 2 ],
  [x^2 + x + 1,
   x^2 - 3*x + 5],
  <x^3 - 1/3*x^2 + 1/3*x - 1/3, x^3 + x - 1, -x^2 + x>,
  [],
  { 19 }>,

// no. 109
<-2*x^6 + x^4 + x^3 + 3*x^2 - 3*x + 2, 2, [],
  [x^2 - x + 1/2,
   x^2 + 1/17*x - 1063/1156],
  <x^3 + x^2 + 1/2*x + 1, x^3 - x^2 + 2*x - 1, 2*x^2 + x>,
  [ 2, 3, 3, 3, 7, 11, 2, 19 ],
  { 3, 5, 7, 13, 23, 29, 41, 47, 251, 311, 367, 431, 499, 503, 967 }>,

// no. 110
<-2*x^6 - x^5 - x^4 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 10/3*x + 13/3,
   x^2 - 26/51*x + 49/51],
  <x^3 - 1/2*x^2 + 3/2*x - 3/2, x^3 + x^2 - 1, -x^2 + x>,
  [ 5, 7, 7, 47, 2, 2, 2, 11, 31, 3 ],
  { 11, 19, 29, 47, 193, 223, 233, 293, 571, 809, 821, 1151, 1229, 1429, 1511, 
1549, 1801 }>,

// no. 111
<-x^6 + 3*x^5 - 2*x^4 - x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 - 3*x + 4,
   x^2 - 12/13*x + 4/13],
  <x^3 - 3*x^2 + 4*x - 3, x^3 - x - 1, -x^2 + x>,
  [ 3, 2, 11, 13, 7, 5 ],
  { 3, 5, 17, 23, 71, 73, 127, 191, 359, 379, 577, 1931 }>,

// no. 112
<3*x^6 - x^5 + 3*x^4 - x^3 + 3*x - 2, 2, [],
  [x^2 - 1/3*x + 2/3,
   x^2 - 62192/18337*x + 38124/18337],
  <x^3 + 9*x + 9, x^3 - 1/3*x^2 - 8*x - 19/3, 15*x + 13>,
  [ 2, 2, 2, 3, 3 ],
  { 23, 53, 113, 157, 479 }>,

// no. 113
<-x^6 + x^5 + x^4 - 2*x^3 + 2*x^2 - 2*x - 3, 2, [],
  [x^2 - 3/2*x + 1,
   x^2 + 73/106*x + 43/53],
  <x^3 - 1/2*x^2 + 1/2*x + 1, x^3 - 1/2*x^2 + 1/2*x + 3, -3/2*x^2 - 1/2*x>,
  [ 3, 5, 3 ],
  { 3, 7, 19, 29, 79, 647 }>,

// no. 114
<-3*x^6 - x^5 + 2*x^4 + 2*x^3 + 3*x^2 - 3*x - 1, 2, [],
  [x^2 - 2/3*x + 1/3,
   x^2 + 90098/268867*x + 245437/268867],
  <x^3 + 3*x^2 + 7*x + 2, x^3 - 8/3*x^2 + 5/3*x + 5/3, -2*x^2 + 7*x + 3>,
  [],
  { 3 }>,

// no. 115
<2*x^6 - x^5 - 2*x^4 - 2*x^2 + 3*x - 3, 2, [],
  [x^2 - 3/2*x + 3/2,
   x^2 - 5/478*x - 2107/478],
  <x^3 + x^2 - x + 1, x^3 - 3/2*x^2 - 1/2*x - 2, 2*x^2 + 1>,
  [ 2, 2, 5, 3, 19, 3 ],
  { 7, 17, 19, 29, 41, 47, 53, 59, 89, 167, 389, 739, 1583, 1627, 1861 }>,

// no. 116
<-3*x^6 - 3*x^5 + 2*x^4 - x^3 - x^2 + 2*x + 3, 2, [],
  [x^2 + 1,
   x^2 - 3377556/381529*x + 16032997/381529],
  <x^3 - 3/4*x^2 + x + 6, x^3 + 7/4*x^2 + 4/3*x + 1/3, 9/4*x^2 + 9/2*x + 3>,
  [ 2, 2, 2, 2, 3, 31, 5, 11, 7 ],
  { 7, 17, 41, 59, 89, 103, 127, 131, 179, 239, 251, 421, 541, 593, 599 }>,

// no. 117
<3*x^6 + 2*x^4 - 3*x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 - 2/3,
   x^2 - 672/733*x - 3244/2199],
  <x^3 - 1/6*x + 1, x^3 + 1/2*x - 1, x^2 - 3/2*x>,
  [ 2, 2, 7, 5, 3, 19 ],
  { 11, 13, 23, 31, 37, 73, 89, 127, 163, 211, 431, 1697, 1877 }>,

// no. 118
<-2*x^6 - 2*x^5 - 3*x^3 + x^2 + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 1/2],
  <x^3 - 1/2, x^3 + x^2 + 2, 0>,
  [ 2, 2, 3, 11, 11, 5, 19, 7 ],
  { 17, 19, 23, 37, 41, 43, 53, 59, 61, 67, 71, 83, 101, 131, 173, 223, 277, 
397, 419 }>,

// no. 119
<-x^6 - 3*x^5 - x^4 - 2*x^2 + 2*x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 2/17*x + 1],
  <x^3 + 5/2*x^2 + x + 1, x^3 + 1/2*x^2 - x + 3, 1/2*x^2 + 2*x + 1>,
  [],
  { 5 }>,

// no. 120
<2*x^6 - 3*x^5 - x^4 + 2*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 6/7*x + 13/28,
   x^2 + 225/34*x + 949/136],
  <x^3 + 3/2*x^2 + 2*x + 2, x^3 - 3*x^2 - 5/2*x - 7/4, 3*x^2 + 7/2*x + 2>,
  [ 2, 2, 3, 5, 2, 2, 13, 7 ],
  { 5, 7, 67, 71, 113, 127, 157, 269, 281, 283, 367, 419, 547, 941, 1093 }>,

// no. 121
<3*x^6 + x^5 - 2*x^4 - x^3 - 2*x^2 + x - 1, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 4/13*x + 4/13],
  <x^3 + 5/6*x^2 - 1/2*x + 1/3, x^3 - 1/2*x^2 - 1/2*x - 1, -3/2*x^2 - 1/2*x>,
  [ 2, 3, 5, 29, 2, 3, 7, 19 ],
  { 7, 11, 13, 17, 19, 29, 59, 61, 73, 433, 643, 953, 1069, 1607, 4547 }>,

// no. 122
<3*x^6 - x^5 - 3*x^4 + 3*x^3 - 3*x^2 - 2*x + 2, 2, [],
  [x^2 - 2,
   x^2 - 99*x + 457/4],
  <x^3 + 1/2*x^2 + 1, x^3 - 5/6*x^2 - 2/3*x + 1/3, -1/2*x^2 + 1>,
  [ 2, 5 ],
  { 3, 5, 13, 37 }>,

// no. 123
<3*x^6 + 3*x^5 + 2*x^4 - 3*x^3 + 2*x^2 - 3*x - 2, 2, [],
  [x^2 + 3/2*x - 3,
   x^2 + 1764/71*x + 20481/568],
  <x^3 - 3/2*x^2 + 1/2*x - 1, x^3 + 5/2*x^2 + 19/6*x + 1, 3/2*x^2 + 5/2*x + 1>,
  [],
  { 5 }>,

// no. 124
<-2*x^6 - x^5 - 2*x^3 - 2*x^2 + 2*x + 2, 2, [],
  [x^2 + 1/3*x - 1/3,
   x^2 + 1/2*x + 97/24],
  <x^3 + 1/2*x^2 + 4*x - 4, x^3 + 1/2*x + 1/4, 3*x^2 - 3/2*x>,
  [ 2, 3, 13, 2, 2, 2, 3, 5 ],
  { 3, 17, 19, 31, 37, 43, 83, 103, 149, 163, 191, 223, 283, 367, 547, 557, 
1193, 1223, 1429 }>,

// no. 125
<3*x^6 - 3*x^5 - 2*x^4 - 3*x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 + x - 1,
   x^2 - 488/107*x - 1248/107],
  <x^3 - x^2 + x - 1/3, x^3 - 2*x - 2, -x^2 + x + 1>,
  [ 5, 2, 7, 3, 7, 2, 37, 19 ],
  { 7, 11, 13, 23, 29, 37, 67, 83, 101, 109, 127, 151, 191, 1129 }>,

// no. 126
<-x^6 + x^5 + 3*x^4 + 3*x^3 + x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 33/26*x + 27/26],
  <x^3 + 2/5*x^2 - 8/5*x - 19/5, x^3 - 7/5*x^2 + 3/5*x - 6/5, -6/5*x^2 - 1/5*x -
8/5>,
  [ 2, 5, 11, 3, 13, 3, 29, 7 ],
  { 3, 19, 41, 53, 59, 61, 79, 107, 137, 167, 173, 211, 229, 277, 349, 457, 499,
1489 }>,

// no. 127
<-3*x^6 - x^5 - 2*x^3 + 2*x^2 - x + 3, 2, [],
  [x^2 + 1,
   x^2 + 199512/275029*x + 265033/275029],
  <x^3 + 5*x - 2, x^3 + 1/3*x^2 - 11/12*x - 1/6, -7/2*x^2 + 1/2*x + 2>,
  [ 2, 2 ],
  { 3, 5 }>,

// no. 128
<3*x^6 + 2*x^5 - 3*x^3 + 2*x^2 - 2*x + 3, 2, [],
  [x^2 + x - 1,
   x^2 + 390997/556501*x + 449051/556501],
  <x^3 - 2*x + 13/9, x^3 + 2/3*x^2 + 2/3*x + 2/3, -2*x^2 + 4/3*x - 1/3>,
  [ 11 ],
  { 5, 67, 457 }>,

// no. 129
<-3*x^6 + x^5 + 2*x^4 + 3*x^3 + 3*x^2 + 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 361684/164773*x + 24787/23539],
  <x^3 + x^2 + 4*x - 4, x^3 - 4/3*x^2 + 3/4*x - 7/12, 7/2*x^2 - 7/2*x + 2>,
  [ 2, 2, 3, 3, 13, 7, 23 ],
  { 3, 7, 13, 23, 31, 37, 101, 163, 167, 173, 251, 397, 419, 557 }>,

// no. 130
<-2*x^6 + 3*x^5 - x^3 + 2*x^2 + x + 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 27126/245209*x + 28953/245209],
  <x^3 - 1/2*x^2 - 1/8*x - 23/8, x^3 - x^2 + 3/4*x + 1/4, 3/2*x^2 - 9/4*x + 
3/4>,
  [ 3, 7, 2, 13, 3, 5, 19 ],
  { 3, 11, 17, 31, 37, 61, 149, 199, 227, 241, 277, 317, 331, 383, 577, 1321, 
1847 }>,

// no. 131
<-x^6 - x^5 + 3*x^3 - 3*x^2 + 2*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 436/565*x - 92/565],
  <x^3 - 3/2*x^2 + 4*x + 2, x^3 + 5/2*x^2 + 2*x - 3/2, -3/2*x^2 - 7/2*x>,
  [ 3, 7, 11, 2, 17, 2 ],
  { 5, 7, 29, 31, 59, 73, 109, 163, 227, 271, 277, 587 }>,

// no. 132
<2*x^6 - x^5 - 3*x^4 - x^2 - 2*x - 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 61818/48073*x + 41361/48073],
  <x^3 - 3*x^2 - 8*x - 6, x^3 + 5/2*x^2 + 3/2*x + 1/2, 5*x^2 + 6*x + 2>,
  [ 2, 3 ],
  { 3, 11 }>,

// no. 133
<-x^6 + 3*x^5 - x^4 - 3*x^3 - 3*x - 2, 2, [],
  [x^2 + 3/2*x + 1,
   x^2 - 26790/23377*x + 12529/23377],
  <x^3 - 3*x^2 + 3*x + 3, x^3 + 1/4*x + 3/4, 3/2*x^2 - 1/2>,
  [ 3, 3, 5, 2 ],
  { 3, 5, 11, 13, 31, 109 }>,

// no. 134
<3*x^6 - 3*x^5 + 2*x^4 - 2*x^3 - x^2 - x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 655/601*x + 5173/9616],
  <x^3 + 1/2*x^2 - 8*x + 8, x^3 - 3/2*x^2 - 2/3*x - 1/6, -11/2*x^2 + 11/2*x + 
1>,
  [ 2, 2, 5, 2, 3, 7 ],
  { 7, 11, 13, 41, 83, 127, 139, 149 }>,

// no. 135
<-x^6 + 2*x^5 - x^4 + x^3 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 - x + 2,
   x^2 - 4019078/4343513*x + 6606841/4343513],
  <x^3 + x^2 + 4*x - 4, x^3 - 3*x^2 + 9/4*x - 3/4, 3/2*x^2 - 9/2*x + 1>,
  [ 3, 2, 2, 3, 31, 2, 2, 5, 7 ],
  { 3, 5, 17, 19, 29, 37, 83, 113, 137, 167, 173, 193, 239, 251, 283, 577, 887 
}>,

// no. 136
<2*x^6 - x^5 + 3*x^4 + x^3 - 2, 2, [],
  [x^2 - 2*x + 3,
   x^2 - 8/17*x + 24/17],
  <x^3 + 11*x^2 - 9, x^3 - 23/2*x^2 + 19/2, 16*x^2 - 13>,
  [ 3, 3, 5, 7, 23, 11 ],
  { 3, 5, 31, 37, 59, 61, 67, 73, 149, 233, 281, 307, 347, 433, 523, 1093 }>,

// no. 137
<3*x^6 - 3*x^4 - 2*x^3 - 2*x^2 + x - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 32133/13619*x - 99233/13619],
  <x^3 - 2*x^2 + 2*x + 9, x^3 + 2*x^2 - 13/3*x - 19/3, -4*x^2 + 6*x + 13>,
  [ 2, 3, 2, 7 ],
  { 5, 13, 47, 67, 97, 157 }>,

// no. 138
<-2*x^6 - 3*x^5 - 2*x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 172181663/165229977*x + 34164803/55076659],
  <x^3 + 11/6*x^2 + 2/3*x + 4/3, x^3 - 1/3*x^2 + 1/6*x - 1/12, -2/3*x^2 - 1/2*x 
+ 5/3>,
  [ 3 ],
  { 5, 11 }>,

// no. 139
<-2*x^6 + 2*x^5 - 2*x^4 - x^3 - 2*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 335/1121*x + 5473/8968],
  <x^3 + 1/2, x^3 - x^2 + 3*x - 2, -2*x^2 + x + 1>,
  [ 2 ],
  { 5, 23 }>,

// no. 140
<-x^6 + 3*x^5 + 2*x^4 + 3*x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 - 1/2*x + 5/2,
   x^2 - 3773/1202*x + 4981/1202],
  <x^3 + 4/5*x^2 + 11/5*x - 1, x^3 - 19/5*x^2 + 4/5*x - 1, 7/5*x^2 - 12/5*x>,
  [ 3, 2, 7, 5, 2 ],
  { 3, 7, 11, 79, 149, 229 }>,

// no. 141
<-x^6 + 3*x^5 + 2*x^4 - 3*x^2 - x - 2, 2, [],
  [x^2 - 3*x + 3,
   x^2 + 69/97*x + 243/97],
  <x^3 - x^2 + 1/4*x - 1/2, x^3 - 2*x^2 - 4*x - 4, -1/2*x^2 + x>,
  [ 3, 13, 7 ],
  { 7, 17, 29, 31, 71, 79, 337 }>,

// no. 142
<3*x^6 - 2*x^5 + 3*x^4 + 3*x^2 + x - 3, 2, [],
  [x^2 + 1/3*x + 1/2,
   x^2 - 445/1222*x + 9181/4888],
  <x^3 - 5/3*x^2 - 1/3*x + 4/3, x^3 + x^2 - 1, -3*x^2 + 1>,
  [ 2, 3, 7, 13, 5 ],
  { 3, 7, 13, 37, 47, 59, 61, 89, 101, 211, 233, 251 }>,

// no. 143
<3*x^6 + x^5 - 2*x^4 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 24/23*x - 57/23,
   x^2 - 105582/152329*x + 180237/152329],
  <x^3 - 2/3*x^2 - 1/3*x - 1/3, x^3 + x^2 - x + 4, -2*x^2 + 3*x + 1>,
  [ 3, 23, 7, 5, 2 ],
  { 5, 7, 17, 31, 41, 59, 61, 107, 131, 179, 433, 619, 709 }>,

// no. 144
<2*x^6 - 2*x^5 - 3*x^3 - 2*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 209/478*x - 359/3824],
  <x^3 + x^2 - 1/2, x^3 - 2*x^2 + 2*x - 3, 2*x>,
  [ 3, 2, 7, 11, 5, 31, 23, 5 ],
  { 5, 11, 13, 17, 31, 41, 59, 89, 137, 149, 167, 673, 733, 809, 853, 1153, 
1231, 3163, 3637, 3659, 3701, 4229 }>,

// no. 145
<3*x^6 - 2*x^5 - 2*x^4 - 2*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - x - 1,
   x^2 + 253744440/346206407*x - 4873655857/1384825628],
  <x^3 + 4*x^2 - 51/2*x + 26, x^3 - 14/3*x^2 + 19/6*x - 2/3, 11*x^2 - 43/2*x + 
7>,
  [ 2, 3, 2, 7, 2 ],
  { 5, 7, 19, 31, 43, 79, 157, 199 }>,

// no. 146
<-2*x^6 + 3*x^5 - x^3 - 2*x^2 + x + 3, 2, [],
  [x^2 - 1/2*x - 1,
   x^2 - 1682233/5703858*x - 332783/950643],
  <x^3 - x^2 + 15*x + 13, x^3 - 1/2*x^2 - 3/8*x + 1/8, 11/2*x^2 + x - 5/2>,
  [ 2, 19, 5, 7, 2 ],
  { 7, 11, 23, 31, 37, 67, 89, 137, 691 }>,

// no. 147
<-3*x^6 + 3*x^5 - 3*x^4 + x^3 - 3*x^2 + x + 2, 2, [],
  [x^2 - 1/4*x - 1/4,
   x^2 + 751/27652*x - 7457/27652],
  <x^3 + x^2 + 4/3*x + 1/3, x^3 - 2*x^2 + 3*x - 1, 2*x^2 + 1>,
  [ 2, 3, 3, 5 ],
  { 5, 23, 37, 107 }>,

// no. 148
<-3*x^6 + 2*x^5 + 2*x^4 + 3*x^3 - 2, 2, [],
  [x^2 - 5/3*x + 1,
   x^2 - 9/7*x + 3/7],
  <x^3 - 2/3*x^2 + 2/3*x - 2/3, x^3 - x - 1, x^2>,
  [ 3, 5, 11, 2, 2 ],
  { 5, 13, 23, 29, 31, 41, 43, 73, 197, 983 }>,

// no. 149
<2*x^6 - 3*x^5 + 3*x^4 + x^3 - 2*x^2 + 3*x + 3, 2, [],
  [x^2 + x - 1,
   x^2 - 99/17*x + 23/17],
  <x^3 - 2*x^2 + 2*x + 1, x^3 + 1/2*x^2 - 3/2*x + 3/2, -2*x^2 + 3*x>,
  [ 2, 2, 2, 19, 5, 3 ],
  { 5, 7, 17, 41, 101, 103, 157, 233, 307, 467, 499, 569 }>,

// no. 150
<-x^6 + x^4 - 2*x^3 - 2*x^2 - 3*x + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 100/89*x + 1736/1513],
  <x^3 - 1/2*x + 1, x^3 + 7/2*x - 1, -2*x^2 + 1/2*x + 1>,
  [ 3 ],
  { 3, 7 }>,

// no. 151
<-x^6 - 3*x^5 + 3*x^4 + x^2 + 2*x + 3, 2, [],
  [x^2 - 126/85*x + 22/85,
   x^2 + 230/97*x + 214/97],
  <x^3 + x^2 + 2, x^3 + 2*x^2 - x - 1, 2*x^2 + 1>,
  [ 3, 5, 7, 2, 3 ],
  { 3, 13, 19, 23, 47, 73, 83, 157, 179, 761 }>,

// no. 152
<-3*x^6 - 3*x^5 - 2*x^4 - 2*x^3 + 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 - 4*x + 5],
  <x^3 - x^2 + x - 1/3, x^3 + 2*x^2 + 3*x - 2, 2*x^2 - 3*x + 1>,
  [ 3, 7, 5, 13, 2, 19 ],
  { 7, 11, 23, 37, 41, 43, 61, 113, 163, 229, 271, 283, 373, 641 }>,

// no. 153
<-2*x^6 + 2*x^5 + 3*x^4 + 3*x^3 - x^2 + 3*x - 2, 2, [],
  [x^2 + 4/3*x + 1,
   x^2 + 36118/21921*x + 9707/7307],
  <x^3 + x^2 - 1/2, x^3 - 2*x^2 + 5*x - 3, -3*x^2 - x + 1>,
  [ 2, 3, 3, 7, 2, 2, 5 ],
  { 5, 7, 11, 17, 23, 43, 47, 59, 61, 83, 331, 593, 599 }>,

// no. 154
<3*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - 2*x^2 - 1, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 20503/326954*x + 1428337/326954],
  <x^3 - 9/2*x^2 - 6*x - 4, x^3 + 7/2*x^2 + 2*x + 5/6, 15/2*x^2 + 13/2*x + 3>,
  [ 2, 3, 3, 5, 13, 2 ],
  { 5, 7, 13, 17, 23, 29, 349 }>,

// no. 155
<2*x^6 + x^5 + 3*x^4 + 3*x^3 - 2*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 451/463*x + 679/463],
  <x^3 + 3/2*x^2 + 2*x + 2, x^3 - x^2 + 1/2*x - 3/4, -x^2 - 3/2*x>,
  [ 2, 2, 3, 7, 11, 5, 3, 37, 7 ],
  { 5, 13, 73, 89, 113, 179, 199, 211, 239, 331, 461, 509, 719, 853, 883, 1657, 
1877, 2351, 3463, 3847, 4013, 4241 }>,

// no. 156
<-2*x^6 - 2*x^5 - x^3 - 3*x^2 + x + 2, 2, [],
  [x^2 - 1/2,
   x^2 + 7/17*x + 353/1224],
  <x^3 - x^2 + 2*x - 1, x^3 + 2*x^2 + 1/2*x - 1, -x^2 - x + 2>,
  [],
  { 7 }>,

// no. 157
<3*x^6 - 2*x^5 - x^4 - 2*x^3 + x^2 + x - 3, 2, [],
  [x^2 + 17/11*x + 399/143,
   x^2 + 235/169*x + 939/1859],
  <x^3 - x + 1, x^3 - 2/3*x^2 - 2/3*x - 1, -2*x^2 + x>,
  [ 2, 2, 29, 3, 3, 7, 19 ],
  { 3, 11, 19, 29, 31, 59, 67, 103, 113, 139, 157, 311, 449, 541, 547 }>,

// no. 158
<-2*x^6 - 3*x^5 + 2*x^4 - 3*x^3 - 3*x^2 + 3*x - 1, 2, [],
  [x^2 - 1/2*x + 5,
   x^2 - 113/166*x + 13/83],
  <x^3 + 3/2*x^2 + 1/2*x + 1, x^3 - x + 1, -x^2 + x + 1>,
  [ 2, 7, 5, 5, 13 ],
  { 3, 5, 7, 13, 17, 19, 59, 223, 269, 467 }>,

// no. 159
<-2*x^6 + 2*x^5 - x^4 + x^3 + 2*x^2 + 2*x - 1, 2, [],
  [x^2 - 2*x + 5/6,
   x^2 + 14/3*x + 97/9],
  <x^3 - x^2 + 3/2*x - 1/2, x^3 - x - 1, x>,
  [ 3, 3, 3, 23, 5, 17, 2 ],
  { 5, 19, 29, 31, 41, 47, 67, 107, 113, 131, 211, 467 }>,

// no. 160
<-2*x^6 + x^5 + x^4 + 3*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 + 5/3*x + 1,
   x^2 + 9095/7414*x + 5262/3707],
  <x^3 + 1/2*x^2 - 1/2*x - 1/2, x^3 - x^2 + 5*x - 4, -3*x^2 + 1>,
  [ 2, 2, 2, 3, 31, 5, 29, 7, 13, 23 ],
  { 3, 7, 13, 23, 29, 47, 53, 71, 131, 149, 211, 223, 239, 449, 563, 733, 1087, 
1123, 1487, 1531 }>,

// no. 161
<3*x^6 + 3*x^5 + x^4 + x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 + 1/73*x - 124/73,
   x^2 - 1441/2399*x + 3892/2399],
  <x^3 + 3/2*x^2 + 1/2*x + 2, x^3 - 1/2*x^2 - 1/6*x - 2/3, 3/2*x^2 - 1/2*x + 1>,
  [ 5, 13, 2, 3 ],
  { 7, 11, 13, 17, 19, 83, 89 }>,

// no. 162
<2*x^6 - 2*x^5 - 2*x^4 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 - 13/17*x + 7/34,
   x^2 - 1706/3713*x + 1729/3713],
  <x^3 - x + 1, x^3 - x^2 - 1/2*x - 2, -x^2 + 1>,
  [ 2, 2, 11 ],
  { 13, 19, 59, 461 }>,

// no. 163
<2*x^6 + 2*x^5 - 2*x^4 + 3*x^3 + 3*x^2 + 2*x - 2, 2, [],
  [x^2 - 4*x + 2,
   x^2 + 13788/11233*x + 7746/11233],
  <x^3 - 3*x + 3/2, x^3 + x^2 - 1, -2*x^2 - 2*x + 1>,
  [],
  { 5 }>,

// no. 164
<-x^6 + 3*x^5 - 3*x^4 - 2*x^3 - x^2 + 3, 2, [],
  [x^2 - 21/13*x + 69/13,
   x^2 + 17259/17125*x + 26601/17125],
  <x^3 - 3*x^2 + 2*x + 2, x^3 + 5*x - 1, -2*x^2 + 4*x + 1>,
  [ 2, 2, 2, 3 ],
  { 5, 11, 19, 79 }>,

// no. 165
<-x^6 + x^5 - 2*x^3 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 + 36/229*x - 156/229],
  <x^3 - x^2 + 2*x + 1, x^3 - x - 2, x^2 - x + 1>,
  [ 5, 3 ],
  { 5, 7, 41, 127 }>,

// no. 166
<3*x^6 - 2*x^5 - x^4 + 2*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 - 2/3*x - 7/3,
   x^2 + 1400/2783*x - 6628/2783],
  <x^3 + 1/3*x^2 + 1/6*x + 1, x^3 - x^2 - 1/2*x - 1, -x^2 - 3/2*x>,
  [ 2, 2, 3, 11, 7, 7 ],
  { 11, 13, 19, 29, 31, 61, 71, 73, 353, 359, 449, 617, 659 }>,

// no. 167
<-2*x^6 + x^5 + x^4 - 2*x^3 - 2*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 22967/55513*x - 9647/55513],
  <x^3 - 1/2*x^2 - 2/3*x + 2/3, x^3 + 13/6*x - 11/12, 2*x^2 - 7/6*x - 4/3>,
  [ 2, 7, 5 ],
  { 5, 31, 59, 83 }>,

// no. 168
<3*x^6 + x^5 - 2*x^3 + x^2 + 2, 2, [],
  [x^2 + x - 1,
   x^2 + 314/311*x + 31/311],
  <x^3 + 1/3*x^2 + 2/3*x - 2/3, x^3 - x - 1, x^2 + 2*x>,
  [ 3, 3, 3, 2, 11, 5 ],
  { 3, 11, 17, 37, 43, 61, 113, 197, 359, 659 }>,

// no. 169
<2*x^6 - 3*x^5 - 2*x^4 - x^2 - 2*x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 4516540/806633*x + 193572/47449],
  <x^3 - 3/2*x^2 - 3/4*x - 9/8, x^3 - 3/8*x + 17/16, -1/2*x^2 + x - 5/8>,
  [ 2, 3, 7, 13, 2, 11, 5, 31 ],
  { 3, 5, 11, 17, 41, 59, 61, 83, 127, 151, 193, 269, 307, 311, 431, 509, 643, 
677, 719 }>,

// no. 170
<3*x^6 - 2*x^5 - 2*x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 - 2/3*x + 7/6,
   x^2 - 96/107*x + 171/214],
  <x^3 + 1/4*x + 1, x^3 - 2/3*x^2 - 1/3*x - 4/3, -1/2*x^2 + 1/2*x + 1>,
  [],
  { 11 }>,

// no. 171
<-x^6 + 3*x^5 + x^4 + x^2 - 2*x + 3, 2, [],
  [x^2 - 1/5*x - 3/5,
   x^2 - 94/29*x + 229/29],
  <x^3 - 1/2*x^2 - x + 1, x^3 - 5/2*x^2 - x - 3, 1/2*x^2 + x>,
  [ 3, 5, 2, 5, 2, 3, 19, 11 ],
  { 3, 5, 7, 11, 17, 19, 79, 149, 151, 233, 277, 619, 937 }>,

// no. 172
<3*x^6 + x^5 - x^4 + 2, 2, [],
  [x^2 - 19/13*x + 7/13,
   x^2 + 61/23*x - 527/184],
  <x^3 + 1/2*x^2 + 5/2*x - 7/2, x^3 - 1/6*x^2 - 17/6*x + 23/6, -1/2*x^2 - 9/2*x 
+ 13/2>,
  [ 3, 3, 3, 5, 2, 7, 31 ],
  { 5, 7, 11, 17, 23, 41, 53, 71, 83, 101, 137, 151, 293, 307, 379, 883, 953 }>,

// no. 173
<-3*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 22/133*x + 37/133],
  <x^3 - x^2 + 4/3*x - 1/3, x^3 + 2*x^2 + 2*x - 1, x^2 - 2*x + 2>,
  [],
  { 7 }>,

// no. 174
<3*x^6 + 2*x^5 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 + x - 1,
   x^2 - 1712/11451*x - 74111/137412],
  <x^3 - 2*x^2 - 36*x + 11, x^3 + 8/3*x^2 + x - 1, -11*x^2 - 12*x + 6>,
  [],
  { 13 }>,

// no. 175
<-3*x^6 + 3*x^5 + 2*x^3 + 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 14178/13909*x + 13101/13909],
  <x^3 - x^2 + 1/3*x + 1/3, x^3 - 3, -x^2 + 3*x>,
  [ 3 ],
  { 5, 17, 61 }>,

// no. 176
<3*x^6 + x^5 - x^4 + x^3 - 3*x^2 - x - 1, 2, [],
  [x^2 + 1/3*x + 1/3,
   x^2 + 863/1438*x + 773/1438],
  <x^3 - x^2 - 3/4*x - 1/2, x^3 + 4/3*x^2 - 1/3*x + 2/3, -5/2*x^2 - 1/2*x>,
  [],
  { 5 }>,

// no. 177
<3*x^6 + 3*x^5 - 3*x^4 + x^2 - x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 877/6911*x - 15061/6911],
  <x^3 - 5*x^2 + 4*x - 1, x^3 + 6*x^2 + 11/3*x + 2/3, -8*x^2 + x + 1>,
  [ 7, 41, 5, 13, 5 ],
  { 11, 17, 19, 37, 137, 197, 229, 307, 383, 997, 1823 }>,

// no. 178
<3*x^6 - 3*x^5 + x^4 + 2*x^2 + 2*x - 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 3041820/1556687*x + 10733553/12453496],
  <x^3 - 9/2*x^2 - 4*x - 4, x^3 + 7/2*x^2 + 4/3*x + 3/2, 15/2*x^2 + 9/2*x + 4>,
  [],
  { 73 }>,

// no. 179
<3*x^6 - x^5 - 2*x^4 + 2*x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 + 2/3*x - 1,
   x^2 - 6666/17797*x + 9411/17797],
  <x^3 - x + 2, x^3 - 1/3*x^2 - 1/3, -x^2 + 2*x>,
  [ 5 ],
  { 3, 17 }>,

// no. 180
<-3*x^6 + x^5 - x^4 - 3*x^3 + x^2 - 3*x + 3, 2, [],
  [x^2 - 1/4*x - 1/4,
   x^2 - 23750/18577*x + 1693/1429],
  <x^3 - x^2 + 6*x - 3, x^3 + 2/3*x^2 + 1/3*x + 1/3, 4*x^2>,
  [],
  { 13 }>,

// no. 181
<-3*x^6 - 3*x^4 - x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 + 8/7*x + 5/14,
   x^2 + 2*x + 17/6],
  <x^3 + x^2 + 2*x + 1, x^3 - x^2 + 1/3*x + 1/3, -x^2 + x>,
  [ 2, 3, 2, 11 ],
  { 5, 17, 19, 29, 131, 179 }>,

// no. 182
<-x^6 - 3*x^5 + 2*x^4 - 2*x^3 + 3*x^2 - 3*x - 1, 2, [],
  [x^2 + 4*x + 1,
   x^2 + 2/97*x + 725/1552],
  <x^3 - 3/5*x^2 + 16/5*x + 1, x^3 + 18/5*x^2 + 9/5*x + 2, 11/5*x^2 + 13/5*x + 
1>,
  [ 2, 3, 2, 5, 3, 7, 3, 19, 2, 11, 13 ],
  { 3, 7, 13, 23, 29, 83, 89, 113, 139, 181, 281, 347, 397, 523, 607, 821, 1109,
1193, 1283, 1997 }>,

// no. 183
<3*x^6 - 2*x^5 - 3*x^4 + 3*x^3 - 2*x^2 - 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 3599173/1999609*x + 4201717/1999609],
  <x^3 + 1/3*x^2 + x + 3, x^3 - x^2 - 2*x - 19/9, x^2 + 8/3*x + 4>,
  [ 2, 3, 13, 7, 2 ],
  { 5, 7, 41, 47, 109, 113, 163, 193, 263, 443 }>,

// no. 184
<3*x^6 - 2*x^5 - x^4 - x^2 + x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 4422229/4782207*x + 5772937/14346621],
  <x^3 - 2*x^2 + x - 4, x^3 + 4/3*x^2 + 7/12*x + 1/3, 3/2*x^2 + 7/2*x + 1>,
  [ 3, 5, 11, 2, 2, 2, 13 ],
  { 13, 17, 23, 31, 47, 79, 109, 181, 257, 379, 421 }>,

// no. 185
<-3*x^6 + 3*x^5 - 2*x^4 - x^3 + 3*x^2 - 3*x - 1, 2, [],
  [x^2 - 1/4*x + 1/4,
   x^2 + 4125/2212*x + 6065/6636],
  <x^3 - x^2 + 4/3, x^3 + 3/4*x + 1/4, -1/2*x^2 - 3/2*x>,
  [ 31, 7, 3, 2, 41, 2 ],
  { 5, 7, 19, 23, 37, 41, 61, 71, 97, 109, 127, 191, 293, 359, 373, 491 }>,

// no. 186
<-3*x^6 + x^5 - 2*x^4 + 3*x^2 + 2*x - 2, 2, [],
  [x^2 - 3/7*x + 1/7,
   x^2 - 3/7*x + 73/28],
  <x^3 + x^2 - 1, x^3 - 4/3*x^2 + 2*x - 1, -2*x + 1>,
  [],
  { 607 }>,

// no. 187
<3*x^6 + 3*x^5 + 2*x^4 + x^3 - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 5935/2101*x + 5617/2101],
  <x^3 + x^2 - 1/3*x + 1/3, x^3 - 2*x - 2, 3*x^2 + 2*x>,
  [ 2, 2, 7, 3, 19, 3, 17 ],
  { 5, 17, 53, 67, 71, 149, 173, 181, 193, 223, 257, 269, 367 }>,

// no. 188
<-x^6 - 3*x^5 + 2*x^3 + x^2 - 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 1321/442*x + 937/442],
  <x^3 - 1/2*x^2 - 2*x + 2, x^3 + 7/2*x^2 + 4*x + 11/2, -1/2*x^2 - 1/2*x + 3>,
  [ 3, 5, 3 ],
  { 3, 11, 41, 53, 113 }>,

// no. 189
<-2*x^6 + 3*x^5 + x^4 - x^3 - x^2 + 3, 2, [],
  [x^2 - x - 1,
   x^2 + 1180/5617*x - 1928/5617],
  <x^3 - x^2 + 3*x + 3, x^3 - 1/2*x^2 + 1/2*x - 1/2, 3*x^2>,
  [],
  { 7 }>,

// no. 190
<3*x^6 + 2*x^4 - 2*x^3 + 3*x^2 - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 9/13*x + 3/13],
  <x^3 - x^2 - 1/3*x + 2/3, x^3 + x^2 - x - 2, -3*x^2 + 1>,
  [ 2, 3, 2, 11, 5 ],
  { 5, 7, 41, 89, 109, 173, 347, 421 }>,

// no. 191
<-3*x^6 - 3*x^5 - x^4 - x^3 - x^2 + 3*x + 2, 2, [],
  [x^2 - 1/4*x - 1/2,
   x^2 - 331/523*x + 1193/2092],
  <x^3 + x^2 + 2*x + 1, x^3 - 1/3*x - 1/3, -2*x^2 + 1>,
  [ 3, 5, 7, 5 ],
  { 5, 17, 23, 29, 41, 43, 53, 167, 191, 197, 311, 811 }>,

// no. 192
<-x^6 + 2*x^5 - 3*x^4 + 2*x^3 + x^2 + 3*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 31925/124933*x + 101723/124933],
  <x^3 - 3/2*x^2 + 9/8*x + 13/8, x^3 - 1/2*x^2 + 9/8*x - 11/8, -15/8*x - 7/8>,
  [ 3, 2, 7 ],
  { 5, 41, 109, 191, 937 }>,

// no. 193
<2*x^6 - 2*x^4 + x^2 - 3*x - 2, 2, [],
  [x^2 - x - 1,
   x^2 - 903/743*x + 513/743],
  <x^3 + 2*x^2 + 4*x - 11, x^3 - 2*x^2 - 11/2*x + 9, -3*x^2 - 7*x + 14>,
  [],
  { 3 }>,

// no. 194
<-2*x^6 + x^4 - 2*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 4/9*x + 13/18,
   x^2 - 464/2419*x + 12112/7257],
  <x^3 + 4/3*x^2 + 2*x + 1, x^3 - 4/3*x^2 - 1/2*x + 2, -2/3*x^2 + 2*x + 1>,
  [ 2, 2, 2, 5, 47, 19 ],
  { 7, 13, 17, 19, 43, 211, 599, 709, 857, 863 }>,

// no. 195
<3*x^6 + 2*x^5 - 3*x^4 - 3*x^3 - x^2 - x - 3, 2, [],
  [x^2 + x + 3,
   x^2 - 1333/1846*x + 4453/7384],
  <x^3 + x^2 - x - 3, x^3 - 1/3*x^2 - x + 4/3, -2*x^2 - x + 3>,
  [ 2, 2, 2, 5 ],
  { 3, 5, 13 }>,

// no. 196
<-x^6 + x^5 + 3*x^4 + 2*x^3 + 3*x^2 - 3*x + 2, 2, [],
  [x^2 + 1,
   x^2 - 532/255*x - 56/45],
  <x^3 - 3*x^2 + 13/4*x - 1/2, x^3 + 2*x^2 - 4, -1/2*x^2 - 4*x + 2>,
  [ 2, 11, 19, 2, 3, 17, 5, 3 ],
  { 7, 11, 19, 23, 37, 41, 61, 109, 383, 389, 409, 433 }>,

// no. 197
<-x^6 + x^5 + 3*x^4 + 2*x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 + 1,
   x^2 - 15708/5713*x + 63977/28565],
  <x^3 - 3/2*x^2 - 2*x - 3/2, x^3 + 1/2*x^2 - 2, -1/2*x^2 + 5/2*x + 1>,
  [ 2, 2, 3, 11, 5, 37, 7 ],
  { 3, 5, 11, 13, 47, 61, 107, 199, 317, 353, 503, 593, 757, 1193, 1409 }>,

// no. 198
<-x^6 + x^5 + 3*x^4 + 2*x^3 + x^2 - 2*x + 3, 2, [],
  [x^2 - x - 3,
   x^2 - 205549/414301*x - 367671/414301],
  <x^3 - x^2 - 19/8*x - 23/8, x^3 - 3/8*x + 1/8, -1/2*x^2 + 3/8*x - 13/8>,
  [ 2, 2, 2, 5, 3, 7 ],
  { 3, 17, 29, 131, 157, 293, 367, 389 }>,

// no. 199
<3*x^6 - 3*x^5 - 2*x^4 - x^3 + 2*x^2 - x - 3, 2, [],
  [x^2 + x - 4,
   x^2 - 236015/293701*x - 3038017/2349608],
  <x^3 - 3/2*x^2 - 2*x - 2, x^3 + 1/2*x^2 + 4/3*x + 7/6, 3/2*x^2 + 7/2*x + 2>,
  [],
  { 11 }>,

// no. 200
<-x^6 - x^5 + x^4 - x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 + 2*x + 2,
   x^2 + 2/5*x + 2/5],
  <x^3 - 1/2*x^2 - x + 1, x^3 + 3/2*x^2 + x + 3, 1/2*x^2 + x>,
  [ 2, 5, 2, 7 ],
  { 3, 5, 41, 43, 61, 103, 197 }>,

// no. 201
<-3*x^6 - 3*x^5 + 3*x^4 - 3*x^3 - x - 2, 2, [],
  [x^2 + 3*x + 6,
   x^2 - 78807/95947*x + 218614/287841],
  <x^3 + 2*x^2 + 3/4*x + 3/4, x^3 - x^2 + 1/3*x + 1, -1/2*x^2 - 2*x - 1/2>,
  [ 2 ],
  { 5, 31 }>,

// no. 202
<-3*x^6 - 3*x^5 + 3*x^4 - x^3 + 3*x^2 - x - 2, 2, [],
  [x^2 + 3/4*x + 1/4,
   x^2 + 11659/17356*x + 15153/17356],
  <x^3 - x^2 - 1/4*x + 1/2, x^3 + 2*x^2 + 4/3*x + 4/3, -1/2*x^2 + x>,
  [ 3, 29, 7, 5, 2, 3, 11, 17, 2, 13, 2 ],
  { 5, 7, 23, 31, 37, 47, 61, 83, 109, 131, 137, 139, 157, 173, 197, 317, 373, 
433, 461, 599, 619, 769, 809, 929, 1019, 1277, 1447, 1459 }>,

// no. 203
<2*x^6 + 3*x^5 - 3*x^4 - x - 3, 2, [],
  [x^2 - 8*x + 103/7,
   x^2 - 2354/2329*x + 1393/2329],
  <x^3 + 3/2*x^2 - x + 3/2, x^3 - x - 1, x^2 + x>,
  [ 5, 2, 2, 3, 7, 13 ],
  { 3, 5, 13, 17, 29, 61, 71, 79, 107, 131, 137, 239, 307 }>,

// no. 204
<-3*x^6 - x^5 - 2*x^4 + 2*x^3 + 3*x^2 + x + 2, 2, [],
  [x^2 + 1,
   x^2 + 32026/62103*x - 134111/434721],
  <x^3 - 1/4*x^2 + 21/4*x - 7/4, x^3 + 7/12*x^2 - 11/12*x - 7/12, 13/4*x^2 + 
3/4*x - 9/4>,
  [ 3, 7 ],
  { 5, 7, 13, 37, 83 }>,

// no. 205
<-3*x^6 + 2*x^5 + 3*x^3 + 3*x^2 + x - 1, 2, [],
  [x^2 + 1,
   x^2 - 1777/889*x + 698/889],
  <x^3 - 7/6*x^2 + 1/6*x - 1/3, x^3 + 1/2*x^2 + 1/2*x - 1, 1/2*x^2 - 5/2*x>,
  [ 2, 5, 3, 2, 13, 3, 7 ],
  { 3, 5, 11, 13, 19, 29, 283, 353, 397, 439, 487 }>,

// no. 206
<2*x^6 - 2*x^5 - x^3 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 326/281*x + 5833/2248],
  <x^3 - x + 3/2, x^3 - x^2 - x - 1, -2*x^2 + x>,
  [ 3, 3, 13, 17, 2, 7, 5, 11, 19 ],
  { 5, 7, 11, 19, 37, 53, 67, 71, 73, 97, 107, 131, 151, 167, 173, 193, 263, 
277, 433, 439, 1013, 1733 }>,

// no. 207
<3*x^6 + 2*x^5 - x^4 - 3*x^3 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 1/2,
   x^2 - 1062/253*x + 3477/1012],
  <x^3 + 2/3*x^2 - 5/6*x + 2/3, x^3 + 1/2*x - 2, -3/2*x + 1>,
  [ 2, 2, 2, 2, 7, 3, 19, 3, 3, 17 ],
  { 11, 17, 19, 23, 53, 71, 113, 127, 151, 173, 239, 317, 457, 919, 941 }>,

// no. 208
<-3*x^6 + 3*x^4 + 3*x^2 - x + 3, 2, [],
  [x^2 - 1/2*x + 3/2,
   x^2 - 1149/1586*x + 1199/1586],
  <x^3 + 1/2*x^2 - 1/2*x + 1, x^3 - 1/2*x^2 - 1/6*x - 1, -1/2*x^2 - 1/2*x>,
  [ 3, 2, 2, 3, 5, 7 ],
  { 5, 11, 29, 31, 53, 59, 109, 179, 727, 739 }>,

// no. 209
<-2*x^6 - 3*x^5 - 2*x^4 + 3*x^3 - 3*x + 3, 2, [],
  [x^2 + x + 2/3,
   x^2 + 107713443/194026043*x - 46858038/194026043],
  <x^3 - x^2 + 8*x - 4, x^3 + 5/2*x^2 + 13/8*x - 1/8, -7/2*x^2 - 9/2*x + 2>,
  [ 7, 3, 2, 3, 17, 2, 23, 5 ],
  { 13, 17, 37, 43, 47, 73, 79, 101, 127, 137, 181, 227, 379, 601, 677, 839, 929
}>,

// no. 210
<3*x^6 + 3*x^5 + 3*x^4 + 2*x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 418/683*x - 558766/458293],
  <x^3 + 5/2*x^2 + 4*x + 2, x^3 - 3/2*x^2 - 4/3*x + 1/2, -5/2*x^2 - 9/2*x>,
  [],
  { 19 }>,

// no. 211
<-x^6 + 3*x^5 + 2*x^4 - 2*x^3 - 3*x^2 - 3, 2, [],
  [x^2 - 15/26*x + 7/13,
   x^2 + 137/394*x + 247/197],
  <x^3 - x^2 - 4*x - 4, x^3 - 2*x^2 + x - 1, x^2 + 1>,
  [ 11, 17, 5, 7, 3, 19 ],
  { 5, 7, 19, 29, 31, 37, 47, 53, 59, 79, 107, 227, 349, 727 }>,

// no. 212
<-2*x^6 + x^5 - 2*x^3 - x + 2, 2, [],
  [x^2 - 1/3,
   x^2 + 1346/2721*x + 937/2721],
  <x^3 - 3/2*x^2 + 3/2*x + 1/2, x^3 + x^2 - 1, -2*x + 1>,
  [ 3, 3, 2, 3, 7, 5 ],
  { 5, 13, 17, 67, 103, 173, 191, 197, 269, 293, 337, 509, 571, 947 }>,

// no. 213
<3*x^6 - 2*x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - 9/11*x - 21/22,
   x^2 - 3521/3386*x + 47989/40632],
  <x^3 + 1/3, x^3 - 3*x - 3, 3*x^2 + x>,
  [ 2, 2, 3, 19, 3, 3, 13, 7, 5 ],
  { 5, 13, 19, 73, 79, 83, 97, 107, 127, 227, 293, 569, 1049, 1091, 1181, 1217 
}>,

// no. 214
<-3*x^6 + 3*x^5 - 3*x^4 - x^3 - x + 3, 2, [],
  [x^2 + 1/4*x - 1/2,
   x^2 - 154/3499*x - 7451/10497],
  <x^3 + x + 1, x^3 - x^2 + 4/3*x - 1, -2*x^2 + x>,
  [ 7, 19, 5 ],
  { 5, 7, 13, 19, 23, 97, 107, 173, 181 }>,

// no. 215
<-3*x^6 - x^5 - 2*x^4 - x^3 + x^2 + 3*x + 2, 2, [],
  [x^2 - x + 2,
   x^2 - 593290/2113153*x + 297767/301879],
  <x^3 + 3/2*x^2 + 43/16*x + 23/16, x^3 - 7/6*x^2 + 1/16*x + 31/48, -x^2 + 
31/16*x + 35/16>,
  [ 3, 2, 2, 5, 2, 2, 17 ],
  { 3, 7, 11, 53, 67, 71, 97, 173 }>,

// no. 216
<-x^6 - x^5 + 3*x^4 + x^3 - x^2 - 2, 2, [],
  [x^2 + 2*x + 2,
   x^2 + 678/629*x + 278/629],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 - x + 3, x^2 + x + 1>,
  [],
  { 11 }>,

// no. 217
<2*x^6 + 3*x^5 + 2*x^4 - x^2 - x - 3, 2, [],
  [x^2 - 2*x + 3,
   x^2 - 404/1057*x + 948/1057],
  <x^3 + 4/7*x^2 - x - 3, x^3 + 13/14*x^2 + 1/2, 12/7*x^2 + 2*x>,
  [ 2, 3, 7, 5, 13, 41, 11, 43, 17 ],
  { 3, 5, 11, 13, 23, 37, 41, 43, 73, 97, 107, 193, 251, 269, 317, 353, 479, 
701, 751, 839, 937, 941, 1039, 1163, 1531, 1949 }>,

// no. 218
<3*x^6 - 3*x^5 + 2*x^3 + 3*x^2 + 3*x + 2, 2, [],
  [x^2 - 1/3,
   x^2 + 417868/325141*x + 83713/325141],
  <x^3 + 5/2*x^2 - 3*x - 7/2, x^3 - 7/2*x^2 - 7/3*x + 23/6, -13/2*x^2 + x + 
13/2>,
  [ 3, 3, 2, 3, 11, 23, 7, 2, 41, 13 ],
  { 5, 7, 11, 17, 37, 41, 103, 211, 223, 251, 281, 331, 787, 863, 1123, 1637, 
1999 }>,

// no. 219
<3*x^6 - 3*x^5 + 3*x^3 - 3*x^2 + x - 3, 2, [],
  [x^2 - 1/2*x - 7/2,
   x^2 + 170/4033*x - 23257/12099],
  <x^3 + x^2 + 2/3*x + 1, x^3 - 2*x^2 + x - 1, x^2 + 2*x>,
  [ 7, 3, 2 ],
  { 5, 23, 29, 37 }>,

// no. 220
<-2*x^6 + x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 5265/3251*x + 16409/13004],
  <x^3 + 2*x^2 + x - 1/2, x^3 - 2*x^2 + 5*x - 2, -2*x^2 - 3*x + 1>,
  [ 3, 3, 2, 2, 5, 2, 2, 17, 7, 11 ],
  { 3, 11, 23, 29, 31, 37, 53, 59, 67, 131, 139, 167, 173, 179, 191, 239, 251, 
313, 353, 773 }>,

// no. 221
<-3*x^6 - 2*x^5 - 3*x^4 + 3*x^3 + 2*x^2 - x + 3, 2, [],
  [x^2 + 1/6*x + 1/4,
   x^2 + 10939/49658*x + 59579/99316],
  <x^3 + 2*x^2 + 11/4*x - 3/2, x^3 - 4/3*x^2 + x + 2/3, 1/2*x^2 - 9/2*x>,
  [ 3, 2, 5, 17, 2 ],
  { 3, 5, 13, 17, 31, 43, 73, 83, 421, 1051, 1321 }>,

// no. 222
<-3*x^6 + 2*x^5 + 2*x^4 + 2*x^3 + 3*x - 3, 2, [],
  [x^2 - 9/7*x + 4/7,
   x^2 + 1639/1533*x + 133/219],
  <x^3 + 1/2*x^2 + 2*x - 2, x^3 - 7/6*x^2 - 1/2, 5/2*x^2 - 5/2*x>,
  [ 2, 2, 2, 3, 7, 3, 17 ],
  { 5, 17, 23, 29, 43, 131, 157, 179, 347, 1307, 1399 }>,

// no. 223
<-x^6 - 3*x^5 - x^4 - 3*x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 + x + 6,
   x^2 + 177873/271753*x + 322278/271753],
  <x^3 + x^2 - x + 3, x^3 + 2*x^2 + 9/4*x + 11/4, -3/2*x^2 - x - 5/2>,
  [ 7, 3 ],
  { 19, 41, 139 }>,

// no. 224
<3*x^6 - 3*x^5 + 3*x^4 + 2*x^3 - 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 10947323/33135299*x - 26650213/33135299],
  <x^3 + 4, x^3 - x^2 + 1/4*x - 1/3, 3/2*x^2 - 3*x + 1>,
  [ 2, 2, 3, 11, 5, 13 ],
  { 11, 17, 19, 37, 43, 47, 53, 67, 73, 179, 293, 409, 569, 947 }>,

// no. 225
<2*x^6 - 2*x^5 - 2*x^4 - 2*x^3 + 3*x - 3, 2, [],
  [x^2 - 37/31*x + 1,
   x^2 - 7439/2993*x - 16171/2993],
  <x^3 + x^2 - 2*x + 1, x^3 - 2*x^2 - 3/2*x - 3/2, -3*x^2 + x>,
  [ 2, 2, 7, 3, 5 ],
  { 17, 19, 29, 37, 61, 101, 107, 139 }>,

// no. 226
<3*x^6 - x^5 - 3*x^4 + x^3 - 3*x^2 + 3*x + 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 13025063/1691834*x + 15152017/1691834],
  <x^3 + 2*x^2 + 4, x^3 - 7/3*x^2 + 19/12*x - 1/6, 5/2*x^2 - 4*x + 2>,
  [ 2, 2 ],
  { 3, 11 }>,

// no. 227
<-3*x^6 + 3*x^5 + x^4 - 2*x^3 + 3*x^2 - 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 88784740/68810047*x + 59944301/206430141],
  <x^3 - 2/3*x^2 + 25/9*x + 26/9, x^3 - 1/3*x^2 - 26/27*x + 17/27, -8/3*x^2 - 
13/9*x + 19/9>,
  [ 2, 2, 3, 2, 3, 2, 2, 2, 2, 17, 7, 23 ],
  { 7, 11, 17, 31, 43, 71, 113, 151, 191, 223, 239, 263, 283, 673, 769 }>,

// no. 228
<-2*x^6 + 3*x^5 + 2*x^4 - x^2 + x - 1, 2, [],
  [x^2 - 7/3*x + 5/3,
   x^2 + 3*x + 13/3],
  <x^3 - 1/2*x^2 + 1/2*x - 1/2, x^3 - x^2 - 1, -2*x^2 + x>,
  [ 2, 3, 3, 5, 11 ],
  { 13, 41, 43, 47, 71, 107, 401, 421, 761 }>,

// no. 229
<-x^6 - x^5 + x^4 + 2*x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 23/13*x + 57/52],
  <x^3 + x^2 - x - 2, x^3 + x - 1, x^2>,
  [ 11, 3, 3, 2, 2, 5, 13, 17, 7, 19 ],
  { 3, 5, 11, 13, 17, 29, 53, 67, 83, 131, 227, 313, 487, 523, 541, 641, 691, 
1619, 2693, 2861, 3209, 4373 }>,

// no. 230
<3*x^6 - x^5 - 2*x^4 - 3*x^3 + 2*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 272457/272341*x + 280813/272341],
  <x^3 - 1/2*x^2 - 2, x^3 + 1/6*x^2 - 2/3*x + 5/6, 1/2*x^2 - 1/2*x + 2>,
  [ 2, 2, 3, 3, 11, 41, 5, 43, 2, 7, 3, 17 ],
  { 3, 11, 13, 43, 71, 107, 167, 191, 193, 211, 251, 263, 311, 353, 379, 487, 
719, 883, 967, 1213, 1373, 1429, 1511, 1559, 1861, 1951 }>,

// no. 231
<-3*x^6 - 2*x^5 - 2*x^4 + x^3 + 2*x^2 - 2*x - 1, 2, [],
  [x^2 + x + 5,
   x^2 + 88/193*x + 89/772],
  <x^3 + 1/2*x^2 + x + 1, x^3 + 1/6*x^2 + 1/3*x + 1/3, 3/2*x^2 + 2*x>,
  [ 2, 5, 3, 2, 7, 2, 5 ],
  { 3, 5, 17, 41, 61, 79, 107, 151, 181, 277, 379, 409 }>,

// no. 232
<3*x^6 - 3*x^5 - x^3 - 3*x^2 + 3*x - 2, 2, [],
  [x^2 - 1/2*x + 1/6,
   x^2 - 1227/766*x + 1809/766],
  <x^3 - 2*x^2 + 5*x + 9, x^3 + x^2 - 6*x - 19/3, 3*x^2 - 10*x - 13>,
  [ 2, 2, 3, 29, 7, 23, 5 ],
  { 7, 19, 83, 107, 181, 197, 199, 239, 353, 383, 431, 449, 937, 1259, 1297, 
1307, 1499 }>,

// no. 233
<-2*x^6 + 2*x^4 + 2*x^3 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 - x + 3,
   x^2 + 2006363/1912369*x + 18442257/7649476],
  <x^3 - 1/4*x - 1/4, x^3 + 75/8*x - 33/8, 9/2*x^2 - 3/4*x - 1/4>,
  [],
  { 37 }>,

// no. 234
<-3*x^6 + x^5 - 2*x^4 + 3*x^3 + x^2 + 3*x + 3, 2, [],
  [x^2 - x + 2,
   x^2 - 1348/481*x + 1396/481],
  <x^3 + 3/4*x + 3/4, x^3 - 1/3*x^2 - 4/3, -1/2*x^2 - 1/2*x>,
  [ 2, 2, 5, 3, 3, 2 ],
  { 7, 19, 37, 79, 97, 113, 199, 263, 383 }>,

// no. 235
<-2*x^6 + x^5 + 3*x^3 + 3*x^2 - x - 2, 2, [],
  [x^2 - 3/2*x + 3/2,
   x^2 + 3*x + 3],
  <x^3 + 1/2*x^2 - 1/2*x - 1/2, x^3 - x^2 + x - 2, x>,
  [ 2, 2, 3, 7, 23, 11, 3, 5, 41 ],
  { 5, 7, 13, 17, 19, 47, 59, 67, 97, 137, 229, 257, 349, 367, 467, 479, 521, 
523, 613, 643, 677, 683, 1447, 1571, 1907 }>,

// no. 236
<-3*x^6 - 3*x^5 + 2*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 14223643/15987607*x + 58731853/47962821],
  <x^3 + x^2 + 7/4*x + 1/2, x^3 + 7/3*x + 2/3, 7/2*x^2 + 3/2*x + 2>,
  [],
  { 53 }>,

// no. 237
<2*x^6 + x^5 + 3*x^4 - 3*x^3 + 3*x^2 - x + 3, 2, [],
  [x^2 - 3/2*x + 1,
   x^2 + 2132/1241*x - 1244/1241],
  <x^3 - x^2 + 2*x - 1, x^3 + 3/2*x^2 + 1/2*x - 1, -x^2 + 2*x + 1>,
  [ 2, 3, 37, 5, 7, 3, 31, 19, 3 ],
  { 3, 5, 11, 13, 19, 41, 61, 97, 131, 157, 239, 257, 269, 373, 647, 827 }>,

// no. 238
<-x^6 - 2*x^5 + 3*x^4 + 3*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 + 12/17*x + 21/17,
   x^2 + 3456/3653*x + 1029/3653],
  <x^3 + 2*x^2 + x + 1, x^3 + 5*x + 4, 3*x^2 + 3*x + 1>,
  [ 2, 2, 3, 3, 13 ],
  { 5, 7, 17, 47, 71, 73, 239, 271, 397 }>,

// no. 239
<-2*x^6 - 3*x^5 - 3*x^4 - 3*x^3 + 3*x^2 + 2*x + 3, 2, [],
  [x^2 + 1/3*x - 1,
   x^2 + 16/57*x - 428/513],
  <x^3 + 2*x^2 + 2*x + 2, x^3 - 1/2*x^2 + 1/2*x - 1/2, x + 1>,
  [ 2, 2, 3, 19, 5 ],
  { 3, 5, 11, 13, 17, 19, 23, 181, 271, 419 }>,

// no. 240
<2*x^6 + 2*x^5 - 3*x^3 - 2*x - 3, 2, [],
  [x^2 + 2*x + 2,
   x^2 + 1468/713*x + 796/713],
  <x^3 + 1/2*x + 1, x^3 + x^2 - x - 2, -x^2 + x + 1>,
  [ 5, 2, 2, 2, 2 ],
  { 3, 61, 83, 347 }>,

// no. 241
<-2*x^6 + 3*x^5 + 3*x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 + 1/2*x + 2,
   x^2 + 305/198*x + 74/99],
  <x^3 - x^2 + 3/4*x - 7/4, x^3 - 1/2*x^2 - 9/8*x - 7/8, -1/2*x^2 + 3/4*x - 
1/4>,
  [ 3, 3, 3, 2, 2, 43, 11 ],
  { 5, 11, 13, 19, 53, 61, 67, 79, 101, 127, 167, 173, 271, 277, 409, 857, 1021 
}>,

// no. 242
<-x^6 + 2*x^5 + 2*x^4 - x^2 + 3*x - 2, 2, [],
  [x^2 - x + 6/5,
   x^2 - 1029/269*x + 33318/11029],
  <x^3 + 1/4*x - 1/2, x^3 - 2*x^2 + 4*x - 4, -5/2*x^2 + x>,
  [ 2, 2, 7, 3 ],
  { 3, 17, 83, 113, 127, 229 }>,

// no. 243
<-2*x^6 - 3*x^5 + 3*x^4 + 3*x^3 + x^2 - 3*x + 3, 2, [],
  [x^2 + 7/2*x + 11/3,
   x^2 - 35/22*x + 1],
  <x^3 + 1/2*x^2 - 3/2*x + 1, x^3 + x^2 - 1, x^2 + 1>,
  [ 3, 5, 2, 2, 31, 7, 2, 17 ],
  { 5, 17, 23, 29, 31, 67, 83, 127, 137, 263, 293, 353, 373, 409, 641, 659, 661 
}>,

// no. 244
<3*x^6 - x^5 + x^4 - 2*x^3 + 2*x^2 - x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 41/39*x + 37/117],
  <x^3 + 2*x^2 + x + 1, x^3 - 7/3*x^2 - 13/3*x - 4, 5*x^2 + 4*x + 3>,
  [ 2, 13, 17, 3, 3, 5, 29, 2 ],
  { 5, 7, 11, 13, 19, 53, 59, 61, 67, 97, 101, 103, 239, 269, 431, 557, 643, 977
}>,

// no. 245
<-x^6 + 2*x^4 - 2*x^3 - x^2 - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 3*x + 3],
  <x^3 + x^2 + 1, x^3 - x^2 + 3, x^2 + x>,
  [ 3, 3, 5, 5, 2, 2, 11, 13, 31, 7, 17 ],
  { 7, 19, 23, 29, 47, 53, 71, 97, 103, 137, 163, 167, 241, 277, 389, 563, 577, 
787, 877 }>,

// no. 246
<-2*x^6 - 2*x^5 - 2*x^4 - x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 - 8/9*x + 22/9,
   x^2 - 4224/11953*x + 20014/11953],
  <x^3 - x^2 + 2/3*x + 2, x^3 + 2*x^2 + 7/3*x - 1/2, 10/3*x + 1>,
  [ 5, 7, 2, 19, 2, 3, 3, 2 ],
  { 7, 11, 17, 37, 43, 47, 53, 61, 229, 409, 971 }>,

// no. 247
<3*x^6 + 3*x^5 - 3*x^4 + 2*x^3 - 2*x^2 - x + 3, 2, [],
  [x^2 + 1,
   x^2 + 239/83*x - 61/83],
  <x^3 - x^2 + x + 1, x^3 + 2*x^2 - 3*x + 2/3, -3*x^2 + 3*x + 1>,
  [ 3, 5 ],
  { 17, 59, 79, 547 }>,

// no. 248
<3*x^6 + x^5 - x^4 + 2*x^3 - 3*x^2 + 3, 2, [],
  [x^2 - x - 1,
   x^2 + 7830/29293*x + 25197/29293],
  <x^3 + 3/2*x^2 + 2*x + 1, x^3 - 7/6*x^2 - 14/3*x - 1/3, 7/2*x^2 + 4*x + 2>,
  [ 11, 2, 2, 2 ],
  { 5, 7, 19, 113, 197 }>,

// no. 249
<3*x^6 + x^5 - 3*x^4 - 2*x^3 - 3*x^2 - 2*x - 1, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 596/517*x + 200/517],
  <x^3 + 7/3*x^2 + 4/3*x + 2/3, x^3 - 2*x^2 + x - 1, 2*x^2 + 1>,
  [],
  { 449 }>,

// no. 250
<2*x^6 - 3*x^5 - 2*x^4 + 2*x^3 + 3*x^2 + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 541/46*x + 2879/184],
  <x^3 + 1/2*x^2 - 1, x^3 - 2*x^2 - 2*x - 1, -2*x^2 - 2*x + 1>,
  [ 2, 3, 2, 43, 3 ],
  { 7, 19, 23, 47, 61, 67, 83, 191, 461 }>,

// no. 251
<-x^6 + x^5 + x^4 + 3*x^3 - 2*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 59/61*x + 57/61],
  <x^3 - x - 3, x^3 - x^2 - 1, x>,
  [ 2, 19, 37, 7, 13, 5, 43, 2, 2, 3 ],
  { 3, 5, 13, 19, 67, 71, 103, 107, 113, 163, 233, 239, 263, 421, 563, 569, 571,
683, 761, 809, 821 }>,

// no. 252
<-3*x^6 - 3*x^5 + x^4 - 3*x^3 + 3*x^2 - 2*x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 16781161/14876167*x + 37145457/59504668],
  <x^3 - 3/4*x^2 - x + 3, x^3 + 7/4*x^2 + 2*x + 2/3, -1/4*x^2 + 7/2*x + 2>,
  [ 2, 2, 3, 11, 13, 5, 29, 3 ],
  { 11, 13, 17, 29, 31, 47, 53, 59, 61, 79, 89, 103, 137, 167, 367, 467, 503, 
547, 593 }>,

// no. 253
<-3*x^6 - 3*x^5 + x^4 - x^3 + x^2 - x - 2, 2, [],
  [x^2 + 509/604*x + 249/302,
   x^2 + 37/28*x + 113/14],
  <x^3 - x^2 + 1, x^3 + 2*x^2 + 5/3*x + 1, 2*x + 1>,
  [ 2, 2, 5, 3, 23, 13, 11, 7, 19 ],
  { 5, 7, 13, 43, 53, 67, 71, 137, 139, 151, 157, 163, 239, 241, 263, 271, 277, 
389 }>,

// no. 254
<2*x^6 - x^5 - 2*x^4 - 3*x^3 - 2, 2, [],
  [x^2 + 3*x + 3,
   x^2 + 1436/1033*x + 1164/1033],
  <x^3 - 3*x^2 + 7*x + 9, x^3 + 5/2*x^2 - 17/2*x - 19/2, 4*x^2 - 11*x - 13>,
  [ 3, 5, 7, 7 ],
  { 11, 17, 19, 37, 53, 83, 89, 103, 107, 137, 307 }>,

// no. 255
<3*x^6 - 2*x^5 - x^4 + x^3 - 2*x^2 + x - 2, 2, [],
  [x^2 - 2*x + 3/2,
   x^2 - 18/11*x + 89/121],
  <x^3 + 1/3*x^2 - 1/3*x + 1, x^3 - x^2 - 1, x^2 + 1>,
  [ 11, 5, 3, 2 ],
  { 5, 13, 73, 83, 97, 647, 661, 991 }>,

// no. 256
<-2*x^6 - 3*x^5 + x^4 - 2*x^3 + x^2 - 2*x - 2, 2, [],
  [x^2 + 7/3*x + 1,
   x^2 - 33681/50371*x + 50259/50371],
  <x^3 + 2*x^2 + 3*x + 3, x^3 - 1/2*x^2 - 5/2*x + 9/2, x + 5>,
  [ 3 ],
  { 3, 7, 13 }>,

// no. 257
<-2*x^6 - x^5 - x^4 - 3*x^3 + 3*x^2 + x - 1, 2, [],
  [x^2 + 5/2*x + 5,
   x^2 - 49/38*x + 97/209],
  <x^3 + 1/2*x^2 + 3/2*x + 1, x^3 - x + 1, x + 1>,
  [],
  { 73 }>,

// no. 258
<3*x^6 + 3*x^5 + 2*x^4 + 2*x^3 + 3*x^2 - x + 3, 2, [],
  [x^2 + 1,
   x^2 + 538/1739*x - 4213/1739],
  <x^3 - 2*x^2 - 3*x + 2, x^3 + 3*x^2 + 4/3*x + 1/3, -5*x^2 - 3*x + 1>,
  [ 2, 2, 5, 5, 2, 2, 7, 3, 19 ],
  { 7, 19, 37, 47, 97, 197, 199, 307, 313, 421, 487, 563, 809, 1223 }>,

// no. 259
<2*x^6 + 3*x^3 + x - 3, 2, [],
  [x^2 - x + 3,
   x^2 + 176649/189271*x - 268831/189271],
  <x^3 + 5*x^2 + 4*x + 3/2, x^3 - 5*x^2 + 3*x - 1, 6*x^2 + x>,
  [ 2, 2, 5, 7, 3 ],
  { 3, 5, 11, 13, 29, 41, 43, 47, 67, 73, 83, 139 }>,

// no. 260
<-3*x^6 + 2*x^5 - x^4 + x^3 + x^2 + 3*x + 2, 2, [],
  [x^2 + 1,
   x^2 + 250134/353989*x + 193393/353989],
  <x^3 - 5/2*x^2 + 21/4*x + 7/4, x^3 + 11/6*x^2 + 7/4*x + 7/12, -5/2*x^2 - 
19/4*x - 9/4>,
  [ 2, 2, 2 ],
  { 5, 7, 17 }>,

// no. 261
<-x^6 + 3*x^5 + 3*x^4 + 3*x^3 - x^2 - 2*x - 2, 2, [],
  [x^2 + 4/5*x + 2/5,
   x^2 - 27/5*x + 121/20],
  <x^3 - 5/2*x^2 - 2*x - 3, x^3 - 1/2*x^2 - 1, 3/2*x^2 + 1>,
  [ 2, 2, 3, 29, 5, 2 ],
  { 53, 67, 83, 101, 107, 113, 199, 443, 613, 823, 967 }>,

// no. 262
<-2*x^6 + 2*x^5 - x^4 + x^3 - x^2 - 3*x + 3, 2, [],
  [x^2 + 3/2,
   x^2 + 20/17*x + 148/17],
  <x^3 - 2/3*x^2 - 1/2*x + 1, x^3 - 1/3*x^2 + x - 1, -2/3*x^2 + 1>,
  [ 3, 3, 5, 2, 2, 5, 11, 7, 13 ],
  { 5, 19, 23, 43, 73, 83, 101, 193, 197, 241, 281, 307, 359, 439, 593, 1439, 
1601, 1697, 1871, 3163, 3851 }>,

// no. 263
<-2*x^6 + x^5 - 3*x^4 + 3*x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 + 1/2*x + 1,
   x^2 - 208/73*x + 328/73],
  <x^3 + x^2 + 2*x + 1, x^3 - 3/2*x^2 + 3/2*x + 1, x^2 + 2*x + 1>,
  [ 2, 3, 13 ],
  { 13, 17, 19, 31, 43, 61 }>,

// no. 264
<3*x^6 - x^4 - 2*x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 - 3*x - 3,
   x^2 + 3573/166*x + 10089/664],
  <x^3 - x^2 - x + 2, x^3 + x^2 - 4/3*x - 1, -3*x^2 + x + 2>,
  [ 2, 3, 7, 3, 3, 2 ],
  { 11, 13, 17, 29, 37, 41, 139, 367, 613, 709, 983 }>,

// no. 265
<2*x^6 - 3*x^5 + 3*x^4 - 2*x^3 + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 19/14*x + 73/112],
  <x^3 + 1/2*x^2 - 1/2*x - 1/2, x^3 - 2*x^2 + 3*x - 3, 2*x>,
  [ 2, 2, 3, 5, 11, 2, 41, 13, 19 ],
  { 5, 7, 11, 13, 23, 47, 53, 113, 179, 181, 239, 257, 311, 313, 419, 787, 1231,
1753 }>,

// no. 266
<2*x^6 + x^5 + 3*x^4 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 - 1/7*x + 1,
   x^2 + 6/31*x - 61/31],
  <x^3 + x^2 + 1, x^3 - 1/2*x^2 + 3/2*x - 3/2, -x^2 + x>,
  [ 2, 3, 13, 5, 7, 23, 11, 41, 11 ],
  { 43, 47, 59, 101, 139, 163, 211, 263, 317, 379, 461, 547, 593, 661, 719, 
1213, 1433, 1823 }>,

// no. 267
<-3*x^6 - 2*x^5 + 3*x^4 + 3*x^2 + x + 3, 2, [],
  [x^2 - 1/2*x + 3/4,
   x^2 + 138065/127022*x + 102567/254044],
  <x^3 + 3*x^2 + 2*x - 1, x^3 - 7/3*x^2 + 7*x + 2/3, -3*x^2 - 8*x + 1>,
  [ 2, 3 ],
  { 3, 5, 11, 31 }>,

// no. 268
<-3*x^6 + 3*x^5 + x^4 - 3*x^3 - x^2 - 3*x - 2, 2, [],
  [x^2 - 1/4*x + 3/2,
   x^2 + x + 3/4],
  <x^3 - x^2 + 1, x^3 + x + 1, -2*x^2 + 1>,
  [],
  { 29 }>,

// no. 269
<-2*x^6 - x^5 + x^4 - 2*x^3 - 2*x^2 - x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 9815/7929*x + 69833/71361],
  <x^3 - 2*x^2 + 5*x + 2, x^3 + 5/2*x^2 + 3/2*x - 1/2, 2*x^2 + 5*x>,
  [ 11, 23, 13, 5, 3, 2, 7, 2 ],
  { 5, 7, 11, 53, 59, 107, 109, 173, 179, 197, 223, 257, 263, 277, 307, 389, 
431, 439 }>,

// no. 270
<3*x^6 + x^5 - x^4 - 3*x^3 - 2*x^2 - 2*x - 2, 2, [],
  [x^2 + 4/3*x + 1,
   x^2 + 36680/19113*x + 23944/19113],
  <x^3 + 4*x^2 - 2*x + 2, x^3 - 11/3*x^2 - 1, 7*x^2 - 2*x + 2>,
  [ 3, 3 ],
  { 7, 13, 19, 89 }>,

// no. 271
<2*x^6 + 2*x^5 - 3*x^4 - x^3 - x^2 + x - 3, 2, [],
  [x^2 + x + 4,
   x^2 - 2835926/3109289*x + 2183833/3109289],
  <x^3 + 2*x^2 - 1/4*x + 3/4, x^3 - x^2 - 19/8*x - 19/8, 5/2*x^2 + 9/4*x + 3/4>,
  [ 2, 3, 5, 41, 2, 31, 3, 7 ],
  { 7, 17, 19, 31, 43, 73, 83, 101, 107, 113, 197, 251, 311, 449, 577, 1151, 
1187 }>,

// no. 272
<-3*x^6 - 2*x^5 + 2*x^4 - x + 3, 2, [],
  [x^2 + 1/2*x - 1,
   x^2 + 90/343*x - 4043/5488],
  <x^3 + x^2 + x + 2, x^3 - 1/3*x^2 - 1/3, -2*x^2 - x + 1>,
  [ 3 ],
  { 3, 17, 31 }>,

// no. 273
<3*x^6 + 2*x^5 - 3*x^4 - x^3 + 2*x^2 + 3*x - 1, 2, [],
  [x^2 - 2*x + 1/2,
   x^2 + 31/2*x - 73/8],
  <x^3 - 3/2*x + 1, x^3 + 2/3*x^2 + 1/2*x - 1/3, -3/2*x>,
  [ 2, 2, 2, 2, 19, 7, 3, 29, 5 ],
  { 19, 31, 37, 83, 97, 113, 293, 331, 347, 383, 661, 827, 1217, 1307, 1879, 
2053, 3061, 3671 }>,

// no. 274
<2*x^6 - 3*x^5 + x^4 - x^2 - 2*x - 2, 2, [],
  [x^2 - 2*x - 2,
   x^2 - 35/47*x - 249/188],
  <x^3 + 1/2*x^2 + x + 1, x^3 - 2*x^2 - 1, x^2 + 2*x>,
  [ 5, 3, 13, 7, 7, 17, 3, 2, 43, 11, 31 ],
  { 3, 5, 7, 29, 43, 61, 67, 73, 89, 103, 113, 181, 193, 233, 311, 313, 487, 
563, 587, 733, 773, 967, 1097, 1193, 1667, 1999 }>,

// no. 275
<-3*x^6 - x^5 + x^4 + 3*x^2 + x - 2, 2, [],
  [x^2 + 1,
   x^2 + 255/1544*x + 10657/12352],
  <x^3 - x^2 + 3/4*x - 1/2, x^3 + 4/3*x^2 + x - 2, 3/2*x^2 - 5/2*x + 1>,
  [],
  { 5 }>,

// no. 276
<-x^6 - 3*x^5 + x^4 + 3*x^3 + 3*x^2 - 2*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 20867269/12787801*x + 41182981/12787801],
  <x^3 + 13/5*x^2 + 13/5*x + 7/5, x^3 + 2/5*x^2 - 16/5*x + 12/5, -6/5*x^2 + 
1/5*x - 3/5>,
  [ 2, 3, 11 ],
  { 3, 17, 23, 127, 653 }>,

// no. 277
<-x^6 - 2*x^5 - 2*x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 + 3*x + 9/5,
   x^2 + 74/29*x + 41/29],
  <x^3 - x + 1, x^3 + 2*x^2 + 2*x + 3, x^2 + 1>,
  [ 7, 3, 13, 11, 3, 2 ],
  { 3, 7, 13, 17, 37, 41, 43, 61, 67, 79, 113, 263, 271 }>,

// no. 278
<2*x^6 + x^5 + 2*x^4 - 3*x^3 - 3*x^2 - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 135535/190241*x + 252353/190241],
  <x^3 - 1/2*x^2 - 2, x^3 + x^2 + 3/2*x + 5/4, 3/2*x + 2>,
  [ 2, 5, 19 ],
  { 3, 7, 29, 37, 41, 53, 101, 223, 593 }>,

// no. 279
<2*x^6 - 3*x^5 - 3*x^4 - 2*x^2 - 2, 2, [],
  [x^2 - 4*x - 6,
   x^2 - 11892/13447*x + 17798/13447],
  <x^3 - 2*x^2 + 3*x + 9, x^3 + 1/2*x^2 - 11/2*x - 19/2, -2*x^2 + 6*x + 13>,
  [ 2, 2, 5, 11, 13, 3, 7 ],
  { 3, 5, 11, 61, 71, 89, 179, 199, 271, 503, 523, 571, 857 }>,

// no. 280
<-3*x^6 - 2*x^5 + 2*x^4 - 2*x^3 - 2*x^2 - 2*x + 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 361/182*x + 23/26],
  <x^3 - 1/3*x^2 + 2/3, x^3 + x^2 + x - 1, -2*x^2 + x>,
  [ 3, 5, 2 ],
  { 3, 5, 13, 23, 31, 47 }>,

// no. 281
<-3*x^6 - x^5 + 3*x^4 - 2*x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 + 1,
   x^2 - 7149/8006*x + 57073/64048],
  <x^3 - 3/4*x^2 - 7/4*x + 7/4, x^3 + 13/12*x^2 + 25/12*x + 31/12, -5/4*x^2 - 
1/4*x + 13/4>,
  [ 7, 3, 5, 5 ],
  { 3, 5, 7, 29, 53, 59, 83 }>,

// no. 282
<2*x^6 - x^5 - x^4 - 2*x^3 - 3*x^2 + 2*x - 1, 2, [],
  [x^2 + 2*x + 2,
   x^2 - 308/113*x - 2813/452],
  <x^3 + 2*x^2 + x + 1, x^3 - 5/2*x^2 + 3/2*x - 1/2, -2*x^2 + x>,
  [ 2, 2, 2, 7 ],
  { 3, 11, 37 }>,

// no. 283
<3*x^6 + 3*x^5 + 3*x^4 + 2*x^3 - 2*x^2 + 3*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 307/13*x - 3473/104],
  <x^3 - x + 1, x^3 + x^2 + 5/3*x + 2/3, x^2>,
  [],
  { 5 }>,

// no. 284
<-x^6 + 3*x^5 + 2*x^4 + 3*x^3 + 3*x - 3, 2, [],
  [x^2 - 15/17*x + 4/17,
   x^2 - 283/709*x + 508/709],
  <x^3 - 4*x^2 + 3*x - 3, x^3 + x^2 - 1, x^2 + x>,
  [ 3, 3, 5, 2, 2 ],
  { 11, 19, 23, 79, 163, 269, 307, 349 }>,

// no. 285
<3*x^6 + 3*x^5 + 3*x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 - 7/13*x - 2/13,
   x^2 + 691/1979*x - 1346/5937],
  <x^3 + 3/2*x^2 - 4/3*x - 4/3, x^3 - 1/2*x^2 + 2*x - 1/2, -1/2*x^2 + 5/2*x + 
1>,
  [ 2, 3, 29, 47, 2, 2, 2, 17, 13, 31, 37, 19, 7 ],
  { 5, 7, 11, 13, 29, 37, 41, 43, 101, 107, 149, 173, 181, 223, 347, 383, 389, 
521, 613, 821, 853, 919 }>,

// no. 286
<-x^6 - x^5 + x^4 - 3*x^3 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 1/2*x - 1,
   x^2 + 3968/2225*x - 2288/2225],
  <x^3 - 3/2*x^2 + 3/2*x + 1, x^3 + 5/2*x^2 + 3/2*x - 3, 1/2*x^2 - 7/2*x>,
  [ 3, 5, 2, 2, 3, 3, 3, 23, 13, 7 ],
  { 5, 7, 19, 41, 67, 71, 83, 101, 113, 127, 151, 233, 269, 547, 701, 773, 883, 
991 }>,

// no. 287
<2*x^6 + 3*x^5 - 3*x^4 + x^3 - 3*x^2 + 3, 2, [],
  [x^2 + 2*x - 1,
   x^2 + 61126/148079*x + 5449/148079],
  <x^3 + 7/2*x^2 - 4*x - 2, x^3 - 2*x^2 + 3/2*x - 3/4, 4*x^2 - 5/2*x>,
  [],
  { 23 }>,

// no. 288
<3*x^6 + 2*x^5 - 3*x^3 - 2*x^2 - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 2215/2257*x + 11653/9028],
  <x^3 + 3, x^3 + 2/3*x^2 - 4/3*x - 4/3, -2*x^2 + 2*x + 3>,
  [],
  { 13 }>,

// no. 289
<-x^6 + x^5 + 3*x^4 + 2*x^3 + x^2 - x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 8813/3965*x + 40769/31720],
  <x^3 - 3/2*x^2 - 3/2, x^3 + 1/2*x^2 - 2, 3/2*x^2 - 1/2*x + 1>,
  [ 3, 5 ],
  { 41, 47 }>,

// no. 290
<-x^6 + 3*x^5 - 2*x^4 + 3*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 3*x + 3,
   x^2 + x + 7/9],
  <x^3 - x^2 + x - 4, x^3 - 2*x^2 - 1, x^2 - 2*x + 1>,
  [ 3, 7 ],
  { 13, 41, 109 }>,

// no. 291
<3*x^6 - x^5 - 2*x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 39/61*x + 9/61],
  <x^3 + x^2 - 3/4*x - 3, x^3 - 4/3*x^2 + 4/3, -5/2*x^2 + 3>,
  [ 2, 5, 2 ],
  { 5, 11, 37, 43, 311 }>,

// no. 292
<3*x^6 + x^5 - x^4 - 2*x^3 - x^2 - 3, 2, [],
  [x^2 + 21/13*x + 42/13,
   x^2 - 39/193*x + 42/193],
  <x^3 + 7/3*x^2 - 2*x + 1, x^3 - 2*x^2 - 2*x - 1, 5*x^2>,
  [ 2, 13 ],
  { 5, 11, 13, 19, 89 }>,

// no. 293
<-2*x^6 - x^5 - x^3 - 2*x^2 - 3*x + 2, 2, [],
  [x^2 + 1/6*x + 1/6,
   x^2 + 3499694/11077939*x + 33313417/33233817],
  <x^3 + 5*x^2 + 24*x + 7, x^3 - 9/2*x^2 + 13/2*x + 1, -4*x^2 + 17*x + 4>,
  [],
  { 19 }>,

// no. 294
<3*x^6 + 3*x^5 + x^4 - x^3 - 3*x^2 + x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 90423/4682*x + 157761/4682],
  <x^3 + 1/2*x^2 - 2/3*x + 1/2, x^3 + 1/2*x^2 - 2, -3/2*x^2 - 3/2*x + 1>,
  [],
  { 17 }>,

// no. 295
<-x^6 + x^5 - 3*x^4 - 2*x^3 + x^2 - x + 3, 2, [],
  [x^2 + 1,
   x^2 + 2535580/4826093*x - 2721027/4826093],
  <x^3 - 2*x^2 + 13/2*x - 11/4, x^3 + x^2 - 1/2*x - 3/4, x^2 + x - 9/4>,
  [],
  { 5 }>,

// no. 296
<2*x^6 + 3*x^4 + 2*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 3/2,
   x^2 + 80/673*x + 208/673],
  <x^3 + 3/2*x + 2, x^3 - 2/9*x - 13/9, -2/3*x^2 - 2/3*x - 5/3>,
  [ 2, 2, 13, 7, 5, 3, 11, 5 ],
  { 7, 19, 23, 29, 37, 59, 67, 79, 101, 137, 151, 167, 227, 283, 337, 467, 499 
}>,

// no. 297
<-2*x^6 + 2*x^5 + 3*x^4 + 2*x^3 - x - 2, 2, [],
  [x^2 - x + 1/2,
   x^2 + 626/1609*x + 1577/1609],
  <x^3 - 2*x^2 + 1/2*x - 1/2, x^3 + x^2 + 2*x - 3, 2*x^2 - 3*x + 1>,
  [],
  { 13 }>,

// no. 298
<-3*x^6 - x^5 + x^4 - x^3 + 2*x^2 - 2*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 567289/1667847*x - 11986759/11674929],
  <x^3 - x^2 + x + 7/4, x^3 + 4/3*x^2 + 4/3*x + 7/12, -2*x^2 - 3/2*x - 9/4>,
  [ 2, 3, 7, 5, 11, 13, 3 ],
  { 11, 19, 37, 41, 53, 67, 79, 149, 157, 167, 173, 229, 271, 421, 821, 1069, 
1627 }>,

// no. 299
<-2*x^6 + 3*x^5 - x^4 - 3*x^3 + x^2 - 2*x - 1, 2, [],
  [x^2 - 1/3*x + 1/3,
   x^2 + 943/1779*x + 425/1779],
  <x^3 - 3/2*x^2 + 2, x^3 + 1/2*x + 1/4, -1/2*x>,
  [],
  { 3 }>,

// no. 300
<-2*x^6 + x^5 - 2*x^4 - 2*x^3 - x^2 + x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 4135/20737*x - 5511/20737],
  <x^3 + 1/6*x^2 + 1/6*x + 1/2, x^3 - 2/3*x^2 + 7/3*x - 2, -5/3*x^2 + 4/3*x + 
1>,
  [ 3, 3, 29, 2, 7, 13, 2, 3, 2, 23, 5 ],
  { 5, 13, 19, 29, 41, 47, 79, 97, 101, 107, 131, 137, 149, 151, 163, 173, 193, 
347, 433, 449, 653, 727, 1123, 1481, 1523 }>,

// no. 301
<2*x^6 - x^5 - 2*x^4 + 3*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 - 2,
   x^2 - 1620/2009*x - 6134/2009],
  <x^3 + 7/2*x^2 + 2*x + 1, x^3 - 4*x^2 + 3*x - 2, 4*x^2 + 1>,
  [ 2, 3 ],
  { 5, 11 }>,

// no. 302
<-2*x^6 - 3*x^5 + 2*x^4 - x^3 - 3*x^2 - 2*x + 3, 2, [],
  [x^2 + 20/9*x + 26/9,
   x^2 - 212/2937*x - 362/979],
  <x^3 + 1/2*x^2 + 2, x^3 + x^2 + 1/2*x - 3/4, -2*x^2 - 1/2*x>,
  [ 3, 3, 13, 5, 7 ],
  { 11, 31, 89, 113, 257, 317 }>,

// no. 303
<3*x^6 - 3*x^5 - 2*x^4 + 2*x^3 - x^2 - 2, 2, [],
  [x^2 - 2,
   x^2 + 116112/154873*x + 222646/464619],
  <x^3 - 3/4*x + 3/4, x^3 - x^2 - 4/3, -1/2*x^2 - 3/2*x + 1>,
  [ 2, 7, 11 ],
  { 7, 13, 23, 53, 61, 71 }>,

// no. 304
<-3*x^6 - 2*x^5 - 3*x^3 + 2*x^2 - x + 2, 2, [],
  [x^2 + x - 1/2,
   x^2 + 135/91*x + 31/182],
  <x^3 + x^2 + 1, x^3 - 1/3*x^2 + 1/3*x - 1/3, 1>,
  [ 3, 3, 2, 5, 3, 2, 2, 17 ],
  { 3, 5, 7, 11, 23, 73, 89, 109, 163, 239, 311 }>,

// no. 305
<3*x^6 + 3*x^5 - x^4 - x^2 - 2, 2, [],
  [x^2 + x + 1/3,
   x^2 - 318/143*x - 1137/143],
  <x^3 + x^2 + 2/3*x + 2, x^3 - x - 1, 2*x + 2>,
  [ 2, 5, 3, 7, 2, 31 ],
  { 5, 7, 17, 19, 29, 47, 71, 79, 101, 227, 599, 673, 887, 937, 947, 1031, 1439 
}>,

// no. 306
<-3*x^6 + x^5 - 3*x^4 + x^3 - x + 3, 2, [],
  [x^2 - 23/19*x + 26/19,
   x^2 - x + 66/547],
  <x^3 - 1/4*x^2 + x - 1, x^3 - 1/12*x^2 + 2/3, -1/4*x^2 + 1/2*x + 1>,
  [ 2, 2, 2 ],
  { 11, 19, 47 }>,

// no. 307
<2*x^6 - 2*x^5 - 3*x^4 + 3*x^3 - 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 2*x - 7,
   x^2 - 703972/367241*x + 104404/52463],
  <x^3 - 6*x^2 - 3*x - 1, x^3 + 5*x^2 + 7*x + 7/2, 7*x^2 + 8*x + 2>,
  [ 2, 2, 3, 3, 7, 2, 2 ],
  { 11, 19, 23, 29, 41, 73, 89, 101, 227, 281, 457 }>,

// no. 308
<3*x^6 - x^5 - 2*x^4 - x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 + 5/3*x + 4/3,
   x^2 - 363691/344891*x + 300604/344891],
  <x^3 + x^2 + 5/4*x + 1, x^3 - 4/3*x^2 - 4/3*x - 4/3, 3/2*x^2 + 3*x + 1>,
  [ 2, 2, 2, 3, 13, 11, 2, 5, 7, 2, 23, 17, 19 ],
  { 5, 13, 17, 19, 23, 31, 53, 67, 73, 107, 113, 137, 191, 239, 257, 419, 739, 
773, 809, 911, 937, 947, 1181, 1453, 1583, 1951 }>,

// no. 309
<3*x^6 + 3*x^5 + x^4 + x^3 - 3*x^2 - x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 57/26*x + 81/26],
  <x^3 + 3/2*x^2 + 3/2*x + 3, x^3 - 1/2*x^2 - 1/2*x - 1/3, -1/2*x^2 + 5/2*x + 
1>,
  [],
  { 47 }>,

// no. 310
<-3*x^6 + x^5 - 2*x^4 + 3*x^2 - 3*x - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 34668262/12852417*x + 26058209/12852417],
  <x^3 + 2*x^2 + 45*x + 22, x^3 - 7/3*x^2 + 2/3*x + 1, -11*x^2 + 11*x + 8>,
  [ 2, 3, 3, 7, 19, 37, 11, 5 ],
  { 11, 13, 17, 19, 29, 41, 47, 61, 71, 73, 83, 107, 113, 137, 271, 683, 911, 
977, 983, 1373 }>,

// no. 311
<-2*x^6 - 2*x^5 - 2*x^4 + x^3 + x + 3, 2, [],
  [x^2 - 2/3*x + 11/18,
   x^2 + 26/9*x + 419/54],
  <x^3 + 1/2*x + 1, x^3 + x^2 + x - 1, x^2 + x + 1>,
  [],
  { 7 }>,

// no. 312
<3*x^6 + x^5 + 2*x^4 - 2*x^3 - 2*x^2 - 3*x - 2, 2, [ 2 ],
  [x^2 + 1,
   x^2 - 5/22*x + 1],
  <x^3 + 1/3*x^2 + 1/3*x + 2/3, x^3 - x - 1, 2*x^2>,
  [ 2, 3, 2, 7, 5 ],
  { 5, 7, 11, 13, 23, 101, 379, 397, 677, 701 }>,

// no. 313
<3*x^6 + 2*x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 272351/74281*x + 759623/222843],
  <x^3 - 2*x^2 + 13/4*x - 1/2, x^3 + 2*x^2 - 4/3*x - 4/3, -5/2*x^2 + 4*x + 1>,
  [ 3, 3, 2 ],
  { 5, 11, 17, 23, 61 }>,

// no. 314
<3*x^6 + x^3 - 3*x^2 - 2*x - 2, 2, [],
  [x^2 - 2,
   x^2 - 4786/6827*x + 21169/20481],
  <x^3 + x^2 + 1/3, x^3 - x^2 - 2*x - 2, 3*x^2 + 2*x>,
  [ 7, 2, 2, 3, 5 ],
  { 5, 53, 83, 109, 179, 1217, 1277 }>,

// no. 315
<3*x^6 + x^3 - 3*x^2 - 2*x - 3, 2, [],
  [x^2 + x - 3,
   x^2 - 1662863/4407577*x - 8699331/4407577],
  <x^3 - 4*x^2 - 4*x + 12, x^3 + 4*x^2 - 4/3*x - 19/3, -8*x^2 - x + 15>,
  [ 3, 2, 3, 19, 2, 7, 5, 23 ],
  { 5, 11, 19, 73, 79, 109, 113, 131, 173, 181, 197, 479, 653, 719 }>,

// no. 316
<-3*x^6 - x^5 - x^4 - 3*x^3 + 2*x^2 - 2*x - 2, 2, [],
  [x^2 - 168/127*x + 162/127,
   x^2 - 42/97*x + 49/97],
  <x^3 + 4/3*x^2 + x + 1, x^3 - x^2 + x + 1, x^2 + 2*x + 1>,
  [],
  { 73 }>,

// no. 317
<-3*x^6 - 3*x^5 + x^3 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 + 97/52*x + 283/156,
   x^2 - 671/868*x + 1171/2604],
  <x^3 + 3*x - 3, x^3 + x^2 - 1/3, -3*x^2 + 1>,
  [ 7, 7 ],
  { 19, 31, 43, 73, 137, 283 }>,

// no. 318
<-3*x^6 - x^5 - 3*x^4 - 3*x^3 - x^2 + x + 2, 2, [],
  [x^2 - 5/4*x + 1/2,
   x^2 + 55/26*x + 289/208],
  <x^3 + x + 1, x^3 + 1/3*x^2 - 1/3, 1>,
  [ 2, 3, 23, 5, 13 ],
  { 3, 17, 19, 23, 31, 41, 59, 67, 79, 131, 137, 151, 181, 229 }>,

// no. 319
<3*x^6 + 3*x^5 - 3*x^4 - x^3 + 3*x^2 - 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 2*x + 89/88],
  <x^3 + 1/2*x^2 - 1/3*x + 1, x^3 + 1/2*x^2 - x - 1, 1/2*x^2 + x + 1>,
  [ 3, 7, 5, 11, 2 ],
  { 5, 7, 23, 59, 67, 83, 113, 193, 347, 1439, 1531, 1667 }>,

// no. 320
<-2*x^6 - 3*x^4 - x^3 - x^2 + 3*x + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 3062/13313*x + 10513/13313],
  <x^3 + 5*x + 2, x^3 - 3/8*x - 1/4, -5/2*x^2 - 1/2*x + 1>,
  [ 2, 2, 11, 13, 3, 5 ],
  { 7, 13, 17, 29, 41, 113, 617 }>,

// no. 321
<3*x^6 + 3*x^5 - 3*x^4 + 2*x^3 + 3*x^2 + 3*x - 1, 2, [],
  [x^2 + 2*x - 1,
   x^2 + 7838/781*x - 2141/781],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 - 1/3*x - 2/3, x^2 + 3*x + 1>,
  [ 3, 2, 19, 11, 5 ],
  { 7, 11, 13, 19, 31, 41, 47, 59, 103, 113, 137, 179 }>,

// no. 322
<-3*x^6 + 3*x^5 + 2*x^3 + x^2 + x - 1, 2, [],
  [x^2 + 5/4*x + 1/2,
   x^2 - 2749/1396*x + 4405/4886],
  <x^3 - x^2 - 1/4*x - 1/2, x^3 + x - 2/3, 3/2*x^2 - 3/2*x>,
  [ 2, 2, 3, 41, 17, 31, 3, 3, 7 ],
  { 5, 7, 13, 17, 19, 23, 59, 67, 71, 73, 157, 241, 313, 359, 541, 593, 859, 907
}>,

// no. 323
<-3*x^6 - x^5 + 3*x^2 - 3*x - 2, 2, [],
  [x^2 - x + 3/7,
   x^2 - 16211/41619*x + 5483/41619],
  <x^3 + 4/7*x^2 + 17/7*x + 22/7, x^3 - 5/21*x^2 - 16/21*x + 11/21, 15/7*x^2 + 
13/7*x - 12/7>,
  [],
  { 227 }>,

// no. 324
<-3*x^6 - 3*x^5 + 3*x^4 + 2*x^3 - 2*x^2 + 3*x + 2, 2, [],
  [x^2 + x + 1/3,
   x^2 + 16505/5281*x + 39673/15843],
  <x^3 + 2*x^2 + 3*x + 1, x^3 - x^2 + x - 2/3, 3*x^2>,
  [ 2, 3, 2, 2, 41, 5, 37, 7 ],
  { 5, 11, 13, 19, 41, 59, 97, 211, 263, 823, 983, 1061, 1259, 1367, 1459, 1699 
}>,

// no. 325
<2*x^6 + 3*x^5 + x^4 - 3*x^3 - 2*x^2 + x - 3, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 118891713/181270082*x - 363828357/181270082],
  <x^3 + x^2 - 7/4*x + 3, x^3 + 1/2*x^2 - 25/32*x - 7/8, 9/4*x^2 - 7/8*x - 3/2>,
  [ 2, 3, 2, 29, 17 ],
  { 3, 7, 13, 23, 29, 47, 53, 197, 241, 421 }>,

// no. 326
<2*x^6 + x^5 + x^4 + x^3 + 3*x^2 - x - 2, 2, [],
  [x^2 - x + 1,
   x^2 + 237/7*x - 249/7],
  <x^3 - 1/2*x^2 + 1/2*x + 1, x^3 + x^2 - 1, x^2>,
  [ 3, 3, 2, 13, 5, 11 ],
  { 5, 7, 17, 29, 31, 59, 67, 79, 97, 179, 193, 211, 389, 691 }>,

// no. 327
<-3*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - 2*x^2 - 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 85/157*x + 1621/157],
  <x^3 + x^2 + 3/4*x + 1/2, x^3 + x + 2/3, -3/2*x^2 - 3/2*x>,
  [ 2, 3, 5 ],
  { 5, 13, 29, 31, 43, 181 }>,

// no. 328
<-3*x^6 + 2*x^5 - 3*x^4 - 3*x^3 - x^2 + 3*x + 3, 2, [],
  [x^2 - 8/3*x + 11/3,
   x^2 - 1564/2263*x + 5063/2263],
  <x^3 - 1/4*x - 1/2, x^3 - 2/3*x^2 + 4/3*x + 4/3, -1/2*x^2 + 1>,
  [ 2, 2, 3, 7, 23, 5, 13, 7, 29 ],
  { 5, 7, 13, 23, 37, 43, 53, 61, 73, 83, 113, 137, 199, 229, 419, 569, 593, 
653, 659, 743, 839, 991, 1307, 1361, 1747 }>,

// no. 329
<-x^6 + 2*x^5 - 2*x^4 + 3*x^3 + 3*x^2 - 2, 2, [],
  [x^2 - x + 3/2,
   x^2 + 1169/1186*x + 4113/4744],
  <x^3 + 2/5*x^2 + 1/5*x - 19/5, x^3 - 12/5*x^2 + 14/5*x - 6/5, -1/5*x^2 + 
17/5*x - 8/5>,
  [ 3, 3, 2, 7, 5, 11, 31, 2, 23 ],
  { 3, 7, 13, 19, 29, 31, 53, 167, 229, 241, 263, 283, 409, 557, 647, 683, 1213,
1279, 1303 }>,

// no. 330
<-2*x^6 + 3*x^4 - x^3 + 3*x^2 + 2*x + 3, 2, [],
  [x^2 + x + 3/2,
   x^2 + 10/33*x + 25/33],
  <x^3 - 1/2*x + 3/2, x^3 - x - 1, 2*x>,
  [ 7, 5, 2, 2, 2, 11, 13 ],
  { 3, 5, 11, 13, 17, 23, 29, 139, 157, 347, 359, 593, 709, 857 }>,

// no. 331
<2*x^6 + 2*x^5 - x^4 - x^3 - 2*x^2 + 2*x - 3, 2, [],
  [x^2 + 2*x + 2,
   x^2 - 8930/7913*x + 15841/7913],
  <x^3 - 2/7*x^2 - 1/7*x - 3, x^3 + 9/7*x^2 - 5/14*x + 1/2, -6/7*x^2 - 17/7*x>,
  [ 3, 13, 19, 2 ],
  { 11, 37, 59, 71, 79, 163, 311 }>,

// no. 332
<2*x^6 + x^5 + 3*x^4 - 2*x^3 + 2*x + 2, 2, [],
  [x^2 - 3*x + 1,
   x^2 + 1171/199*x + 79/199],
  <x^3 + 1/2*x^2 - 3/2*x - 1/2, x^3 + x - 1, 2*x^2 + 1>,
  [],
  { 31 }>,

// no. 333
<3*x^6 - 2*x^4 - 2*x^3 + x^2 - x + 3, 2, [],
  [x^2 + x - 1,
   x^2 - 4/3*x - 11/36],
  <x^3 - 2*x^2 - 1, x^3 + 2*x^2 + 1/3*x - 1, 3*x^2 + x>,
  [ 2, 5, 3, 2, 13, 2 ],
  { 5, 11, 41, 97, 173, 211, 233, 379 }>,

// no. 334
<-3*x^6 + x^5 + x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 - 3/4*x + 1/4,
   x^2 + 6128293/20120359*x + 27641585/80481436],
  <x^3 + x^2 + 4*x - 17/4, x^3 - 4/3*x^2 + 1/3*x - 1/12, -3*x^2 + 9/2*x - 1/4>,
  [ 3, 3, 2, 13, 7, 11, 2, 5, 13, 29 ],
  { 3, 7, 11, 17, 23, 29, 53, 61, 79, 107, 113, 137, 173, 197, 229, 233, 317, 
331, 401, 787, 1187, 1279, 1721 }>,

// no. 335
<-x^6 - x^5 + 3*x^4 - x^3 - 2*x^2 - 2*x - 2, 2, [],
  [x^2 + 4/5*x + 6/5,
   x^2 + 1642/545*x + 1041/545],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 - x + 3, x^2 + 1>,
  [ 2, 41, 2, 11, 7 ],
  { 3, 13, 43, 149, 173, 463, 887 }>,

// no. 336
<3*x^6 - 3*x^5 - 3*x^4 + 3*x^3 - 2*x^2 + 3*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 30/13*x - 79/13],
  <x^3 - x + 1, x^3 - x^2 - 1, x>,
  [ 2, 3, 23, 2, 17 ],
  { 5, 7, 67, 71, 113, 233, 443, 1063, 1069 }>,

// no. 337
<-3*x^6 - x^5 + 3*x^4 + 2*x^2 - 2*x + 3, 2, [],
  [x^2 + 151/84*x + 13/28,
   x^2 - 222708/137617*x + 123892/137617],
  <x^3 - 5/4*x + 3/4, x^3 + 1/3*x^2 + 1/3*x - 1/3, -1/2*x^2 - 3/2>,
  [],
  { 11 }>,

// no. 338
<2*x^6 + x^5 + x^4 - x^3 + 3*x^2 - 2*x + 3, 2, [],
  [x^2 + 1,
   x^2 - 531/434*x - 421/1736],
  <x^3 + x^2 + 1, x^3 - 1/2*x^2 - x + 3/2, -2*x^2 + x>,
  [ 2, 2, 3, 17, 5 ],
  { 5, 7, 113, 191, 193, 311, 571 }>,

// no. 339
<-2*x^6 - x^5 + 2*x^4 + 3*x^3 - x^2 + 2*x - 1, 2, [],
  [x^2 - x + 1/3,
   x^2 - 4*x + 20],
  <x^3 - 1/2*x^2 + 1/2*x - 1/2, x^3 + x^2 + x - 1, 2*x^2>,
  [],
  { 13 }>,

// no. 340
<-x^6 + 3*x^5 + 3*x^4 - 2*x^2 - 2*x - 2, 2, [],
  [x^2 + 2*x + 2,
   x^2 + 1172534/1369253*x + 1556214/1369253],
  <x^3 + x^2 - 4, x^3 - 4*x^2 + 5/4*x - 3/4, 1/2*x^2 - 7/2*x + 1>,
  [ 3 ],
  { 11, 17 }>,

// no. 341
<-x^6 + 3*x^5 + 3*x^4 + x^3 + 3*x^2 - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 1/5*x + 1/20],
  <x^3 - 3*x - 3, x^3 - 3*x^2 + x - 1, x^2 + 3*x>,
  [ 2, 3, 19, 3, 7, 5, 2 ],
  { 11, 19, 47, 61, 83, 97, 113, 137, 193, 311, 653, 659, 733, 941 }>,

// no. 342
<-2*x^6 - 2*x^5 - x^4 + 3*x^3 - 2*x^2 - 2*x + 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 676/257*x + 1144/257],
  <x^3 + 15/11*x^2 + 8/11*x - 2, x^3 - 4/11*x^2 + 3/11*x + 1/2, -1/11*x^2 - 
13/11*x + 1>,
  [],
  { 7 }>,

// no. 343
<-3*x^6 - 3*x^5 + x^4 + x^3 - 3*x^2 + 3*x + 2, 2, [],
  [x^2 - x + 2,
   x^2 - 35311209/29031337*x + 14731234/29031337],
  <x^3 - 1/4*x - 1/4, x^3 + x^2 + 4*x + 4/3, -7/2*x^2 - 1/2*x + 1>,
  [ 2, 2, 3, 5, 7, 47, 19 ],
  { 11, 19, 41, 47, 53, 67, 109, 113, 131, 263, 337, 521, 569, 743, 787, 809, 
859, 919 }>,

// no. 344
<-2*x^6 + x^5 - 3*x^4 + x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 + 2,
   x^2 + 530/2777*x + 3525/2777],
  <x^3 - 5/2*x^2 + 4*x - 2, x^3 + 2*x^2 + 5/2*x - 1/4, -7/2*x + 2>,
  [],
  { 3 }>,

// no. 345
<-x^6 - x^5 + 2*x^4 - 2*x^3 - x^2 + 2*x - 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 18/25*x + 9/25],
  <x^3 - x + 1, x^3 + x^2 + 2, x^2>,
  [ 2, 3, 19, 7, 5 ],
  { 19, 41, 43, 47, 113, 163, 199, 521, 563, 617 }>,

// no. 346
<-x^6 - 3*x^5 + 3*x^4 - 2*x^3 - 2*x^2 - 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 + 16/15*x + 13/45],
  <x^3 - x + 1, x^3 + 3*x^2 + 7*x + 4, -3*x^2 + 1>,
  [ 3, 2, 5, 19, 3 ],
  { 7, 13, 17, 31, 47, 59, 71, 107, 137, 151, 157, 173, 179 }>,

// no. 347
<2*x^6 + 2*x^5 + x^4 - x^2 + x - 2, 2, [],
  [x^2 - x + 1,
   x^2 + 9063/8353*x + 9537/8353],
  <x^3 + 2*x^2 - 7/2*x + 3/2, x^3 - x^2 - 2*x - 1, -4*x^2 + 1>,
  [ 2, 3, 7, 2, 5 ],
  { 5, 11, 29, 31, 37, 101, 137, 263, 709 }>,

// no. 348
<-2*x^6 + 2*x^5 + 3*x^4 + 3*x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 56289084/62383081*x + 14602773/62383081],
  <x^3 - 4/3*x^2 + 11/3*x - 28/3, x^3 + 1/3*x^2 - 2*x - 3/2, -7/3*x^2 + 7/3*x + 
5>,
  [],
  { 139 }>,

// no. 349
<-2*x^6 - 3*x^5 - 2*x^4 - 3*x^3 + 3*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 467/562*x + 6169/6744],
  <x^3 + x^2 + 1, x^3 + 1/2*x^2 + 5/2*x + 2, 2*x^2 + 2*x + 1>,
  [],
  { 17 }>,

// no. 350
<2*x^6 - 2*x^5 - 3*x^4 - 3*x^3 + x^2 + x - 2, 2, [],
  [x^2 - x - 3,
   x^2 + 2489719/221833*x - 6389267/221833],
  <x^3 - 1/7*x^2 - 3/7*x + 3/7, x^3 - 6/7*x^2 - 9/7*x - 33/14, -3/7*x^2 + 2/7*x 
+ 1/7>,
  [ 2, 2, 2, 3, 5, 17 ],
  { 3, 11, 13, 17, 19, 37, 43, 59, 89, 107, 173, 281 }>,

// no. 351
<-x^6 - 2*x^5 + x^4 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 + 5*x + 13/2,
   x^2 + 29/26*x + 229/520],
  <x^3 + x^2 + 1, x^3 + x^2 - x + 4, -x^2 - 2*x + 1>,
  [ 2, 3, 2, 2, 2, 2, 5, 11 ],
  { 5, 11, 13, 23, 31, 53, 97, 127, 163, 223, 419, 719, 743, 809, 881 }>,

// no. 352
<-x^6 + 3*x^5 - 2*x^4 + 2*x^3 - 3*x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 153/218*x + 417/218],
  <x^3 - 5/2*x^2 + 3/2*x - 3, x^3 - 1/2*x^2 - 1/2*x - 1, 1/2*x^2 - 3/2*x + 1>,
  [],
  { 37 }>,

// no. 353
<3*x^6 + x^5 + x^4 + x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 1/2*x - 2,
   x^2 - 1047/854*x - 4478/2989],
  <x^3 + 3/2*x^2 + 2*x + 2, x^3 - 7/6*x^2 - 1/2, -1/2*x^2 - 7/2*x>,
  [ 2, 2, 2, 3, 2, 3, 19, 11 ],
  { 5, 11, 13, 31, 41, 53, 167, 173, 379, 659, 1033 }>,

// no. 354
<-2*x^6 + 3*x^5 - x^4 + x^3 + 2*x^2 + 3*x - 3, 2, [],
  [x^2 + x + 4,
   x^2 - 775/514*x + 1141/2056],
  <x^3 - 3/2*x^2 + 3/2*x - 2, x^3 + x - 1, 2*x^2 - 2*x + 1>,
  [ 2, 3, 7, 5, 5, 41 ],
  { 5, 7, 13, 41, 59, 83, 103, 127, 149, 197, 227, 683, 971, 977 }>,

// no. 355
<-2*x^6 + 3*x^5 - x^4 + 3*x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 - 3*x + 3,
   x^2 + 73/128],
  <x^3 - 1/2*x^2 - 1/2*x - 1/2, x^3 - x^2 + x - 4, -x^2 + 3*x + 1>,
  [],
  { 7 }>,

// no. 356
<-x^6 - x^5 + x^4 - 2*x^3 - 2*x^2 - x - 3, 2, [],
  [x^2 + 1,
   x^2 - 10/13*x + 1],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 + x + 4, x^2 + 2*x + 1>,
  [ 2, 2, 2, 7, 3, 7, 3, 2, 11, 5, 29 ],
  { 19, 29, 47, 89, 107, 109, 163, 229, 277, 307, 419, 467, 607, 653, 877, 887, 
1471, 1609, 1777 }>,

// no. 357
<-3*x^6 - 3*x^5 + 3*x^4 - x^3 - 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 170612/210283*x + 135532/630849],
  <x^3 + x^2 + 3/4*x + 1/2, x^3 - 5/3*x + 2, -1/2*x^2 - 3/2*x>,
  [ 2, 3, 5, 3, 2, 2, 13, 3, 7 ],
  { 13, 37, 43, 59, 61, 71, 103, 149, 157, 233, 467, 883, 971 }>,

// no. 358
<3*x^6 - 2*x^5 - 2*x^4 - 3*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 5108/37*x + 5968/37],
  <x^3 + 1/3*x^2 - 4/3*x + 4/3, x^3 - x^2 - 2*x - 1, -3*x^2 + x + 1>,
  [ 3, 7, 2, 2, 3, 2, 29, 19, 17, 5 ],
  { 5, 7, 11, 19, 53, 193, 197, 211, 241, 311, 331, 353, 449, 523, 647, 1543, 
1583, 1621 }>,

// no. 359
<3*x^6 + 2*x^4 + x^3 + 3*x^2 - 2*x - 2, 2, [],
  [x^2 - 2,
   x^2 + 22412/11891*x + 3138/1081],
  <x^3 + x^2 + 2/3*x + 1, x^3 - x^2 - 2*x - 2, 3*x^2 + 2*x + 2>,
  [ 2 ],
  { 5, 257 }>,

// no. 360
<-x^6 - 3*x^5 + x^4 + 2*x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 1732294/5171009*x + 5255721/5171009],
  <x^3 - 2*x^2 + 4, x^3 + 5*x^2 + 37/4*x + 19/2, -1/2*x^2 + 3*x + 6>,
  [ 3, 5, 11, 7, 19, 17, 2 ],
  { 3, 7, 13, 23, 29, 43, 53, 83, 101, 193, 239, 347, 401, 463 }>,

// no. 361
<-2*x^6 - 3*x^5 + 3*x^4 - 2*x^3 + 2*x^2 - 2*x - 3, 2, [],
  [x^2 + 7/3*x + 2,
   x^2 + 11770/15649*x + 22009/15649],
  <x^3 + 3*x^2 + 8*x + 4, x^3 - 3/2*x^2 - 1/2*x + 3/2, -3*x^2 + 3*x + 3>,
  [ 7, 3, 13 ],
  { 3, 5, 29, 31, 37 }>,

// no. 362
<-3*x^6 - x^5 + x^4 + 3*x^3 + 3*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 - 1397/2307*x + 1657/2307],
  <x^3 - 5/4*x^2 + x - 1, x^3 + 19/12*x^2 + 2/3*x - 2/3, -1/4*x^2 - 1/2*x + 1>,
  [ 3, 3, 5, 19, 2, 2, 7, 29, 3, 11 ],
  { 3, 5, 17, 23, 29, 61, 89, 137, 167, 211, 269, 311, 347, 593, 673, 953 }>,

// no. 363
<-3*x^6 + 3*x^5 + x^4 + x^3 + 3*x^2 + 2*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 35252741/45583801*x - 60151251/45583801],
  <x^3 + 7/4*x^2 + 5*x + 2, x^3 - 11/4*x^2 + 2*x - 1/3, -11/4*x^2 + 9/2*x + 1>,
  [ 2, 2, 3, 23, 13, 5, 3, 11, 7, 47 ],
  { 7, 11, 41, 53, 71, 73, 79, 89, 109, 113, 137, 139, 157, 181, 211, 223, 271, 
419, 661, 701, 739, 1447, 1619, 1979 }>,

// no. 364
<3*x^6 + 3*x^5 + 2*x^3 + x^2 + x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 293/676*x - 61/32],
  <x^3 + 2*x^2 + 5/3*x + 4/3, x^3 - x^2 - 1, x^2 + 3*x + 1>,
  [ 3, 3, 29, 5, 13, 2, 31 ],
  { 5, 19, 41, 59, 107, 109, 113, 173, 349, 359, 433, 1381, 1553 }>,

// no. 365
<-2*x^6 - x^5 + 3*x^4 - 3*x^3 - 3*x^2 - x - 1, 2, [],
  [x^2 - 1/3*x + 2/9,
   x^2 + 85/81*x + 50/81],
  <x^3 - 7/6*x^2 - 2/3*x + 17/6, x^3 + 5/3*x^2 + 7/6*x + 5/12, 1/3*x^2 - 13/6*x 
- 7/6>,
  [ 2, 5, 5, 3, 7, 47, 2, 2, 3 ],
  { 11, 13, 19, 29, 43, 47, 67, 83, 113, 277, 353, 383, 571, 719, 911, 937 }>,

// no. 366
<3*x^6 - 3*x^5 + x^3 + 3*x^2 - 3*x + 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 2848/37*x - 3716/37],
  <x^3 - 5/2*x^2 - 11/6*x - 1/3, x^3 + 3/2*x^2 + 3/2*x - 1, -7/2*x^2 - 7/2*x + 
1>,
  [ 2, 2, 11 ],
  { 5, 17, 41, 83, 101, 103 }>,

// no. 367
<2*x^6 + 2*x^5 - x^4 + x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 + 2*x - 2,
   x^2 + 3876/4319*x - 4924/4319],
  <x^3 + 3*x^2 + 4*x + 3, x^3 - 2*x^2 + x - 1/2, x^2 + 3*x>,
  [],
  { 89 }>,

// no. 368
<-3*x^6 + 3*x^5 + 3*x^4 - 3*x^3 + x^2 - 2*x - 1, 2, [],
  [x^2 - x + 1/3,
   x^2 + 25/19*x + 13/19],
  <x^3 - 7/4*x^2 + 1, x^3 + 3/4*x^2 + 1/3*x + 2/3, -1/4*x^2 - 1/2*x + 1>,
  [ 3, 7, 11, 2, 2, 3, 2 ],
  { 13, 17, 29, 43, 103, 439, 643, 751, 773, 823 }>,

// no. 369
<2*x^6 + x^5 - 3*x^4 + 2*x^3 + 2*x^2 + 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 1/14*x - 181/56],
  <x^3 + 1/2*x^2 - 4*x + 4, x^3 + 1/2*x - 1/4, 2*x^2 - 3/2*x + 1>,
  [ 11, 5, 7, 13, 3 ],
  { 5, 7, 23, 41, 71, 73, 181, 251, 743 }>,

// no. 370
<-3*x^6 + 3*x^5 - 3*x^4 - 2*x^3 - 3*x^2 + 2, 2, [],
  [x^2 + 1/4*x + 1/4,
   x^2 + 725559817/791676607*x + 5557113137/12666825712],
  <x^3 - 7/4*x^2 + 5*x + 1, x^3 + 3/4*x^2 + 5/6*x + 1/12, -13/4*x^2 - 5/4*x - 
3/2>,
  [ 3, 47 ],
  { 7, 59, 67, 103, 109, 163, 367, 929 }>,

// no. 371
<-3*x^6 + 2*x^5 + 2*x^4 - 3*x^3 - 2*x^2 - 3*x - 2, 2, [],
  [x^2 + 2*x + 3/2,
   x^2 + 4/3*x + 1/2],
  <x^3 - x^2 + 1, x^3 + 1/3*x^2 + x + 1, -2*x^2 + 1>,
  [ 3, 3, 2, 5, 3, 5, 7, 2, 2, 11, 13, 17 ],
  { 5, 23, 59, 67, 97, 127, 137, 139, 151, 233, 271, 277, 349, 439, 443, 449, 
643, 797, 929 }>,

// no. 372
<-3*x^6 - x^5 - 2*x^4 - 3*x^3 + 2*x^2 + x + 2, 2, [],
  [x^2 + 3/4*x + 1/4,
   x^2 - 2573591/4773019*x + 20086337/19092076],
  <x^3 - 8/3*x^2 + 15*x - 23/3, x^3 + 3*x^2 + 2*x - 1, -5*x^2 - 9*x + 5>,
  [ 7, 11 ],
  { 7, 11, 67, 79 }>,

// no. 373
<-3*x^6 + 2*x^5 - 2*x^4 + x^3 + 2*x^2 + x + 2, 2, [],
  [x^2 + 1/2,
   x^2 - 154/211*x + 17/422],
  <x^3 - x^2 + 1, x^3 + 1/3*x^2 + x - 1/3, 2*x + 1>,
  [ 5, 3 ],
  { 3, 5, 11, 23 }>,

// no. 374
<3*x^6 + 3*x^5 + 3*x^3 + 3*x^2 - 2*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 1191331/354803*x - 1447293/354803],
  <x^3 + 3/2*x^2 - 2*x + 3/2, x^3 - 1/2*x^2 - 4/3*x - 2/3, -7/2*x^2 - 1/2*x>,
  [ 2, 2, 7, 3, 5, 19 ],
  { 5, 7, 11, 19, 29, 41, 89, 277, 503, 643, 863, 1523 }>,

// no. 375
<2*x^6 + 3*x^5 - 3*x^4 + 3*x^3 + 2*x^2 + 2*x - 2, 2, [],
  [x^2 - 6*x + 3,
   x^2 - 3566/1897*x + 1387/1897],
  <x^3 + x^2 - 2*x + 3, x^3 + 1/2*x^2 - 1/2, 1>,
  [ 2, 2, 3, 7, 2, 2, 23, 3, 19 ],
  { 5, 11, 23, 61, 67, 71, 73, 89, 149, 263, 307, 347, 389, 587, 1061 }>,

// no. 376
<-3*x^6 + 2*x^5 + 2*x^4 + 3*x^2 + x - 3, 2, [],
  [x^2 + 41/74*x + 26/37,
   x^2 + 101/1022*x + 2/73],
  <x^3 + 1/2*x^2 + 3/2*x - 2, x^3 - 7/6*x^2 + 1/2*x - 2/3, 5/2*x^2 - 5/2*x + 1>,
  [ 3, 2, 11, 11 ],
  { 3, 7, 11, 13, 19, 127, 149, 271 }>,

// no. 377
<-2*x^6 + 3*x^5 - x^4 + 2*x^3 + 2*x^2 - 3*x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 268/137*x + 216/137],
  <x^3 - 1/6*x^2 - 7/6*x - 1/2, x^3 - 4/3*x^2 + 5/3*x - 2, 2/3*x^2 - 1/3*x>,
  [ 2, 3, 5, 7, 11, 13, 3, 31, 3 ],
  { 7, 17, 29, 31, 43, 67, 71, 73, 103, 127, 139, 181, 191, 193, 223, 263, 277, 
367, 379, 443, 479, 569, 619, 683, 809, 839, 1307, 1637, 1949 }>,

// no. 378
<-3*x^6 + x^5 - 3*x^4 - 2*x^3 - 2*x^2 - 3*x + 2, 2, [],
  [x^2 + 1,
   x^2 + 38316/482521*x + 615172/482521],
  <x^3 + 2*x^2 + 9*x + 2, x^3 - 7/3*x^2 + 2*x - 1/3, -4*x^2 + 6*x>,
  [ 3, 2, 13, 2, 5, 3, 2 ],
  { 3, 7, 19, 29, 67, 97, 103, 139, 271, 373 }>,

// no. 379
<-2*x^6 - 3*x^5 - 2*x^4 - 2*x^3 - 2*x + 2, 2, [],
  [x^2 + 5/3*x + 1/3,
   x^2 + 555/473*x - 799/1419],
  <x^3 + 3/2*x^2 + x + 1, x^3 + 2*x - 1, 2*x^2 + x>,
  [ 2 ],
  { 13, 53 }>,

// no. 380
<-2*x^6 + 2*x^4 - x^3 + 2*x^2 - 2*x - 3, 2, [],
  [x^2 - x + 1/3,
   x^2 + 235/411*x + 403/274],
  <x^3 + x^2 + 7/6*x + 1, x^3 - x^2 - 2/3*x + 2, x^2 + 2/3*x + 1>,
  [],
  { 5 }>,

// no. 381
<-x^6 + 3*x^5 - 3*x^4 + x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 - 3/2*x + 3/2,
   x^2 - 4/3*x + 8/9],
  <x^3 - x^2 - 3/4*x - 1/2, x^3 - 2*x^2 + 4*x - 4, -3/2*x^2 + 2*x>,
  [],
  { 37 }>,

// no. 382
<3*x^6 - 2*x^5 - x^4 - 3*x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 - 2/3*x + 1/3,
   x^2 - 112/47*x - 112/47],
  <x^3 - 2*x^2 + 3*x - 7/2, x^3 + 4/3*x^2 - 11/3*x + 19/6, -3*x^2 + 6*x - 11/2>,
  [ 2, 2, 2, 5, 3, 31, 17 ],
  { 3, 5, 19, 23, 31, 61, 101, 113, 271, 313, 331, 607, 829, 863 }>,

// no. 383
<3*x^6 - x^5 - 2*x^4 - 3*x^3 + x^2 - 3*x + 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 193960/117203*x - 44444/117203],
  <x^3 + 2*x^2 - 3*x + 1, x^3 - 7/3*x^2 - 4/3*x + 1/3, -5*x^2 + 2*x + 1>,
  [ 3, 2, 2, 3 ],
  { 3, 5, 29, 47 }>,

// no. 384
<3*x^6 + x^5 - 3*x^4 - 2, 2, [],
  [x^2 + x - 3,
   x^2 + 26155/22539*x + 20323/22539],
  <x^3 + x^2 + 3, x^3 - 2/3*x^2 - 2/3*x - 1/3, -x^2 + 3*x + 1>,
  [ 2, 3, 3, 23, 5, 37, 7 ],
  { 3, 7, 11, 17, 29, 37, 41, 73, 173, 181, 193, 283, 557, 653, 827 }>,

// no. 385
<-3*x^6 + 2*x^5 - x^4 - 3*x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 + 5/2*x + 13/4,
   x^2 - 73/222*x - 71/444],
  <x^3 - x^2 + x + 1, x^3 + 1/3*x^2 - 1, -x^2 + x>,
  [ 2, 2, 2, 3, 41, 5, 3, 7 ],
  { 7, 19, 29, 31, 43, 71, 103, 109, 113, 163, 167, 199, 239, 269, 277, 491 }>,

// no. 386
<-3*x^6 + 3*x^5 + 3*x^4 + x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 - x + 4,
   x^2 - 9361/3409*x + 5956/3409],
  <x^3 - 7/4*x^2 + 3/4*x - 1, x^3 + 3/4*x^2 - 5/12*x - 1, 1/4*x^2 - 9/4*x>,
  [ 3, 2, 5, 2, 23, 2, 19, 7 ],
  { 43, 79, 97, 131, 317, 331, 449, 619, 997, 1039, 1399, 1583 }>,

// no. 387
<-2*x^6 + 3*x^5 + 2*x^4 - 3*x^3 - x^2 + 3*x + 3, 2, [],
  [x^2 + 3/2*x + 3,
   x^2 - 45/22*x + 1],
  <x^3 - x^2 + 1, x^3 - 1/2*x^2 - 3/2*x - 1, 1>,
  [],
  { 13 }>,

// no. 388
<2*x^6 - 3*x^5 + 2*x^4 - 2*x^3 - 2*x^2 + x - 3, 2, [ 2 ],
  [x^2 + 1,
   x^2 - 4216/1841*x + 688/263],
  <x^3 + 2*x^2 + 7/4*x + 1, x^3 - 7/2*x^2 + 25/8*x - 3/2, 5/2*x^2 - 1/4*x>,
  [],
  { 5 }>,

// no. 389
<-3*x^6 - 3*x^4 - 2*x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 + x + 1/3,
   x^2 - 145/217*x + 442/651],
  <x^3 + 1/2*x^2 + 1/2*x - 1/3, x^3 - 1/2*x^2 + 3/2*x - 1, 3/2*x^2 - 3/2*x>,
  [ 3, 3, 11, 13, 2, 5, 2 ],
  { 5, 7, 11, 31, 61, 71, 89, 107, 167, 397, 613, 839 }>,

// no. 390
<-2*x^6 - 3*x^5 + 2*x^3 - 2*x^2 + 2, 2, [],
  [x^2 - 2/3,
   x^2 - 17156/14531*x + 8434/14531],
  <x^3 - x^2 + 2*x + 2, x^3 + 5/2*x^2 + 5/2*x + 1/2, 2*x^2 + 3*x + 2>,
  [ 3, 13, 2, 7, 5 ],
  { 7, 23, 31, 43, 83, 89, 139, 193, 227, 367, 593, 743 }>,

// no. 391
<3*x^6 + x^5 - 3*x^4 - 3*x^3 - x - 1, 2, [],
  [x^2 - 1/2*x - 1,
   x^2 - 406/71*x - 293/71],
  <x^3 + 1/3*x^2 + 1/3, x^3 - x - 1, x>,
  [ 3, 3, 2, 23 ],
  { 7, 13, 31, 59, 79 }>,

// no. 392
<-x^6 + 3*x^5 + x^4 + 2*x^3 - x^2 - 3*x - 2, 2, [],
  [x^2 - 2*x + 3,
   x^2 + 21158/17705*x + 8907/17705],
  <x^3 - 9/5*x - 6/5, x^3 - 3*x^2 + 24/5*x - 19/5, 2*x^2 + 3/5*x - 8/5>,
  [],
  { 3 }>,

// no. 393
<-3*x^6 + 2*x^5 + x^4 + 3*x^3 + 2*x^2 + 3*x - 1, 2, [],
  [x^2 - 2/7*x + 1/7,
   x^2 + 10/43*x + 1/43],
  <x^3 - 1/4*x - 1/2, x^3 - 2/3*x^2 - 4/3, -1/2*x^2 + 2*x + 1>,
  [],
  { 17 }>,

// no. 394
<3*x^6 + 3*x^4 + x^3 - 3*x - 2, 2, [],
  [x^2 - x - 1,
   x^2 + 264561/1030847*x + 1109169/1030847],
  <x^3 + 5*x^2 + 5*x + 6, x^3 - 5*x^2 - 1/3*x - 11, 8*x^2 + 6*x + 14>,
  [ 2, 2, 3, 11 ],
  { 13, 29, 59, 113, 227 }>,

// no. 395
<-3*x^6 - 3*x^5 - 3*x^4 - 3*x^3 - 2*x^2 + x + 2, 2, [],
  [x^2 + 1/4*x - 1/2,
   x^2 + 178579/133252*x + 311351/199878],
  <x^3 + 7/4*x^2 + 2*x + 1, x^3 - 3/4*x^2 + 1/3*x + 2/3, -1/4*x^2 + 3/2*x + 2>,
  [ 3, 7, 5, 43, 2, 3, 13, 2 ],
  { 7, 13, 17, 19, 29, 53, 83, 107, 131, 173, 239, 491, 503, 523, 769, 857 }>,

// no. 396
<3*x^6 - 2*x^5 + 2*x^4 + 3*x^3 - 2*x^2 - 2*x + 3, 2, [],
  [x^2 + 1/3*x - 1/2,
   x^2 - 19/313*x - 97/626],
  <x^3 - x^2 + 1/4*x + 3/4, x^3 + 1/3*x^2 - 4/3*x + 4/3, 5/2*x^2 - 3/2*x>,
  [],
  { 3 }>,

// no. 397
<-3*x^6 - 3*x^5 + x^4 - x^3 + 3*x^2 - 3*x - 2, 2, [],
  [x^2 - 9/4*x + 3/2,
   x^2 - 2349/4999*x + 57353/19996],
  <x^3 + 2*x^2 + 3*x + 3, x^3 - x^2 + 1/3, -2*x^2 + 1>,
  [ 5 ],
  { 31, 41 }>,

// no. 398
<2*x^6 + 3*x^5 - x^4 - 3*x - 2, 2, [],
  [x^2 - 3,
   x^2 - 13968/2303*x + 12123/2303],
  <x^3 + 5/2*x^2 + x + 1/2, x^3 - x^2 + x - 2, 3*x>,
  [ 2, 5, 11, 3, 11, 2, 2, 13 ],
  { 3, 7, 17, 19, 29, 149, 173, 227, 239, 359, 383, 809 }>,

// no. 399
<3*x^6 - 2*x^5 - x^4 + x^2 - x - 1, 2, [],
  [x^2 + x + 1/2,
   x^2 + 96/13*x + 64/13],
  <x^3 - x + 1, x^3 - 2/3*x^2 - 2/3*x - 1/3, -2*x^2 + x>,
  [ 2, 2, 3 ],
  { 3, 11, 83, 151 }>,

// no. 400
<-2*x^6 + 3*x^5 + 3*x^4 + 2*x^2 + 2, 2, [],
  [x^2 - 2/3,
   x^2 + 778392/1800283*x - 249074/1800283],
  <x^3 - 13/9*x^2 - 2/3*x - 2, x^3 - 1/18*x^2 - 1/6*x + 1/2, -11/9*x^2 + x>,
  [],
  { 7 }>,

// no. 401
<2*x^6 - x^5 + 2*x^4 + 2*x^3 - 3*x^2 - 3, 2, [],
  [x^2 - x + 2,
   x^2 + 3/626*x - 3441/2504],
  <x^3 + 2*x^2 - 4*x + 2, x^3 - 5/2*x^2 - 5/2*x - 1, -5*x^2 + x + 1>,
  [ 2, 2, 5, 13, 3, 11, 29 ],
  { 5, 7, 11, 47, 61, 67, 83, 89, 137, 149, 167, 173, 281, 313, 397, 401, 463, 
487 }>,

// no. 402
<3*x^6 - x^5 + 3*x^4 - 3*x^2 - x - 2, 2, [],
  [x^2 - 9*x - 9,
   x^2 + 145/71*x + 73/71],
  <x^3 + 2/3*x^2 + 4/3*x + 4/3, x^3 - x^2 + 1/4*x - 1/2, 1/2*x^2 + x>,
  [],
  { 223 }>,

// no. 403
<-x^6 + 3*x^5 - 3*x^4 - 3*x^3 - 3*x^2 - 2*x + 2, 2, [],
  [x^2 + 1,
   x^2 + 91897848/223330361*x + 103437793/1116651805],
  <x^3 + 1/6*x^2 + 8/9*x - 4/9, x^3 - 19/6*x^2 + 26/9*x + 79/18, 1/2*x^2 - 
25/18*x - 2/9>,
  [ 3, 7, 5, 2 ],
  { 5, 7, 13, 17, 131, 149, 397 }>,

// no. 404
<-3*x^6 + x^5 - 2*x^4 - 3*x^2 + 2*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 161939/122765*x + 892257/613825],
  <x^3 - 4*x^2 + 8*x + 1, x^3 + 11/3*x^2 + 22/3*x - 1, 14*x>,
  [ 3, 3, 5, 17 ],
  { 7, 13, 23, 29, 31, 41, 47, 67, 103, 109, 229 }>,

// no. 405
<-x^6 + 3*x^5 + 3*x^4 + x^3 - x^2 - 2*x - 1, 2, [],
  [x^2 + 1,
   x^2 - 3/5*x + 9/20],
  <x^3 - 2*x^2 - 4*x - 2, x^3 - x^2 - 1, x^2 + x + 1>,
  [ 2 ],
  { 3, 31 }>,

// no. 406
<-3*x^6 - 2*x^5 - 2*x^4 + x^3 - 3*x + 3, 2, [],
  [x^2 - 1/2,
   x^2 + 2928/2401*x + 5447/4802],
  <x^3 - 1/3*x^2 + 1, x^3 + x^2 + x - 1, 2*x>,
  [],
  { 23 }>,

// no. 407
<-2*x^6 - 3*x^5 - 3*x^4 + 3*x^3 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 + 3/2*x + 3,
   x^2 + 17348376/61993849*x - 332640032/557944641],
  <x^3 - 7/2*x^2 + 6*x + 2, x^3 + 5*x^2 + 27/2*x + 1/4, -x^2 + 27/2*x + 2>,
  [ 3, 5 ],
  { 5, 11, 29, 31 }>,

// no. 408
<3*x^6 + 3*x^5 - x^4 + 3*x^3 - x^2 - 2*x - 3, 2, [],
  [x^2 + x + 1/3,
   x^2 - 2019/649*x + 14557/1947],
  <x^3 + 2*x^2 + 4/3*x + 4/3, x^3 - x^2 - x - 1, 2*x^2 + 3*x + 1>,
  [ 2, 2, 2, 19, 13, 3, 5, 7, 29 ],
  { 5, 7, 31, 43, 71, 79, 103, 109, 149, 179, 181, 191, 283, 419, 547, 631, 797 
}>,

// no. 409
<-3*x^6 - 2*x^5 - 2*x^4 - 2*x^2 + 3*x + 2, 2, [],
  [x^2 + 1/6*x + 1/6,
   x^2 + 5/38*x + 1129/38],
  <x^3 + 2*x^2 + 6*x - 1, x^3 - 4/3*x^2 + 1/3*x + 1/3, -3*x^2 + 4*x + 1>,
  [ 2, 2, 3, 11, 2, 13, 5 ],
  { 3, 7, 13, 41, 61, 67, 79, 349, 499 }>,

// no. 410
<-x^6 - x^5 + 2*x^4 - 2*x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 1962/481*x + 2253/481],
  <x^3 + x + 1, x^3 + x^2 + x + 4, 2*x^2 + x + 1>,
  [ 2, 3, 7, 23, 43, 5 ],
  { 5, 29, 41, 47, 59, 101, 181, 197, 241, 373, 443 }>,

// no. 411
<-x^6 + 2*x^5 + 3*x^3 - 3*x^2 - 2*x + 3, 2, [],
  [x^2 - x + 1/2,
   x^2 - 944/965*x - 284/965],
  <x^3 - 1/2*x^2 + 5/8*x - 23/8, x^3 - 3/2*x^2 - 11/8*x + 1/8, -5/8*x - 13/8>,
  [],
  { 5 }>,

// no. 412
<2*x^6 + 3*x^5 - 2*x^4 + 2*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 4*x - 49,
   x^2 + 16/17*x - 133/17],
  <x^3 + 13/7*x^2 + 3, x^3 - 5/14*x^2 - 1/2*x - 1/2, -4/7*x^2 + x>,
  [ 2, 3, 7, 13, 17, 2, 11, 23 ],
  { 5, 11, 17, 29, 71, 79, 103, 109, 167, 257, 263, 353, 467, 571, 809, 997, 
1181, 1451, 1571, 1609 }>,

// no. 413
<-2*x^6 + 3*x^5 - x^4 - 2*x^3 + 2*x^2 - 3*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 69784/80713*x + 10352/80713],
  <x^3 - 1/2*x^2 + 2, x^3 - x^2 + 1/2*x - 1/4, -x^2 - 1/2*x + 1>,
  [ 2, 2, 3, 7, 17, 11, 3 ],
  { 11, 13, 31, 53, 59, 71, 73, 79, 101, 113, 137, 173, 229, 419, 601, 619, 881 
}>,

// no. 414
<-3*x^6 - x^5 + x^4 - 2*x^3 + 3*x^2 - 2*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 20128013087/12461192041*x + 18617811853/12461192041],
  <x^3 - 7/4*x^2 + x + 5, x^3 + 25/12*x^2 + 17/6*x + 25/12, -5/4*x^2 - 17/4*x - 
11/2>,
  [ 2, 2, 2, 5, 3, 7, 11 ],
  { 3, 13, 23, 29, 37, 67, 97, 149, 223, 229, 1039 }>,

// no. 415
<-3*x^6 - x^5 + x^4 - x^3 - 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 15/19*x - 2/19,
   x^2 + 165/536*x - 2199/4288],
  <x^3 - x^2 + 1, x^3 + 4/3*x^2 + x + 1/3, 2>,
  [ 3, 13, 2, 3, 5, 2, 31, 11, 37, 29 ],
  { 13, 29, 41, 43, 53, 67, 109, 113, 157, 179, 241, 271, 293, 311, 379, 509, 
677, 761, 1049, 1063, 1283, 1709 }>,

// no. 416
<-x^6 - 3*x^5 + 3*x^4 - x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 + 27/26*x + 21/26,
   x^2 + 29493627/6760106*x + 19590501/6760106],
  <x^3 - 5/2*x^2 + 1/2*x + 2, x^3 + 11/2*x^2 + 81/2*x + 26, -11/2*x^2 + 13/2*x +
7>,
  [],
  { 11 }>,

// no. 417
<-3*x^6 - 3*x^5 - 2*x^4 - 3*x^3 + x^2 - 3*x - 2, 2, [],
  [x^2 + 11/28*x + 11/14,
   x^2 - 56/37*x + 164/111],
  <x^3 + x^2 + 2*x + 1, x^3 - x + 1, -x^2 + 1>,
  [ 3 ],
  { 5, 31, 61 }>,

// no. 418
<2*x^6 + 2*x^5 - 3*x^4 - x^3 - 3*x^2 - 2, 2, [],
  [x^2 - x + 3/4,
   x^2 - 61768/34439*x + 43016/34439],
  <x^3 - x^2 - x - 3, x^3 + 2*x^2 + 3/8*x + 3/8, -3/2*x^2 - 3*x - 1/2>,
  [ 2, 2, 3, 5, 7, 19, 31 ],
  { 5, 7, 29, 43, 59, 79, 101, 199, 211, 263, 277, 421, 521, 1451, 1559 }>,

// no. 419
<-x^6 + x^5 + 3*x^4 + 2*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 - x + 2,
   x^2 + 175/533*x + 366/533],
  <x^3 - 1/2*x^2 - 1/2*x - 3, x^3 - 1/2*x^2 - 1/2*x - 1, 3/2*x^2 - 1/2*x>,
  [ 3, 5, 11, 13, 7 ],
  { 5, 13, 19, 37, 41, 47, 241, 379, 443, 523, 593 }>,

// no. 420
<-x^6 + x^5 + 2*x^4 - 3*x^3 - 3*x^2 - 3*x - 1, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 205952/88465*x + 42568/17693],
  <x^3 - 2*x^2 + 4, x^3 + x^2 + 1/4*x + 1/2, -1/2*x^2 - x + 1>,
  [ 2, 5, 7, 3 ],
  { 3, 5, 7, 29, 107, 149, 617 }>,

// no. 421
<-3*x^6 - x^5 + x^4 + 3*x^2 + 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 423395684/191112157*x + 349399453/191112157],
  <x^3 + 6/5*x^2 + 17/25*x - 2/5, x^3 - 13/15*x^2 + 38/75*x - 13/15, -6/5*x^2 + 
39/25*x + 1/5>,
  [ 2, 3, 3, 2, 5, 2, 31, 7, 2, 2 ],
  { 3, 11, 17, 19, 23, 29, 31, 37, 41, 47, 179, 191, 229, 409, 457, 487, 1039, 
1481, 1759, 3911, 3931 }>,

// no. 422
<3*x^6 + 3*x^5 - 2*x^4 + 2*x^3 + x^2 - 3*x - 2, 2, [],
  [x^2 + x - 3,
   x^2 - 13162/11831*x - 47721/11831],
  <x^3 + 2*x^2 + x + 2/3, x^3 - x^2 - 1, x^2 + 3*x>,
  [ 3, 11, 3, 2, 2 ],
  { 5, 11, 13, 17, 19, 37, 41, 971 }>,

// no. 423
<3*x^6 - x^5 - x^4 + 2*x^3 + 3*x^2 - 1, 2, [],
  [x^2 - 2,
   x^2 + 1/2*x + 5/16],
  <x^3 - x^2 + 1, x^3 + 2/3*x^2 - 1/3, x^2>,
  [ 2, 2, 3, 3, 7, 2, 5, 3 ],
  { 3, 7, 13, 23, 29, 37, 43, 53, 67, 73, 79, 109, 163, 503, 677 }>,

// no. 424
<-3*x^6 + x^5 - x^4 - 3*x^2 - x + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 31445597/254610129*x - 105986743/254610129],
  <x^3 - 13/4*x^2 + 5*x - 2, x^3 + 35/12*x^2 + 16/3*x - 7/3, 5/4*x^2 - 17/2*x + 
4>,
  [ 3, 5, 2, 3 ],
  { 3, 19, 37, 79, 109, 191, 389 }>,

// no. 425
<2*x^6 - 3*x^5 - 3*x^4 + x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 9/14*x + 3/14,
   x^2 + 24/223*x + 381/892],
  <x^3 - x^2 + 1, x^3 - 1/2*x^2 - 5/2*x - 2, -x^2 + x + 1>,
  [ 2, 2, 11, 23, 2, 3, 37, 5, 7 ],
  { 5, 11, 17, 19, 31, 37, 53, 73, 127, 173, 283, 293, 311, 431 }>,

// no. 426
<2*x^6 - 3*x^5 + x^4 - 3*x^3 - 2*x^2 - 2*x - 2, 2, [],
  [x^2 - 2*x + 3,
   x^2 - 1578/3017*x + 1243/3017],
  <x^3 - 1/2*x^2 + 1/2, x^3 - x^2 - 2*x - 3, -2*x^2 + 1>,
  [ 5, 3 ],
  { 3, 29, 43 }>,

// no. 427
<3*x^6 - 3*x^4 - 2*x^3 - 3*x + 2, 2, [],
  [x^2 - 2*x + 1/2,
   x^2 - 511/458*x - 889/1832],
  <x^3 + 3*x^2 - 3/2*x + 7/2, x^3 - 3*x^2 + 7/6*x - 23/6, 5*x^2 - 5/2*x + 13/2>,
  [],
  { 7 }>,

// no. 428
<-3*x^6 + x^5 - x^3 + x^2 + 3*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 16/13*x + 28/13],
  <x^3 + x + 1, x^3 - 1/3*x^2 - 2/3*x - 1/3, -x^2 + 1>,
  [ 2, 3, 3 ],
  { 5, 11, 37, 149 }>,

// no. 429
<-2*x^6 + 3*x^5 + 3*x^4 - x^3 - 3*x - 3, 2, [],
  [x^2 + 13/11*x + 4/11,
   x^2 + 127/1238*x + 5677/4952],
  <x^3 - 7/6*x^2 + 3/2*x - 2, x^3 - 1/3*x^2 - 2*x - 1, -5/3*x^2 + x + 1>,
  [ 2, 2, 3, 5, 2, 3, 3, 11 ],
  { 5, 11, 19, 61, 83, 139, 317, 373, 983, 991, 1321, 1753 }>,

// no. 430
<2*x^6 - 3*x^5 + x^4 - 2*x^3 - 2*x^2 + 3*x - 1, 2, [],
  [x^2 + 1,
   x^2 - 172796/130201*x + 88969/130201],
  <x^3 - 6*x^2 + x + 10, x^3 + 9/2*x^2 - 11/2*x - 17/2, -8*x^2 + 5*x + 13>,
  [ 3, 3, 17, 2, 2 ],
  { 3, 23, 37, 43, 73, 173, 229, 383, 641 }>,

// no. 431
<-2*x^6 + 3*x^4 + 2*x^3 - 2*x^2 + 3*x - 1, 2, [],
  [x^2 + 5/6,
   x^2 - 1568/681*x + 1640/681],
  <x^3 + 2*x^2 + x - 1, x^3 - 2*x^2 + 3/2*x - 1, -x + 1>,
  [ 2, 3, 5, 5 ],
  { 5, 7, 13, 17, 31, 61, 73, 83, 193 }>,

// no. 432
<3*x^6 - 3*x^5 + 3*x^3 + 2*x^2 + 2*x + 3, 2, [],
  [x^2 - 2*x - 2,
   x^2 - 150/59*x - 650/177],
  <x^3 - 11/2*x^2 + 1/2, x^3 + 9/2*x^2 + 2/3*x + 4/3, 17/2*x^2 + 1/2*x + 1>,
  [],
  { 59 }>,

// no. 433
<-x^6 + 3*x^5 + 2*x^4 + 3*x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 - 3/2*x + 2,
   x^2 + 24477/10834*x + 12398/5417],
  <x^3 - x^2 + 6*x - 3, x^3 - 2*x^2 - x - 1, -3*x^2 + 2*x>,
  [ 2, 2, 17, 7, 11, 47 ],
  { 7, 13, 19, 23, 41, 61, 163, 173, 353, 373, 577, 677, 787, 983 }>,

// no. 434
<-x^6 + 3*x^5 + 2*x^4 + x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 - 7/2*x + 2,
   x^2 - 257823/550042*x + 347918/275021],
  <x^3 - 4, x^3 - 3*x^2 - 7/4*x - 1, -1/2*x^2 + 4*x + 1>,
  [ 2, 7, 3, 31 ],
  { 5, 61, 73, 89, 199, 263, 443 }>,

// no. 435
<-x^6 - 3*x^5 + x^4 + 2*x^3 + x^2 - x + 3, 2, [],
  [x^2 + 8/5*x + 1/5,
   x^2 + 4/3*x + 13/9],
  <x^3 + 2*x^2 - 3*x + 2, x^3 + x^2 - 1, x + 1>,
  [ 3, 2, 2, 5, 17, 11 ],
  { 3, 43, 107, 137, 151, 337, 439, 449, 569, 619, 761, 787, 883 }>,

// no. 436
<3*x^6 + x^5 + 3*x^4 + x^3 + 2*x^2 - x - 2, 2, [],
  [x^2 + x + 1,
   x^2 + 1685/4317*x + 5329/4317],
  <x^3 + x^2 - 3*x + 2, x^3 - 2/3*x^2 - 2/3*x - 1/3, -4*x^2 + x>,
  [ 2, 2, 3, 13, 31, 5 ],
  { 3, 5, 19, 29, 37, 41, 47, 61, 67, 313, 1229, 1453, 1531, 1973 }>,

// no. 437
<-2*x^6 - 3*x^5 + 3*x^4 - 2*x^3 - 3, 2, [],
  [x^2 - 8/17*x + 14/17,
   x^2 - 272/107*x + 854/321],
  <x^3 - x + 1, x^3 + 3/2*x^2 + 3/2*x + 3/2, 2*x^2>,
  [ 2, 2, 3, 31, 5, 3, 37, 47 ],
  { 5, 13, 19, 53, 83, 197, 281, 353, 487, 673, 1109, 1567 }>,

// no. 438
<-x^6 - x^5 + x^4 - 3*x^3 + x^2 - 2*x - 2, 2, [],
  [x^2 + 1,
   x^2 + 4/13*x + 1/13],
  <x^3 - x^2 + 1, x^3 + 2*x^2 + 2*x + 2, -x^2 + x>,
  [ 7, 3, 3, 2, 11, 5 ],
  { 3, 5, 7, 17, 19, 23, 37, 101, 127, 457 }>,

// no. 439
<2*x^6 + x^5 + 2*x^4 + 3*x^3 - 2*x^2 + x - 1, 2, [],
  [x^2 + x - 1,
   x^2 + 5*x - 5],
  <x^3 + x^2 + x + 2, x^3 - 1/2*x^2 + 1/2*x - 1/2, 1>,
  [ 3, 5, 13, 2 ],
  { 3, 5, 7, 43, 73, 419, 461 }>,

// no. 440
<2*x^6 + 2*x^5 - 3*x^4 - 2*x^3 - 3*x^2 - 3*x - 2, 2, [],
  [x^2 + x + 1/2,
   x^2 + 90945737/69056969*x + 183850713/138113938],
  <x^3 + 10/3*x^2 + 26/9*x + 1, x^3 - 7/3*x^2 + 25/18*x - 1, 2*x^2 + 5/9*x>,
  [ 3, 11, 2, 7, 2, 2, 3 ],
  { 5, 13, 19, 23, 29, 43, 67, 103, 719, 997, 1123 }>,

// no. 441
<-2*x^6 + 2*x^5 + 2*x^4 + x^2 - x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 86546/39489*x + 43873/39489],
  <x^3 - 2/3*x^2 + 8/3*x + 11/3, x^3 - 1/3*x^2 - 7/6*x + 1/3, 7/3*x^2 + 5/3*x - 
7/3>,
  [ 3, 2, 2, 5, 11, 5, 7, 47, 23, 7 ],
  { 7, 29, 47, 61, 101, 127, 151, 167, 271, 347, 461, 479, 577, 863, 883, 947, 
1151 }>,

// no. 442
<-2*x^6 - x^4 - 3*x^3 + 3*x^2 - 1, 2, [],
  [x^2 - x + 5,
   x^2 - 258/257*x + 117/257],
  <x^3 - 6/11*x^2 + 10/11*x + 25/11, x^3 + 6/11*x^2 + 1/11*x + 5/22, -7/11*x^2 -
25/11*x - 2/11>,
  [ 2, 23, 31, 11, 2, 2, 7, 19, 43, 29, 3, 5 ],
  { 3, 5, 7, 13, 23, 37, 43, 59, 71, 107, 263, 367, 659, 683, 1237, 2579, 2917, 
3041, 4483, 4801 }>,

// no. 443
<-x^6 - 3*x^5 + 3*x^4 - 3*x^3 + x^2 + 2*x + 3, 2, [],
  [x^2 - 4/13*x - 2/13,
   x^2 + 904/337*x - 498/337],
  <x^3 + 5/2*x^2 + 2*x + 3, x^3 + 1/2*x^2 - 1, -5/2*x^2>,
  [],
  { 7 }>,

// no. 444
<-x^6 - 3*x^5 + 3*x^4 - x^3 + x^2 - 2*x - 2, 2, [],
  [x^2 + 4*x + 2,
   x^2 - 281/3733*x + 14321/14932],
  <x^3 - 3/2*x^2 + 1, x^3 + 9/2*x^2 + 6*x + 3, -3/2*x^2 + 2*x + 1>,
  [],
  { 11 }>,

// no. 445
<-x^6 - 3*x^5 + 3*x^4 - x^3 + 3*x^2 - x - 3, 2, [],
  [x^2 - 3/2*x + 2,
   x^2 - 727294/3419401*x + 10758337/3419401],
  <x^3 - x^2 + 4, x^3 + 4*x^2 + 13/4*x + 19/4, 3/2*x^2 + 3/2*x + 4>,
  [],
  { 5 }>,

// no. 446
<-3*x^6 - 2*x^5 + 3*x^4 + 3*x^3 + 3*x - 2, 2, [],
  [x^2 - 4/3*x + 1,
   x^2 + 434818964/287043051*x + 123752017/95681017],
  <x^3 + x^2 + 31/16*x - 11/8, x^3 - 1/3*x^2 - 1/12*x - 1/2, 11/4*x^2 - 7/8*x - 
1/4>,
  [ 5, 3 ],
  { 3, 5, 13 }>,

// no. 447
<-2*x^6 + 3*x^5 + 2*x^4 + 3*x^3 - x^2 + x - 3, 2, [],
  [x^2 - x + 3,
   x^2 - 7/3*x + 109/19],
  <x^3 + 1/2*x^2 + 1/2*x - 3/2, x^3 - 2*x^2 - 1, -x^2 + 2*x>,
  [ 2, 2, 5, 2, 2, 3, 3, 31, 11, 7 ],
  { 3, 5, 11, 13, 29, 47, 61, 83, 103, 131, 173, 191, 211, 223, 239, 317, 487, 
557, 701, 811 }>,

// no. 448
<2*x^6 - 2*x^5 - 3*x^4 + 2*x^3 + x^2 + x - 3, 2, [],
  [x^2 - x + 1/2,
   x^2 - 332417/12593*x + 968817/25186],
  <x^3 - 2*x^2 - 3/2*x - 1/2, x^3 + x^2 + 2*x + 7, 6*x + 2>,
  [ 3, 7, 13, 5, 3, 11, 2, 2, 37 ],
  { 3, 5, 7, 19, 37, 47, 67, 71, 83, 127, 179, 197, 227, 229 }>,

// no. 449
<-x^6 + 3*x^5 + 3*x^4 - 3*x^3 + x + 2, 2, [],
  [x^2 - 3*x - 2,
   x^2 - 25587/9049*x + 20014/9049],
  <x^3 - 2*x^2 - 19/8*x - 17/8, x^3 - x^2 - 3/8*x + 7/8, 3/2*x^2 - 3/8*x + 3/8>,
  [ 2, 3, 2, 3, 7 ],
  { 3, 5, 7, 17, 79, 113, 137, 139, 167, 233, 337 }>,

// no. 450
<2*x^6 - 2*x^5 - 2*x^4 - 3*x^2 - 3*x + 3, 2, [],
  [x^2 - 37/17*x + 13/34,
   x^2 - 17/49*x - 1/98],
  <x^3 + x^2 + 3/2*x + 1, x^3 - 2*x^2 - x + 1, -x^2 - 2*x + 1>,
  [ 2, 5, 11, 3, 3, 3, 2, 5, 31, 7 ],
  { 13, 73, 83, 103, 113, 139, 181, 211, 223, 383, 467 }>,

// no. 451
<2*x^6 + 2*x^5 - 2*x^4 + x^3 + 3*x^2 + x - 1, 2, [],
  [x^2 + x - 1,
   x^2 + 17/14*x - 185/224],
  <x^3 + x^2 - x + 1, x^3 - 1/2, 2*x>,
  [ 3, 2, 7, 5, 23, 13, 11, 17 ],
  { 7, 13, 17, 23, 29, 31, 79, 109, 131, 137, 139, 151, 191, 251, 277, 353, 367,
643, 1279, 1523 }>,

// no. 452
<3*x^6 - 3*x^5 - 3*x^4 + x^2 - x + 2, 2, [],
  [x^2 + 8*x - 7,
   x^2 + 6200/2557*x + 1244/2557],
  <x^3 - 3*x^2 + 1, x^3 + 2*x^2 - 1/3*x + 2/3, -4*x^2 + x>,
  [],
  { 11 }>,

// no. 453
<-3*x^6 + x^5 - 3*x^2 - 2*x + 3, 2, [],
  [x^2 + 1/4*x + 3/4,
   x^2 + 1761/1087*x + 2817/4348],
  <x^3 - 3/4*x^2 + 1, x^3 + 5/12*x^2 + 1/3*x - 2/3, -1/4*x^2 - 1/2*x + 1>,
  [ 2, 3, 2, 13, 3, 5, 7 ],
  { 3, 5, 17, 53, 67, 83, 179, 181, 191, 197, 251, 337, 349, 431 }>,

// no. 454
<-3*x^6 - x^5 - 3*x^4 - 2*x^3 + x^2 - x + 3, 2, [],
  [x^2 + 15/13*x + 1/13,
   x^2 + 7123/32907*x + 39707/43876],
  <x^3 + 7/4*x^2 + 13/4*x + 11/4, x^3 - 17/12*x^2 + 5/12*x + 11/12, -3/4*x^2 + 
7/4*x + 13/4>,
  [],
  { 19 }>,

// no. 455
<-3*x^6 - 3*x^5 + x^4 - 2*x^3 - 1, 2, [],
  [x^2 + 10/7*x + 10/7,
   x^2 + 228/109*x + 136/109],
  <x^3 + x^2 + 1, x^3 + 1/3, x^2 + x>,
  [ 2, 7, 11, 3, 5, 7 ],
  { 17, 29, 37, 103, 149, 167, 173, 233, 547, 617 }>,

// no. 456
<-3*x^6 + x^5 - x^4 - x^3 - 3*x - 1, 2, [],
  [x^2 - 5/4*x + 1/2,
   x^2 + 251/196*x + 37/98],
  <x^3 - x^2 + 1, x^3 + 2/3*x^2 + x + 1/3, x>,
  [ 2, 3, 5, 3, 2, 7, 23 ],
  { 5, 19, 23, 29, 83, 113, 373, 617, 1399 }>,

// no. 457
<-2*x^6 + 2*x^5 + x^4 + 3*x^3 + x^2 - x - 2, 2, [],
  [x^2 + 1,
   x^2 + 1065/4994*x + 150961/119856],
  <x^3 - x^2 + 7/4*x - 3/2, x^3 - 9/8*x - 3/4, 3/2*x^2 + 1/4*x - 1/2>,
  [ 3, 3, 7, 5, 11 ],
  { 7, 11, 29, 31, 59, 61, 139, 233, 307 }>,

// no. 458
<2*x^6 - 3*x^5 - 2*x^4 - 2*x^3 - 2*x^2 - x - 2, 2, [],
  [x^2 - 4/3*x - 19/9,
   x^2 + 20/21*x + 59/63],
  <x^3 + 3/2*x^2 + 3/2*x + 3/2, x^3 - 3*x^2 + 2*x - 1, -2*x + 1>,
  [],
  { 3 }>,

// no. 459
<2*x^6 + x^5 + x^4 + 3*x^3 + 3*x - 3, 2, [],
  [x^2 + 5/2*x - 2,
   x^2 + 126075/36094*x + 53466/18047],
  <x^3 + 1/2*x^2 - 3/8*x + 3/2, x^3 + 3/4*x - 1, -1/2*x^2 - 5/4*x>,
  [],
  { 29 }>,

// no. 460
<3*x^6 + 2*x^5 - 3*x^2 + x - 1, 2, [],
  [x^2 - x + 2,
   x^2 - 1415/1931*x - 20705/7724],
  <x^3 + 2*x^2 + 4, x^3 - 4/3*x^2 + 7/12*x - 1/6, 5/2*x^2 - 3*x + 1>,
  [ 5, 2, 3, 3, 7, 13, 2 ],
  { 3, 13, 23, 31, 47, 67, 101, 167, 179, 193, 251, 293, 421, 487 }>,

// no. 461
<-3*x^6 + 3*x^5 - 2*x^4 + x^3 + 3*x + 3, 2, [],
  [x^2 + x + 2,
   x^2 - 406192343/107158369*x + 442110794/107158369],
  <x^3 - 2/3*x^2 + 31/36*x + 1/36, x^3 - 1/3*x^2 - 11/27*x - 11/27, -1/6*x^2 + 
5/9*x + 31/18>,
  [],
  { 23 }>,

// no. 462
<2*x^6 + 3*x^5 + x^4 - 3*x^3 - 3*x^2 + 2*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 2384977/5533873*x + 2336137/5533873],
  <x^3 + 3*x^2 - 17*x - 37, x^3 - 3/2*x^2 - 5/2*x + 7/2, -7*x^2 - 2*x + 16>,
  [ 3 ],
  { 3, 11 }>,

// no. 463
<-3*x^6 - 3*x^5 - 3*x^4 - 3*x^3 + 2*x^2 - x + 3, 2, [],
  [x^2 + 9/4*x + 11/4,
   x^2 + 854/883*x - 683/2649],
  <x^3 + x + 1, x^3 + x^2 + 4/3*x + 1/3, 2*x^2 + x + 2>,
  [ 3, 3 ],
  { 7, 11, 17, 37 }>,

// no. 464
<-3*x^6 + 3*x^5 + x^3 - 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 1/4*x - 1/2,
   x^2 + 1582617/2769004*x + 48819/1384502],
  <x^3 - 9/4*x^2 + 5*x - 1, x^3 + 5/4*x^2 + 4/3*x + 2/3, 13/4*x^2 + 3/2*x + 1>,
  [ 2, 2, 5, 3 ],
  { 5, 7, 13, 23, 41, 79, 227, 311 }>,

// no. 465
<-3*x^6 + 3*x^5 + 2*x^3 + x^2 + x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 1256/853*x + 736/853],
  <x^3 - x^2 + 1, x^3 + 1/3*x - 2/3, x^2 + x + 1>,
  [],
  { 13 }>,

// no. 466
<-3*x^6 - 3*x^5 - 3*x^4 - x^3 + 2*x^2 - 3*x + 3, 2, [],
  [x^2 - 3/4*x + 3/4,
   x^2 + 32829/22708*x + 15591/22708],
  <x^3 + x^2 + 3/4*x + 3/2, x^3 + x - 2/3, -3/2*x^2 - 3/2*x>,
  [ 3, 2, 2, 3, 31, 3, 17, 5, 11 ],
  { 5, 13, 17, 23, 31, 41, 59, 79, 89, 113, 131, 223, 227, 281, 439, 647, 743, 
811, 829, 971 }>,

// no. 467
<3*x^6 - x^5 - 2*x^4 + 3*x^3 - 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 1/2*x + 2,
   x^2 + 802/1261*x + 373/1261],
  <x^3 + 1/2*x^2 - 1/2*x + 2, x^3 - 5/6*x^2 - 1/2*x - 2/3, 3/2*x^2 - 1/2*x + 1>,
  [ 3, 2, 7, 11, 5 ],
  { 5, 7, 13, 71, 79, 107, 137, 149, 199, 757 }>,

// no. 468
<-3*x^6 + x^5 + x^3 + 2*x^2 + 2*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 236/181*x + 136/181],
  <x^3 - 1/3*x^2 - 2/3*x - 1/3, x^3 + 2*x - 2, -2*x^2 + 2*x + 1>,
  [ 2, 2, 3, 7, 5, 13, 7 ],
  { 5, 7, 11, 17, 31, 59, 83, 89, 97, 109, 131, 269, 311, 349, 547, 701 }>,

// no. 469
<3*x^6 - 2*x^5 - 3*x^4 + x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 - 2/3*x + 1,
   x^2 - 6014740/1913577*x + 5336524/1913577],
  <x^3 - 8*x - 19/2, x^3 - 2/3*x^2 - 4/3*x + 7/6, 5*x^2 + x - 11/2>,
  [ 2, 2, 3, 7, 17, 13, 3, 19, 11 ],
  { 3, 5, 7, 11, 13, 17, 61, 67, 89, 103, 137, 157, 173, 179, 191, 227, 311, 
331, 419, 463, 521, 769, 1297, 2287, 3229 }>,

// no. 470
<-3*x^6 + x^5 + x^4 - 3*x^3 - 3*x^2 + 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 6506/6357*x + 718/6357],
  <x^3 - 6/7*x^2 - 1/7*x + 1, x^3 + 11/21*x^2 + 17/21*x - 1/3, -9/7*x^2 + 9/7*x 
+ 1>,
  [],
  { 23 }>,

// no. 471
<2*x^6 - 2*x^5 + 2*x^4 - 3*x^3 - 2*x^2 + x - 3, 2, [],
  [x^2 + 1/2,
   x^2 - 4858884/27812359*x + 63103177/55624718],
  <x^3 + 3*x^2 - 16*x + 21, x^3 - 4*x^2 + 9/2*x - 2, -7*x^2 + 14*x - 9>,
  [ 2, 2, 2, 2, 2, 2, 2, 11, 47, 3, 23 ],
  { 3, 11, 17, 23, 31, 41, 47, 89, 97, 233, 311, 353, 881 }>,

// no. 472
<-3*x^6 + x^4 + x^3 + 2*x^2 + 3*x - 1, 2, [],
  [x^2 - x + 1/2,
   x^2 + 5/13*x + 25/26],
  <x^3 - 3*x^2 + 4*x - 1, x^3 + 3*x^2 + 5*x - 5/3, x^2 - 8*x + 2>,
  [],
  { 5 }>,

// no. 473
<-3*x^6 + x^5 - 2*x^4 + 2*x^2 - x + 2, 2, [],
  [x^2 + 1,
   x^2 + 1886/3747*x + 1489/11241],
  <x^3 - x^2 + 3/4*x - 1/2, x^3 + 2/3*x^2 + 4/3*x + 4/3, -3/2*x^2>,
  [ 2, 2, 11 ],
  { 3, 5, 47, 61 }>,

// no. 474
<2*x^6 + x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - x - 7/2,
   x^2 - 742/607*x - 1873/607],
  <x^3 + x^2 + 3/2*x + 2, x^3 - x^2 - x - 1, x^2 + 2*x + 1>,
  [ 2, 2, 5 ],
  { 7, 43 }>,

// no. 475
<3*x^6 + 3*x^5 + x^4 + x^3 - 3*x^2 - 3*x + 3, 2, [],
  [x^2 + x + 2,
   x^2 + 43245/26269*x + 216214/78807],
  <x^3 - x^2 + 1/4*x - 1/2, x^3 + 2*x^2 - 4/3, -5/2*x^2 - x + 1>,
  [ 2, 3, 7, 3, 5, 5 ],
  { 5, 7, 11, 37, 53, 97, 131, 151, 251, 277, 433, 607 }>,

// no. 476
<-x^6 - 3*x^5 + x^2 - 2*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 152/97*x - 48/97],
  <x^3 + x^2 + 1, x^3 + 2*x^2 + 2*x - 3, 2*x^2>,
  [],
  { 5 }>,

// no. 477
<-2*x^6 - 3*x^5 + 2*x^4 - 2*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 + 1,
   x^2 + 5712685648/1879792113*x + 4131108961/1879792113],
  <x^3 - 23/8*x + 39/16, x^3 + 3/2*x^2 + 2*x + 7/2, 1/2*x^2 + 5/4*x - 15/4>,
  [ 5, 13, 3, 11, 2, 7, 3, 13, 31 ],
  { 3, 7, 11, 13, 19, 31, 37, 43, 53, 67, 71, 83, 167, 173, 179, 229, 293, 337, 
401, 421, 607, 647, 691, 839 }>,

// no. 478
<-3*x^6 + 2*x^5 - x^3 - x + 2, 2, [],
  [x^2 - x + 1/2,
   x^2 + 23/21*x + 41/126],
  <x^3 - x^2 + x + 1, x^3 + 1/3*x^2 + 2/3*x - 1/3, 2*x^2 + 1>,
  [ 3 ],
  { 3, 5, 29 }>,

// no. 479
<-x^6 - 2*x^4 + 2*x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 3*x + 3,
   x^2 - 9/13*x + 3/13],
  <x^3 - x^2 + 3*x - 4, x^3 + x^2 - 1, 1>,
  [ 3, 3, 2, 7, 11, 5, 13 ],
  { 5, 11, 23, 29, 31, 43, 197, 257, 331, 571, 647, 823, 1117, 2621, 3163, 3469,
3923 }>,

// no. 480
<-3*x^6 + x^5 + 2*x^4 - x^3 + 2*x^2 - 2*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 392835/3491989*x + 141856345/55871824],
  <x^3 - 3/4*x^2 - x + 1, x^3 + 5/12*x^2 + 7/6*x + 5/12, 5/4*x^2 - 1/4*x - 1/2>,
  [ 2, 3, 7 ],
  { 5, 11, 13, 19, 23, 131 }>,

// no. 481
<-x^6 - 3*x^5 + 3*x^4 - 3*x^3 - x + 3, 2, [],
  [x^2 + 7/2*x - 3/2,
   x^2 + 10078/11009*x - 6483/11009],
  <x^3 + 7/2*x^2 + 7/2*x + 3, x^3 - 1/2*x^2 + 3/2*x - 1, -5/2*x^2 - 1/2*x>,
  [ 13 ],
  { 11, 19 }>,

// no. 482
<-2*x^6 + 2*x^5 + 3*x^4 + x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 - 4*x + 13/3,
   x^2 - 112/43*x + 217/43],
  <x^3 - x^2 - 3/2, x^3 - x - 1, -x^2 + x>,
  [ 2, 2, 3, 7, 5 ],
  { 7, 11, 13, 17, 29, 67, 113 }>,

// no. 483
<2*x^6 - 2*x^5 - 2*x^4 - 3*x^3 - 2*x - 2, 2, [],
  [x^2 + 5*x + 3,
   x^2 + 387/343*x + 979/2401],
  <x^3 + x^2 - x + 3/2, x^3 - 2*x^2 - 1, 2*x^2 - 2*x + 1>,
  [ 2, 2, 2, 2, 2, 5, 3, 17, 5, 7, 13 ],
  { 7, 11, 17, 29, 43, 67, 83, 103, 109, 137, 163, 197, 223, 229, 271, 317, 479,
503, 523, 571 }>,

// no. 484
<-3*x^6 - 2*x^5 - 3*x^4 - 2*x^3 - 3*x^2 + 2*x + 3, 2, [],
  [x^2 - 1/2,
   x^2 + 22/133*x - 26/133],
  <x^3 + x + 1, x^3 + 2/3*x^2 + 1/3*x - 1, x^2>,
  [ 2, 7, 5, 3, 23 ],
  { 3, 5, 37, 43, 47, 79, 109, 157, 251 }>,

// no. 485
<-2*x^6 - 3*x^5 - 2*x^4 - 3*x^3 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 1/2*x + 1/3,
   x^2 + 14709/15458*x + 4353/7729],
  <x^3 + x^2 + 2*x + 1, x^3 + 1/2*x^2 + 1/2*x - 1, 2*x^2 + 1>,
  [ 2, 2, 2, 23, 7, 11, 3, 5, 41 ],
  { 5, 17, 61, 83, 103, 109, 127, 163, 167, 269, 277, 383, 467, 919, 1009, 1511,
1579, 1697, 1783 }>,

// no. 486
<-x^6 + 3*x^5 + 2*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + x + 13/4],
  <x^3 - 3/2*x^2 - 3/2, x^3 - 3/2*x^2 - 2*x - 2, -1/2*x^2 - 3/2*x>,
  [ 2, 3, 5, 11, 19, 2, 2 ],
  { 7, 11, 17, 31, 41, 71, 107, 113, 139, 199, 499, 751, 941, 947 }>,

// no. 487
<-3*x^6 + 3*x^5 - 3*x^3 + x^2 - x - 1, 2, [],
  [x^2 - 1/4*x + 1/4,
   x^2 + 74/61*x + 25/61],
  <x^3 - x^2 + 1, x^3 + 1/3*x + 1/3, x^2>,
  [ 3, 7, 3, 13 ],
  { 7, 11, 13, 17, 19, 37, 71, 127, 167, 541 }>,

// no. 488
<-3*x^6 - x^5 - x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 1747/2127*x + 3977/2127],
  <x^3 - 2/3*x^2 + 2/3*x - 1/3, x^3 + x^2 + 3*x - 2, 3*x^2 - 2*x + 1>,
  [ 11, 5, 3 ],
  { 5, 11, 23, 41, 131, 191, 211 }>,

// no. 489
<-2*x^6 - 3*x^5 + 2*x^4 - x^2 + x - 3, 2, [],
  [x^2 - 2/3*x + 1/3,
   x^2 - 475450/721411*x + 540597/721411],
  <x^3 - 2*x^2 - x + 4, x^3 + 7/2*x^2 + 23/2*x + 21/2, 3*x^2 - 4*x - 9>,
  [ 2, 3, 11, 13, 7, 2, 2, 2, 5, 17, 3 ],
  { 3, 5, 7, 23, 29, 37, 41, 43, 47, 109, 131, 139, 271, 313, 317, 401, 409, 
421, 439, 509, 557, 701, 1093, 1117, 1201 }>,

// no. 490
<-x^6 - 2*x^4 - 2*x^3 + 3*x^2 - 3*x - 2, 2, [],
  [x^2 - 11/29*x + 113/58,
   x^2 + 201/125*x + 129/250],
  <x^3 + x^2 + 5/2*x + 1, x^3 - x^2 + 1/2*x + 3, 5/2*x + 1>,
  [ 3 ],
  { 5, 7, 23 }>,

// no. 491
<3*x^6 - 2*x^5 - 2*x^4 - 3*x^3 - x^2 - 2*x - 2, 2, [],
  [x^2 + x + 1/2,
   x^2 - 146713/238813*x + 278049/477626],
  <x^3 - 17/2*x - 11/2, x^3 - 2/3*x^2 - 1/2*x + 1/2, 5*x^2 - 1/2*x - 5/2>,
  [ 3, 5, 3, 3, 7 ],
  { 3, 5, 7, 83, 131, 139, 743 }>,

// no. 492
<-3*x^6 - 3*x^5 + 2*x^4 + 3*x^3 - x^2 + 3*x - 2, 2, [],
  [x^2 - x + 2/3,
   x^2 - 32875014/48768241*x + 9589737/48768241],
  <x^3 + 1/4*x - 3/4, x^3 + x^2 + 37/48*x - 17/16, 9/4*x^2 - 3/8*x - 5/8>,
  [ 2, 3, 13, 3, 5, 3 ],
  { 13, 37, 59, 71, 89, 103, 107, 109, 163, 199, 617 }>,

// no. 493
<2*x^6 - x^5 - 3*x^4 + 3*x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 + x - 4,
   x^2 - 320129/493687*x + 411852/493687],
  <x^3 - 2*x^2 + 3/4*x - 1, x^3 + 3/2*x^2 - 19/8*x + 7/2, 5/2*x^2 - 11/4*x + 2>,
  [ 2, 2, 2, 41, 19, 3, 5, 5, 11, 29 ],
  { 5, 7, 17, 37, 47, 53, 71, 73, 97, 389, 421, 563, 661, 827, 863, 1231, 1607 
}>,

// no. 494
<-2*x^6 - 2*x^5 + 2*x^4 + 2*x^3 + x^2 + 3*x - 2, 2, [],
  [x^2 - x + 1/2,
   x^2 + 2133139/7703201*x + 663667/1400582],
  <x^3 - 2/3*x^2 + 4*x - 4, x^3 + 5/3*x^2 + 1/8*x - 3/4, -17/6*x^2 - x + 2>,
  [ 17 ],
  { 5, 37, 41 }>,

// no. 495
<-x^6 + 3*x^5 + 2*x^4 + 2*x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 + 1,
   x^2 - 2072/1493*x + 2101/1493],
  <x^3 - 3*x^2 - x + 1, x^3 + 3*x - 2, -2*x^2 + 2*x + 1>,
  [ 2, 3, 7, 7, 47, 23, 2 ],
  { 7, 23, 29, 41, 53, 109, 157, 479, 491, 709 }>,

// no. 496
<3*x^6 + 3*x^5 + x^2 + x - 3, 2, [],
  [x^2 + x - 3,
   x^2 - 394/1019*x + 5149/3057],
  <x^3 + 7/2*x^2 + x - 7/2, x^3 - 5/2*x^2 - 7/3*x + 19/6, 11/2*x^2 + 3*x - 
11/2>,
  [ 2, 5, 3, 43, 17, 2, 7, 7, 3 ],
  { 5, 17, 29, 47, 61, 71, 107, 113, 131, 139, 179, 181, 313, 389, 439, 601, 
1583, 1877, 2861, 4133 }>,

// no. 497
<-3*x^6 + x^5 - x^4 + 3*x^3 - x^2 - 3*x + 3, 2, [],
  [x^2 + 3/4*x + 3/4,
   x^2 - 2346/2257*x + 1401/2257],
  <x^3 - x^2 + 1, x^3 + 2/3*x^2 + x - 1, 2*x>,
  [ 2, 3, 7, 2, 2, 5, 17 ],
  { 7, 11, 13, 43, 53, 73, 79, 149, 197, 283, 293, 379 }>,

// no. 498
<2*x^6 + 3*x^5 + 2*x^4 + 2*x^3 - 3*x^2 + 2*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 135/94*x + 297/376],
  <x^3 + 2*x - 1, x^3 + 3/2*x^2 - x - 1, 2*x + 1>,
  [ 2, 3, 13, 23, 2 ],
  { 7, 19, 47, 53, 67, 71, 83, 97, 101, 139, 337, 449 }>,

// no. 499
<2*x^6 - x^5 + 3*x^4 - 3*x^2 + x - 3, 2, [],
  [x^2 + 1,
   x^2 - 3/46*x + 181/184],
  <x^3 + 2/7*x^2 - 1/7*x + 3, x^3 - 11/14*x^2 + 1/7*x - 1/2, 13/7*x^2 - 10/7*x>,
  [ 2, 3, 7, 31, 3, 17, 19 ],
  { 11, 13, 31, 47, 53, 59, 67, 139, 317, 347, 359, 379, 673, 977 }>,

// no. 500
<-3*x^6 - x^5 + 3*x^4 - 2*x^3 + 2*x^2 - 3*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 12068/26437*x + 23204/26437],
  <x^3 - 2*x^2 + x + 1, x^3 + 7/3*x^2 + 3*x + 2/3, -x^2 + 4*x + 1>,
  [ 2, 2, 2, 2, 23, 5 ],
  { 5, 13, 17, 31, 83, 97, 101, 191 }>,

// no. 501
<3*x^6 - 3*x^5 + 2*x^4 - 3*x^3 + 3*x^2 - 3*x - 2, 2, [],
  [x^2 + x + 2,
   x^2 - 6554129/10201031*x - 7888578/10201031],
  <x^3 + x^2 - x + 3, x^3 - 2*x^2 + 19/12*x - 11/12, -5/2*x^2 + 4*x - 5/2>,
  [ 3 ],
  { 5, 7 }>,

// no. 502
<-2*x^6 - x^5 - 2*x^4 + x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 + 3/2*x + 11/6,
   x^2 - 78/211*x + 769/844],
  <x^3 - 4/3*x^2 + x + 1, x^3 + 11/6*x^2 + 5/2*x - 1, -1/3*x^2 + 3*x + 1>,
  [ 2, 3, 7, 41, 2, 19, 11 ],
  { 5, 11, 13, 29, 47, 59, 61, 67, 71, 89, 109, 151, 197, 227, 283, 331, 569 }>,

// no. 503
<2*x^6 + x^5 - 3*x^4 - 3*x^3 + 3*x^2 + 3*x + 2, 2, [],
  [x^2 + 3*x + 1,
   x^2 + 33/47*x - 1/47],
  <x^3 + 4/7*x^2 - 9/7*x - 1, x^3 - 1/14*x^2 - 3/14*x - 1, 2/7*x^2 + 13/7*x>,
  [ 2, 2, 29, 11 ],
  { 3, 19, 23, 113, 139, 167, 223, 263, 431 }>,

// no. 504
<3*x^6 - 2*x^5 - 2*x^4 - x^3 - 3*x - 2, 2, [],
  [x^2 - x - 1,
   x^2 - 146/611*x - 1601/611],
  <x^3 - 2/3*x^2 + 1, x^3 - x - 2, -x^2 + 2>,
  [ 2, 17 ],
  { 11, 19, 37, 61 }>,

// no. 505
<-3*x^6 + x^5 + 3*x^4 - 2*x^3 + x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 13/11*x + 61/121],
  <x^3 - 3/7*x^2 + 24/7*x + 11/7, x^3 + 2/21*x^2 - 23/21*x + 2/21, -22/7*x^2 - 
6/7*x + 13/7>,
  [ 3, 13, 7, 5, 3, 2 ],
  { 5, 11, 13, 89, 107, 197, 499, 661, 761 }>,

// no. 506
<2*x^6 + 3*x^5 + 2*x^4 - 2*x^3 + x^2 + 2*x + 3, 2, [],
  [x^2 + 2*x + 2,
   x^2 + 61166/35569*x - 23422/35569],
  <x^3 - x^2 - 1/4*x + 3/4, x^3 + 5/2*x^2 + 29/8*x + 13/8, -1/2*x^2 - 7/4*x + 
3/4>,
  [ 3, 5, 2, 7, 37 ],
  { 3, 5, 17, 19, 37, 53, 89, 103, 199, 353, 523 }>,

// no. 507
<-3*x^6 + 2*x^5 + 2*x^4 + 2*x^3 + x^2 + 2*x - 1, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 620/4351*x + 6065/17404],
  <x^3 - 7/6*x^2 + x - 5/3, x^3 + 1/2*x^2 - x - 1, -1/2*x^2 + x + 2>,
  [ 2 ],
  { 23, 127 }>,

// no. 508
<3*x^6 + 2*x^5 - 3*x^4 - 2*x^3 - x^2 - 3*x + 3, 2, [],
  [x^2 + 15*x + 9,
   x^2 + 79/109*x - 71/109],
  <x^3 - 1/3*x^2 + 1, x^3 + x^2 - x - 2, -x^2 + 3>,
  [ 3 ],
  { 7, 31, 293 }>,

// no. 509
<2*x^6 - 3*x^5 - x^4 - 2*x^3 - 3*x^2 + 2*x - 3, 2, [],
  [x^2 + 2,
   x^2 - 1364/679*x - 2294/679],
  <x^3 - 1/2*x^2 - x + 6, x^3 - x^2 - 2*x - 1, -2*x^2 + 4*x + 3>,
  [ 2, 7, 17 ],
  { 3, 7, 19, 29, 53, 359 }>,

// no. 510
<3*x^6 - 2*x^5 + x^4 + x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - 14/13*x - 37/13,
   x^2 - 2*x + 49/47],
  <x^3 + x + 1, x^3 - 2/3*x^2 - x - 4/3, x^2 + 2*x + 1>,
  [ 3, 3, 2, 2, 5, 2, 2, 19, 2, 7, 11 ],
  { 5, 11, 13, 17, 31, 53, 139, 149, 151, 163, 239, 241, 281, 401, 409, 449, 
479, 499, 677, 709, 797, 829 }>,

// no. 511
<2*x^6 - 2*x^5 - 3*x^4 - 2*x^3 - 3*x - 3, 2, [],
  [x^2 + 33/17*x + 19/17,
   x^2 - 1137/1439*x - 3943/1439],
  <x^3 - x^2 - 24/7*x - 3, x^3 - 1/14*x + 1/2, -2*x^2 - 5/7*x>,
  [ 3, 3, 5, 2, 7 ],
  { 5, 17, 41, 47, 61, 71, 73, 157, 163, 313, 607, 727, 809 }>,

// no. 512
<-2*x^6 - 3*x^5 - 2*x^4 - 3*x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 + 1/2*x - 1/6,
   x^2 + 1020/283*x + 3721/1132],
  <x^3 + 5/2*x^2 + 7/2*x + 1, x^3 - x^2 + 2*x - 1, 2*x^2 + 1>,
  [ 3, 3, 2, 13, 7, 37, 17 ],
  { 5, 7, 13, 19, 41, 47, 79, 101, 137, 193, 313, 353, 439 }>,

// no. 513
<3*x^6 + x^5 - 2*x^4 - 2*x^3 + 2*x^2 - x + 2, 2, [],
  [x^2 - 2*x - 1,
   x^2 - 446/327*x + 577/327],
  <x^3 + 4/3*x^2 + 1/3*x - 2/3, x^3 - x^2 - 1, x^2 + 2*x>,
  [ 2, 31, 11, 11, 3, 5, 17 ],
  { 5, 7, 11, 13, 19, 29, 53, 89, 107, 113, 179, 197, 857 }>,

// no. 514
<3*x^6 - x^5 - 3*x^4 + 2*x^2 + x - 3, 2, [],
  [x^2 - 4/3*x + 1,
   x^2 - 30596/34633*x - 382759/34633],
  <x^3 + 3*x^2 - x - 4, x^3 - 10/3*x^2 - 19/3*x + 31/3, 7*x^2 + 2*x - 11>,
  [ 2, 2, 2, 2, 11, 3 ],
  { 3, 7, 23, 29, 61, 71, 167, 191, 673 }>,

// no. 515
<2*x^6 + 2*x^5 - 2*x^4 - 3*x^3 - 3*x^2 + 3*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 335/257*x + 1609/1028],
  <x^3 + 3*x^2 - 3*x + 1, x^3 - 2*x^2 - 1/2, -4*x^2 + 2*x>,
  [ 2, 2, 2, 2, 3, 2, 5, 37, 7 ],
  { 7, 11, 31, 59, 101, 103, 127, 139, 173, 181, 197, 199, 229, 293, 337, 991 
}>,

// no. 516
<-3*x^6 + x^5 + x^4 + x^3 + 3*x^2 + 2*x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 181171/79267*x + 630849/317068],
  <x^3 + 1/4*x^2 - x - 1, x^3 - 7/12*x^2 + 4/3*x - 2/3, 5/4*x^2 - 1/2*x>,
  [ 3, 3, 5, 3, 3, 7 ],
  { 5, 11, 13, 17, 19, 83, 131, 139, 179, 239, 359, 1741 }>,

// no. 517
<-2*x^6 + 3*x^5 + 2*x^4 + 2*x^3 - x^2 + 3*x - 1, 2, [],
  [x^2 - 1/2*x + 1,
   x^2 - 216963/132806*x + 363845/199209],
  <x^3 + 5*x - 2, x^3 - 3/2*x^2 + 1/8*x - 1/4, 7/2*x^2 - 5/2*x>,
  [],
  { 7 }>,

// no. 518
<-3*x^6 + 2*x^5 - 3*x^3 - x^2 - 2*x + 3, 2, [],
  [x^2 - 1/2,
   x^2 - 48987/74971*x + 15493/23068],
  <x^3 - 1/2*x^2 + 2*x + 4, x^3 - 1/6*x^2 - 1/6, -5/2*x^2 - 3/2*x + 1>,
  [ 3, 2, 2, 11, 2 ],
  { 3, 19, 23, 53, 89, 97, 107, 139, 191 }>,

// no. 519
<-3*x^6 + 2*x^5 - 2*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 + 3/2*x + 3/2,
   x^2 - 678/6007*x + 27453/24028],
  <x^3 + 3/2*x^2 + 7/2*x + 2, x^3 - 13/6*x^2 + 1/2*x + 2, -3/2*x^2 + 7/2*x + 3>,
  [ 3, 3, 2, 2, 5, 17, 29 ],
  { 11, 13, 17, 19, 23, 43, 59, 79, 89, 233, 241, 1061, 1453 }>,

// no. 520
<-2*x^6 + x^4 + 3*x^3 + 3*x^2 - x - 2, 2, [],
  [x^2 + x + 3/2,
   x^2 + 2528/1889*x + 1632/1889],
  <x^3 - 1/3*x^2 + 2*x - 3, x^3 + 1/3*x^2 - 3/2*x - 1, -4/3*x^2 + x + 2>,
  [ 3 ],
  { 13, 53 }>,

// no. 521
<3*x^6 + 3*x^5 + x^4 + x^3 + 2*x - 2, 2, [],
  [x^2 + x - 1,
   x^2 + 1776/47*x - 2712/47],
  <x^3 + 3*x^2 + 10/3*x + 2, x^3 - 2*x^2 - 1, 3*x^2 + 3*x + 2>,
  [ 3, 7, 5, 11, 17 ],
  { 7, 11, 13, 17, 29, 59, 67, 673 }>,

// no. 522
<-3*x^6 + 2*x^5 - x^4 + x^3 + 2*x^2 + 2*x - 1, 2, [],
  [x^2 + 1/2*x + 1/4,
   x^2 + 27514/22633*x + 14165/22633],
  <x^3 - 2*x^2 + 4*x - 2, x^3 + 4/3*x^2 + 1/3*x - 1/3, -2*x^2 - 2*x + 1>,
  [ 3, 3, 19, 2, 5, 13 ],
  { 3, 5, 7, 13, 19, 37, 47, 67, 107, 229, 673, 709, 743, 863, 919, 937 }>,

// no. 523
<-3*x^6 - 3*x^5 - 3*x^4 + 3*x^3 + x^2 + 3*x - 2, 2, [],
  [x^2 + 3/4*x + 3/2,
   x^2 - 21/229*x + 121/916],
  <x^3 + x^2 + 7/16*x - 19/16, x^3 + 31/48*x - 9/16, -1/2*x^2 + 5/16*x - 1/16>,
  [ 3, 31, 7, 19 ],
  { 17, 19, 29, 37, 47, 269, 271, 457 }>,

// no. 524
<2*x^6 - 2*x^5 - 2*x^4 + 3*x^3 - 3*x^2 - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 143/967*x + 7393/3868],
  <x^3 - 2*x + 2, x^3 - x^2 - x - 1/2, -2*x^2 + x + 1>,
  [ 2, 3, 13, 5, 7, 2, 11, 19 ],
  { 5, 13, 29, 31, 37, 41, 59, 67, 73, 89, 97, 103, 113, 127, 149, 283, 313, 
389, 677, 829, 1549 }>,

// no. 525
<3*x^6 - x^5 + 3*x^4 + x^3 - 3*x - 1, 2, [],
  [x^2 - x - 1,
   x^2 - 94/239*x - 109/239],
  <x^3 + 1/6*x^2 + 5/6*x + 1/3, x^3 - 1/2*x^2 - 1/2*x - 1, -3/2*x^2 - 3/2*x>,
  [ 2, 2, 5, 2, 31, 19, 11, 3, 17 ],
  { 3, 7, 13, 17, 31, 53, 179, 211, 317, 373, 379, 431, 607, 1289, 1733, 3329, 
4021, 4801, 4967 }>,

// no. 526
<-3*x^6 - x^5 - 3*x^4 - 3*x^3 + 3*x^2 - 2*x + 2, 2, [],
  [x^2 + 1,
   x^2 + 1158/1261*x + 553/1261],
  <x^3 + 4/3*x^2 + 2/3*x + 2/3, x^3 - x^2 + 2*x - 1, x^2 + x>,
  [ 2, 5, 3, 5, 3 ],
  { 3, 13, 31, 79, 83, 101, 109, 113 }>,

// no. 527
<2*x^6 + 3*x^5 - x^4 + 3*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 + 9/2*x - 6,
   x^2 - 24/833*x + 1168/833],
  <x^3 + 3/2*x^2 - 3/2*x + 2, x^3 - x - 1, -2*x^2 - x + 1>,
  [ 2, 11, 7 ],
  { 5, 19, 29, 37 }>,

// no. 528
<3*x^6 + x^4 - 3*x^3 - x^2 + x + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 1077/25357*x + 19159/76071],
  <x^3 - 3/4*x - 1/2, x^3 + x - 2/3, 1/2*x^2 + 1/2*x + 1>,
  [ 2, 3, 23, 7, 5, 13 ],
  { 5, 11, 29, 31, 37, 47, 109, 127, 131, 211, 229, 233, 241, 281 }>,

// no. 529
<-x^6 + 3*x^5 + x^4 - 2*x^3 - 3*x^2 - 3*x - 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 27/26*x + 9/26],
  <x^3 - 3/2*x^2 + 3/2*x - 3, x^3 - 3/2*x^2 - 5/2*x - 1, -3/2*x^2 + 3/2*x + 1>,
  [ 2, 3 ],
  { 3, 5, 17, 19 }>,

// no. 530
<-3*x^6 + 2*x^5 - 3*x^4 - x^3 + x^2 + 3*x + 3, 2, [],
  [x^2 - 1/2*x - 1/4,
   x^2 + 3706/4179*x + 2893/16716],
  <x^3 + 1/3*x^2 + 4/3*x - 1/3, x^3 - x^2 + 3*x - 1, 3*x^2 - x + 2>,
  [ 2, 2, 3, 3 ],
  { 5, 13, 83, 211, 547 }>,

// no. 531
<-3*x^6 + 3*x^5 - 2*x^4 + 2*x^3 + 3*x^2 + x + 2, 2, [],
  [x^2 + 1,
   x^2 - 7/4597*x - 143519/1673308],
  <x^3 + 3/4*x^2 + 2*x + 1, x^3 - 7/4*x^2 + x - 2/3, 7/4*x^2 - 3/2*x>,
  [ 3, 3, 2, 11, 5, 29 ],
  { 5, 11, 17, 23, 29, 43, 59, 163, 229, 311, 463, 1901 }>,

// no. 532
<-x^6 + x^5 + 3*x^4 - 3*x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 454/193*x + 217/193],
  <x^3 + x + 1, x^3 - x^2 + 3, 2*x^2>,
  [ 3, 3, 5, 7, 13, 2 ],
  { 29, 31, 41, 47, 89, 101, 109, 163, 211, 227, 281, 283, 331, 457, 499 }>,

// no. 533
<2*x^6 + x^5 + x^4 + 2*x^3 + 3*x - 3, 2, [],
  [x^2 + 3/7,
   x^2 + 984/1097*x - 8229/4388],
  <x^3 + x^2 + 3, x^3 - 1/2*x^2 + 1/2*x - 1/2, -x^2 + 2*x>,
  [ 3, 19, 5, 2, 2 ],
  { 5, 7, 17, 47, 73, 83, 109, 197, 373 }>,

// no. 534
<3*x^6 - 2*x^4 - 2*x^2 + x - 1, 2, [],
  [x^2 + x + 1/2,
   x^2 + 13/2*x - 145/8],
  <x^3 + x^2 - 1/6*x + 1/3, x^3 - x^2 + 1/2*x - 1, -3/2*x>,
  [ 5, 5, 2, 3, 2, 2, 7, 11 ],
  { 7, 11, 17, 19, 41, 53, 173, 211, 439, 937 }>,

// no. 535
<-3*x^6 - x^4 + 3*x^3 - x^2 + 3*x - 2, 2, [],
  [x^2 + 1,
   x^2 - 4/13*x + 1/13],
  <x^3 + x^2 - 1, x^3 - x^2 + 5/3*x - 1, -x^2 - x + 1>,
  [ 2, 2, 2, 7, 23, 29, 5, 3 ],
  { 5, 29, 37, 61, 67, 73, 101, 179, 487, 719, 727, 1471 }>,

// no. 536
<-2*x^6 + x^5 + 3*x^4 + 3*x^3 + 2*x^2 + x - 2, 2, [],
  [x^2 - 7/3*x + 1,
   x^2 + 209/139*x + 99/139],
  <x^3 - 1/2*x^2 + 3/2*x - 1, x^3 - x - 1, 2*x^2>,
  [ 3, 23, 7, 2, 2, 19 ],
  { 7, 11, 13, 17, 19, 43, 59, 73, 103, 109, 223 }>,

// no. 537
<-3*x^6 + 3*x^5 + x^3 + x^2 + x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 1788/11749*x + 184/11749],
  <x^3 + 1/7*x^2 - 6/7*x - 1, x^3 - 8/7*x^2 + 25/21*x + 1/3, -5/7*x^2 - 12/7*x +
1>,
  [ 5, 5, 2, 3, 19, 2 ],
  { 13, 17, 19, 23, 31, 47, 59, 67, 571, 607 }>,

// no. 538
<3*x^6 + 3*x^5 - 3*x^4 + 2*x^3 - 2*x^2 + 3*x - 1, 2, [],
  [x^2 + 2*x - 1,
   x^2 - 590/1307*x + 265/1307],
  <x^3 + 2*x^2 - 7/3*x + 2/3, x^3 - x^2 + 2*x - 1, 2*x^2 - 4*x + 1>,
  [ 2, 2, 2, 2, 3, 13 ],
  { 13, 17, 19, 23, 43, 397 }>,

// no. 539
<-2*x^6 - x^3 - 3*x^2 + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 1291/1507*x + 3841/6028],
  <x^3 + 1/2, x^3 + 2*x - 2, -2*x^2 + x + 1>,
  [ 2, 3, 11, 19, 2, 3, 29, 5, 13, 7 ],
  { 5, 23, 29, 37, 43, 53, 67, 71, 83, 101, 137, 197, 233, 241, 269, 293, 349, 
421, 523, 563, 599, 1061, 1201, 1259, 1723 }>,

// no. 540
<3*x^6 + x^5 - 3*x^4 - 2*x^3 - 3*x^2 - 3*x - 2, 2, [],
  [x^2 + 4/3*x + 1,
   x^2 - 4464/2543*x + 2363/2543],
  <x^3 - 7/6*x^2 - 2/3, x^3 + 3/2*x^2 + 3/2, 3/2*x^2 - 3/2*x + 1>,
  [ 2, 7, 7, 3, 5, 13, 17, 11 ],
  { 3, 19, 23, 31, 37, 47, 53, 71, 101, 113, 127, 157, 257, 409, 443, 503, 523, 
937, 997 }>,

// no. 541
<3*x^6 + x^5 - 3*x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 275453/46374*x + 907841/139122],
  <x^3 + 4/3*x^2 - 3*x + 2, x^3 - x^2 + 1/4*x - 1/2, 7/2*x^2 - 5/2*x + 1>,
  [ 2, 11, 23, 3, 5 ],
  { 5, 17, 37, 59, 73, 163, 211, 233, 397, 401, 701, 809, 859 }>,

// no. 542
<2*x^6 + x^5 - 2*x^4 + 2*x^3 + x^2 + 2*x - 1, 2, [],
  [x^2 + x - 1,
   x^2 + 360/271*x - 180/271],
  <x^3 + x^2 + 2, x^3 - 1/2*x^2 - 1/2*x - 1/2, 2*x + 1>,
  [ 3, 7, 3, 13 ],
  { 3, 11, 13, 43, 47, 97, 103, 149 }>,

// no. 543
<-x^6 + x^5 + x^4 + x^2 - 3, 2, [],
  [x^2 - x + 2,
   x^2 - 37/13*x + 2],
  <x^3 - 3, x^3 - x^2 - 1, -x^2 + 2*x>,
  [ 3, 3, 7, 11, 3, 19, 13 ],
  { 11, 23, 37, 53, 73, 139, 199, 211, 467, 547, 691, 829, 977 }>,

// no. 544
<2*x^6 - x^5 - 2*x^4 - x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 - 2,
   x^2 - 2356/943*x + 1478/943],
  <x^3 + 1/2*x^2 - 2*x + 1, x^3 - x^2 - 3*x - 2, -3*x^2 + 1>,
  [ 2, 5, 5, 2, 17, 2, 3, 19, 7 ],
  { 3, 11, 13, 17, 37, 59, 73, 113, 137, 181, 317, 353, 709, 751 }>,

// no. 545
<-2*x^6 - 2*x^5 + 3*x^4 - x^3 + 3*x + 2, 2, [],
  [x^2 - 1/3*x - 1/3,
   x^2 - 2972/561*x + 11768/561],
  <x^3 + 2*x^2 + 2*x + 1/2, x^3 - x^2 + 3*x - 1, 3*x^2 + x + 1>,
  [ 2, 2, 5 ],
  { 3, 7, 37 }>,

// no. 546
<-3*x^6 + x^5 + 2*x^3 + x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 59/61*x + 37/61],
  <x^3 - 5/4*x^2 + x - 1, x^3 + 11/12*x^2 + 2/3*x + 2/3, -5/4*x^2 - 1/2*x + 1>,
  [ 2, 3, 5, 3, 7, 19, 2 ],
  { 5, 7, 11, 17, 19, 41, 109, 127, 167, 191, 269, 331, 563, 607, 1097, 1297 }>,

// no. 547
<-2*x^6 - 3*x^5 + x^4 - 3*x^3 - 2*x^2 + 2*x - 2, 2, [],
  [x^2 + 4/3*x + 2,
   x^2 + 36/11*x + 38/11],
  <x^3 + 1/2*x^2 + 1, x^3 + x^2 - x + 1, x>,
  [],
  { 37 }>,

// no. 548
<-3*x^6 - x^5 + 3*x^4 + x^3 + x^2 + 2*x - 1, 2, [],
  [x^2 + 1,
   x^2 + 922660/587613*x + 692893/587613],
  <x^3 - 1/4*x^2 - 1, x^3 + 7/12*x^2 - 1/3*x - 2/3, -5/4*x^2 + 3/2*x + 1>,
  [ 3, 13, 3 ],
  { 7, 23, 41, 109 }>,

// no. 549
<-2*x^6 + 2*x^5 - x^4 - 3*x^3 + 3*x^2 + x + 3, 2, [],
  [x^2 - 1/2,
   x^2 + 24112/97291*x + 331288/291873],
  <x^3 - 3*x^2 + x + 3, x^3 + 2*x^2 + 27/2*x + 13, 4*x^2 - 6*x - 9>,
  [],
  { 137 }>,

// no. 550
<-2*x^6 - 2*x^5 - 2*x^4 + 2*x^2 + 3*x - 1, 2, [],
  [x^2 - x + 1/2,
   x^2 - 579/1003*x + 1433/2006],
  <x^3 + 2*x - 1, x^3 + x^2 - 1/2*x - 1, -x^2 + 1>,
  [ 5, 5, 7, 3, 3, 2, 41 ],
  { 3, 11, 13, 23, 47, 53, 101, 109, 137, 139, 331, 383, 397, 599 }>,

// no. 551
<3*x^6 + 3*x^5 + 2*x^4 + x^3 - x^2 + 3*x + 2, 2, [],
  [x^2 - 1/2*x + 1,
   x^2 + 4609/2902*x + 2903/4353],
  <x^3 + 1/2*x^2 - 5/2*x - 1, x^3 + 1/2*x^2 + 5/6*x - 1/3, 5/2*x^2 + 3/2*x + 1>,
  [ 3, 11, 3, 2, 5 ],
  { 7, 29, 31, 43, 61, 281, 349, 383 }>,

// no. 552
<3*x^6 - 3*x^5 + x^4 - x^3 + 2*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 6315/4069*x + 4977/4069],
  <x^3 + 6*x^2 - 2*x + 1, x^3 - 7*x^2 - 11/3*x - 4/3, 12*x^2 + x + 1>,
  [ 3, 3, 3, 2, 19, 2, 5, 41 ],
  { 13, 23, 43, 53, 73, 101, 113, 131, 149, 157, 683, 1579, 1997 }>,

// no. 553
<-x^6 + 3*x^5 + 3*x^4 + x^2 + 2*x - 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 - 111/1313*x + 6649/6565],
  <x^3 - 3*x^2 + 4*x - 6, x^3 - 6*x - 14, -x^2 + x - 9>,
  [ 3, 3 ],
  { 3, 11 }>,

// no. 554
<3*x^6 - x^5 + 3*x^4 - x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 + 3/2*x - 3/2,
   x^2 + 47/397*x - 1593/3176],
  <x^3 + x + 1, x^3 - 1/3*x^2 - 1, 2*x + 1>,
  [],
  { 11 }>,

// no. 555
<2*x^6 - x^5 + x^4 + 3*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 + 15/2*x - 21/2,
   x^2 + 9823/434*x - 11011/62],
  <x^3 - 3*x^2 + 11/4*x - 7/4, x^3 + 5/2*x^2 + 17/8*x + 7/8, 5/2*x^2 + 3/4*x - 
1/4>,
  [ 2, 2, 13, 7, 47, 23 ],
  { 5, 7, 17, 19, 43, 79, 127, 307, 443, 683, 757, 761, 811 }>,

// no. 556
<-2*x^6 + 3*x^5 + 2*x^4 + 2*x^3 - 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 3/2*x + 3/2,
   x^2 - 280/129*x + 208/129],
  <x^3 - 3/2*x^2 - 3/2, x^3 - x - 1, x>,
  [ 2, 3, 5, 5, 11, 5, 3, 43, 31 ],
  { 5, 11, 29, 61, 89, 109, 113, 181, 197, 227, 397, 433, 499, 829, 1033, 1187, 
1279, 1583 }>,

// no. 557
<-x^6 - x^5 + 2*x^4 - 3*x^3 - 2*x^2 + 3*x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 439/314*x + 249/157],
  <x^3 - 6/5*x^2 + 2/5*x + 19/5, x^3 + 11/5*x^2 + 3/5*x + 6/5, -3/5*x^2 - 9/5*x 
- 8/5>,
  [ 2, 5, 3, 2, 29, 5, 3 ],
  { 3, 11, 17, 19, 23, 181, 263, 419, 641 }>,

// no. 558
<3*x^6 - 3*x^5 + 2*x^4 + 3*x^3 - x^2 - x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 76/61*x + 8/61],
  <x^3 + 2/3*x - 1/3, x^3 - x^2 - 3*x - 2, 3*x^2 + 2*x>,
  [ 2, 3, 11, 2, 3 ],
  { 13, 19, 127, 149, 163, 293, 373, 443 }>,

// no. 559
<-x^6 + 3*x^5 - 2*x^4 + 3*x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 153/37*x + 733/185],
  <x^3 - 2*x^2 + 3*x - 3, x^3 - x^2 - 2*x - 1, x^2>,
  [ 3, 3, 2, 17 ],
  { 7, 61, 71, 109, 167, 257 }>,

// no. 560
<-3*x^6 + 3*x^5 - 3*x^4 + x^3 - 3*x - 1, 2, [],
  [x^2 + 1/4*x + 1/4,
   x^2 - 103/124*x + 37/124],
  <x^3 - x^2 + 2*x + 1, x^3 + 1/3*x + 1/3, 2*x^2 + x>,
  [ 3, 11, 2, 5, 7, 29 ],
  { 5, 11, 13, 23, 29, 31, 53, 89, 109, 263, 269, 317, 347, 397, 557, 569 }>,

// no. 561
<2*x^6 + 3*x^5 - 3*x^4 + 2*x^3 - x^2 + 3*x - 1, 2, [],
  [x^2 + 2*x - 1,
   x^2 + 326/161*x - 145/161],
  <x^3 + 5*x^2 - 11*x + 10, x^3 - 7/2*x^2 + 9*x - 17/2, -6*x^2 + 14*x - 13>,
  [ 2, 5 ],
  { 3, 97 }>,

// no. 562
<2*x^6 + 3*x^5 - x^3 - 2*x^2 - 3, 2, [],
  [x^2 + 1,
   x^2 + 88/291*x + 481/873],
  <x^3 + x^2 - 1/2*x + 7/4, x^3 + 1/2*x^2 - 2, -1/2*x + 2>,
  [ 2, 3, 5, 3, 23, 7 ],
  { 5, 19, 23, 29, 127, 131, 211, 233, 251, 311, 313, 509, 659 }>,

// no. 563
<-3*x^6 + 3*x^5 - x^4 + 3*x^3 + 2*x^2 - x + 2, 2, [],
  [x^2 - 1/4*x + 1/4,
   x^2 - 1384/769*x + 796/769],
  <x^3 - 4/7*x^2 + 5/7*x - 1, x^3 - 3/7*x^2 - 8/21*x + 1/3, 6/7*x^2 + 3/7*x + 
1>,
  [ 2, 3, 7, 5, 2, 3, 19, 17, 7 ],
  { 11, 23, 43, 47, 59, 67, 73, 101, 113, 127, 149, 151, 167, 193, 199, 229, 
269, 271, 281, 293, 317, 379, 563, 739, 1129, 1759, 1999 }>,

// no. 564
<-2*x^6 + x^5 + 2*x^4 + 2*x^3 + 3*x^2 - 2*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 + 284/361*x + 24/361],
  <x^3 + 1/2*x^2 - 1/2*x + 1/2, x^3 - x^2 - 2, 1>,
  [ 3, 2, 3, 5, 11 ],
  { 19, 23, 31, 127, 131, 223 }>,

// no. 565
<-3*x^6 + 3*x^5 + x^4 + 2*x^3 + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 6849/18919*x + 38297/56757],
  <x^3 - x^2 - 4/3, x^3 - 1/4*x + 1/4, -1/2*x^2 + 1/2*x + 1>,
  [ 2, 3, 13, 2, 17, 7 ],
  { 19, 29, 101, 131, 151, 311, 349, 383, 457, 601, 661, 691 }>,

// no. 566
<3*x^6 - x^5 + 2*x^4 + x^3 + x^2 + x + 3, 2, [],
  [x^2 + x - 1,
   x^2 + 565/33*x + 611/33],
  <x^3 + 1/2*x^2 - 7/2*x + 1, x^3 - 5/6*x^2 + 23/6*x + 1, -3/2*x^2 + 13/2*x>,
  [ 2, 5, 7 ],
  { 3, 5, 11, 19, 31, 131 }>,

// no. 567
<-3*x^6 - 2*x^5 + 2*x^4 - x^3 + 3*x^2 - 3*x - 1, 2, [],
  [x^2 + 1/2*x + 1,
   x^2 - 5835/4274*x + 1025/2137],
  <x^3 - x^2 + 2*x + 1, x^3 + 5/3*x^2 + 1/3*x + 1/3, 2*x^2 + 3*x>,
  [ 2, 3, 5, 7 ],
  { 11, 17, 19, 79, 137, 457 }>,

// no. 568
<-2*x^6 + x^5 - x^4 + x^3 - 3*x^2 - 3*x + 2, 2, [],
  [x^2 + 163/358*x - 119/358,
   x^2 - 677/566*x + 569/566],
  <x^3 - 3/2*x^2 + 1/2*x + 1, x^3 + x^2 + 2*x - 1, -x^2 + 2*x>,
  [ 2, 3, 2, 2, 2, 5, 29, 13 ],
  { 7, 23, 37, 41, 53, 83, 101, 113, 179, 181, 401, 467 }>,

// no. 569
<3*x^6 - 3*x^4 - 3*x^3 + 2*x^2 - x - 3, 2, [],
  [x^2 - x - 3,
   x^2 + 189/179*x + 79/179],
  <x^3 + 1/4*x + 1, x^3 - 4/3*x - 4/3, -1/2*x^2 + 2*x + 1>,
  [ 2, 2, 3, 11, 3, 5, 7, 5, 13, 19 ],
  { 11, 13, 23, 37, 73, 101, 137, 173, 181, 223, 227, 251, 577, 647, 709, 1237, 
1319, 1321, 1559, 1783, 1789 }>,

// no. 570
<-3*x^6 - x^5 - 2*x^4 - x^3 + 3*x - 1, 2, [],
  [x^2 - 3/4*x + 1/4,
   x^2 + 4/109*x + 148/109],
  <x^3 - 5/3*x^2 + 10/3*x - 5/3, x^3 + 2*x^2 + x - 1, -x^2 - 3*x + 2>,
  [ 2, 5, 2, 3, 5 ],
  { 3, 5, 17, 19, 41, 83, 179, 317 }>,

// no. 571
<2*x^6 - x^5 + 3*x^4 + 2*x^2 + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 32/23*x + 8/23],
  <x^3 + 1/2*x^2 - 1, x^3 - x^2 - 1, 2*x^2 + x>,
  [ 5, 2, 2, 3, 2 ],
  { 3, 5, 7, 11, 13, 41, 59, 73 }>,

// no. 572
<3*x^6 - x^5 + 2*x^4 + 2*x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 343945/21107*x - 316225/21107],
  <x^3 - 3*x^2 + 5*x - 4, x^3 + 8/3*x^2 + 11/3*x + 7/3, x + 5>,
  [ 2, 2, 13, 3, 31, 3, 5, 19, 7, 37, 47 ],
  { 5, 11, 17, 23, 29, 37, 61, 83, 109, 179, 263, 277, 313, 613, 647, 739, 1163,
1217, 1597, 1637, 2029, 3347, 3413, 3467, 3469, 3517 }>,

// no. 573
<-x^6 - 2*x^5 - x^4 + 3*x^3 + x + 2, 2, [],
  [x^2 - x + 1,
   x^2 + 20/409*x + 68/409],
  <x^3 + x^2 + 3*x + 2, x^3 + x^2 + x - 1, 2*x^2 + 2*x>,
  [ 2, 2, 3, 2, 3, 7, 11, 5, 13 ],
  { 3, 5, 11, 13, 17, 23, 37, 67, 79, 101, 103, 131, 167, 251, 349, 491, 499 }>,

// no. 574
<2*x^6 - 2*x^4 - x^3 - x^2 + x - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 2/17*x + 1],
  <x^3 + x^2 - x + 1/2, x^3 - x^2 - x - 1, 2*x^2>,
  [],
  { 13 }>,

// no. 575
<-3*x^6 - 2*x^5 - 3*x^4 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 + 3/2,
   x^2 - 28/129*x + 49/86],
  <x^3 - 2*x^2 + 3*x - 3/2, x^3 + 8/3*x^2 + 11/3*x - 19/6, -x^2 + 6*x - 7/2>,
  [],
  { 5 }>,

// no. 576
<3*x^6 - 3*x^5 + 2*x^4 - 2*x^3 + x^2 + 2*x + 3, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 144177/96997*x + 648433/2327928],
  <x^3 + 1/2*x^2 + 2*x + 1/2, x^3 - 3/2*x^2 - 2/3*x + 4/3, -1/2*x^2 - 5/2*x + 
1>,
  [ 2, 2 ],
  { 7, 13, 17, 47 }>,

// no. 577
<-x^6 - 2*x^4 - 3*x^3 - 2*x^2 + 2*x + 2, 2, [],
  [x^2 - 1/2,
   x^2 - 16/7*x + 136/49],
  <x^3 - 2*x^2 + 4*x - 2, x^3 + 2*x^2 + 3*x - 1, x^2 - 2*x + 2>,
  [ 2, 2, 3, 7, 5, 43, 13, 17, 3, 47, 37 ],
  { 3, 5, 17, 19, 41, 53, 61, 71, 79, 101, 131, 151, 181, 229, 277, 293, 317, 
349, 457, 461, 853, 997, 1481, 4603, 4751 }>,

// no. 578
<-x^6 - x^5 - 3*x^4 + 2*x^3 + 3*x^2 - 1, 2, [],
  [x^2 - x + 5,
   x^2 + 12/5*x + 8/5],
  <x^3 + 1/5*x^2 + 14/5*x - 2, x^3 + 4/5*x^2 + 1/5*x - 1, -2/5*x^2 - 8/5*x + 1>,
  [],
  { 7 }>,

// no. 579
<3*x^6 + x^5 - x^4 - 3*x^3 + 3*x^2 - x - 3, 2, [],
  [x^2 + 5/6*x - 2,
   x^2 - 4195/5158*x - 5666/2579],
  <x^3 - 1/6*x^2 + 1/6*x + 2/3, x^3 + 1/2*x^2 - 1/2*x - 2, 1/2*x^2 + 1/2*x + 1>,
  [],
  { 13 }>,

// no. 580
<-2*x^6 - x^5 + x^4 - 3*x^3 - x^2 - 3*x - 3, 2, [],
  [x^2 + 7/6*x + 14/9,
   x^2 + 108/139*x + 1708/417],
  <x^3 - x^2 + 1, x^3 + 3/2*x^2 + 3/2*x + 2, -x^2 + 1>,
  [ 3, 5, 7 ],
  { 5, 11, 41, 233, 269 }>,

// no. 581
<3*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - 3*x^2 - 3, 2, [],
  [x^2 - 1/2*x + 1,
   x^2 + 278355/127994*x + 106153/63997],
  <x^3 + x^2 + 1/4*x + 1/2, x^3 - 2*x^2 - 4/3*x - 8/3, 5/2*x^2 + 2*x + 1>,
  [ 5, 3, 3, 5, 2, 2, 7, 13, 11 ],
  { 5, 7, 23, 29, 71, 113, 191, 251, 257, 337, 353, 557, 719, 1153, 1697, 2699 
}>,

// no. 582
<-3*x^6 + x^5 + x^4 + 2*x^3 + x^2 + 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 398472955/894079627*x + 4451815033/3576318508],
  <x^3 - 19/12*x^2 + 11/6*x - 19/12, x^3 + 5/4*x^2 - 1/6*x - 67/36, -1/4*x^2 + 
4/3*x - 29/12>,
  [ 2, 3, 3, 3, 47, 5 ],
  { 11, 23, 37, 73, 83, 139, 149, 163, 199, 331, 499 }>,

// no. 583
<-3*x^6 - 3*x^5 + 2*x^4 - 3*x^3 + x^2 - x - 2, 2, [],
  [x^2 + 1/4*x + 1/4,
   x^2 - 792/1627*x + 5196/11389],
  <x^3 + 2*x^2 + x + 1, x^3 - x^2 + 2/3*x + 1, x^2 + 2*x + 1>,
  [ 2, 3, 3, 3, 11, 29, 13, 17 ],
  { 7, 11, 23, 29, 31, 43, 67, 73, 89, 131, 149, 241, 281, 293, 307, 557, 701 
}>,

// no. 584
<2*x^6 + 3*x^5 - 2*x^4 + 2*x^3 - x - 2, 2, [],
  [x^2 + 3/2*x - 3,
   x^2 + 7/10*x - 83/25],
  <x^3 + 2*x^2 + 4, x^3 - 1/2*x^2 - 9/8*x - 9/4, 3/2*x^2 + x + 4>,
  [ 3, 11 ],
  { 3, 5, 13, 47, 61, 241 }>,

// no. 585
<2*x^6 + 3*x^5 - 3*x^4 - x^3 + x^2 + 3*x + 2, 2, [],
  [x^2 - 9/2*x + 1/2,
   x^2 - 14/3*x - 23/9],
  <x^3 + 12/7*x^2 - 9/7*x - 1, x^3 - 3/14*x^2 - 3/14*x - 1, -6/7*x^2 - 13/7*x>,
  [ 11, 2, 3, 2 ],
  { 3, 5, 31, 43, 59, 73 }>,

// no. 586
<-x^6 - x^5 - 3*x^4 - 3*x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 2*x + 17],
  <x^3 + 4/5*x^2 + 1/5*x + 1, x^3 + 1/5*x^2 + 14/5*x + 1, -2/5*x^2 - 8/5*x>,
  [ 2, 2, 3, 5, 3, 2, 31, 11, 13, 7 ],
  { 3, 7, 17, 19, 29, 37, 41, 71, 97, 101, 103, 139, 149, 157, 163, 347, 353, 
401, 449, 479 }>,

// no. 587
<-x^6 - 3*x^5 + 2*x^3 + x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 565/229*x + 1525/916],
  <x^3 + 2/3*x^2 - 25/9*x + 28/9, x^3 + 7/3*x^2 + 20/9*x + 13/9, -x^2 - 7/9*x - 
11/9>,
  [ 3, 7, 41, 5, 2, 13 ],
  { 11, 31, 73, 79, 103, 277, 373, 883, 997 }>,

// no. 588
<-x^6 + 2*x^5 - 2*x^4 - 2*x^3 - 3*x^2 + x + 2, 2, [ 2 ],
  [x^2 + x + 2,
   x^2 - 103/337*x - 62/337],
  <x^3 - x^2 + 2*x + 1, x^3 - x^2 + 3*x - 2, -2*x^2 + 2*x>,
  [ 3 ],
  { 7, 11, 139 }>,

// no. 589
<3*x^6 - 2*x^5 + 3*x^4 - x^3 + x^2 + x - 3, 2, [],
  [x^2 + 1,
   x^2 - 99280/39489*x + 18928/13163],
  <x^3 + 10*x^2 + 13*x + 7, x^3 - 32/3*x^2 - 77/3*x - 52/3, -19*x^2 - 32*x - 
19>,
  [ 2, 2, 3, 5, 7, 47, 13, 17 ],
  { 3, 5, 11, 41, 61, 79, 89, 103, 109, 113, 241, 337, 503, 641, 647, 1033, 1499
}>,

// no. 590
<-3*x^6 + 2*x^4 + x^3 - 2*x^2 + x + 3, 2, [],
  [x^2 + x + 1/3,
   x^2 + 558/13153*x - 1607/13153],
  <x^3 - x^2 - 1/3*x + 2/3, x^3 + x^2 + x - 1, -x^2 + 2*x + 1>,
  [ 3, 5, 2, 2 ],
  { 5, 7, 13, 17, 53, 61, 131 }>,

// no. 591
<-3*x^6 + x^5 - 3*x^4 + x^3 + 2*x^2 + 3*x - 2, 2, [],
  [x^2 - x + 2,
   x^2 + 524/1569*x + 136/523],
  <x^3 - 3/4*x^2 + 3*x - 2, x^3 + 5/12*x^2 - 1/3, 9/4*x^2 - 1/2*x>,
  [],
  { 13 }>,

// no. 592
<-2*x^6 - x^5 - x^4 - 3*x^3 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 - x + 2,
   x^2 - 83817/61561*x + 867962/554049],
  <x^3 + 1/2*x^2 + 1/4*x + 11/8, x^3 + 3/8*x + 3/16, 1/2*x^2 + 1/2*x - 15/8>,
  [ 2, 2, 2, 3, 3, 19, 11 ],
  { 5, 11, 19, 31, 73, 107, 173, 193, 419, 761, 1451 }>,

// no. 593
<-3*x^6 - 3*x^5 + 3*x^3 + 2*x - 1, 2, [],
  [x^2 - 6/7*x + 2/7,
   x^2 - 502/487*x + 146/487],
  <x^3 + 1/3*x - 1/3, x^3 + x^2 + x - 1, 2*x^2>,
  [ 2, 3, 5, 2, 3, 7, 29 ],
  { 7, 11, 13, 29, 73, 79, 89, 103, 109, 113, 131, 157, 181, 197, 359, 409 }>,

// no. 594
<3*x^6 - 2*x^4 - 3*x^3 - 3*x^2 + 2*x - 1, 2, [],
  [x^2 - 2,
   x^2 - 14/13*x + 17/13],
  <x^3 - x^2 + 2*x - 10/3, x^3 + x^2 - 2*x + 1, x^2 - 4*x + 3>,
  [],
  { 13 }>,

// no. 595
<-3*x^6 - x^5 - 3*x^4 - 2*x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 - 2/7*x + 1/7,
   x^2 + 162/139*x + 333/139],
  <x^3 + 5*x - 2, x^3 + 1/3*x^2 + 1/12*x - 1/6, 7/2*x^2 - 1/2*x>,
  [ 3, 3, 3, 2, 31, 11, 5, 5, 17 ],
  { 5, 7, 17, 23, 37, 47, 83, 89, 97, 107, 137, 173, 283, 461, 503, 659, 709, 
857, 907, 1249, 1759 }>,

// no. 596
<-2*x^6 + 3*x^5 - 2*x^4 - 2*x^3 - 2*x + 2, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 16162/102057*x + 113417/102057],
  <x^3 - 7/6*x^2 + 4/3, x^3 - 1/3*x^2 + 3/2*x - 7/12, 4/3*x^2 - 3/2*x - 2/3>,
  [ 2, 2, 3, 3, 41, 7, 2, 13, 5, 7 ],
  { 7, 11, 19, 61, 79, 97, 193, 233, 271, 389, 409, 487, 547, 587, 607, 1069, 
1723 }>,

// no. 597
<2*x^6 + 2*x^5 + 2*x^4 + 3*x^3 - x^2 + 2*x - 2, 2, [],
  [x^2 + x - 1,
   x^2 + 409/1457*x - 2753/1457],
  <x^3 + 2*x^2 + 2*x + 2, x^3 - x^2 + x - 1/2, x>,
  [ 7, 3, 17, 5, 2, 11, 41 ],
  { 11, 19, 41, 43, 61, 67, 71, 83, 103, 109, 227, 251, 317, 397, 719, 1051, 
1087, 1103, 1319, 1531, 1993 }>,

// no. 598
<3*x^6 - 2*x^5 - x^3 + 2*x^2 - 3, 2, [],
  [x^2 + 45/61*x + 57/122,
   x^2 - 309/37*x + 1389/74],
  <x^3 + 2*x^2 + x + 1, x^3 - 8/3*x^2 - 4*x - 4, 5*x^2 + 4*x + 3>,
  [ 2, 7, 5, 23, 13, 3, 5, 3, 5, 29, 19 ],
  { 7, 13, 31, 37, 59, 83, 101, 107, 139, 179, 211, 227, 337, 383, 599, 673, 
709, 719, 811, 827, 919, 1009, 1061 }>,

// no. 599
<-x^6 + 2*x^5 - 2*x^4 + 3*x^3 + 2*x^2 - 3*x - 2, 2, [],
  [x^2 - 3*x + 3,
   x^2 - 34/5*x + 81/5],
  <x^3 - 9/5*x^2 + 13/5*x - 19/5, x^3 - 1/5*x^2 - 3/5*x - 6/5, -3/5*x^2 + 6/5*x 
- 8/5>,
  [ 3, 3, 2, 2, 13, 5, 29 ],
  { 3, 7, 11, 23, 47, 59, 61, 71, 139, 149, 431, 499, 787 }>,

// no. 600
<-2*x^6 - x^5 + 2*x^4 - 3*x^3 + x^2 + 2*x + 3, 2, [],
  [x^2 + x - 1,
   x^2 + 97612/76761*x + 1684/76761],
  <x^3 + 1/2*x^2 + 2, x^3 - 1/2*x - 3/4, x^2 - 1/2*x>,
  [ 2, 5, 2, 2, 3, 31, 13, 17, 11 ],
  { 5, 7, 11, 13, 17, 29, 47, 89, 109, 181, 307, 449, 487, 509, 619, 631, 881 
}>,

// no. 601
<-2*x^6 - 3*x^5 - 3*x^4 - 2*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - 3*x + 3,
   x^2 + x + 7/25],
  <x^3 + 2*x^2 + 3*x + 3, x^3 - 1/2*x^2 + 1/2, x^2 + x>,
  [ 3, 7, 2, 2 ],
  { 5, 29, 31, 43, 59, 61, 79, 163 }>,

// no. 602
<-x^6 + 3*x^5 + x^4 + x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 199/5485*x + 3607/5485],
  <x^3 - x^2 + 3*x - 4, x^3 - 2*x^2 - 2*x - 1, -2*x^2 + 2*x + 1>,
  [ 2, 2, 7, 3, 5, 3, 31, 2, 17 ],
  { 5, 11, 13, 43, 47, 139, 167, 233, 263, 401, 499, 613, 631, 1213, 1627, 2543,
2729, 3919 }>,

// no. 603
<-3*x^6 + 3*x^5 + 2*x^3 + x^2 + 2*x - 2, 2, [],
  [x^2 - 2/7*x + 6/7,
   x^2 - 30/13*x + 2033/793],
  <x^3 - x^2 + 4/3*x - 2/3, x^3 - x - 1, x^2>,
  [ 2, 2, 37, 7, 3, 11, 5 ],
  { 7, 11, 13, 37, 53, 59, 103, 653, 673, 757, 1049, 1787 }>,

// no. 604
<2*x^6 + x^5 - 2*x^4 - 3*x^3 + x^2 + x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 15/7*x + 9/7],
  <x^3 + 5/2*x^2 - 1/2*x - 3/2, x^3 - 2*x^2 - 1, 3*x^2>,
  [],
  { 7 }>,

// no. 605
<3*x^6 + x^5 + 2*x^4 + 3*x^3 - x^2 - 3, 2, [],
  [x^2 - 2,
   x^2 + 516/431*x + 3458/431],
  <x^3 + 1/2*x^2 + 1, x^3 - 1/6*x^2 - 1, 3/2*x^2 + x>,
  [ 3, 5, 23, 19 ],
  { 5, 7, 11, 23, 37, 61, 79, 137, 257, 269, 283 }>,

// no. 606
<3*x^6 + 3*x^4 + 2*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 3/2*x + 23/48],
  <x^3 - 2*x^2 + 2/3*x + 1, x^3 + 2*x^2 - x + 1, -4*x^2 + 2*x>,
  [ 5, 13, 2, 3 ],
  { 5, 11, 37, 97, 139, 211, 277, 389 }>,

// no. 607
<-3*x^6 + 3*x^5 - 2*x^4 + 2*x^3 - x^2 - 3*x + 2, 2, [],
  [x^2 - 1/3,
   x^2 + 17940/40627*x + 9311/40627],
  <x^3 + x^2 + x + 2/3, x^3 - 2*x^2 + 3*x - 1, 2*x^2 + x>,
  [ 2, 3, 5, 5, 2, 7, 3 ],
  { 5, 7, 11, 17, 23, 109, 149, 397, 479, 719 }>,

// no. 608
<-3*x^6 - x^5 - 3*x^4 + 3*x^3 + 2*x^2 + x - 1, 2, [],
  [x^2 - 5/4*x + 1/2,
   x^2 - 45/52*x + 5/26],
  <x^3 + 1/3*x^2 - 1/3, x^3 + x - 1, x>,
  [],
  { 37 }>,

// no. 609
<-x^6 - x^4 - x^3 + 3*x^2 + 3*x - 1, 2, [],
  [x^2 + 23/13*x + 1,
   x^2 + 259/65*x + 317/65],
  <x^3 - 3/5*x^2 + 3*x - 2, x^3 + 3/5*x^2 - x - 1, -4/5*x^2 + x + 1>,
  [],
  { 19 }>,

// no. 610
<3*x^6 + 3*x^4 + 2*x^3 + x^2 - 3*x - 3, 2, [],
  [x^2 - 95/13*x - 97/13,
   x^2 + 11831/2711*x + 7129/2711],
  <x^3 - x^2 + 1, x^3 + x^2 - x - 4/3, -3*x^2 + 1>,
  [ 2, 3, 2, 2, 7, 5, 19 ],
  { 5, 7, 13, 17, 19, 23, 29, 31, 73, 131, 149, 157, 251, 439 }>,

// no. 611
<-2*x^6 + x^5 + 3*x^4 + 3*x^3 - x^2 - 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 20/27*x + 157/108],
  <x^3 + 1/2*x^2 - x - 3/2, x^3 - x^2 - 1, x>,
  [],
  { 13 }>,

// no. 612
<-x^6 + 3*x^5 - x^4 + 2*x^3 - 2*x^2 - x - 3, 2, [],
  [x^2 + 1,
   x^2 - 24/13*x + 1],
  <x^3 - 3*x^2 + 3*x - 4, x^3 - x - 1, -x^2 + 1>,
  [],
  { 37 }>,

// no. 613
<3*x^6 + x^5 - x^4 + 2*x^3 + x^2 + 2*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 - 29/37*x + 13/37],
  <x^3 + 5/6*x^2 - x + 1/3, x^3 - 1/2*x^2 - x - 1, 5/2*x^2 + x>,
  [],
  { 5 }>,

// no. 614
<-2*x^6 - x^5 + 3*x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 1/2*x - 1,
   x^2 - 1844504573/2190723218*x - 818523817/3286084827],
  <x^3 + 7/9*x^2 + 104/9*x + 61/9, x^3 - 5/18*x^2 + 11/18*x - 1/9, -44/9*x^2 - 
10/9*x - 11/9>,
  [],
  { 7 }>,

// no. 615
<2*x^6 - 2*x^5 - x^4 - x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 7/5*x + 49/25],
  <x^3 + x^2 - x + 1, x^3 - 2*x^2 - 2*x - 3/2, 3*x^2>,
  [],
  { 5 }>,

// no. 616
<-2*x^6 - 3*x^5 - 3*x^4 - 2*x^3 - 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 14/19*x + 37/76],
  <x^3 + 3/2*x^2 + 1/2*x + 1/2, x^3 + 3*x - 2, -2*x^2 - x + 1>,
  [ 2, 5, 37, 2 ],
  { 5, 13, 41, 73, 103, 197, 409 }>,

// no. 617
<3*x^6 + x^5 - 3*x^4 - 2*x^3 + x^2 + x - 2, 2, [],
  [x^2 + 4/3*x + 1,
   x^2 + 2224/9039*x + 577/3013],
  <x^3 - 3*x + 3, x^3 + 1/3*x^2 - x - 2/3, -3*x^2 + x + 2>,
  [],
  { 7 }>,

// no. 618
<3*x^6 + 3*x^5 - 3*x^4 - x^3 + x^2 - 2*x - 2, 2, [],
  [x^2 - 2,
   x^2 + 909996/1453141*x - 4475574/1453141],
  <x^3 + 1/3*x^2 - 5/9*x - 1, x^3 + 2/3*x^2 - 19/27*x + 1, -1/3*x^2 - 11/9*x + 
1>,
  [ 3, 19, 5, 2, 2 ],
  { 11, 19, 23, 29, 37, 151, 173, 389 }>,

// no. 619
<3*x^6 + 3*x^5 - 3*x^4 - 2*x^3 - 3*x^2 - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 94/61*x + 37/61],
  <x^3 + 5/2*x^2 + 2*x + 1, x^3 - 3/2*x^2 + 2/3*x - 1/3, -1/2*x^2>,
  [ 2, 2, 5, 5, 3, 17, 3, 7, 11 ],
  { 17, 37, 89, 131, 181, 193, 257, 347, 359, 397, 653, 821, 1091, 1523, 1549 
}>,

// no. 620
<-3*x^6 - 3*x^4 - x^3 + 2*x^2 - 3*x - 2, 2, [],
  [x^2 + x + 1/2,
   x^2 + 55/259*x + 969/518],
  <x^3 - x^2 + x + 1, x^3 + x^2 + 4/3*x + 1, x^2 + 2*x + 1>,
  [ 7, 3 ],
  { 5, 23, 29, 31, 163, 191 }>,

// no. 621
<3*x^6 + 3*x^3 - 2*x^2 - 2*x + 3, 2, [],
  [x^2 + 6*x - 22/3,
   x^2 - 14/61*x + 1202/671],
  <x^3 - 3*x^2 - 4/3*x + 2, x^3 + 3*x^2 + 2*x - 1, -5*x^2 - 3*x + 3>,
  [ 3, 2, 5 ],
  { 5, 11, 43, 67, 83, 113 }>,

// no. 622
<-2*x^6 + 2*x^5 - x^4 - x^3 - x^2 - 2*x + 2, 2, [],
  [x^2 + 1/3*x - 1/3,
   x^2 - 21458/17529*x + 68777/17529],
  <x^3 + x^2 + x + 1/2, x^3 - 2*x^2 + 6*x - 1, 3*x^2 + x + 1>,
  [],
  { 7 }>,

// no. 623
<-2*x^6 + x^5 + 3*x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 3*x + 6,
   x^2 - 25/27*x - 50/81],
  <x^3 - 2*x^2 + 3*x - 3, x^3 + 3/2*x^2 + 1/2*x - 1, -x^2 - x + 3>,
  [ 2, 5, 5, 19, 3, 37, 7, 2, 3 ],
  { 11, 19, 23, 31, 37, 41, 67, 71, 83, 179, 197, 199, 223, 229, 283, 433 }>,

// no. 624
<3*x^6 - x^5 - x^4 - 3*x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 - 3/2*x - 2,
   x^2 - 5/6*x + 50/27],
  <x^3 - 1/2*x^2 - 3/2*x + 2, x^3 + 1/6*x^2 - 5/6*x - 2/3, -5/2*x^2 + 3/2*x + 
1>,
  [ 3, 2, 7, 17, 31, 11 ],
  { 3, 5, 11, 41, 79, 157, 179, 191, 263, 331, 421, 487, 727 }>,

// no. 625
<-2*x^6 + 2*x^5 + x^4 - x^3 + x^2 + 3*x + 3, 2, [],
  [x^2 + 2/3*x + 1/3,
   x^2 + 542/1411*x - 923/4233],
  <x^3 - 4/3*x^2 + 11/9*x - 2/9, x^3 + 1/3*x^2 - 11/9*x - 23/18, 1/3*x^2 + 1/9*x
+ 17/9>,
  [ 3, 3, 7, 2, 5, 2, 2, 2, 2 ],
  { 5, 7, 11, 37, 43, 47, 53, 71, 151, 181, 193 }>,

// no. 626
<-2*x^6 - 3*x^4 - x^2 + x + 3, 2, [],
  [x^2 - 5/9*x - 1/9,
   x^2 + 8*x + 24],
  <x^3 + x + 1, x^3 + 1/2*x - 1, 1>,
  [ 2, 2, 3, 19, 11, 5 ],
  { 5, 11, 17, 31, 61, 83, 89, 113, 163, 257, 277, 487, 547, 619, 1021 }>,

// no. 627
<2*x^6 - 2*x^5 - 3*x^4 + 2*x^3 - x - 1, 2, [],
  [x^2 - x + 1/2,
   x^2 + 44/79*x - 292/79],
  <x^3 + x^2 + 1/2*x + 1, x^3 - 2*x^2 - 2*x - 1, 2*x^2 + 2*x + 1>,
  [ 5 ],
  { 3, 5, 31, 787 }>,

// no. 628
<-2*x^6 - 2*x^5 - 2*x^3 + 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 1/3*x + 7/3,
   x^2 - 9549/5203*x + 5119/5203],
  <x^3 + x^2 + 2*x + 1, x^3 - 3/2*x + 3/2, x^2>,
  [ 2, 2, 2, 5, 5, 3 ],
  { 7, 11, 13, 23, 29, 53, 61, 79, 113 }>,

// no. 629
<-3*x^6 + x^5 - 2*x^4 - 3*x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 29501/36457*x + 2293/36457],
  <x^3 + x + 1, x^3 - 1/3*x^2 + 1/3, -x^2 + 2>,
  [ 2, 13, 5, 3, 2, 5, 11 ],
  { 3, 5, 7, 13, 17, 61, 79, 103, 127, 137, 193, 541, 569, 587, 599, 719, 823 
}>,

// no. 630
<-x^6 - 2*x^5 + 2*x^4 + x^3 + x^2 - 2*x - 3, 2, [],
  [x^2 - 1/5*x + 1/5,
   x^2 + 439/629*x + 97/629],
  <x^3 + 8/5*x^2 + 28/5, x^3 + 2/5*x^2 - 2*x + 7/5, 4/5*x^2 + 3*x - 11/5>,
  [ 2, 2, 2, 2, 3, 5, 17, 3 ],
  { 3, 13, 17, 23, 101, 107, 109, 137, 173, 199, 491 }>,

// no. 631
<3*x^6 - 3*x^5 + 3*x^4 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 - 1/2*x - 1,
   x^2 + 312/457*x - 3292/1371],
  <x^3 + 2/3*x + 1, x^3 - x^2 - 1, x^2 + x>,
  [],
  { 17 }>,

// no. 632
<2*x^6 - x^5 + x^4 - x^3 + 2*x^2 - 2*x - 2, 2, [],
  [x^2 - x - 1,
   x^2 + x + 9/32],
  <x^3 - x^2 + x + 9, x^3 + 1/2*x^2 - 1/2*x - 19/2, -x^2 + x + 13>,
  [ 2, 2, 2, 3, 17, 2, 19, 7 ],
  { 11, 13, 29, 41, 67, 71, 89, 97, 109, 137, 311, 449, 967 }>,

// no. 633
<-2*x^6 - 3*x^5 + 2*x^4 + 3*x^3 + 3*x + 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 - 284887/185474*x + 69889/185474],
  <x^3 + 1/2*x^2 - 9/8*x - 7/8, x^3 + x^2 + 3/4*x - 7/4, 3/2*x^2 - 5/4*x - 9/4>,
  [ 2, 3, 3, 5, 7, 3, 23, 11, 17 ],
  { 3, 5, 17, 23, 29, 71, 79, 101, 127, 137, 149, 181, 193, 199, 251, 257, 263, 
271, 277, 281, 349, 431, 491 }>,

// no. 634
<-3*x^6 - 3*x^5 + 3*x^4 - 2*x^3 - 2*x^2 + 2*x - 2, 2, [],
  [x^2 + 1/2*x + 121/48,
   x^2 - 603/1843*x + 1051/1843],
  <x^3 - x + 1, x^3 + x^2 + 2/3, x>,
  [ 2, 3, 2, 7 ],
  { 5, 7, 13, 19, 103, 227 }>,

// no. 635
<-2*x^6 + x^5 + 2*x^4 + 3*x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 31/18*x + 37/54],
  <x^3 - 2*x^2 + 7/3*x - 2, x^3 + 3/2*x^2 + 1/6*x - 1, -x^2 - 5/3*x + 1>,
  [ 3, 5, 3, 2, 7, 2, 2, 17, 11 ],
  { 7, 11, 13, 19, 29, 41, 47, 67, 109, 191, 317, 331, 443, 463, 499, 599, 787, 
839, 911 }>,

// no. 636
<-x^6 + 3*x^5 - x^4 - x^3 - x^2 + 3*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 4/17*x + 4/17],
  <x^3 - 2*x^2 + 3*x - 3, x^3 - x^2 - 1, -2*x^2 + 2*x>,
  [ 3, 2, 5, 2, 19, 2, 5, 13, 3, 11 ],
  { 5, 7, 13, 17, 23, 29, 73, 89, 97, 131, 137, 157, 163, 179, 467, 577, 601, 
631, 773, 1283, 1367, 1439, 1993 }>,

// no. 637
<-x^6 + 2*x^5 - 3*x^4 - 3*x^3 - 3*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 11462348/24959513*x - 436172/24959513],
  <x^3 - x^2 + 21/16*x + 33/8, x^3 - x^2 + 5/4*x + 1/2, -3/4*x^2 + 5/8*x + 9/4>,
  [ 3, 3, 2, 2 ],
  { 19, 41, 89 }>,

// no. 638
<3*x^6 - 3*x^5 + x^3 + 3*x^2 + 2*x - 3, 2, [],
  [x^2 - x - 3,
   x^2 - 3409/772*x + 50077/18528],
  <x^3 + 3*x^2 + x + 1, x^3 - 4*x^2 - 16/3*x - 4, 7*x^2 + 5*x + 3>,
  [ 2, 5, 3 ],
  { 17, 19, 23, 163 }>,

// no. 639
<2*x^6 + x^4 + 3*x^3 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 337332/317561*x + 227773/317561],
  <x^3 + x^2 + 3/4*x + 3, x^3 - x^2 + 5/8*x - 1/2, -1/2*x^2 + 7/4*x>,
  [ 3, 3 ],
  { 5, 29, 43, 157, 331 }>,

// no. 640
<2*x^6 + x^4 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - 3*x - 1,
   x^2 - 144/313*x - 48/313],
  <x^3 + 1/7*x^2 - 9/7*x + 2/7, x^3 - 1/7*x^2 + 11/14*x - 11/14, 10/7*x^2 + 
1/7*x + 13/7>,
  [ 3, 3, 7, 29, 5, 2 ],
  { 19, 29, 41, 79, 83, 101, 137, 151, 173, 239, 241, 331, 347 }>,

// no. 641
<-2*x^6 - x^5 + 3*x^4 - 2*x^3 + 2*x^2 - x + 3, 2, [],
  [x^2 - x + 1,
   x^2 + 127/918*x - 1801/1224],
  <x^3 + 4/3*x^2 + 1/3*x + 2, x^3 - 5/6*x^2 + 1/6*x - 1/2, -4/3*x^2 - 1/3*x + 
1>,
  [ 2, 3, 7, 3, 3, 5, 11, 2 ],
  { 5, 13, 41, 47, 59, 67, 103, 107, 131, 167, 233, 263, 271, 389, 577 }>,

// no. 642
<2*x^6 + 2*x^5 - x^4 - 2*x^2 - x - 3, 2, [],
  [x^2 - x + 3/2,
   x^2 + 14866/15833*x + 8049/15833],
  <x^3 - x^2 - 5*x + 12, x^3 + 2*x^2 - 3/2*x - 7/2, 4*x^2 - 9>,
  [],
  { 3 }>,

// no. 643
<-2*x^6 + 2*x^5 + 2*x^4 - 3*x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 10/27*x + 113/81],
  <x^3 + 5*x - 2, x^3 - x^2 + 1/8*x - 1/4, 7/2*x^2 - 5/2*x>,
  [ 3, 3, 19, 7, 11 ],
  { 3, 5, 11, 19, 31, 41, 67, 71, 73, 101, 137, 463 }>,

// no. 644
<2*x^6 + 2*x^5 + 3*x^4 + x^3 + 3*x^2 + x - 1, 2, [],
  [x^2 - 1/2,
   x^2 + 8/89],
  <x^3 + 1/2*x + 1, x^3 + x^2 + x - 1, 1>,
  [ 2, 5, 5, 2, 11, 2, 2, 31 ],
  { 3, 7, 23, 43, 47, 71, 79, 89, 113, 137, 157, 167, 271, 317 }>,

// no. 645
<-2*x^6 - 2*x^5 - 3*x^4 + 2*x^3 - 3*x^2 - 3*x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 37537/75913*x - 2063/75913],
  <x^3 - 4/3*x^2 + 7/3*x + 11/3, x^3 + 7/3*x^2 + 19/6*x + 1/3, -4/3*x^2 - 14/3*x
- 7/3>,
  [ 2, 2, 3, 7, 5, 5, 31 ],
  { 5, 7, 11, 23, 37, 73, 137, 149, 197, 281, 293, 331, 373, 431, 487 }>,

// no. 646
<-x^6 - 3*x^5 + x^4 - x^3 + x^2 + 2*x + 3, 2, [],
  [x^2 + 1,
   x^2 + 45244/35605*x + 27213/35605],
  <x^3 - x^2 + 1, x^3 + 4*x^2 + 4*x - 2, -x^2 + 3*x + 1>,
  [ 3, 2, 2, 11, 7 ],
  { 3, 7, 19, 59, 97, 101, 241, 307, 487 }>,

// no. 647
<-3*x^6 + 3*x^5 - 3*x^4 - x^3 + 2*x^2 + 3*x - 2, 2, [],
  [x^2 - x + 2,
   x^2 - 95261/32761*x + 88518/32761],
  <x^3 - 3/4*x^2 + 9/2*x - 11/4, x^3 - 1/4*x^2 - 1/6*x - 1/4, 13/4*x^2 - 2*x - 
1/4>,
  [ 3, 3, 7, 5 ],
  { 5, 41, 43, 47, 113, 163, 167, 179, 239, 307 }>,

// no. 648
<2*x^6 - x^5 + 3*x^4 - 3*x + 2, 2, [],
  [x^2 + 1,
   x^2 - 33168/25463*x + 53567/25463],
  <x^3 + 3*x^2 - 7*x + 2, x^3 - 7/2*x^2 + x + 1/2, -6*x^2 + 5*x>,
  [ 2, 2 ],
  { 3, 41 }>,

// no. 649
<-2*x^6 + x^5 - x^4 + 2*x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 - 2/3*x + 1/3,
   x^2 - 5/2*x + 13/8],
  <x^3 - 1/2*x^2 - 3/2, x^3 + x - 1, -x^2 + 2*x>,
  [ 3, 3, 3, 7, 37 ],
  { 5, 19, 31, 47, 67, 73, 163, 229, 241, 271, 613 }>,

// no. 650
<-x^6 + x^5 + 3*x^3 + 3*x^2 - 2*x - 2, 2, [],
  [x^2 - 13/5*x + 9/5,
   x^2 + 7*x + 57/4],
  <x^3 - 6/5, x^3 - x^2 + x - 19/5, -x^2 + x - 8/5>,
  [],
  { 3 }>,

// no. 651
<3*x^6 - x^5 + 2*x^4 - x^2 - x - 3, 2, [],
  [x^2 + 3/11*x - 19/11,
   x^2 - 1341/5687*x - 26827/5687],
  <x^3 + x^2 + 5/4*x + 1, x^3 - 4/3*x^2 - 4/3, 3/2*x^2 + 2*x + 1>,
  [ 2, 3, 2, 13, 7, 5 ],
  { 5, 11, 19, 43, 59, 71, 263, 353, 641, 1567 }>,

// no. 652
<-3*x^6 + x^5 - x^4 + 3*x^3 + 2*x^2 + x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 16859/19461*x + 23369/19461],
  <x^3 + 9/7*x - 17/7, x^3 - 1/3*x^2 + 8/21*x - 5/21, -2*x^2 + 11/7*x - 6/7>,
  [ 3, 3 ],
  { 3, 37 }>,

// no. 653
<3*x^6 + 3*x^5 - 2*x^4 - 2*x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 45730/43693*x + 38101/43693],
  <x^3 - 3*x - 4, x^3 + x^2 - 2/3*x + 1/3, -3*x^2 - 3*x + 1>,
  [ 2, 13 ],
  { 7, 13, 31, 487, 727 }>,

// no. 654
<3*x^6 - 3*x^5 + 3*x^3 - 2*x^2 + 3*x - 1, 2, [],
  [x^2 - 3/2*x + 1,
   x^2 + 17/37*x - 901/444],
  <x^3 - 1/2*x^2 - 5/2*x + 1, x^3 - 1/2*x^2 + 1/6*x - 1/3, 5/2*x^2 - 1/2*x>,
  [ 3, 3, 2, 3, 3, 2, 43, 7, 5, 41 ],
  { 5, 11, 17, 19, 53, 59, 97, 137, 239, 521, 631, 1109 }>,

// no. 655
<-3*x^6 - 2*x^5 + 2*x^3 - 3*x + 2, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 601/1813*x - 391/7252],
  <x^3 - 5/6*x^2 + 5/6*x + 1/3, x^3 + 3/2*x^2 + 1/2*x - 1, -1/2*x^2 - 5/2*x + 
1>,
  [ 2, 2, 3 ],
  { 3, 7, 11, 101 }>,

// no. 656
<-3*x^6 + 3*x^5 - x^4 - x^2 - 2*x + 2, 2, [],
  [x^2 - 1/4*x - 1/4,
   x^2 - 157879/180859*x + 91967/413392],
  <x^3 - x^2 + 3*x + 1, x^3 - 7/12*x + 1/12, 5/2*x^2 + x - 3/2>,
  [ 5, 19, 17, 2, 3, 2 ],
  { 5, 19, 29, 37, 61, 67, 83, 149, 563, 947 }>,

// no. 657
<3*x^6 + 2*x^5 + x^4 - 3*x^2 + x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 173/44*x + 3445/352],
  <x^3 + 2*x^2 - 2*x + 1, x^3 - 4/3*x^2 - 1/3*x - 1/3, -4*x^2 + x>,
  [ 2, 7, 3, 5, 3, 11 ],
  { 7, 11, 19, 31, 41, 79, 97, 181, 191, 199 }>,

// no. 658
<-2*x^6 + 3*x^5 + x^4 + x^3 + 3*x^2 + 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 + 1607062/3461217*x + 667639/1153739],
  <x^3 + 3*x^2 + 2*x - 4, x^3 - 9/2*x^2 + 13*x - 21/2, 2*x^2 + 8*x - 9>,
  [ 11, 2, 3, 23, 5, 2 ],
  { 7, 37, 41, 47, 67, 103, 179, 191, 223, 271, 487, 743, 761 }>,

// no. 659
<-x^6 + 2*x^5 + x^4 + x^2 - 3*x - 3, 2, [],
  [x^2 - x + 1/2,
   x^2 + 41/39*x + 469/234],
  <x^3 - 2*x^2 + x - 4, x^3 - 7/4*x - 1, -1/2*x^2 + 3/2*x + 1>,
  [ 2, 3, 11, 7 ],
  { 5, 7, 17, 73, 83, 89, 107, 467, 1097 }>,

// no. 660
<3*x^6 + 3*x^5 + x^4 - 2*x^3 - x^2 + x - 3, 2, [],
  [x^2 - 28/97*x - 163/97,
   x^2 + 25960/18371*x + 12967/18371],
  <x^3 + x^2 - 2*x + 1, x^3 + 7/3*x - 4, -5*x + 3>,
  [ 3, 2, 5, 2, 3, 13, 7 ],
  { 5, 11, 17, 23, 29, 31, 179, 311, 479, 641, 1361, 2039, 3301, 4639 }>,

// no. 661
<3*x^6 + x^5 - 2*x^4 - 2*x^3 + 2*x^2 - 3*x + 3, 2, [],
  [x^2 + 1,
   x^2 - 840/937*x - 3368/937],
  <x^3 + x^2 - 3/4*x + 1/2, x^3 - 2/3*x^2 - 4/3*x + 4/3, -5/2*x^2 + x + 1>,
  [ 2, 2 ],
  { 7, 29 }>,

// no. 662
<-3*x^6 + 2*x^5 + 3*x^4 + 2*x^3 + 3*x^2 + 3*x + 3, 2, [],
  [x^2 - x - 1,
   x^2 - 3399/961*x + 15133/3844],
  <x^3 - 2/3*x^2 + 4/3*x - 1/3, x^3 + 3*x - 1, 4*x^2 - x + 2>,
  [ 2, 2, 2, 2, 2, 5, 3, 11, 43, 19 ],
  { 11, 17, 37, 47, 71, 73, 113, 421, 479, 499, 1051, 3253, 3919, 4073, 4349, 
4591 }>,

// no. 663
<-3*x^6 + 2*x^5 + 3*x^4 + 3*x^3 - 2*x^2 + 2*x - 2, 2, [],
  [x^2 + 4/3*x + 2,
   x^2 - 1524/919*x + 1026/919],
  <x^3 - 5/3*x^2 + 2/3*x - 2/3, x^3 + x^2 - 1, x>,
  [ 2, 2 ],
  { 11, 23 }>,

// no. 664
<-3*x^6 + 3*x^5 - x^4 - 3*x^3 + 2*x^2 - 3*x - 3, 2, [],
  [x^2 - x + 4,
   x^2 - 36100/16369*x + 54028/16369],
  <x^3 - x^2 - 1/4*x + 1, x^3 + 4/3*x + 4/3, -3/2*x^2 + 1>,
  [],
  { 23 }>,

// no. 665
<-3*x^6 - 3*x^4 + 3*x^3 + 3*x^2 + x + 2, 2, [],
  [x^2 + 1/2,
   x^2 - 468/6373*x + 3128/6373],
  <x^3 + x + 1, x^3 + 1/3*x - 2/3, x^2 + 2*x>,
  [ 2, 3, 5, 3, 3, 3, 23, 7, 5, 13 ],
  { 5, 7, 37, 61, 67, 83, 103, 211, 227, 433, 1733, 2099, 2311, 2729 }>,

// no. 666
<-3*x^6 + 3*x^5 + 2*x^4 + 2*x^2 - 3*x - 2, 2, [],
  [x^2 + 1,
   x^2 - 21/10*x + 673/400],
  <x^3 + x^2 + 2*x + 1, x^3 - 2*x^2 - 1/3*x + 2, -x^2 + 2*x + 2>,
  [ 3 ],
  { 7, 13 }>,

// no. 667
<3*x^6 + x^5 - 3*x^4 + 2*x^3 + 2*x^2 + 2*x - 1, 2, [],
  [x^2 - 3*x + 1,
   x^2 - 9115/32289*x + 28825/32289],
  <x^3 + 2*x^2 - 2*x + 5, x^3 - 5/3*x^2 + 4/3*x - 1/3, 3*x^2 - 5*x + 2>,
  [ 2, 3, 2, 2, 11 ],
  { 3, 5, 11, 17, 41, 47, 139 }>,

// no. 668
<-x^6 + 3*x^5 + 3*x^4 + x^3 - x^2 + 2*x - 2, 2, [],
  [x^2 + 1,
   x^2 - 35484/95045*x + 359657/6938285],
  <x^3 + 3/2*x^2 - 4*x - 17/2, x^3 - 9/2*x^2 + 10*x - 57/2, -3/2*x^2 + x + 
31/2>,
  [ 3, 3, 3, 2, 5, 7 ],
  { 3, 5, 11, 19, 23, 43, 47, 97, 191, 197, 307, 359, 569, 587, 997 }>,

// no. 669
<-3*x^6 + 2*x^5 - x^4 + 2*x^3 - 3*x^2 + 3*x + 3, 2, [],
  [x^2 + x + 1,
   x^2 - 9843576/7679041*x + 9355128/7679041],
  <x^3 - 1/4*x - 1/2, x^3 - 2/3*x^2 + 8/3*x + 4/3, -5/2*x^2 - x + 1>,
  [ 2, 2, 3, 3, 7, 31, 3, 13, 19, 11, 47, 5 ],
  { 11, 23, 29, 31, 41, 43, 73, 83, 101, 103, 149, 151, 167, 193, 229, 257, 277,
463, 479, 557, 577, 613, 673, 941, 991 }>,

// no. 670
<-3*x^6 - 2*x^5 - x^4 + 2*x^3 - 3*x + 3, 2, [],
  [x^2 + x + 1/2,
   x^2 - 4703/8689*x + 8833/17378],
  <x^3 - 4/3*x^2 + x + 1, x^3 + 2*x^2 + 2*x - 1, 4*x>,
  [ 3, 5, 2, 2, 2 ],
  { 7, 11, 17, 41, 61, 137, 233 }>,

// no. 671
<3*x^6 - 2*x^5 + 2*x^4 - 3*x^3 + 2*x^2 - 2*x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 81/59*x + 3073/1593],
  <x^3 - 5*x^2 - 2*x - 1, x^3 + 13/3*x^2 - 8/3*x + 4/3, 9*x^2 - x + 1>,
  [],
  { 5 }>,

// no. 672
<-3*x^6 - 3*x^5 - 3*x^4 + 2*x^3 - 2*x^2 + x + 3, 2, [],
  [x^2 - 1/7,
   x^2 - 482050/1556317*x - 600231/1556317],
  <x^3 - 2*x^2 + 5*x + 2, x^3 + 3*x^2 + 10/3*x - 1/3, 2*x^2 + 8*x + 1>,
  [ 2, 2, 3, 3, 2, 3, 7, 5, 37, 43 ],
  { 5, 17, 19, 37, 47, 79, 103, 211, 227, 257, 311, 353, 389, 593, 617, 673, 
719, 739, 1109, 1213, 1231 }>,

// no. 673
<-2*x^6 + 2*x^5 - x^4 - 3*x^3 + 2*x^2 + 2*x - 1, 2, [],
  [x^2 - x + 1,
   x^2 + 25033/15467*x + 34669/46401],
  <x^3 - 2*x^2 + 11/4*x - 5/4, x^3 + x^2 - 1/8*x - 5/8, 1/2*x^2 - 3/4*x + 3/4>,
  [ 2, 11 ],
  { 5, 7, 43, 181 }>,

// no. 674
<-x^6 + x^5 - 3*x^3 + 3*x^2 - x - 3, 2, [],
  [x^2 - 1/2*x + 2,
   x^2 - 82/29*x + 73/29],
  <x^3 - x^2 + 1, x^3 + x + 3, x^2>,
  [ 5, 2, 2, 3, 11, 41 ],
  { 3, 5, 13, 37, 53, 103, 113, 137, 167, 181, 229, 461, 541, 599, 739, 853, 
1103 }>,

// no. 675
<-x^6 + x^5 - 3*x^3 + 2*x^2 - 3*x - 1, 2, [],
  [x^2 - 1/2*x + 1,
   x^2 - 10/13*x + 1],
  <x^3 + x^2 + 1, x^3 - 2*x^2 + 3*x + 1, x^2 + x>,
  [ 5, 5, 3, 7 ],
  { 3, 13, 19, 71, 109, 113, 137, 421 }>,

// no. 676
<-3*x^6 - x^5 - x^4 - 2*x^3 + x^2 + 3*x + 2, 2, [],
  [x^2 + 1,
   x^2 - 8774244/7494709*x + 2015752/7494709],
  <x^3 + 5*x^2 + 12*x + 7, x^3 - 14/3*x^2 + 13*x + 46/3, -2*x^2 - 23*x - 18>,
  [ 2, 3 ],
  { 3, 19, 241 }>,

// no. 677
<3*x^6 - 2*x^5 - 3*x^4 - 2*x^2 - 3*x + 2, 2, [],
  [x^2 + 7*x + 1,
   x^2 - 937/1154*x - 6769/4616],
  <x^3 - 4*x^2 + 3/2*x - 7/2, x^3 + 10/3*x^2 - 7/6*x + 23/6, 6*x^2 - 5/2*x + 
13/2>,
  [ 3, 5, 19, 3, 3, 7, 11 ],
  { 3, 7, 17, 29, 41, 47, 73, 149, 163, 179, 1783, 2731 }>,

// no. 678
<-3*x^6 - x^5 - 3*x^4 - 2*x^3 - 3*x^2 + x + 2, 2, [],
  [x^2 + 1/3*x + 1/3,
   x^2 - 17343/176491*x - 4513/25213],
  <x^3 + x^2 + 5*x + 2, x^3 - 2/3*x^2 - 1/3*x + 1/3, -3*x^2 + x + 2>,
  [],
  { 11 }>,

// no. 679
<2*x^6 - x^5 + 3*x^4 - x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 - 3/2*x - 3/2,
   x^2 + 190/103*x - 369/103],
  <x^3 - 1/2*x^2 + 1/2*x + 1, x^3 + x - 1, x>,
  [],
  { 7 }>,

// no. 680
<2*x^6 + x^5 + 3*x^4 - x^3 + 2*x^2 + 2*x - 2, 2, [ 2 ],
  [x^2 + 1,
   x^2 + 32/73*x - 288/511],
  <x^3 + x^2 + 7*x + 9, x^3 - 1/2*x^2 - 11/2*x - 19/2, -x^2 - 9*x - 13>,
  [ 2, 7, 3, 5, 11 ],
  { 5, 7, 19, 23, 31, 43, 71, 89, 797 }>,

// no. 681
<3*x^6 - x^5 + x^4 + 3*x - 3, 2, [],
  [x^2 - 1/3*x + 1/3,
   x^2 + 829374/883333*x + 1254081/883333],
  <x^3 - 2*x^2 + 3*x - 4, x^3 + 5/3*x^2 + 2/3*x + 1/3, 4*x + 1>,
  [ 2, 5, 7, 3, 11 ],
  { 5, 13, 17, 37, 71, 101, 137, 151, 311, 499 }>,

// no. 682
<3*x^6 - 3*x^5 + 3*x^4 - 3*x^3 - 3*x^2 + x - 1, 2, [],
  [x^2 - 1/2*x - 1,
   x^2 - 35/229*x + 1025/916],
  <x^3 + 1/2*x^2 - 1/2*x + 1, x^3 - 3/2*x^2 + 1/6*x - 1/3, 5/2*x^2 - 3/2*x>,
  [ 2, 2, 5, 13, 3, 7, 11, 19 ],
  { 7, 11, 13, 29, 43, 67, 89, 101, 103, 151, 193, 197, 541, 577, 1039, 1103, 
1249, 1879 }>,

// no. 683
<2*x^6 - 3*x^5 - 2*x^4 - 3*x^3 - x^2 - x - 1, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 - 18328/1913*x - 49025/7652],
  <x^3 + 9*x^2 - 2*x + 1, x^3 - 21/2*x^2 - 5/2*x - 1, 14*x^2 + 1>,
  [ 2, 5, 7, 29, 3, 13 ],
  { 3, 5, 7, 17, 19, 31, 107, 131, 401, 499, 557, 631, 709 }>,

// no. 684
<-3*x^6 - 3*x^5 - 3*x^4 - 2*x^3 + x^2 - 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 170/199*x + 545/3184],
  <x^3 + x^2 + 2*x + 1, x^3 + 1/3*x + 2/3, 2*x^2 + x + 1>,
  [ 2, 2, 2, 2, 3, 5, 11, 17 ],
  { 11, 17, 19, 31, 37, 47, 53, 83, 101, 103, 139, 157, 181, 409, 461 }>,

// no. 685
<-2*x^6 + 3*x^5 - 2*x^4 + 3*x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 - 4*x + 6,
   x^2 + 2/9],
  <x^3 - 3/2*x^2 + 2*x - 2, x^3 - x - 1, x + 1>,
  [ 3, 7, 5, 19, 5, 13 ],
  { 5, 11, 23, 43, 61, 137, 181, 251, 317, 353, 619, 751, 877 }>,

// no. 686
<2*x^6 + 3*x^5 + x^4 - 2*x^3 - 2*x^2 - 2*x - 3, 2, [],
  [x^2 + 1/2*x + 1/2,
   x^2 + 19/6*x + 49/18],
  <x^3 + 3/2*x^2 - 1/2*x + 3/2, x^3 - x - 1, 2*x^2>,
  [ 3, 2, 7, 5, 19, 5, 3 ],
  { 3, 5, 17, 23, 53, 71, 89, 97, 283, 293, 1321, 1931 }>,

// no. 687
<3*x^6 - 2*x^5 - 3*x^4 - 2*x^3 + x - 1, 2, [],
  [x^2 + x + 1/2,
   x^2 - 3365017/938951*x - 7251313/1877902],
  <x^3 - 8/3*x^2 - 2*x - 3, x^3 + 2*x^2 + x + 17/9, 4*x^2 + 8/3*x + 4>,
  [],
  { 19 }>,

// no. 688
<-x^6 - 3*x^5 + 2*x^4 + x^3 - 2*x^2 + x - 3, 2, [],
  [x^2 - 1/2*x + 2,
   x^2 - 1157/394*x + 446/197],
  <x^3 + 2*x^2 + x + 1, x^3 + x^2 - 4*x + 3, -x^2 + x>,
  [ 2, 2, 2, 7, 3, 5, 17 ],
  { 7, 11, 13, 19, 37, 41, 71, 89, 239, 251, 263, 317, 379, 593, 751 }>,

// no. 689
<-3*x^6 - x^4 + 2*x^2 + 2*x + 3, 2, [],
  [x^2 + 2*x + 3,
   x^2 + 322/403*x - 83/1612],
  <x^3 + 3/2*x^2 + 2*x + 1, x^3 - 3/2*x^2 + 4/3*x - 1, -3/2*x^2 + x>,
  [ 2, 2, 3, 7, 17, 5, 23, 11 ],
  { 5, 19, 37, 53, 59, 61, 89, 103, 113, 167, 359, 577, 607, 643, 683, 1051, 
1249, 1531 }>,

// no. 690
<-3*x^6 + 2*x^5 - 3*x^4 - x^3 + x^2 + 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 904/1983*x + 4469/7932],
  <x^3 + 5*x - 2, x^3 - 2/3*x^2 + 1/12*x - 1/6, 7/2*x^2 - 5/2*x>,
  [ 2, 2, 7, 5, 3, 3, 29, 3 ],
  { 3, 5, 11, 47, 61, 67, 101, 139, 151, 163, 199, 233, 293, 373, 419 }>,

// no. 691
<2*x^6 + x^5 + 3*x^4 - 2*x^3 - 3*x^2 - x + 3, 2, [],
  [x^2 + x - 3,
   x^2 + 1366/641*x - 1443/641],
  <x^3 + 4/7*x^2 + 13/7*x + 2/7, x^3 - 1/14*x^2 - 5/14*x - 11/14, 2/7*x^2 - 
4/7*x - 13/7>,
  [ 5, 7, 2, 3, 3, 3 ],
  { 13, 29, 31, 47, 71, 89, 101, 137, 269, 443 }>,

// no. 692
<3*x^6 - 2*x^5 - 3*x^4 + 3*x^3 + 3*x^2 + x - 2, 2, [],
  [x^2 + x - 1,
   x^2 - 120600447/53774089*x - 241777233/53774089],
  <x^3 + 2*x^2 + 4*x + 4, x^3 - 8/3*x^2 - 7/4*x - 1/2, 5/2*x^2 + 7*x + 2>,
  [ 2, 2, 3, 7, 19, 31, 37, 17, 11, 47 ],
  { 5, 11, 17, 19, 29, 43, 67, 83, 89, 113, 163, 181, 271, 277, 313, 409, 439, 
503, 563, 577, 587, 659, 839, 877 }>,

// no. 693
<-x^6 - x^5 - 2*x^4 - 3*x^3 + x^2 - 2*x - 2, 2, [],
  [x^2 + 1,
   x^2 - 1611/6409*x + 929/1508],
  <x^3 + 3*x^2 + 6*x + 3, x^3 - 2*x^2 + 2*x + 6, 5*x + 4>,
  [ 3, 7, 5, 2, 3, 37 ],
  { 3, 5, 11, 13, 23, 31, 43, 67, 107, 163, 383, 457 }>,

// no. 694
<-2*x^6 - 3*x^5 + x^4 - x^3 - x^2 - 3, 2, [],
  [x^2 - 2*x + 2,
   x^2 + 138/73*x + 78/73],
  <x^3 - 1/3*x^2 - x + 1, x^3 + 11/6*x^2 + 2*x + 2, -4/3*x^2 + 1>,
  [ 2, 2, 3, 7, 7, 2, 2, 11, 13 ],
  { 7, 19, 23, 31, 47, 59, 83, 239, 389, 683, 1063, 1153, 1381, 1627, 2593, 
3163, 3677, 3967, 4733 }>,

// no. 695
<-2*x^6 + x^5 - 2*x^2 + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 3484/4009*x + 3004/4009],
  <x^3 - 3/2*x^2 + 1, x^3 + x^2 + 2*x + 1, -x^2 + x + 2>,
  [],
  { 5 }>,

// no. 696
<-2*x^6 - 2*x^5 - 2*x^4 + 2*x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 5/11*x - 1,
   x^2 + 4985/5907*x + 124753/53163],
  <x^3 - 3*x^2 + 15/2*x - 3, x^3 + 4*x^2 + 6*x - 1, -x^2 - 9*x + 3>,
  [ 2, 2 ],
  { 5, 7 }>,

// no. 697
<2*x^6 + 2*x^5 + 3*x^4 - 3*x^3 + 2*x^2 - 3, 2, [],
  [x^2 - 3/2,
   x^2 - 12986/6673*x + 9121/6673],
  <x^3 + 2*x^2 + 4*x + 4, x^3 - x^2 - 1/2*x - 1/2, 4*x + 1>,
  [ 2, 5, 17, 3, 3, 3, 3 ],
  { 5, 11, 19, 29, 37, 67, 89, 101, 139, 149, 311, 317 }>,

// no. 698
<3*x^6 - 3*x^5 - 2*x^3 + 2*x^2 - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 8908/1633*x + 14348/1633],
  <x^3 + 1/2*x^2 + 4, x^3 - 3/2*x^2 - 1/6, 3/2*x^2 - 9/2*x>,
  [ 3, 5, 13, 7, 2, 29, 11, 17 ],
  { 5, 13, 23, 31, 37, 137, 167, 197, 199, 211, 317, 353, 577, 647, 751, 829, 
863 }>,

// no. 699
<-x^6 + 3*x^5 + 3*x^4 - x^3 - x^2 + 3, 2, [],
  [x^2 - 6/5*x + 6/5,
   x^2 - 3906/5513*x - 282/5513],
  <x^3 - 1/2*x^2 - x + 1, x^3 - 5/2*x^2 - 3*x - 3, 1/2*x^2 + x>,
  [ 2, 3, 2 ],
  { 5, 11, 17, 31, 73 }>,

// no. 700
<3*x^6 + 3*x^5 + 2*x^4 + 2*x^2 - 2, 2, [],
  [x^2 - 2/3,
   x^2 + 1752/29243*x - 18738/29243],
  <x^3 + x^2 + 3/8*x - 11/8, x^3 + 5/24*x + 9/8, 1/2*x^2 + 1/8*x - 13/8>,
  [ 2, 2, 7, 37, 11, 5, 3, 2 ],
  { 5, 13, 31, 41, 53, 61, 67, 79, 83, 89, 101, 167, 349, 509, 643, 809, 1031, 
1291, 1367 }>,

// no. 701
<-2*x^6 + x^4 + 3*x^3 + 2*x^2 + 2*x - 3, 2, [],
  [x^2 - 2/3*x + 2/3,
   x^2 + 1076/3363*x + 604/531],
  <x^3 + 5/3*x^2 + 4/3*x - 2, x^3 - 5/3*x^2 + 7/6*x - 1, 2/3*x^2 - 8/3*x + 1>,
  [ 17, 3, 3, 2, 7, 13, 5 ],
  { 5, 7, 13, 23, 31, 113, 197, 269, 283, 311, 599, 677 }>,

// no. 702
<-2*x^6 - x^5 - x^4 + x^3 - 3*x^2 + 3*x + 2, 2, [],
  [x^2 - 493/946*x - 503/1419,
   x^2 + 306/281*x + 153/281],
  <x^3 + x^2 - 1, x^3 - 1/2*x^2 + 3/2*x - 1, -x^2 + 2>,
  [ 2, 2, 7, 17, 3, 19, 5 ],
  { 3, 5, 7, 11, 13, 23, 31, 37, 47, 107, 389, 743, 853 }>,

// no. 703
<-x^6 - x^5 - 3*x^4 - 3*x^3 - 3*x^2 + 3*x + 2, 2, [],
  [x^2 + 3/2*x + 1,
   x^2 - 127/519*x + 3649/6228],
  <x^3 - x^2 + 3*x + 1, x^3 + 2*x^2 + 9/4*x + 1/4, -1/2*x^2 - 2*x - 3/2>,
  [],
  { 19 }>,

// no. 704
<3*x^6 + 2*x^5 + 2*x^4 - x^2 - 3*x + 3, 2, [],
  [x^2 - 1/2,
   x^2 + 13386/5113*x + 9141/5113],
  <x^3 + x^2 + 2*x + 1, x^3 - 1/3*x^2 - x + 2/3, -2*x + 1>,
  [],
  { 7 }>,

// no. 705
<3*x^6 - 3*x^5 - 3*x^4 - x^3 - 2*x^2 - x - 1, 2, [],
  [x^2 + x + 2/3,
   x^2 + 402/649*x + 261/649],
  <x^3 + 1/2*x^2 - 1/2*x + 1, x^3 - 3/2*x^2 - 1/2*x - 1/3, 3/2*x^2 - 3/2*x>,
  [],
  { 11 }>,

// no. 706
<3*x^6 + 2*x^4 - 2*x^3 - x^2 - 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 101327/82487*x + 338641/247461],
  <x^3 - 5*x^2 + 3*x + 2, x^3 + 5*x^2 - 32/3*x - 13/3, -10*x^2 + 10*x + 5>,
  [ 7, 5, 19 ],
  { 5, 7, 13, 19, 23, 67, 139, 331, 353 }>,

// no. 707
<-x^6 - 3*x^5 + 3*x^4 - 2*x^3 + 3*x^2 - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 16304/29825*x + 37348/29825],
  <x^3 - 3*x + 6, x^3 + 3*x^2 + 1/4*x + 1/2, 1/2*x^2 - 9/2*x>,
  [ 3 ],
  { 7, 11, 43 }>,

// no. 708
<-2*x^6 + 2*x^5 + 3*x^4 + 2*x^3 - 3*x^2 - 3*x - 3, 2, [],
  [x^2 - 3*x + 3,
   x^2 - x + 1/2],
  <x^3 - x^2 - 1, x^3 - 3/2*x - 3/2, 0>,
  [ 2, 2, 7, 3, 5 ],
  { 5, 11, 19, 41, 43, 53, 59, 67, 83, 113, 127, 137, 151, 239, 293 }>,

// no. 709
<3*x^6 + x^5 - 2*x^4 - x^3 - x^2 + x - 3, 2, [],
  [x^2 + x + 1,
   x^2 + 7406/4261*x + 18201/4261],
  <x^3 + 3/2*x^2 - 3/2*x + 2, x^3 - 7/6*x^2 + 1/2*x - 2/3, 5/2*x^2 - 5/2*x + 1>,
  [],
  { 5 }>,

// no. 710
<3*x^6 - 3*x^5 + 2*x^4 + 3*x^3 - x^2 + 2*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 2526998/1627523*x + 6464317/4882569],
  <x^3 + 2*x^2 + 4*x + 4, x^3 - 3*x^2 + 4/3*x - 1/3, -2*x^2 - 5*x + 1>,
  [ 2, 11, 5, 3, 13, 7 ],
  { 5, 17, 19, 43, 127, 137, 149, 193, 251, 257, 431, 569, 727, 827 }>,

// no. 711
<-3*x^6 - 3*x^5 - 2*x^4 - 3*x^3 + 3*x^2 - x - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 71/52*x + 313/364],
  <x^3 + x^2 + x + 2, x^3 + 1/3, x^2 + 2*x>,
  [ 7, 5, 2, 17, 13, 3, 19 ],
  { 5, 7, 11, 17, 19, 23, 29, 59, 71, 97, 131, 269, 479 }>,

// no. 712
<-x^6 + x^5 + 3*x^4 + 3*x^3 + 3*x - 1, 2, [],
  [x^2 - 3*x + 1,
   x^2 - 327/685*x + 1153/685],
  <x^3 + x^2 - 1, x^3 - 2*x^2 + 3*x - 1, 2*x^2 + x>,
  [ 3, 37 ],
  { 5, 13, 17, 23, 41 }>,

// no. 713
<-2*x^6 + x^5 - 3*x^4 - 2*x^3 + 3*x^2 - 3*x + 3, 2, [],
  [x^2 + 1,
   x^2 - 5/2*x + 13/8],
  <x^3 + 1/3*x^2 + x + 2, x^3 - 5/6*x^2 + x - 1/2, 2/3*x^2 + 1>,
  [],
  { 43 }>,

// no. 714
<3*x^6 - 2*x^5 - 2*x^4 - 2*x^3 - x^2 - x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 216511795/276051597*x + 195105289/276051597],
  <x^3 + x^2 - 37/2*x - 39/2, x^3 - 5/3*x^2 - 11/6*x + 19/6, 8*x^2 - 5/2*x - 
27/2>,
  [ 2, 2, 2, 2, 5 ],
  { 3, 5, 11, 71, 907 }>,

// no. 715
<-2*x^6 + x^5 + 2*x^4 + 3*x^3 - x^2 - x - 3, 2, [],
  [x^2 - 1/2*x + 2,
   x^2 + 21/22*x + 49/88],
  <x^3 - 1/2*x^2 + 1/2*x - 2, x^3 - x - 1, -x^2 + x + 1>,
  [ 2, 2, 3, 2, 11, 5, 13, 19 ],
  { 3, 7, 31, 37, 53, 59, 73, 101, 127, 179, 719, 883 }>,

// no. 716
<-2*x^6 + 2*x^5 + x^3 + x^2 + 3*x - 3, 2, [],
  [x^2 - 1/11*x + 7/11,
   x^2 - 18/7771*x + 28009/23313],
  <x^3 + 1/3*x^2 + 5*x - 7, x^3 - 4/3*x^2 + x - 1/2, 10/3*x^2 - 4*x + 2>,
  [ 2, 3, 23, 5 ],
  { 11, 31, 41, 107, 157, 197 }>,

// no. 717
<-2*x^6 + 2*x^5 + 3*x^3 - 3*x + 2, 2, [],
  [x^2 - 1/3,
   x^2 - 248/177*x + 112/177],
  <x^3 - 8/9*x^2 - 7/9*x - 1/9, x^3 - 1/9*x^2 + 7/9*x - 7/18, -4/9*x^2 - 8/9*x +
13/9>,
  [ 2, 2, 3, 5, 2, 17, 13, 37 ],
  { 5, 11, 13, 19, 59, 97, 103, 151, 181, 199, 257, 283, 359, 383, 431, 569, 
607, 613, 709, 971 }>,

// no. 718
<-2*x^6 - x^5 + 3*x^4 - 2*x^3 - x^2 + 2, 2, [],
  [x^2 - 2/3,
   x^2 + 122/89*x - 31/89],
  <x^3 + 5/2*x^2 + 2*x + 1, x^3 - 2*x^2 + 2*x + 1, x^2 + 2*x + 2>,
  [ 2 ],
  { 5, 13 }>,

// no. 719
<-2*x^6 + 2*x^5 + 2*x^4 - 2*x^3 - 3*x + 2, 2, [],
  [x^2 + x - 1/3,
   x^2 - 48/737*x - 196/737],
  <x^3 - x^2 - x + 2, x^3 + 1/2*x - 1/2, x^2>,
  [ 3, 3, 3, 13, 7, 2 ],
  { 7, 29, 59, 71, 89, 103, 127, 263, 347, 1279 }>,

// no. 720
<3*x^6 + x^5 + x^4 - 2*x^3 + 3*x^2 + 2*x - 3, 2, [],
  [x^2 - x + 1,
   x^2 + 172460029/190746611*x - 393371629/190746611],
  <x^3 + 2*x^2 - 70*x - 97, x^3 - 5/3*x^2 - 4/3*x + 7/3, 15*x^2 - 2*x - 26>,
  [],
  { 239 }>,

// no. 721
<-3*x^6 - 3*x^5 - 2*x^4 + x^3 + x^2 - x + 3, 2, [],
  [x^2 + 1/4*x - 1/4,
   x^2 - 761291/1462012*x + 2462231/1462012],
  <x^3 + x^2 - 1/4*x - 1/2, x^3 + x - 2/3, -1/2*x^2 - 1/2*x + 2>,
  [ 2, 3, 29, 5, 7, 11 ],
  { 5, 7, 13, 31, 37, 47, 53, 73, 101, 139, 149, 167, 179, 599, 617, 1301 }>,

// no. 722
<3*x^6 + 2*x^5 + 3*x^4 - x^3 + 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 7*x + 7,
   x^2 + 1716/599*x - 4989/2396],
  <x^3 + 3*x^2 + x + 1, x^3 - 7/3*x^2 - 5*x - 4, 6*x^2 + 5*x + 3>,
  [ 2, 5, 3, 7, 19, 37, 2 ],
  { 5, 7, 13, 17, 23, 41, 47, 59, 151, 157, 181, 269, 283, 467, 487 }>,

// no. 723
<-x^6 - 3*x^5 - 3*x^4 + 3*x^3 + x^2 - 2*x + 3, 2, [],
  [x^2 + 1,
   x^2 + 2629/6161*x - 16319/24644],
  <x^3 - x^2 + 1, x^3 + 4*x^2 + 8*x - 2, -x^2 + 3*x + 1>,
  [ 2, 2, 2, 3, 3, 5, 7, 17 ],
  { 3, 5, 13, 17, 29, 47, 53, 59, 97, 109, 197, 257, 641, 701, 853, 859, 919 }>,

// no. 724
<-2*x^6 + 3*x^5 + 3*x^4 - x^3 - 2*x - 2, 2, [],
  [x^2 + 2/3,
   x^2 - 4120/5547*x + 326/1849],
  <x^3 - 3/2*x - 3/4, x^3 - 3/2*x^2 + 2*x - 2, -2*x^2 + 1/2*x + 1>,
  [ 2, 3, 13, 2, 7, 23 ],
  { 3, 5, 11, 37, 41, 43, 47, 89, 109, 197, 373, 383, 491 }>,

// no. 725
<3*x^6 + 2*x^5 - 3*x^4 - 3*x^2 - 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 275209/972717*x + 24161/972717],
  <x^3 - 7/4*x + 5/2, x^3 + 2/3*x^2 - 4/3*x - 4/3, -5/2*x^2 + 3>,
  [],
  { 11 }>,

// no. 726
<3*x^6 + 3*x^5 - 2*x^4 + 3*x^3 + 3*x^2 + x - 3, 2, [],
  [x^2 + 10*x - 7,
   x^2 - 32304/35113*x + 23472/35113],
  <x^3 - 7/4*x + 7/4, x^3 + x^2 + 1/3*x - 1, 3/2*x^2 + 2*x - 3/2>,
  [ 3, 7, 13, 2, 5 ],
  { 5, 7, 13, 17, 47, 67, 71, 79, 97, 227, 673 }>,

// no. 727
<-3*x^6 + 3*x^5 + x^4 + 3*x^3 + x - 2, 2, [],
  [x^2 - x + 1,
   x^2 - 549/421*x + 201/421],
  <x^3 - 1/3, x^3 - x^2 + x - 2, -2*x^2 + x>,
  [ 5, 7, 19, 3, 2, 29, 11 ],
  { 5, 7, 11, 17, 23, 67, 89, 109, 211, 227, 239, 269, 463, 509, 521, 859, 887 
}>,

// no. 728
<-3*x^6 - 3*x^5 + 3*x^4 - 2*x^3 - 3*x^2 + x + 2, 2, [],
  [x^2 + x - 1,
   x^2 + 2120/3511*x - 10532/10533],
  <x^3 + 2/7*x^2 + x + 2, x^3 + 5/7*x^2 - 1/3, 18/7*x^2 + x>,
  [ 2, 7, 3, 5, 19 ],
  { 11, 31, 37, 43, 53, 73, 149, 227, 263, 787 }>,

// no. 729
<-3*x^6 + 3*x^5 - 3*x^4 + 3*x^3 - x^2 + x + 3, 2, [],
  [x^2 - x + 1,
   x^2 - 53/133*x - 911/2793],
  <x^3 - 2*x^2 + 3*x + 1, x^3 + x^2 + 4/3*x + 1/3, 2*x^2 + 2*x + 2>,
  [],
  { 11 }>,

// no. 730
<-2*x^6 - 3*x^5 + 2*x^4 + 2*x^3 - x^2 - 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 5788/4307*x + 10180/12921],
  <x^3 + 2*x^2 + 5*x + 2, x^3 - 1/2*x^2 - 1/2*x + 1/2, -3*x^2 + 1>,
  [ 2, 2, 2, 3, 7, 41, 17, 11, 13, 31 ],
  { 7, 11, 17, 31, 37, 41, 59, 71, 79, 137, 167, 199, 211, 233, 293, 313, 397, 
467, 653, 659, 1129, 1231, 1787 }>,

// no. 731
<3*x^6 + x^5 + x^4 - 3*x^2 - x - 2, 2, [],
  [x^2 + 1,
   x^2 + 45076/91299*x + 163859/243464],
  <x^3 - 7/6*x^2 - 2/3, x^3 + 3/2*x^2 + 3/2, 5/2*x^2 - 1/2*x + 1>,
  [ 2, 5, 3, 2, 11, 7, 19 ],
  { 7, 23, 43, 71, 89, 359, 379, 523, 541, 571, 811 }>,

// no. 732
<-x^6 + 3*x^5 - 2*x^4 + 3*x^3 - 3*x^2 - 2*x - 3, 2, [],
  [x^2 - 2*x + 4,
   x^2 - 16/5*x + 76/25],
  <x^3 - 2*x^2 + x - 3, x^3 - x^2 - x - 1, x>,
  [ 5, 5, 2, 3, 3, 13, 7, 2, 19 ],
  { 3, 5, 7, 17, 23, 67, 89, 137, 331, 523, 661, 751, 2579, 2609, 3793 }>,

// no. 733
<3*x^6 - 2*x^5 + x^4 - 3*x - 3, 2, [],
  [x^2 + 1/3*x + 4/3,
   x^2 + 479183/1507861*x - 5672428/1507861],
  <x^3 + 2*x^2 + 9/4*x + 1, x^3 - 8/3*x^2 + 8/3*x - 4/3, -3/2*x^2 - x + 1>,
  [ 2, 3, 7, 5, 19, 3, 11 ],
  { 7, 11, 13, 23, 31, 73, 131, 223, 1409, 1451, 1697 }>,

// no. 734
<-x^6 + 3*x^5 + x^3 + x^2 + 3, 2, [],
  [x^2 - 2*x - 2,
   x^2 + 2586/3425*x - 354/3425],
  <x^3 + x + 1, x^3 - 3*x^2 + 3*x - 3, -2*x^2 + x>,
  [],
  { 19 }>,

// no. 735
<2*x^6 + x^5 - x^4 + 2*x^3 + 2*x^2 + 3*x - 3, 2, [],
  [x^2 + x - 1,
   x^2 + 244313521/211335481*x - 352524793/211335481],
  <x^3 + 1/2*x^2 - 18*x + 21/2, x^3 - 1/2*x - 1/4, 6*x^2 - 3/2*x - 3/2>,
  [ 2, 2, 2, 2, 3, 5, 31, 19 ],
  { 5, 11, 29, 43, 83, 113, 127, 157, 349, 359, 431, 593 }>,

// no. 736
<-3*x^6 - x^5 + x^4 - x^3 + 2*x^2 + 3*x - 2, 2, [],
  [x^2 - 1/4*x + 1/2,
   x^2 - 701/380*x + 1201/950],
  <x^3 + 5/4*x^2 - 1, x^3 - 11/12*x^2 + x - 2/3, 3/4*x^2 - 3/2*x>,
  [ 2, 3, 3, 13, 7, 31, 17 ],
  { 3, 5, 7, 13, 23, 29, 47, 61, 89, 109, 139, 211, 233, 373, 383, 401 }>,

// no. 737
<2*x^6 - x^5 - 3*x^4 - x^3 + x^2 + x - 3, 2, [],
  [x^2 - 9/46*x + 14/23,
   x^2 + 71/46*x + 26/23],
  <x^3 + 1/7*x^2 - 2/7*x + 1, x^3 - 9/14*x^2 - 17/14*x - 2, 3/7*x^2 + 8/7*x + 
1>,
  [ 2, 3, 7, 17, 19, 13, 2, 2, 11, 23 ],
  { 3, 5, 11, 13, 17, 19, 29, 41, 47, 53, 59, 71, 103, 107, 131, 199, 277, 293, 
353, 409, 499 }>,

// no. 738
<-3*x^6 - x^5 - x^4 + x^3 - 2*x^2 - 3*x + 2, 2, [],
  [x^2 + 3/7*x + 1/7,
   x^2 + 11511/7519*x + 14697/7519],
  <x^3 - 1/4*x^2 + 1, x^3 + 7/12*x^2 + x - 2/3, -5/4*x^2 - 1/2*x>,
  [ 3, 2, 19, 2, 2, 3, 17 ],
  { 3, 5, 11, 17, 23, 43, 59, 103, 131, 149, 181, 227, 1669 }>,

// no. 739
<3*x^6 + x^4 + x^3 + 2*x^2 - 2*x - 2, 2, [],
  [x^2 + x + 1,
   x^2 - 84/359*x - 204/359],
  <x^3 + 2*x^2 - 2*x + 1, x^3 - 2*x^2 - 2*x - 2/3, 5*x^2>,
  [ 5, 3, 7, 2, 13, 2 ],
  { 7, 17, 19, 31, 41, 53, 73, 101, 193, 317, 691 }>,

// no. 740
<3*x^6 - 3*x^5 - 2*x^4 + 2*x^3 - 3*x^2 - 2, 2, [],
  [x^2 + 2,
   x^2 + 15474/2521*x + 14409/2521],
  <x^3 + 2*x^2 - x + 1, x^3 - 3*x^2 + 10/3*x - 2, 3*x^2 - 4*x + 2>,
  [ 2, 13, 7, 5, 5 ],
  { 7, 11, 19, 29, 101, 163, 263, 337, 937 }>,

// no. 741
<3*x^6 - 3*x^5 - x^3 + 2*x^2 - x - 3, 2, [ 2 ],
  [x^2 - x + 1,
   x^2 - 370*x - 925/3],
  <x^3 - 5/2*x^2 + 3/2*x - 2, x^3 + 3/2*x^2 + 3/2*x + 2/3, 3/2*x^2 + 5/2*x + 1>,
  [ 2, 3, 13 ],
  { 5, 11, 13, 109, 181, 823 }>,

// no. 742
<-3*x^6 - 2*x^5 - x^4 + x^3 + x^2 + 3*x - 2, 2, [],
  [x^2 + 1,
   x^2 + 22/13*x + 17/13],
  <x^3 + 9*x - 6, x^3 + 2/3*x^2 - 1/3*x - 1/3, -5*x^2 + 2>,
  [ 2, 2, 2, 3, 3, 3, 7, 5, 41, 5, 37, 11, 11 ],
  { 5, 13, 17, 19, 43, 61, 83, 89, 113, 191, 193, 199, 269, 293, 317, 383, 461, 
569, 601, 647, 661, 823, 967, 1223, 1361, 1559, 1747 }>,

// no. 743
<3*x^6 + 3*x^5 - x^4 - x^3 - x^2 + x - 2, 2, [],
  [x^2 - 1/2*x + 1/2,
   x^2 + 287546901/231981958*x + 632862401/695945874],
  <x^3 - 1/6*x^2 - 8/9*x - 3/2, x^3 + 7/6*x^2 + 14/27*x + 4/3, 5/6*x^2 + 31/18*x
+ 2>,
  [ 2, 2, 5, 7, 3, 5, 11, 2, 37, 31, 47 ],
  { 5, 7, 11, 13, 19, 23, 73, 97, 101, 107, 137, 211, 233, 331, 353, 457, 487, 
661, 911, 1153, 1163, 1223, 1229 }>,

// no. 744
<3*x^6 - x^5 + 3*x^4 + 2*x^2 + x + 2, 2, [ 2 ],
  [x^2 + 1/2*x + 1,
   x^2 - 9/22*x + 31/11],
  <x^3 - 10/3*x^2 + x - 2/3, x^3 + 3*x^2 - 2*x - 1, -6*x^2 + 2*x>,
  [ 2, 3, 7 ],
  { 3, 7, 13, 17, 73, 131, 151 }>,

// no. 745
<3*x^6 + x^5 - 2*x^3 + x^2 + 2*x + 2, 2, [],
  [x^2 + x + 1,
   x^2 - 262865/4045323*x - 3602809/4045323],
  <x^3 + x^2 - 4, x^3 - 2/3*x^2 - 17/12*x + 7/12, -5/2*x^2 - 5/2*x + 3>,
  [ 3, 2, 2, 37, 19, 5, 7 ],
  { 5, 17, 37, 41, 79, 103, 131, 137, 149, 163, 197, 283, 461, 463, 491 }>,

// no. 746
<3*x^6 + x^5 - 3*x^4 - 2*x^3 + 2*x^2 + 2, 2, [],
  [x^2 - 2,
   x^2 - 98/73*x + 49/73],
  <x^3 + 7/3*x^2 + 2/3*x - 1/3, x^3 - 2*x^2 - 1, 3*x^2 + x + 1>,
  [ 2 ],
  { 5, 131 }>,

// no. 747
<3*x^6 - x^5 - 2*x^4 + x^3 - 2*x^2 - 2, 2, [],
  [x^2 + 2/3*x + 2/3,
   x^2 - 18/37*x + 57/37],
  <x^3 - x + 1, x^3 - 1/3*x^2 - x - 1, -2*x^2 + 1>,
  [ 3, 2, 19, 17, 2 ],
  { 3, 5, 19, 29, 71, 103, 131, 137, 167, 179, 317 }>,

// no. 748
<-3*x^6 + 2*x^5 - 3*x^4 - x^3 - 3*x^2 - 3*x + 2, 2, [],
  [x^2 - 1/19,
   x^2 - 208/1147*x + 607/1147],
  <x^3 - 2*x^2 + 11/4*x + 1/2, x^3 + 4/3*x^2 + x - 2/3, -1/2*x^2 - 7/2*x + 1>,
  [ 2, 2, 2, 2, 5, 3, 7 ],
  { 3, 11, 19, 37, 79, 107, 113, 139, 233, 293 }>,

// no. 749
<3*x^6 + 3*x^5 + 3*x^4 - x^3 + 2, 2, [],
  [x^2 + x + 1,
   x^2 + 198/83*x + 217/249],
  <x^3 + x^2 + 3*x + 1, x^3 - 2*x + 2/3, 4*x>,
  [ 2, 2, 7, 3, 5 ],
  { 7, 11, 13, 29, 31, 67 }>,

// no. 750
<-2*x^6 - x^5 + 2*x^3 - 3*x^2 - 2*x + 2, 2, [],
  [x^2 - x + 1,
   x^2 - 41630971/31114907*x + 44657329/93344721],
  <x^3 + 10/3*x^2 + 6*x + 3, x^3 - 17/6*x^2 + 11/3*x + 17/3, 2/3*x^2 + 22/3*x + 
6>,
  [],
  { 13 }>,

// no. 751
<2*x^6 + 2*x^5 - 3*x^3 - 2*x^2 + 3*x - 3, 2, [],
  [x^2 - 7/2,
   x^2 + 830/217*x + 733/217],
  <x^3 + 3/7*x^2 - 4/7*x + 1, x^3 + 4/7*x^2 + 1/14*x - 2, -5/7*x^2 + 2/7*x + 1>,
  [ 3, 3, 13, 5, 11 ],
  { 5, 11, 17, 29, 43, 73, 193, 197 }>,

// no. 752
<-3*x^6 + 3*x^5 + 2*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 - 278/133*x + 67/57,
   x^2 - 149266/149359*x + 110353/149359],
  <x^3 - 4*x^2 + 11*x - 7, x^3 + 3*x^2 + 7/3*x - 4, 2*x^2 + 10*x - 9>,
  [ 17, 5, 2, 3, 7, 13, 43 ],
  { 5, 11, 13, 17, 23, 31, 37, 43, 47, 67, 103, 281, 569, 587, 757, 1609 }>,

// no. 753
<2*x^6 + x^5 + x^4 + 3*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 + x + 1,
   x^2 - 4507/3881*x + 6289/3881],
  <x^3 + 2*x^2 - 2*x + 1, x^3 - 3/2*x^2 - 5/2*x - 3/2, 4*x^2 + x>,
  [ 7, 5, 3, 3, 13, 2, 41 ],
  { 3, 5, 17, 47, 71, 73, 103, 107, 109, 151, 157, 179, 241, 503, 1213, 1523 }>,

// no. 754
<-2*x^6 + 2*x^5 + x^4 + 2*x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 + 5/3*x + 1,
   x^2 - 7474428235/1257597587*x + 24142563199/1257597587],
  <x^3 + 3/7*x^2 + 298/147*x - 19/7, x^3 - 10/7*x^2 + 205/294*x - 13/14, 
16/7*x^2 - 337/147*x + 10/7>,
  [ 2, 2, 3, 3, 3, 7, 2, 3, 19, 5, 17 ],
  { 13, 29, 43, 107, 167, 181, 211, 257, 269, 367, 439, 547, 761, 811, 1093, 
1423 }>,

// no. 755
<-3*x^6 - x^5 - x^4 - x^3 - 3*x^2 + 3, 2, [],
  [x^2 + x + 1,
   x^2 + 13061400840/10980369379*x + 64887349956/76862585653],
  <x^3 - 10/7*x^2 + 248/49*x + 166/49, x^3 + 37/21*x^2 + 251/147*x + 73/147, 
24/7*x^2 + 215/49*x + 139/49>,
  [ 3, 2, 2, 2, 2, 47, 13, 5, 19 ],
  { 5, 11, 19, 23, 37, 43, 47, 61, 89, 167, 431, 593, 1229, 1381, 1607 }>,

// no. 756
<3*x^6 + 2*x^5 - 2*x^3 - 3*x^2 - x - 3, 2, [],
  [x^2 + x + 3,
   x^2 + 8996163827/12485775731*x - 27532090227/12485775731],
  <x^3 + 14/3*x^2 + 229/36*x + 31/9, x^3 - 4*x^2 - 88/27*x - 52/27, -41/6*x^2 - 
76/9*x - 37/9>,
  [ 2, 2, 2, 3, 7, 11, 13, 19, 47 ],
  { 13, 29, 31, 73, 101, 103, 113, 151, 157, 199, 223, 307, 353, 983, 1093, 
1277, 1607 }>,

// no. 757
<-2*x^6 + 3*x^5 + 2*x^4 + 3*x^2 - x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 2731927996/3718552801*x + 5435347996/3718552801],
  <x^3 - 11/6*x^2 + 10/9*x - 61/18, x^3 + 1/3*x^2 - 143/162*x - 193/324, 
10/9*x^2 - 97/54*x - 55/54>,
  [],
  { 7 }>,

// no. 758
<-3*x^6 + 3*x^5 + 3*x^4 - 2*x^3 + 3*x^2 + 3*x - 1, 2, [],
  [x^2 + x + 1,
   x^2 - 7869667/2454277*x + 8322913/2454277],
  <x^3 - 43/20*x^2 + 61/50*x - 13/20, x^3 + 23/20*x^2 + 269/150*x - 37/60, 
-43/20*x^2 + 153/50*x - 9/20>,
  [ 2, 2, 3, 3, 2, 2, 2 ],
  { 41, 73, 79, 97, 131, 149, 227, 239 }>,

// no. 759
<-2*x^6 + 3*x^5 - 3*x^4 - 3*x^3 - 2*x^2 - 3*x + 3, 2, [],
  [x^2 + 3/2*x + 3,
   x^2 - 2760687131/1982041986*x + 3889832567/2973062979],
  <x^3 - 29/15*x^2 + 112/75*x + 71/75, x^3 + 13/30*x^2 + 61/50*x + 39/25, 
13/15*x^2 - 61/75*x - 61/25>,
  [],
  { 11 }>,

// no. 760
<3*x^6 - 3*x^5 + 3*x^4 + 2*x^3 - 3*x^2 + 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 824188943488116/889295129728549*x + 521194060342333/889295129728549],
  <x^3 + 3/2*x^2 - 97/2, x^3 - 5/2*x^2 - 29/4*x + 361/24, 6*x^2 + 45/4*x - 
187/4>,
  [ 3, 7, 2 ],
  { 5, 29, 149, 181, 233 }>,

// no. 761
<3*x^6 + 2*x^5 - 2*x^4 - 2*x^3 - 3*x^2 + x - 1, 2, [],
  [x^2 + x + 1,
   x^2 + 1075556903/1447127319*x + 2287592521/4341381957],
  <x^3 + 19/9*x^2 - 77/81*x + 74/81, x^3 - 13/9*x^2 + 134/243*x - 365/243, 
-26/9*x^2 + 110/81*x - 143/81>,
  [ 3, 3, 2, 2, 31, 7, 47 ],
  { 5, 7, 29, 41, 59, 97, 101, 139, 251, 307, 373, 761, 1889 }>,

// no. 762
<3*x^6 + x^5 - x^4 + 2*x^3 + x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 27050518/228768951*x + 241253629/686306853],
  <x^3 - 5*x^2 - 11*x - 12, x^3 + 16/3*x^2 + 167/27*x + 31/9, 29/3*x^2 + 46/3*x 
+ 11>,
  [],
  { 7 }>,

// no. 763
<3*x^6 + 3*x^5 + 3*x^4 + 2*x^3 + 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 13950042738/1630618571*x - 26398904113/1630618571],
  <x^3 - 20*x^2 + 33*x + 84, x^3 + 21*x^2 - 280/3*x - 481/3, 38*x^2 - 98*x - 
201>,
  [ 7, 5, 11, 3, 5, 3, 19 ],
  { 5, 7, 11, 19, 43, 59, 67, 73, 173, 293, 367, 409, 509, 631, 1187, 1669 }>,

// no. 764
<-2*x^6 + 2*x^5 + 2*x^4 + 3*x^3 + x^2 + 3*x - 3, 2, [],
  [x^2 + 1,
   x^2 - 208205881056/180573700609*x + 126978493717/180573700609],
  <x^3 + 1/2*x^2 - 5/16*x - 1/4, x^3 - 3/2*x^2 + 531/32*x - 129/8, 23/4*x^2 - 
17/16*x - 9/4>,
  [ 2, 2, 2, 3, 2, 3, 5, 13, 23 ],
  { 7, 11, 17, 37, 43, 47, 53, 79, 109, 157, 167, 307, 557, 1181, 1559 }>,

// no. 765
<-3*x^6 - 3*x^5 + 2*x^4 - 3*x^3 - x^2 - 3*x + 3, 2, [],
  [x^2 + 1/4*x - 1/2,
   x^2 + 21522893875/11983834924*x + 20017022387/17975752386],
  <x^3 + 17/4*x^2 + 13/2*x - 11/4, x^3 - 13/4*x^2 + 359/54*x - 299/108, 1/12*x^2
+ 11*x - 61/12>,
  [ 3, 11, 5 ],
  { 7, 11, 13, 23, 61, 71, 257, 311 }>,

// no. 766
<3*x^6 + x^5 + x^4 + x - 3, 2, [],
  [x^2 - x + 3,
   x^2 + 35780706/17086429*x + 27234981/17086429],
  <x^3 + 43/33*x^2 - 415/99*x + 364/99, x^3 - 32/33*x^2 + 13/297*x - 91/297, 
-137/33*x^2 + 268/99*x - 61/99>,
  [ 2, 5, 7, 3, 29, 13, 3, 3, 17, 11 ],
  { 5, 13, 17, 19, 37, 79, 103, 149, 191, 281, 349, 479, 701, 1061, 1451, 1979 
}>,

// no. 767
<2*x^6 - 3*x^5 - x^3 - x^2 - x - 3, 2, [],
  [x^2 + 3*x + 4,
   x^2 + 400703920675/111884653289*x + 280244796988/111884653289],
  <x^3 - x^2 - 337/196*x - 57/28, x^3 - 1/2*x^2 - 3/8*x + 7/8, -25/14*x^2 + 
9/28*x + 3/4>,
  [ 2, 5 ],
  { 3, 13, 79 }>,

// no. 768
<-2*x^6 - 3*x^5 + 3*x^4 + 2*x^2 + x - 3, 2, [],
  [x^2 + 1,
   x^2 - 2011442508770426104/21056625099087095409*x + 
1982251510372485193/21056625099087095409],
  <x^3 - 23/66*x^2 - 26/33*x + 14/33, x^3 + 61/33*x^2 + 581/66*x + 1729/132, 
-139/33*x^2 - 47/22*x + 94/33>,
  [ 3, 3, 11, 2, 17, 29, 5, 2, 5, 19, 23, 7, 13 ],
  { 5, 7, 13, 19, 29, 31, 53, 59, 61, 67, 107, 113, 127, 137, 167, 173, 193, 
269, 313, 359, 373, 389, 593, 709, 911, 983 }>,

// no. 769
<-3*x^6 + 3*x^5 + x^4 + x^3 + 2*x^2 + x - 3, 2, [],
  [x^2 - 1/4*x + 1,
   x^2 - 5795330878889726/31082218511628073*x + 
39510088586385949/31082218511628073],
  <x^3 - 245/156*x^2 + 49291/18252*x - 5653/1521, x^3 + 89/156*x^2 - 4205/6084*x
- 307/507, 25/12*x^2 - 5969/6084*x - 982/507>,
  [ 2, 2, 3, 11, 3, 13, 3, 2, 29, 23, 5 ],
  { 5, 7, 11, 17, 37, 53, 59, 61, 137, 139, 151, 163, 199, 211, 541, 1033, 1493,
1789 }>,

// no. 770
<3*x^6 - 3*x^5 - 2*x^4 - 2*x^3 - x^2 - x - 3, 2, [],
  [x^2 - x + 1,
   x^2 - 1520826127564/3209876453199*x - 68181833645548/28888888078791],
  <x^3 + 19/17*x^2 + 45/1156*x + 283/289, x^3 - 36/17*x^2 + 1168/867*x - 
1108/867, 33/34*x^2 - 800/289*x + 251/289>,
  [ 2, 2, 3, 3, 23, 3 ],
  { 7, 29, 47, 53, 59, 89, 137, 167, 277, 347, 977 }>,

// no. 771
<-2*x^6 + 2*x^5 + 3*x^4 - 3*x^3 + 3*x^2 - x - 3, 2, [],
  [x^2 - 1/3*x - 1,
   x^2 - 342053/616547*x - 752179/616547],
  <x^3 - 2/3*x^2 + 16/3*x + 31/6, x^3 - 1/3*x^2 - 1/3*x + 1/3, -11/3*x^2 - 2/3*x
+ 2/3>,
  [ 2, 3, 7, 5, 17, 3 ],
  { 5, 7, 17, 31, 79, 83, 131, 173, 199, 227, 239, 317, 409, 449, 601, 839, 997 
}>,

// no. 772
<-2*x^6 - 3*x^5 + x^4 - 3*x^3 + 3*x^2 + 3*x - 2, 2, [],
  [x^2 + x - 1,
   x^2 - 38/41*x + 9/41],
  <x^3 - 5/6*x^2 + 3/2*x - 1, x^3 + 7/3*x^2 - 1, -1/3*x^2>,
  [ 2, 17, 7, 2, 23, 3, 2, 3, 29 ],
  { 7, 13, 19, 31, 47, 83, 263, 353, 421, 557, 761, 881, 1021, 1181, 1193 }>
];
